# We have to override the new %%install behavior because, well... the kernel is special.
%global __spec_install_pre %{___build_pre}

Summary: The Linux kernel

# % define buildid .local

# For a kernel released for public testing, released_kernel should be 1.
# For internal testing builds during development, it should be 0.
%global released_kernel 1

%define rpmversion 3.10.0
%define pkgrelease 229.11.1.el7

# allow pkg_release to have configurable %{?dist} tag
%define specrelease 229.11.1%{?dist}

%define pkg_release %{specrelease}%{?buildid}

# The kernel tarball/base version
%define rheltarball %{rpmversion}-%{pkgrelease}

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# kernel
%define with_default   %{?_without_default:   0} %{?!_without_default:   1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-kdump (only for s390x)
%define with_kdump     %{?_without_kdump:     0} %{?!_without_kdump:     0}
# kernel-bootwrapper (for creating zImages from kernel + initrd)
%define with_bootwrapper %{?_without_bootwrapper: 0} %{?!_without_bootwrapper: 0}
# kernel-abi-whitelists
%define with_kernel_abi_whitelists %{?_with_kernel_abi_whitelists: 0} %{?!_with_kernel_abi_whitelists: 1}

# In RHEL, we always want the doc build failing to build to be a failure,
# which means settings this to false.
%define doc_build_fail false

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}

# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}

# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}

# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'. RHEL only ever does 1.
%define debugbuildsenabled 1

%define make_target bzImage

# Kernel Version Release + Arch -> KVRA
%define KVRA %{version}-%{release}.%{_target_cpu}
%define hdrarch %{_target_cpu}
%define asmarch %{_target_cpu}
%define cross_target %{_target_cpu}

%if !%{debugbuildsenabled}
%define with_debug 0
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_debug 0
%define with_kdump 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_default 0
%define with_kdump 0
%define with_tools 0
%define with_perf 0
%endif

# These arches install vdso/ directories.
%define vdso_arches %{all_x86} x86_64 ppc ppc64 ppc64le s390 s390x

# Overrides for generic default options

# only build kernel-debug on x86_64, s390x, ppc64 ppc64le
%ifnarch x86_64 s390x ppc64 ppc64le
%define with_debug 0
%endif

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define with_kernel_abi_whitelists 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_default 0
%define with_headers 0
%define with_tools 0
%define with_perf 0
%define all_arch_configs kernel-%{version}-*.config
%endif

# sparse blows up on ppc64
%ifarch ppc64 ppc64le ppc
%define with_sparse 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%define all_arch_configs kernel-%{version}-i?86*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs kernel-%{version}-x86_64*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc
%define asmarch powerpc
%define hdrarch powerpc
%endif

%ifarch ppc64 ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc64*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define with_bootwrapper 1
%define cross_target powerpc64
%define kcflags -O3
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x*.config
%define image_install_path boot
%define kernel_image arch/s390/boot/bzImage
%define with_tools 0
%define with_kdump 1
%endif

#cross compile make
%if %{with_cross}
%define cross_opts CROSS_COMPILE=%{cross_target}-linux-gnu-
%define with_perf 0
%define with_tools 0
%endif

# Should make listnewconfig fail if there's config options
# printed out?
%define listnewconfig_fail 1

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%define nobuildarches s390 ppc

%ifarch %nobuildarches
%define with_default 0
%define with_debuginfo 0
%define with_kdump 0
%define with_tools 0
%define with_perf 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%define cpupowerarchs i686 x86_64 ppc64
%define cpupowerarchs i686 x86_64 ppc64 ppc64le

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2, device-mapper-libs < 1.02.63-2, mdadm < 3.2.1-5

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%define kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools >= 3.16-2, initscripts >= 8.11.1-1, grubby >= 8.28-2

%ifarch ppc64le
%define initrd_prereq  dracut >= 033-241.ael7b_1.5
%else
%define initrd_prereq  dracut >= 033-241.el7_1.5
%endif

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel-drm = 4.3.0\
Provides: kernel-drm-nouveau = 16\
Provides: kernel-modeset = 1\
Provides: kernel-uname-r = %{KVRA}%{?1:.%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): linux-firmware >= 20140911\
Requires(post): %{_sbindir}/new-kernel-pkg\
Requires(preun): %{_sbindir}/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

Name: kernel%{?variant}
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch i686 x86_64 ppc ppc64 ppc64le s390 s390x
ExclusiveOS: Linux

%kernel_reqprovconf

#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: xz, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config >= 9.1.0-55
BuildRequires: hostname, net-tools, bc
BuildRequires: xmlto, asciidoc
BuildRequires: openssl
BuildRequires: hmaccalc
BuildRequires: python-devel, newt-devel, perl(ExtUtils::Embed)
%ifarch x86_64
BuildRequires: pesign >= 0.109-4
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%if %{with_perf}
BuildRequires: elfutils-devel zlib-devel binutils-devel bison
BuildRequires: audit-libs-devel
%ifnarch s390 s390x
BuildRequires: numactl-devel
%endif
%endif
%if %{with_tools}
BuildRequires: pciutils-devel gettext ncurses-devel
%endif
%if %{with_debuginfo}
# Fancy new debuginfo generation introduced in Fedora 8/RHEL 6.
# The -r flag to find-debuginfo.sh invokes eu-strip --reloc-debug-sections
# which reduces the number of relocations in kernel module .ko.debug files and
# was introduced with rpm 4.9 and elfutils 0.153.
BuildRequires: rpm-build >= 4.9.0-1, elfutils >= 0.153-1
%define debuginfo_args --strict-build-id -r
%endif
%ifarch s390x
# required for zfcpdump
BuildRequires: glibc-static
%endif

Source0: linux-%{rpmversion}-%{pkgrelease}.tar.xz

Source1: Makefile.common

Source10: sign-modules
%define modsign_cmd %{SOURCE10}
Source11: x509.genkey
Source12: extra_certificates
%if %{?released_kernel}
Source13: securebootca.cer
Source14: secureboot.cer
%define pesign_name redhatsecureboot301
%else
Source13: redhatsecurebootca2.cer
Source14: redhatsecureboot003.cer
%define pesign_name redhatsecureboot003
%endif
Source15: rheldup3.x509
Source16: rhelkpatch1.x509

Source18: check-kabi

Source20: Module.kabi_x86_64
Source21: Module.kabi_ppc64
Source22: Module.kabi_ppc64le
Source23: Module.kabi_s390x

Source25: kernel-abi-whitelists.tar.bz2

Source50: kernel-%{version}-x86_64.config
Source51: kernel-%{version}-x86_64-debug.config

Source60: kernel-%{version}-ppc64.config
Source61: kernel-%{version}-ppc64-debug.config
Source62: kernel-%{version}-ppc64le.config
Source63: kernel-%{version}-ppc64le-debug.config

Source70: kernel-%{version}-s390x.config
Source71: kernel-%{version}-s390x-debug.config
Source72: kernel-%{version}-s390x-kdump.config

Source80: kernel-%{version}-i686.config
Source81: kernel-%{version}-i686-debug.config

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config

Patch10000: ignorewarnings.patch
Patch10001: removejiffies.patch
Patch10002: cpufreq.patch
Patch10003: i386-audit-stop-scri-stack-frame.patch
# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

BuildRoot: %{_tmppath}/kernel-%{KVRA}-root

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package bootwrapper
Summary: Boot wrapper files for generating combined kernel + initrd images
Group: Development/System
Requires: gzip binutils
%description bootwrapper
Kernel-bootwrapper contains the wrapper code which makes bootable "zImage"
files combining both kernel and initial ramdisk.

%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Group: Development/System
License: GPLv2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|XXX' -o perf-debuginfo.list}

%package -n python-perf
Summary: Python bindings for apps which will manipulate perf events
Group: Development/Libraries
%description -n python-perf
The python-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%package -n python-perf-debuginfo
Summary: Debug information for package perf python bindings
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{python_sitearch}/perf.so(\.debug)?|XXX' -o python-perf-debuginfo.list}


%endif # with_perf

%if %{with_tools}

%package -n kernel-tools
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:2.0
Requires: kernel-tools-libs = %{version}-%{release}
%description -n kernel-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n kernel-tools-libs
Summary: Libraries for the kernels-tools
Group: Development/System
License: GPLv2
%description -n kernel-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n kernel-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
Requires: kernel-tools = %{version}-%{release}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
Requires: kernel-tools-libs = %{version}-%{release}
Provides: kernel-tools-devel
%description -n kernel-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n kernel-tools-debuginfo
Summary: Debug information for package kernel-tools
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n kernel-tools-debuginfo
This package provides debug information for package kernel-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|XXX' -o kernel-tools-debuginfo.list}

%endif # with_tools

%package -n kernel-abi-whitelists
Summary: The Springdale Enterprise Linux kernel ABI symbol whitelists
Group: System Environment/Kernel
AutoReqProv: no
%description -n kernel-abi-whitelists
The kABI package contains information pertaining to the Springdale Enterprise
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVRA}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVRA}%{?1:\.%{1}}/.*|/.*%%{KVRA}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-devel-uname-r = %{KVRA}%{?1:.%{1}}\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
Requires: perl\
%description -n kernel%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package


# Now, each variant package.

%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%define variant_summary A minimal Linux kernel compiled for crash dumps
%kernel_variant_package kdump
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_default}
echo "Cannot build --with baseonly, default kernel build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME%%%%%{?variant}}.spec ; then
    if [ "${patch:0:8}" != "patch-3." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n kernel-%{rheltarball} -c
mv linux-%{rheltarball} linux-%{KVRA}
cd linux-%{KVRA}

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-%{version}-*.config .

%ifarch %{ix86}
ApplyPatch ignorewarnings.patch
ApplyPatch removejiffies.patch
ApplyPatch cpufreq.patch
ApplyPatch i386-audit-stop-scri-stack-frame.patch
%endif
ApplyOptionalPatch linux-kernel-test.patch

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
	mkdir configs
fi

# Remove configs not for the buildarch
for cfg in kernel-%{version}-*.config; do
  if [ `echo %{all_arch_configs} | grep -c $cfg` -eq 0 ]; then
    rm -f $cfg
  fi
done

%if !%{debugbuildsenabled}
rm -f kernel-%{version}-*debug.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make %{?cross_opts} ARCH=$Arch listnewconfig | grep -E '^CONFIG_' >.newoptions || true
%if %{listnewconfig_fail}
  if [ -s .newoptions ]; then
    cat .newoptions
    exit 1
  fi
%endif
  rm -f .newoptions
  make %{?cross_opts} ARCH=$Arch oldnoconfig
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
done
# end of kernel config
%endif

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -exec rm -f {} \; >/dev/null

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

%if %{with_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK='sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug -i $@ > $@.id"'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVRA}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{KVRA}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile

    # and now to start the build process

    make %{?cross_opts} -s mrproper

    cp %{SOURCE11} .	# x509.genkey
    cp %{SOURCE12} .	# extra_certificates
    cp %{SOURCE15} .	# rheldup3.x509
    cp %{SOURCE16} .	# rhelkpatch1.x509

    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

%ifarch s390x
    if [ "$Flavour" == "kdump" ]; then
        pushd arch/s390/boot
        gcc -static -o zfcpdump zfcpdump.c
        popd
    fi
%endif

    make -s %{?cross_opts} ARCH=$Arch oldnoconfig >/dev/null
    make -s %{?cross_opts} ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="%{?kcflags}" $MakeTarget %{?sparse_mflags}

    if [ "$Flavour" != "kdump" ]; then
        make -s %{?cross_opts} ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="%{?kcflags}" modules %{?sparse_mflags} || exit 1
    fi

    # Start installing the results
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
# EFI SecureBoot signing, x86_64-only
%ifarch x86_64
    %pesign -s -i $KernelImage -o $KernelImage.signed -a %{SOURCE13} -c %{SOURCE14} -n %{pesign_name}
    mv $KernelImage.signed $KernelImage
%endif
    $CopyKernel $KernelImage $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel
    if [ "$Flavour" != "kdump" ]; then
        # Override $(mod-fw) because we don't want it to install any firmware
        # we'll get it from the linux-firmware package and we don't want conflicts
        make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi
%ifarch %{vdso_arches}
    make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc64 ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    if test -s vmlinux.id; then
      cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id
    else
      echo >&2 "*** ERROR *** no vmlinux build ID! ***"
      exit 1
    fi

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking 'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt2x00(pci|usb)_probe|register_netdevice'
    collect_modules_list block 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm 'drm_open|drm_init'
    collect_modules_list modesetting 'drm_crtc_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' modinfo && exit 1

    rm -f modinfo modnames

    # Save off the .tmp_versions/ directory.  We'll use it in the
    # __debug_install_post macro below to sign the right things
    # Also save the signing keys so we actually sign the modules with the
    # right key.
    cp -r .tmp_versions .tmp_versions.sign${Flavour:+.${Flavour}}
    cp signing_key.priv signing_key.priv.sign${Flavour:+.${Flavour}}
    cp signing_key.x509 signing_key.x509.sign${Flavour:+.${Flavour}}

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias alias.bin builtin.bin ccwmap dep dep.bin ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols symbols.bin usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -exec rm -f {} \;
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVRA}

%if %{with_default}
BuildKernel %make_target %kernel_image
%endif

%if %{with_debug}
BuildKernel %make_target %kernel_image debug
%endif

%if %{with_kdump}
BuildKernel %make_target %kernel_image kdump
%endif

%global perf_make make %{?_smp_mflags} -C tools/perf -s V=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 prefix=%{_prefix} lib=%{_lib}
%if %{with_perf}
# perf
%{perf_make} all
%{perf_make} man || %{doc_build_fail}
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
make %{?cross_opts} %{?_smp_mflags} -C tools/power/cpupower CPUFREQ_BENCH=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    make %{?_smp_mflags} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64 i686
   pushd tools/power/x86/x86_energy_perf_policy/
   make
   popd
   pushd tools/power/x86/turbostat
   make
   popd
%endif #turbostat/x86_energy_perf_policy
%endif
pushd tools
make tmon
popd
%endif

%if %{with_doc}
# Make the HTML and man pages.
make htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "flavour" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that flavour.  3) We
# grab the arch and invoke 'make modules_sign' and the mod-extra-sign.sh
# commands to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Finally, pick a module at random and check that it's signed and fail the build
# if it isn't.

%define __modsign_install_post \
  if [ "%{with_debug}" -ne "0" ]; then \
    Arch=`head -1 configs/kernel-%{version}-%{_target_cpu}-debug.config | cut -b 3-` \
    rm -rf .tmp_versions \
    mv .tmp_versions.sign.debug .tmp_versions \
    mv signing_key.priv.sign.debug signing_key.priv \
    mv signing_key.x509.sign.debug signing_key.x509 \
    %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVRA}.debug || exit 1 \
  fi \
    if [ "%{with_default}" -ne "0" ]; then \
    Arch=`head -1 configs/kernel-%{version}-%{_target_cpu}.config | cut -b 3-` \
    rm -rf .tmp_versions \
    mv .tmp_versions.sign .tmp_versions \
    mv signing_key.priv.sign signing_key.priv \
    mv signing_key.x509.sign signing_key.x509 \
    %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVRA} || exit 1 \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%define __debug_install_post \
  /usr/lib/rpm/find-debuginfo.sh %{debuginfo_args} %{_builddir}/%{?buildsubdir}\
%{nil}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif

%endif

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVRA}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif # with_doc

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
make %{?cross_opts} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make %{?cross_opts} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \( -name .install -o -name .check -o -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

%endif

%if %{with_kernel_abi_whitelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE25} -C $INSTALL_KABI_PATH
%endif  # with_kernel_abi_whitelists

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install
# remove the 'trace' symlink.
rm -f $RPM_BUILD_ROOT/%{_bindir}/trace

# perf-python extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
%{perf_make} DESTDIR=$RPM_BUILD_ROOT try-install-man || %{doc_build_fail}
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
make -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%ifarch %{ix86} x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   make DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   make DESTDIR=%{buildroot} install
   popd
%endif #turbostat/x86_energy_perf_policy
pushd tools/thermal/tmon
make INSTALL_ROOT=%{buildroot} install
popd
%endif

%endif

%if %{with_bootwrapper}
make %{?cross_opts} DESTDIR=$RPM_BUILD_ROOT bootwrapper_install WRAPPER_OBJDIR=%{_libdir}/kernel-wrapper WRAPPER_DTSDIR=%{_libdir}/kernel-wrapper/dts
%endif

%if %{with_doc}
# Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}
install -m 0644 %{SOURCE13} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}/kernel-signing-ca.cer
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%if %{with_tools}
%post -n kernel-tools
/sbin/ldconfig

%postun -n kernel-tools
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVRA}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.%{?dist}.*/$f $f\
     done)\
fi\
%{nil}


# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVRA}%{?1:.%{1}} || exit $?\
fi\
%{_sbindir}/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --mkinitrd --dracut --depmod --update %{KVRA}%{?-v:.%{-v*}} || exit $?\
%{_sbindir}/new-kernel-pkg --package kernel%{?1:-%{1}} --rpmposttrans %{KVRA}%{?1:.%{1}} || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*}}\
%{-r:\
if [ `uname -i` == "x86_64" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
%{expand:\
%{_sbindir}/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --install %{KVRA}%{?-v:.%{-v*}} || exit $?\
}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
%{_sbindir}/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVRA}%{?1:.%{1}} || exit $?\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVRA}%{?1:.%{1}} || exit $?\
fi\
%{nil}

%kernel_variant_preun
%kernel_variant_post 

%kernel_variant_preun debug
%kernel_variant_post -v debug

%ifarch s390x
%postun kdump
    # Create softlink to latest remaining kdump kernel.
    # If no more kdump kernel is available, remove softlink.
    if [ "$(readlink /boot/zfcpdump)" == "/boot/vmlinuz-%{KVRA}.kdump" ]
    then
        vmlinuz_next=$(ls /boot/vmlinuz-*.kdump 2> /dev/null | sort | tail -n1)
        if [ $vmlinuz_next ]
        then
            ln -sf $vmlinuz_next /boot/zfcpdump
        else
            rm -f /boot/zfcpdump
        fi
    fi

%post kdump
    ln -sf /boot/vmlinuz-%{KVRA}.kdump /boot/zfcpdump
%endif # s390x

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_bootwrapper}
%files bootwrapper
%defattr(-,root,root)
/usr/sbin/*
%{_libdir}/kernel-wrapper
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%{_datadir}/man/man9/*
%{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}/kernel-signing-ca.cer
%dir %{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}
%dir %{_datadir}/doc/kernel-keys
%endif

%if %{with_kernel_abi_whitelists}
%files -n kernel-abi-whitelists
%defattr(-,root,root,-)
/lib/modules/kabi-*
%endif

%if %{with_perf}
%files -n perf
%defattr(-,root,root)
%{_bindir}/perf
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_libdir}/traceevent
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf

%files -n python-perf
%defattr(-,root,root)
%{python_sitearch}

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo
%defattr(-,root,root)

%files -f python-perf-debuginfo.list -n python-perf-debuginfo
%defattr(-,root,root)
%endif
%endif

%if %{with_tools}
%files -n kernel-tools -f cpupower.lang
%defattr(-,root,root)
%ifarch %{cpupowerarchs}
%{_bindir}/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch %{ix86} x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%endif
%endif
%{_bindir}/tmon
%if %{with_debuginfo}
%files -f kernel-tools-debuginfo.list -n kernel-tools-debuginfo
%defattr(-,root,root)
%endif

%ifarch %{cpupowerarchs}
%files -n kernel-tools-libs
%defattr(-,root,root)
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.0

%files -n kernel-tools-libs-devel
%defattr(-,root,root)
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif

%endif # with_tools

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVRA}%{?2:.%{2}}\
/%{image_install_path}/.vmlinuz-%{KVRA}%{?2:.%{2}}.hmac \
%attr(600,root,root) /boot/System.map-%{KVRA}%{?2:.%{2}}\
/boot/symvers-%{KVRA}%{?2:.%{2}}.gz\
/boot/config-%{KVRA}%{?2:.%{2}}\
%dir /lib/modules/%{KVRA}%{?2:.%{2}}\
/lib/modules/%{KVRA}%{?2:.%{2}}/kernel\
/lib/modules/%{KVRA}%{?2:.%{2}}/build\
/lib/modules/%{KVRA}%{?2:.%{2}}/source\
/lib/modules/%{KVRA}%{?2:.%{2}}/extra\
/lib/modules/%{KVRA}%{?2:.%{2}}/updates\
/lib/modules/%{KVRA}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVRA}%{?2:.%{2}}/vdso\
/etc/ld.so.conf.d/kernel-%{KVRA}%{?2:.%{2}}.conf\
%endif\
/lib/modules/%{KVRA}%{?2:.%{2}}/modules.*\
%ghost /boot/initramfs-%{KVRA}%{?2:.%{2}}.img\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
/usr/src/kernels/%{KVRA}%{?2:.%{2}}\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%defattr(-,root,root)\
%endif\
%endif\
%endif\
%{nil}

%kernel_variant_files %{with_default}
%kernel_variant_files %{with_debug} debug
%kernel_variant_files %{with_kdump} kdump

%changelog
* Wed Jul 22 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.11.1.el7]
- [fs] Fixing lease renewal (Steve Dickson) [1226328 1205048]
- [fs] revert "nfs: Fixing lease renewal" (Carlos Maiolino) [1226328 1205048]
- [redhat] spec: Update dracut dependency to 033-241.[el7|ael7b]_1.5 (Phillip Lougher) [1241571 1241344]

* Wed Jul 15 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.10.1.el7]
- [redhat] spec: Update dracut dependency to pull in drbg module (Phillip Lougher) [1241571 1241344]

* Sat Jul 04 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.9.1.el7]
- [crypto] krng: Remove krng (Herbert Xu) [1238210 1229738]
- [crypto] drbg: Add stdrng alias and increase priority (Herbert Xu) [1238210 1229738]
- [crypto] seqiv: Move IV seeding into init function (Herbert Xu) [1238210 1229738]
- [crypto] eseqiv: Move IV seeding into init function (Herbert Xu) [1238210 1229738]
- [crypto] chainiv: Move IV seeding into init function (Herbert Xu) [1238210 1229738]
- [s390] crypto: ghash - Fix incorrect ghash icv buffer handling (Herbert Xu) [1238211 1207598]
- [kernel] module: Call module notifier on failure after complete_formation() (Bandan Das) [1238937 1236273]
- [net] ipv4: kABI fix for 0bbf87d backport (Aristeu Rozanski) [1238208 1184764]
- [net] ipv4: Convert ipv4.ip_local_port_range to be per netns (Aristeu Rozanski) [1238208 1184764]
- [of] Eliminate of_allnodes list (Gustavo Duarte) [1236983 1210533]
- [scsi] ipr: Increase default adapter init stage change timeout (Steve Best) [1236139 1229217]
- [fs] libceph: fix double __remove_osd() problem (Sage Weil) [1236462 1229488]
- [fs] ext4: fix data corruption caused by unwritten and delayed extents (Lukas Czerner) [1235563 1213487]
- [kernel] watchdog: update watchdog_thresh properly (Ulrich Obergfell) [1223924 1216074]
- [kernel] watchdog: update watchdog attributes atomically (Ulrich Obergfell) [1223924 1216074]
- [virt] kvm: ensure hard lockup detection is disabled by default (Andrew Jones) [1236461 1111262]
- [watchdog] control hard lockup detection default (Andrew Jones) [1236461 1111262]
- [watchdog] Fix print-once on enable (Andrew Jones) [1236461 1111262]

* Fri Jun 19 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.8.1.el7]
- [fs] fs-cache: The retrieval remaining-pages counter needs to be atomic_t (David Howells) [1231809 1130457]
- [net] libceph: tcp_nodelay support (Sage Weil) [1231803 1197952]
- [powerpc] pseries: Simplify check for suspendability during suspend/migration (Gustavo Duarte) [1231638 1207295]
- [powerpc] pseries: Introduce api_version to migration sysfs interface (Gustavo Duarte) [1231638 1207295]
- [powerpc] pseries: Little endian fixes for post mobility device tree update (Gustavo Duarte) [1231638 1207295]
- [fs] sunrpc: Add missing support for RPC_CLNT_CREATE_NO_RETRANS_TIMEOUT (Steve Dickson) [1227825 1111712]
- [fs] nfs: Fixing lease renewal (Benjamin Coddington) [1226328 1205048]
- [powerpc] iommu: ddw: Fix endianness (Steve Best) [1224406 1189040]
- [usb] fix use-after-free bug in usb_hcd_unlink_urb() (Don Zickus) [1223239 1187256]
- [net] ipv4: Missing sk_nulls_node_init() in ping_unhash() (Denys Vlasenko) [1218104 1218105] {CVE-2015-3636}
- [net] nf_conntrack: reserve two bytes for nf_ct_ext->len (Marcelo Leitner) [1211096 1206164] {CVE-2014-9715}
- [net] ipv6: Don't reduce hop limit for an interface (Denys Vlasenko) [1208494 1208496] {CVE-2015-2922}
- [x86] kernel: execution in the early microcode loader (Jacob Tanenbaum) [1206829 1206830] {CVE-2015-2666}
- [fs] pipe: fix pipe corruption and iovec overrun on partial copy (Seth Jennings) [1202861 1198843] {CVE-2015-1805}

* Fri May 15 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.7.1.el7]
- [scsi] storvsc: get rid of overly verbose warning messages (Vitaly Kuznetsov) [1215770 1206437]
- [scsi] storvsc: force discovery of LUNs that may have been removed (Vitaly Kuznetsov) [1215770 1206437]
- [scsi] storvsc: in responce to a scan event, scan the host (Vitaly Kuznetsov) [1215770 1206437]
- [scsi] storvsc: NULL pointer dereference fix (Vitaly Kuznetsov) [1215770 1206437]
- [virtio] defer config changed notifications (David Gibson) [1220278 1196009]
- [virtio] unify config_changed handling (David Gibson) [1220278 1196009]
- [x86] kernel: Remove a bogus 'ret_from_fork' optimization (Mateusz Guzik) [1209234 1209235] {CVE-2015-2830}
- [kernel] futex: Mention key referencing differences between shared and private futexes (Larry Woodman) [1219169 1205862]
- [kernel] futex: Ensure get_futex_key_refs() always implies a barrier (Larry Woodman) [1219169 1205862]
- [scsi] megaraid_sas: revert: Add release date and update driver version (Tomas Henzl) [1216213 1207175]
- [kernel] module: set nx before marking module MODULE_STATE_COMING (Hendrik Brueckner) [1214788 1196977]
- [kernel] module: Clean up ro/nx after early module load failures (Pratyush Anand) [1214403 1202866]
- [drm] radeon: fix kernel segfault in hwmonitor (Jerome Glisse) [1213467 1187817]
- [fs] btrfs: make xattr replace operations atomic (Eric Sandeen) [1205086 1205873]
- [x86] mm: Linux stack ASLR implementation (Jacob Tanenbaum) [1195684 1195685] {CVE-2015-1593}
- [net] netfilter: nf_tables: fix flush ruleset chain dependencies (Jiri Pirko) [1192880 1192881] {CVE-2015-1573}
- [fs] isofs: Fix unchecked printing of ER records (Mateusz Guzik) [1180482 1180483] {CVE-2014-9584}
- [security] keys: memory corruption or panic during key garbage collection (Jacob Tanenbaum) [1179851 1179852] {CVE-2014-9529}
- [fs] isofs: infinite loop in CE record entries (Jacob Tanenbaum) [1175246 1175248] {CVE-2014-9420}

* Fri May 01 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.6.1.el7]
- [net] tcp: abort orphan sockets stalling on zero window probes (Florian Westphal) [1215924 1151756]
- [x86] crypto: aesni - fix memory usage in GCM decryption (Kurt Stutsman) [1213331 1212178] {CVE-2015-3331}

* Wed Apr 22 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.5.1.el7]
- [powerpc] mm: thp: Add tracepoints to track hugepage invalidate (Gustavo Duarte) [1212977 1199016]
- [powerpc] mm: Use read barrier when creating real_pte (Gustavo Duarte) [1212977 1199016]
- [powerpc] mm: thp: Use ACCESS_ONCE when loading pmdp (Gustavo Duarte) [1212977 1199016]
- [powerpc] mm: thp: Invalidate with vpn in loop (Gustavo Duarte) [1212977 1199016]
- [powerpc] mm: thp: Handle combo pages in invalidate (Gustavo Duarte) [1212977 1199016]
- [powerpc] mm: thp: Invalidate old 64K based hash page mapping before insert of 4k pte (Gustavo Duarte) [1212977 1199016]
- [powerpc] mm: thp: Don't recompute vsid and ssize in loop on invalidate (Gustavo Duarte) [1212977 1199016]
- [powerpc] mm: thp: Add write barrier after updating the valid bit (Gustavo Duarte) [1212977 1199016]

* Tue Apr 14 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.4.1.el7]
- [crypto] x86: sha256_ssse3 - also test for BMI2 (Herbert Xu) [1211484 1201563]
- [crypto] testmgr: fix RNG return code enforcement (Herbert Xu) [1211487 1198978]
- [crypto] rng: RNGs must return 0 in success case (Herbert Xu) [1211487 1198978]
- [crypto] x86: sha1 - reduce size of the AVX2 asm implementation (Herbert Xu) [1211291 1177968]
- [crypto] x86: sha1 - fix stack alignment of AVX2 variant (Herbert Xu) [1211291 1177968]
- [crypto] x86: sha1 - re-enable the AVX variant (Herbert Xu) [1211291 1177968]
- [crypto] sha: SHA1 transform x86_64 AVX2 (Herbert Xu) [1211291 1177968]
- [crypto] sha-mb: sha1_mb_alg_state can be static (Herbert Xu) [1211290 1173756]
- [crypto] mcryptd: mcryptd_flist can be static (Herbert Xu) [1211290 1173756]
- [crypto] sha-mb: SHA1 multibuffer job manager and glue code (Herbert Xu) [1211290 1173756]
- [crypto] sha-mb: SHA1 multibuffer crypto computation (x8 AVX2) (Herbert Xu) [1211290 1173756]
- [crypto] sha-mb: SHA1 multibuffer submit and flush routines for AVX2 (Herbert Xu) [1211290 1173756]
- [crypto] sha-mb: SHA1 multibuffer algorithm data structures (Herbert Xu) [1211290 1173756]
- [crypto] sha-mb: multibuffer crypto infrastructure (Herbert Xu) [1211290 1173756]
- [kernel] sched: Add function single_task_running to let a task check if it is the only task running on a cpu (Herbert Xu) [1211290 1173756]
- [crypto] ahash: initialize entry len for null input in crypto hash sg list walk (Herbert Xu) [1211290 1173756]
- [crypto] ahash: Add real ahash walk interface (Herbert Xu) [1211290 1173756]
- [char] random: account for entropy loss due to overwrites (Herbert Xu) [1211288 1110044]
- [char] random: allow fractional bits to be tracked (Herbert Xu) [1211288 1110044]
- [char] random: statically compute poolbitshift, poolbytes, poolbits (Herbert Xu) [1211288 1110044]

* Thu Apr 09 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.3.1.el7]
- [netdrv] mlx4_en: tx_info->ts_requested was not cleared (Doug Ledford) [1209240 1178070]

* Thu Apr 02 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.2.1.el7]
- [char] tpm: Added Little Endian support to vtpm module (Steve Best) [1207051 1189017]
- [powerpc] pseries: Fix endian problems with LE migration (Steve Best) [1207050 1183198]
- [iommu] vt-d: Work around broken RMRR firmware entries (Myron Stowe) [1205303 1195802]
- [iommu] vt-d: Store bus information in RMRR PCI device path (Myron Stowe) [1205303 1195802]
- [s390] zcrypt: enable s390 hwrng to seed kernel entropy (Hendrik Brueckner) [1205300 1196398]
- [s390] zcrypt: improve device probing for zcrypt adapter cards (Hendrik Brueckner) [1205300 1196398]
- [net] team: fix possible null pointer dereference in team_handle_frame (Jiri Pirko) [1202359 1188496]
- [fs] fsnotify: fix handling of renames in audit (Paul Moore) [1202358 1191562]
- [net] openvswitch: Fix net exit (Jiri Benc) [1202357 1200859]
- [fs] gfs2: Move gfs2_file_splice_write outside of #ifdef (Robert S Peterson) [1201256 1193910]
- [fs] gfs2: Allocate reservation during splice_write (Robert S Peterson) [1201256 1193910]
- [crypto] aesni: fix "by8" variant for 128 bit keys (Herbert Xu) [1201254 1174971]
- [crypto] aesni: remove unused defines in "by8" variant (Herbert Xu) [1201254 1174971]
- [crypto] aesni: fix counter overflow handling in "by8" variant (Herbert Xu) [1201254 1174971]
- [crypto] aes: AES CTR x86_64 "by8" AVX optimization (Herbert Xu) [1201254 1174971]
- [kernel] audit: restore AUDIT_LOGINUID unset ABI (Richard Guy Briggs) [1197748 1120491]
- [kernel] audit: replace getname()/putname() hacks with reference counters (Paul Moore) [1197746 1155208]
- [kernel] audit: fix filename matching in __audit_inode() and __audit_inode_child() (Paul Moore) [1197746 1155208]
- [kernel] audit: enable filename recording via getname_kernel() (Paul Moore) [1197746 1155208]
- [fs] namei: simpler calling conventions for filename_mountpoint() (Paul Moore) [1197746 1155208]
- [fs] namei: create proper filename objects using getname_kernel() (Paul Moore) [1197746 1155208]
- [fs] namei: rework getname_kernel to handle up to PATH_MAX sized filenames (Paul Moore) [1197746 1155208]
- [fs] namei: cut down the number of do_path_lookup() callers (Paul Moore) [1197746 1155208]
- [fs] execve: use 'struct filename *' for executable name passing (Paul Moore) [1197746 1155208]
- [infiniband] core: Prevent integer overflow in ib_umem_get address arithmetic (Doug Ledford) [1181177 1179347] {CVE-2014-8159}

* Thu Mar 05 2015 Phillip Lougher <plougher@redhat.com> [3.10.0-229.1.1.el7]
- [crypto] testmgr: mark rfc4106(gcm(aes)) as fips_allowed (Jarod Wilson) [1197751 1185400]
- [virt] storvsc: ring buffer failures may result in I/O freeze (Vitaly Kuznetsov) [1197749 1171409]
- [md] dm-thin: don't allow messages to be sent to a pool target in READ_ONLY or FAIL mode (Mike Snitzer) [1197745 1184592]
- [kernel] workqueue: fix subtle pool management issue which can stall whole worker_pool (Eric Sandeen) [1197744 1165535]
- [platform] thinkpad_acpi: support new BIOS version string pattern (Benjamin Tissoires) [1197743 1194830]
- [x86] ioapic: kcrash: Prevent crash_kexec() from deadlocking on ioapic_lock (Baoquan He) [1197742 1182424]
- [net] sctp: fix slab corruption from use after free on INIT collisions (Daniel Borkmann) [1196588 1183959] {CVE-2015-1421}

* Thu Jan 29 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-229.el7]
- [net] rtnetlink: allow to register ops without ops->setup set (Jiri Benc) [1186492]

* Thu Jan 29 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-228.el7]
- [fs] NFSv4.1: Fix an Oops in nfs41_walk_client_list (Steve Dickson) [1185784]
- [misc] redhat: don't suppress Revert patches from changelog (Jarod Wilson) [1187353]
- [infiniband] Revert: ipoib: Consolidate rtnl_lock tasks in workqueue (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: Make the carrier_on_task race aware (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: fix MCAST_FLAG_BUSY usage (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: fix mcast_dev_flush/mcast_restart_task race (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: change init sequence ordering (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: Use dedicated workqueues per interface (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: Make ipoib_mcast_stop_thread flush the workqueue (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: No longer use flush as a parameter (Doug Ledford) [1179740]
- [fs] fix deadlock in cifs_ioctl_clone() (Sachin Prabhu) [1183980]
- [md] dm-cache: fix missing ERR_PTR returns and handling (Mike Snitzer) [1182665]
- [fs] cifs: fix regression in cifs_create_mf_symlink() (Sachin Prabhu) [1186324]
- [net] ipv4: try to cache dst_entries which would cause a redirect (Hannes Frederic Sowa) [1181819]
- [fs] coredump: add new P variable in core_pattern (Jiri Olsa) [1186360]
- [drm] fix fb-helper vs MST dangling connector ptrs (Rob Clark) [1184968]
- [net] bridge: Program port vlan filters only if filtering is enabled in bridge (Vlad Yasevich) [1183958]
- [fs] cifs: Complete oplock break jobs before closing file handle (Sachin Prabhu) [1177215]
- [fs] LOCKD: Fix a race when initialising nlmsvc_timeout (Benjamin Coddington) [1144982]
- [scsi] hpsa: add in P840ar controller model name (Joseph Szczypek) [1185467]
- [scsi] hpsa: add in gen9 controller model names (Joseph Szczypek) [1185467]

* Tue Jan 27 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-227.el7]
- [fs] ext4: fix overwrite race condition (Jacob Tanenbaum) [1152607] {CVE-2014-8086}
- [media] ttusb-dec: buffer overflow in ioctl (Alexander Gordeev) [1167116] {CVE-2014-8884}
- [drm] i915: demote opregion excessive timeout WARN_ONCE to DRM_INFO_ONCE (Rob Clark) [1145627]
- [md] Revert: raid56: Don't perform reads to support writes until stripe is ready (Jes Sorensen) [1153796]
- [md] Revert: raid5: avoid livelock caused by non-aligned writes (Jes Sorensen) [1153796]
- [drm] i915: further quiet i915 (Rob Clark) [1163074]
- [scsi] megaraid_sas: endianness related bug fixes and code optimization (Tomas Henzl) [1179748]
- [s390] crypto: kernel oops at insmod of the z90crypt device driver (Hendrik Brueckner) [1172136]
- [drm] mgag200: Add command line option to specify preferred depth (Dave Airlie) [1044555]
- [drm] mgag200: Consolidate depth/bpp handling (Dave Airlie) [1044555]
- [fs] Revert: ext4: revert Disable punch hole on non-extent mapped files (Lukas Czerner) [1176840]

* Sun Jan 25 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-226.el7]
- [md] dm-cache: fix problematic dual use of a single migration count variable (Mike Snitzer) [1182665]
- [md] dm-cache: share cache-metadata object across inactive and active DM tables (Mike Snitzer) [1182665]
- [net] tun/macvtap: use consume_skb() instead of kfree_skb() when needed (Jiri Pirko) [1182805]
- [virt] Revert: hyperv: Add handler for RNDIS_STATUS_NETWORK_CHANGE event (Jason Wang) [1164163]
- [virt] kvm/vmx: invalid host cr4 handling across vm entries (Jacob Tanenbaum) [1153329] {CVE-2014-3690}
- [virt] virtio-scsi: Fix the race condition in virtscsi_handle_event (Fam Zheng) [1152140]
- [virt] kvm: workaround SuSE's 2.6.16 pvclock vs masterclock issue (Marcelo Tosatti) [1177718]
- [fs] bdi: avoid oops on device removal (Fam Zheng) [1087179]
- [mm] backing_dev: fix hung task on sync (Fam Zheng) [1087179]
- [mm] Revert: vmstat: create separate function to fold per cpu diffs into local counters (Larry Woodman) [1179654]
- [mm] Revert: vmstat: create fold_diff (Larry Woodman) [1179654]
- [mm] Revert: vmstat: use this_cpu() to avoid irqon/off sequence in refresh_cpu_vm_stats (Larry Woodman) [1179654]
- [mm] Revert: vmstat: on-demand vmstat workers V8 (Larry Woodman) [1179654]

* Thu Jan 22 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-225.el7]
- [net] team: avoid possible underflow of count_pending value for notify_peers and mcast_rejoin (Jiri Pirko) [1176697]
- [fs] seq_file: don't include mm.h in genksyms calculation (Ian Kent) [1183280]
- [scsi] Avoid crashing if device uses DIX but adapter does not support it (Ewan Milne) [1093012]

* Mon Jan 19 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-224.el7]
- [fs] xfs: catch invalid negative blknos in _xfs_buf_find() (Eric Sandeen) [1164128]
- [fs] proc: make proc_fd_permission() thread-friendly (Carlos Maiolino) [1171242]
- [fs] rpc: fix xdr_truncate_encode to handle buffer ending on page boundary ("J. Bruce Fields") [1176641]
- [fs] nfs: nfs4_fl_prepare_ds, fix bugs when the connect attempt fails (Steve Dickson) [1113248]
- [fs] gfs2: fix bad inode i_goal values during block allocation (Abhijith Das) [1144209]
- [fs] nfsd: allow turning off nfsv3 readdir_plus (Steve Dickson) [1178949]
- [fs] nfsd4: fix xdr4 count of server in fs_location4 (Benjamin Coddington) [1164055]
- [fs] nfsd4: fix xdr4 inclusion of escaped char (Benjamin Coddington) [1164055]
- [fs] xfs: replace global xfslogd wq with per-mount wq (Brian Foster) [1155929]
- [fs] xfs: mark all internal workqueues as freezable (Brian Foster) [1155929]
- [fs] overlayfs: Add call to mark_tech_preview (BZ 1180613) (David Howells) [1180613]
- [fs] aio: fix uncorrent dirty pages accouting when truncating AIO ring buffer (Jeff Moyer) [1159346]
- [infiniband] ocrdma: fix hardcoded max cqe and max send wr (Doug Ledford) [1158148]
- [crypto] aesni-intel: Add support for 192 & 256 bit keys to AESNI RFC4106 (Jarod Wilson) [1176266]
- [block] blk-mq: Fix a use-after-free (Fam Zheng) [1152159]
- [crypto] drbg: panic on continuous self test error (Jarod Wilson) [1179496]
- [ethernet] mlx4: Cache line CQE/EQE stride fixes (Doug Ledford) [1088499 1173483]
- [ethernet] mlx4: Add mlx4_en_get_cqe helper (Doug Ledford) [1088499 1173483]
- [ethernet] mlx4: Cache line EQE size support (Doug Ledford) [1088499 1173483]
- [infiniband] ocrdma: Fix ocrdma_query_qp() to report q_key value for UD QPs (Doug Ledford) [1167256]
- [infiniband] ocrdma: Always resolve destination mac from GRH for UD QPs (Doug Ledford) [1167256]
- [net] gre: fix the inner mac header in nbma tunnel xmit path (Alexander Duyck) [1168608]

* Tue Jan 13 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-223.el7]
- [md] dm-thin: fix crash by initializing thin device's refcount and completion earlier (Mike Snitzer) [1175282]
- [scsi] storvsc: Fix a bug in storvsc limits (Vitaly Kuznetsov) [1174162]
- [iser-target] Ignore non TEXT + LOGOUT opcodes for discovery (Andy Grover) [1058736]
- [iser-target] Add support for ISCSI_OP_TEXT opcode + payload handling (Andy Grover) [1058736]
- [iser-target] Rename sense_buf_dma/len to pdu_dma/len (Andy Grover) [1058736]
- [iscsi-target] Add IFC_SENDTARGETS_SINGLE support (Andy Grover) [1058736]
- [iscsi-target] Move sendtargets parsing into iscsit_process_text_cmd (Andy Grover) [1058736]
- [iscsi-target] Allow ->MaxXmitDataSegmentLength assignment for iser discovery (Andy Grover) [1058736]
- [iscsi-target] Refactor ISCSI_OP_TEXT_RSP TX handling (Andy Grover) [1058736]
- [iscsi-target] Refactor ISCSI_OP_TEXT RX handling (Andy Grover) [1058736]
- [iscsi] isert-target: Refactor ISCSI_OP_NOOP RX handling (Andy Grover) [1058736]
- [net] description of dma_cookie cause make xmldocs warning (Jiri Benc) [1173444]
- [net] tcp: make tcp_cleanup_rbuf private (Jiri Benc) [1173444]
- [net] net_dma: revert 'copied_early' (Jiri Benc) [1173444]
- [net] net_dma: mark broken (Jiri Benc) [1173444]
- [net] unix: allow set_peek_off to fail (Jiri Benc) [1123777]
- [net] ppp: ppp-ioctl.h: pull in ppp_defs.h (Jiri Benc) [1159802]
- [net] bridge: Add filtering support for default_pvid (Vlad Yasevich) [1164653]
- [net] bridge: Simplify pvid checks (Vlad Yasevich) [1164653]
- [net] bridge: Add a default_pvid sysfs attribute (Vlad Yasevich) [1164653]
- [net] bridge: Prepare for 802.1ad vlan filtering support (Vlad Yasevich) [1164653]
- [net] bridge: Fix the way to check if a local fdb entry can be deleted (Vlad Yasevich) [1164653]
- [net] bridge: Fix the way to insert new local fdb entries in br_fdb_changeaddr (Vlad Yasevich) [1164653]
- [net] Remove extern from function prototypes (Vlad Yasevich) [1164653]
- [ethernet] mlx5: Add more supported devices (Amir Vadai) [1169277]
- [infiniband] mlx4: Fix wrong usage of IPv4 protocol for multicast attach/detach (Amir Vadai) [1151331]
- [ethernet] mlx4: mlx4_en_set_settings() always fails when autoneg is set (Amir Vadai) [1170129]

* Thu Jan 08 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-222.el7]
- [scsi] qla2xxx: Update version number to 8.07.00.08.07.1-k2 (Chad Dupuis) [1085239]
- [scsi] qla2xxx: Move mailbox failure messages to a default debug level (Chad Dupuis) [1085239]
- [security] commoncap: don't alloc the credential unless needed in cap_task_prctl (Paul Moore) [1056347]
- [iommu] vt-d: Fix dmar_domain leak in iommu_attach_device (Myron Stowe) [1109829]
- [iommu] vt-d: Only remove domain when device is removed (Myron Stowe) [1109829]
- [base] core: Add BUS_NOTIFY_REMOVED_DEVICE event (Myron Stowe) [1109829]
- [powerpc] kdump: Ignore failure in enabling big endian exception during crash (Steve Best) [1170362]
- [infiniband] srpt: convert printk's to pr_* functions (Doug Ledford) [1174910]
- [infiniband] srpt: Handle GID change events (Doug Ledford) [1174910]
- [input] alps: fix v4 button press recognition (Benjamin Tissoires) [1107819]
- [input] alps: v7 - document the v7 touchpad packet protocol (Benjamin Tissoires) [1107819]
- [input] alps: v7 - fix finger counting for > 2 fingers on clickpads (Benjamin Tissoires) [1107819]
- [input] alps: v7 - sometimes a single touch is reported in mt[1] (Benjamin Tissoires) [1107819]
- [input] alps: v7 - ignore new packets (Benjamin Tissoires) [1107819]
- [powerpc] perf/hv-24x7: Use kmem_cache_free() instead of kfree (Gustavo Duarte) [1171795]
- [powerpc] perf/hv-24x7: Use per-cpu page buffer (Gustavo Duarte) [1171795]
- [powerpc] perf/hv-24x7: use kmem_cache instead of aligned stack allocations (Gustavo Duarte) [1171795]
- [powerpc] perf/hv-24x7: Use kmem_cache_free (Gustavo Duarte) [1171795]
- [powerpc] Fill in si_addr_lsb siginfo field (Gustavo Duarte) [1173267]
- [powerpc] Add VM_FAULT_HWPOISON handling to powerpc page fault handler (Gustavo Duarte) [1173267]
- [fs] dlm: fix missing endian conversion of rcom_status flags (Andrew Price) [1175900]
- [scsi] add Intel Multi-Flex to scsi scan blacklist (Hannes Frederic Sowa) [1175862]
- [scsi] do not issue SCSI RSOC command to Promise Vtrak E610f (Hannes Frederic Sowa) [1175862]
- [scsi] scsi_lib: rate-limit the error message from failing commands (Tomas Henzl) [1175785]
- [scsi] iscsi_ibft: Fix finding Broadcom specific ibft sign (Chris Leech) [1095169]

* Tue Jan 06 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-221.el7]
- [ethernet] enic: fix rx skb checksum (Stefan Assmann) [1154182]
- [x86] uv: make kdump default action for 'power nmi' (George Beshers) [1175560]
- [virt] powerpc/kvm: book3s_hv - Fix KSM memory corruption (David Gibson) [1170394]
- [pci] Revert: Remove from bus_list and release resources in pci_release_dev() (Prarit Bhargava) [1172946]
- [powercap] rapl: add support for CPU model 0x3f (Rui Wang) [1177579]
- [kernel] audit: don't attempt to lookup PIDs when changing PID filtering audit rules (Paul Moore) [1172624]
- [ethernet] ixgbe: avoid possible read_reg panic caused by late method binding (John Greene) [1145772]
- [ethernet] ixgbe: bump version number (John Greene) [1145772]
- [ethernet] ixgbe: Add X550 support function pointers (John Greene) [1145772]
- [ethernet] ixgbe: Add new support for X550 MAC's (John Greene) [1145772]
- [ethernet] ixgbe: Add x550 SW/FW semaphore support (John Greene) [1145772]
- [ethernet] ixgbe: add methods for combined read and write operations (John Greene) [1145772]
- [ethernet] ixgbe: cleanup checksum to allow error results (John Greene) [1145772]
- [ethernet] ixgbe: Add timeout parameter to ixgbe_host_interface_command (John Greene) [1145772]
- [ethernet] ixgbe: Fix spurious release of semaphore in EEPROM access (John Greene) [1145772]
- [drm] i915: remove the IRQs enabled WARN from intel_disable_gt_powersave (Rob Clark) [1173317]
- [drm] i915: tame the chattermouth (Rob Clark) [1173317]
- [drm] ttm: Avoid memory allocation from shrinker functions (Rob Clark) [1173317]
- [drm] ttm: Fix possible stack overflow by recursive shrinker calls (Rob Clark) [1173317]
- [drm] ttm: Use mutex_trylock() to avoid deadlock inside shrinker functions (Rob Clark) [1173317]
- [drm] video/fb: Propagate error code from failing to unregister conflicting fb (Rob Clark) [1173317]
- [drm] i915: save/restore GMBUS freq across suspend/resume on gen4 (Rob Clark) [1173317]
- [drm] i915: resume MST after reading back hw state (Rob Clark) [1173317]
- [drm] dp-mst: Remove branches before dropping the reference (Rob Clark) [1173317]
- [drm] fb_helper: move deferred fb checking into restore mode (Rob Clark) [1173317]
- [drm] dp: retry AUX transactions 32 times (v1.1) (Rob Clark) [1173317]
- [drm] i915: Ignore long hpds on eDP ports (Rob Clark) [1173317]
- [drm] i915/dp: only use training pattern 3 on platforms that support it (Rob Clark) [1173317]
- [drm] radeon: sync all BOs involved in a CS (Rob Clark) [1173317]
- [drm] radeon: kernel panic in drm_calc_vbltimestamp_from_scanoutpos with 3.18.0-rc6 (Rob Clark) [1173317]
- [drm] i915: Unlock panel even when LVDS is disabled (Rob Clark) [1173317]
- [drm] i915: More cautious with pch fifo underruns (Rob Clark) [1173317]
- [drm] i915: Ignore SURFLIVE and flip counter when the GPU gets reset (Rob Clark) [1173317]
- [drm] i915: Kick fbdev before vgacon (Rob Clark) [1173317]
- [drm] i915: Handle failure to kick out a conflicting fb driver (Rob Clark) [1173317]
- [drm] i915: drop WaSetupGtModeTdRowDispatch:snb (Rob Clark) [1173317]
- [drm] radeon: add locking around atombios scratch space usage (Rob Clark) [1173317]
- [drm] radeon: add missing crtc unlock when setting up the MC (Rob Clark) [1173317]
- [drm] i915: Disable caches for Global GTT (Rob Clark) [1173317]
- [drm] i915: Do not leak pages when freeing userptr objects (Rob Clark) [1173317]
- [drm] ast: Fix HW cursor image (Rob Clark) [1173317]
- [drm] radeon: Use drm_malloc_ab instead of kmalloc_array (Rob Clark) [1173317]
- [drm] radeon/dpm: disable ulv support on SI (Rob Clark) [1173317]
- [drm] i915: Do a dummy DPCD read before the actual read (Rob Clark) [1173317]
- [drm] nouveau/bios: memset dcb struct to zero before parsing (Rob Clark) [1173317]
- [drm] nv50/disp: fix dpms regression on certain boards (Rob Clark) [1173317]
- [drm] nouveau/ltc: fix cbc issues on certain boards (Rob Clark) [1173317]
- [drm] nouveau/ltc: fix tag base address getting truncated if above 4GiB (Rob Clark) [1173317]
- [drm] nvc0-/fb/ram: fix use of non-existant ram if partitions aren't uniform (Rob Clark) [1173317]
- [drm] nouveau/bar: behave better if ioremap failed (Rob Clark) [1173317]
- [drm] nouveau: make sure display hardware is reinitialised on runtime resume (Rob Clark) [1173317]
- [drm] nouveau: punt fbcon resume out to a workqueue (Rob Clark) [1173317]
- [drm] nouveau/kms: restore acceleration before fb_set_suspend() resumes (Rob Clark) [1173317]
- [drm] nouveau/kms: take more care when pulling down accelerated fbcon (Rob Clark) [1173317]
- [drm] i915: Flush the PTEs after updating them before suspend (Rob Clark) [1153301]
- [drm] radeon/cik: use a separate counter for CP init timeout (Rob Clark) [1173317]
- [drm] radeon/dpm: fix resume on mullins (Rob Clark) [1173317]
- [drm] radeon: don't reset dma on r6xx-evergreen init (Rob Clark) [1173317]
- [drm] radeon: don't reset sdma on CIK init (Rob Clark) [1173317]
- [drm] radeon: don't reset dma on NI/SI init (Rob Clark) [1173317]
- [drm] radeon: add connector quirk for fujitsu board (Rob Clark) [1173317]
- [drm] radeon/dpm: set the thermal type properly for special configs (Rob Clark) [1173317]
- [drm] radeon: fix semaphore value init (Rob Clark) [1173317]
- [drm] radeon: handle broken disabled rb mask gracefully (6xx/7xx) (Rob Clark) [1173317]
- [drm] radeon: fix active_cu mask on SI and CIK after re-init (v3) (Rob Clark) [1173317]
- [drm] radeon: fix active cu count for SI and CIK (Rob Clark) [1173317]
- [drm] radeon: fix pm handling in radeon_gpu_reset (Rob Clark) [1173317]
- [drm] radeon: properly document reloc priority mask (Rob Clark) [1173317]
- [drm] radeon/dpm: select the appropriate vce power state for KV/KB/ML (Rob Clark) [1173317]
- [drm] radeon: Add missing lines to ci_set_thermal_temperature_range (Rob Clark) [1173317]
- [drm] radeon: Add ability to get and change dpm state when radeon PX card is turned off (Rob Clark) [1173317]
- [drm] vmwgfx: Fix a potential infinite spin waiting for fifo idle (Rob Clark) [1173317]
- [drm] ast: AST2000 cannot be detected correctly (Rob Clark) [1173317]
- [drm] ast: open key before detect chips (Rob Clark) [1173317]
- [drm] i915: Don't leak command parser tables on suspend/resume (Rob Clark) [1153301]
- [drm] i915/hdmi: fix hdmi audio state readout (Rob Clark) [1153301]
- [drm] i915: Wait for vblank before enabling the TV encoder (Rob Clark) [1153301]
- [drm] i915: Fix EIO/wedged handling in gem fault handler (Rob Clark) [1153301]
- [drm] i915: Fix lock dropping in intel_tv_detect() (Rob Clark) [1153301]
- [drm] i915: Remove bogus __init annotation from DMI callbacks (Rob Clark) [1153301]
- [drm] i915: Ignore VBT backlight presence check on Acer C720 (4005U) (Rob Clark) [1153301]
- [drm] i915: fix plane/cursor handling when runtime suspended (Rob Clark) [1153301]
- [drm] i915: don't try to retrain a DP link on an inactive CRTC (Rob Clark) [1153301]
- [drm] i915: Fix locking for intel_enable_pipe_a() (Rob Clark) [1153301]
- [drm] i915: Skip load detect when intel_crtc->new_enable==true (Rob Clark) [1153301]
- [drm] i915: Disable RCS flips on Ivybridge (Rob Clark) [1153301]
- [drm] i915: read HEAD register back in init_ring_common() to enforce ordering (Rob Clark) [1153301]
- [drm] i915: Fix crash when failing to parse MIPI VBT (Rob Clark) [1153301]
- [drm] radeon: tweak ACCEL_WORKING2 query for hawaii (Rob Clark) [1173317]
- [drm] radeon/atom: add new voltage fetch function for hawaii (Rob Clark) [1173317]
- [drm] radeon: set VM base addr using the PFP (Rob Clark) [1173317]
- [drm] radeon: load the lm63 driver for an lm64 thermal chip (Rob Clark) [1173317]
- [drm] radeon: re-enable dpm by default on BTC (Rob Clark) [1173317]
- [drm] radeon: re-enable dpm by default on cayman (Rob Clark) [1173317]
- [drm] radeon/dpm: handle voltage info fetching on hawaii (Rob Clark) [1173317]
- [drm] ttm: Choose a pool to shrink correctly in ttm_dma_pool_shrink_scan() (Rob Clark) [1173317]
- [drm] ttm: Fix possible division by 0 in ttm_dma_pool_shrink_scan() (Rob Clark) [1173317]
- [drm] ttm: fix handling of TTM_PL_FLAG_TOPDOWN (Rob Clark) [1173317]
- [drm] nouveau: Bump version from 1.1.1 to 1.1.2 (Rob Clark) [1173317]
- [drm] nouveau: Dis/Enable vblank irqs during suspend/resume (Rob Clark) [1173317]
- [drm] radeon: add additional SI pci ids (Rob Clark) [1173317]
- [drm] radeon: add new bonaire pci ids (Rob Clark) [1173317]
- [drm] radeon: add new KV pci id (Rob Clark) [1173317]
- [powerpc] add little endian flag to syscall_get_arch() (Richard Guy Briggs) [1169461]
- [powerpc] simplify syscall_get_arch() (Richard Guy Briggs) [1169461]

* Tue Dec 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-220.el7]
- [scsi] libcxgbi: fix freeing skb prematurely (Sai Vemuri) [1174982]
- [scsi] cxgb4i: use set_wr_txq() to set tx queues (Sai Vemuri) [1174982]
- [scsi] cxgb4i: handle non-pdu-aligned rx data (Sai Vemuri) [1174982]
- [scsi] cxgb4i: additional types of negative advice (Sai Vemuri) [1174982]
- [scsi] cxgb4i: set the max. pdu length in firmware (Sai Vemuri) [1174982]
- [scsi] cxgb4i: fix credit check for tx_data_wr (Sai Vemuri) [1174982]
- [scsi] cxgb4i: fix tx immediate data credit check (Sai Vemuri) [1174982]
- [net] ipv6: update Destination Cache entries when gateway turn into host (Jiri Pirko) [1114781]
- [net] ipsec: Don't update the pmtu on ICMPV6_DEST_UNREACH (Herbert Xu) [1158771]
- [s390] zfcp: remove access control tables interface (port leftovers) (Hendrik Brueckner) [1173553]
- [x86] perf: Use extended offcore mask on Haswell (Don Zickus) [1170795]
- [fs] ovl: ovl_dir_fsync() cleanup (David Howells) [985875]
- [fs] ovl: pass dentry into ovl_dir_read_merged() (David Howells) [985875]
- [fs] ovl: use lockless_dereference() for upperdentry (David Howells) [985875]
- [fs] ovl: allow filenames with comma (David Howells) [985875]
- [fs] ovl: fix race in private xattr checks (David Howells) [985875]
- [fs] ovl: fix remove/copy-up race (David Howells) [985875]
- [fs] ovl: rename filesystem type to "overlay" (David Howells) [985875]
- [fs] Don't warn if both ->rename() and ->rename2() iops are defined (David Howells) [985875]
- [fs] overlayfs: Fix the kABI for overlayfs (David Howells) [985875]
- [fs] overlayfs: don't poison cursor (David Howells) [985875]
- [fs] overlayfs: initialize ->is_cursor (David Howells) [985875]
- [fs] overlayfs: fix lockdep misannotation (David Howells) [985875]
- [fs] overlayfs: fix check for cursor (David Howells) [985875]
- [fs] overlayfs: barriers for opening upper-layer directory (David Howells) [985875]
- [kernel] rcu: Provide counterpart to rcu_dereference() for non-RCU situations (David Howells) [985875]
- [fs] overlayfs: embed middle into overlay_readdir_data (David Howells) [985875]
- [fs] overlayfs: embed root into overlay_readdir_data (David Howells) [985875]
- [fs] overlayfs: make ovl_cache_entry->name an array instead of pointer (David Howells) [985875]
- [fs] overlayfs: don't hold ->i_mutex over opening the real directory (David Howells) [985875]
- [fs] overlayfs: limit filesystem stacking depth (David Howells) [985875]
- [fs] overlayfs: overlay filesystem documentation (David Howells) [985875]
- [fs] overlayfs: implement show_options (David Howells) [985875]
- [fs] overlayfs: add statfs support (David Howells) [985875]
- [fs] overlayfs: filesystem (David Howells) [985875]
- [mm] shmem: support RENAME_WHITEOUT (David Howells) [985875]
- [fs] ext4: support RENAME_WHITEOUT (David Howells) [985875]
- [fs] vfs: add RENAME_WHITEOUT (David Howells) [985875]
- [fs] vfs: add whiteout support (David Howells) [985875]
- [fs] vfs: export check_sticky() (David Howells) [985875]
- [fs] vfs: introduce clone_private_mount() (David Howells) [985875]
- [fs] vfs: export __inode_permission() to modules (David Howells) [985875]
- [fs] vfs: export do_splice_direct() to modules (David Howells) [985875]
- [fs] vfs: add i_op->dentry_open() (David Howells) [985875]
- [fs] namei: trivial fix to vfs_rename_dir comment (David Howells) [985875]
- [fs] cifs: support RENAME_NOREPLACE (David Howells) [985875]
- [fs] hostfs: support rename flags (David Howells) [985875]
- [mm] shmem: support RENAME_EXCHANGE (David Howells) [985875]
- [mm] shmem: support RENAME_NOREPLACE (David Howells) [985875]
- [fs] btrfs: add RENAME_NOREPLACE (David Howells) [985875]
- [fs] bad_inode: add ->rename2() (David Howells) [985875]
- [fs] call rename2 if exists (David Howells) [985875]
- [fs] fuse: restructure ->rename2() (David Howells) [985875]
- [fs] fuse: add renameat2 support (David Howells) [985875]
- [fs] dcache: fix races between __d_instantiate() and checks of dentry flags (David Howells) [985875]
- [fs] ext4: add cross rename support (David Howells) [985875]
- [fs] vfs: add cross-rename (David Howells) [985875]
- [fs] vfs: lock_two_nondirectories - allow directory args (David Howells) [985875]
- [security] add flags to rename hooks (David Howells) [985875]
- [fs] vfs: add RENAME_NOREPLACE flag (David Howells) [985875]
- [fs] vfs: add renameat2 syscall (David Howells) [985875]
- [fs] namei: use common code for dir and non-dir (David Howells) [985875]
- [fs] namei: move d_move() up (David Howells) [985875]
- [fs] vfs: add d_is_dir() (David Howells) [985875]
- [fs] vfs: Put a small type field into struct dentry::d_flags (David Howells) [985875]

* Thu Dec 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-219.el7]
- [mm] vmstat: on-demand vmstat workers V8 (Larry Woodman) [1157802]
- [mm] vmstat: use this_cpu() to avoid irqon/off sequence in refresh_cpu_vm_stats (Larry Woodman) [1157802]
- [mm] vmstat: create fold_diff (Larry Woodman) [1157802]
- [mm] vmstat: create separate function to fold per cpu diffs into local counters (Larry Woodman) [1157802]
- [block] blk-mq: Fix uninitialized kobject at CPU hotplugging (Jeff Moyer) [1169232]
- [kernel] audit: AUDIT_FEATURE_CHANGE message format missing delimiting space (Richard Guy Briggs) [1165469]
- [fs] NFSv4.1: nfs41_clear_delegation_stateid shouldn't trust NFS_DELEGATED_STATE (Steve Dickson) [1166845]
- [fs] NFSv4: Fix races between nfs_remove_bad_delegation() and delegation return (Steve Dickson) [1166845]
- [fs] NFS: Don't try to reclaim delegation open state if recovery failed (Steve Dickson) [1166845]
- [fs] NFSv4: Ensure that we call FREE_STATEID when NFSv4.x stateids are revoked (Steve Dickson) [1166845]
- [fs] NFSv4: Ensure that we remove NFSv4.0 delegations when state has expired (Steve Dickson) [1166845]

* Wed Dec 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-218.el7]
- [scsi] cxgb4i: Don't block unload/cxgb4 unload when remote closes TCP connection (Sai Vemuri) [1169941]
- [kernel] kthread: partial revert of 81c98869faa5 ("kthread: ensure locality of task_struct allocations") (Gustavo Duarte) [953583]
- [mm] slub: fall back to node_to_mem_node() node if allocating on memoryless node (Gustavo Duarte) [953583]
- [mm] topology: add support for node_to_mem_node() to determine the fallback node (Gustavo Duarte) [953583]
- [mm] slub: search partial list on numa_mem_id(), instead of numa_node_id() (Gustavo Duarte) [953583]
- [kernel] kthread: ensure locality of task_struct allocations (Gustavo Duarte) [953583]
- [md] dm-thin: fix missing out-of-data-space to write mode transition if blocks are released (Mike Snitzer) [1173181]
- [md] dm-thin: fix inability to discard blocks when in out-of-data-space mode (Mike Snitzer) [1173181]
- [wireless] iwlwifi/mvm: update values for Smart Fifo (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/dvm: fix flush support for old firmware (Stanislaw Gruszka) [1155538]
- [wireless] ath5k: fix hardware queue index assignment (Stanislaw Gruszka) [1155538]
- [wireless] ath9k: fix BE/BK queue order (Stanislaw Gruszka) [1155538]
- [wireless] ath9k_hw: fix hardware queue allocation (Stanislaw Gruszka) [1155538]
- [wireless] ath9k: Fix RTC_DERIVED_CLK usage (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: do not align payload on modern H/W (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: Fix regression that triggers a kernel BUG with CCMP (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: fix RFkill while calibrating (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: fix use-after-free in defragmentation (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: properly flush delayed scan work on interface removal (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: schedule the actual switch of the station before CSA count 0 (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: use secondary channel offset IE also beacons during CSA (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: add new rt2800usb device (Stanislaw Gruszka) [1155538]
- [wireless] Revert: iwlwifi/mvm: treat EAPOLs like mgmt frames wrt rate (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/dvm: drop non VO frames when flushing (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: configure the LTR (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: fix typo in starting baserate for rts_cts_rate_idx (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: add new rt2800usb devices (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: support Ralink 5362 (Stanislaw Gruszka) [1155538]
- [wireless] Revert: ath9k: reduce ANI firstep range for older chips (Stanislaw Gruszka) [1155538]
- [wireless] rt2800: correct BBP1_TX_POWER_CTRL mask (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: Add missing PCI IDs for the 7260 series (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: disable BT Co-running by default (Stanislaw Gruszka) [1155538]
- [wireless] nl80211: clear skb cb before passing to netlink (Stanislaw Gruszka) [1155538]
- [wireless] ath9k/htc: fix random decryption failure (Stanislaw Gruszka) [1155538]
- [wireless] brcmfmac: handle IF event for P2P_DEVICE interface (Stanislaw Gruszka) [1155538]
- [wireless] Revert: mac80211: disable uAPSD if all ACs are under ACM (Stanislaw Gruszka) [1155538]
- [wireless] rtlwifi/rtl8192cu: Add new ID (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: set MAC_FILTER_IN_BEACON correctly for STA/P2P client (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: treat EAPOLs like mgmt frames wrt rate (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: increase DEFAULT_MAX_TX_POWER (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: fix endianity issues with Smart Fifo commands (Stanislaw Gruszka) [1155538]
- [wireless] Revert: iwlwifi/dvm: don't enable CTS to self (Stanislaw Gruszka) [1155538]
- [wireless] carl9170: fix sending URBs with wrong type when using full-speed (Stanislaw Gruszka) [1155538]

* Fri Dec 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-217.el7]
- [net] ipv6: yet another new IPV6_MTU_DISCOVER option IPV6_PMTUDISC_OMIT (Hannes Frederic Sowa) [1170116]
- [net] ipv4: yet another new IP_MTU_DISCOVER option IP_PMTUDISC_OMIT (Hannes Frederic Sowa) [1170116]
- [net] ipv4: use ip_skb_dst_mtu to determine mtu in ip_fragment (Hannes Frederic Sowa) [1170116]
- [net] ipv4: introduce ip_dst_mtu_maybe_forward and protect forwarding path against pmtu spoofing (Hannes Frederic Sowa) [1170116]
- [net] ipv6: move ip6_sk_accept_pmtu from generic pmtu update path to ipv6 one (Hannes Frederic Sowa) [1170116]
- [net] ipv6: support IPV6_PMTU_INTERFACE on sockets (Hannes Frederic Sowa) [1170116]
- [net] udp: do not report ICMP redirects to user space (Hannes Frederic Sowa) [1170116]
- [net] ipv4: new ip_no_pmtu_disc mode to always discard incoming frag needed msgs (Hannes Frederic Sowa) [1170116]
- [net] inet: make no_pmtu_disc per namespace and kill ipv4_config (Hannes Frederic Sowa) [1170116]
- [net] ipv4: improve documentation of ip_no_pmtu_disc (Hannes Frederic Sowa) [1170116]
- [net] ipv4: introduce new IP_MTU_DISCOVER mode IP_PMTUDISC_INTERFACE (Hannes Frederic Sowa) [1170116]
- [net] xfrm: revert ipv4 mtu determination to dst_mtu (Hannes Frederic Sowa) [1170116]
- [net] xfrm: introduce helper for safe determination of mtu (Hannes Frederic Sowa) [1170116]
- [net] netfilter: conntrack: disable generic tracking for known protocols (Daniel Borkmann) [1170520]
- [net] gre: Fix use-after-free panic in ipgre_rcv() (Panu Matilainen) [1117543]
- [net] netfilter: nf_conntrack_h323: lookup route from proper net namespace (Florian Westphal) [1163847]
- [net] netfilter: xt_tcpmss: lookup route from proper net namespace (Florian Westphal) [1163847]
- [net] netfilter: xt_tcpmss: Get mtu only if clamp-mss-to-pmtu is specified (Florian Westphal) [1163847]
- [wireless] cfg80211: don't WARN about two consecutive Country IE hint (Stanislaw Gruszka) [1164282]
- [fs] aio: fix race between aio event completion and reaping (Jeff Moyer) [1131312]
- [fs] proc/task_mmu: fix missing check during hugepage migration (Jacob Tanenbaum) [1105040] {CVE-2014-3940}
- [kernel] trace: insufficient syscall number validation in perf and ftrace subsystems (Jacob Tanenbaum) [1161570] {CVE-2014-7825 CVE-2014-7826}
- [ethernet] i40e: get pf_id from HW rather than PCI function (Stefan Assmann) [1078740]
- [ethernet] i40e: increase ARQ size (Stefan Assmann) [1078740]
- [x86] uv: Update the UV3 TLB shootdown logic (Frank Ramsay) [1170253]
- [tools] peeksiginfo: add PAGE_SIZE definition (Steve Best) [1172250]
- [base] bus: Fix unbalanced device reference in drivers_probe (Alex Williamson) [1158862]
- [char] tpm: Fix NULL return in tpm_ibmvtpm_get_desired_dma (Gustavo Duarte) [1154818]
- [powerpc] kvm: book3s_hv - Reserve cma region only in hypervisor mode (Gustavo Duarte) [1147740]
- [x86] traps: stop using IST for #SS (Petr  Matousek) [1172813] {CVE-2014-9322}

* Tue Dec 09 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-216.el7]
- [acpi] Revert: hotplug/pci: Simplify disable_slot() (Prarit Bhargava) [1158720]
- [infiniband] iser: Adjust data_length to include protection information (Amir Vadai) [1107622]
- [infiniband] iser: Bump version to 1.4.1 (Amir Vadai) [1107622]
- [infiniband] iser: Allow bind only when connection state is UP (Amir Vadai) [1107622]
- [infiniband] iser: Fix RX/TX CQ resource leak on error flow (Amir Vadai) [1107622]
- [infiniband] iser: Clarify a duplicate counters check (Amir Vadai) [1107622]
- [infiniband] iser: Replace connection waitqueue with completion object (Amir Vadai) [1107622]
- [infiniband] iser: Protect iser state machine with a mutex (Amir Vadai) [1107622]
- [infiniband] iser: Remove redundant return code in iser_free_ib_conn_res() (Amir Vadai) [1107622]
- [infiniband] iser: Seperate iser_conn and iscsi_endpoint storage space (Amir Vadai) [1107622]
- [infiniband] iser: Fix responder resources advertisement (Amir Vadai) [1107622]
- [infiniband] iser: Add TIMEWAIT_EXIT event handling (Amir Vadai) [1107622]
- [infiniband] iser: Support IPv6 address family (Amir Vadai) [1107622]
- [infiniband] iser: Bump version to 1.4 (Amir Vadai) [1107622]
- [infiniband] iser: Add missing newlines to logging messages (Amir Vadai) [1107622]
- [infiniband] iser: Fix a possible race in iser connection states transition (Amir Vadai) [1107622]
- [infiniband] iser: Simplify connection management (Amir Vadai) [1107622]
- [infiniband] iser: Bump driver version to 1.3 (Amir Vadai) [1107622]
- [infiniband] iser: Update Mellanox copyright note (Amir Vadai) [1107622]
- [infiniband] iser: Print QP information once connection is established (Amir Vadai) [1107622]
- [infiniband] iser: Remove struct iscsi_iser_conn (Amir Vadai) [1107622]
- [infiniband] iser: Drain the tx cq once before looping on the rx cq (Amir Vadai) [1107622]
- [infiniband] iser: Fix sector_t format warning (Amir Vadai) [1107622]
- [infiniband] iser: Publish T10-PI support to SCSI midlayer (Amir Vadai) [1107622]
- [infiniband] iser: Implement check_protection (Amir Vadai) [1107622]
- [infiniband] iser: Support T10-PI operations (Amir Vadai) [1107622]
- [infiniband] iser: Initialize T10-PI resources (Amir Vadai) [1107622]
- [infiniband] iser: Introduce pi_enable, pi_guard module parameters (Amir Vadai) [1107622]
- [infiniband] iser: Generalize fall_to_bounce_buf routine (Amir Vadai) [1107622]
- [infiniband] iser: Generalize iser_unmap_task_data and finalize_rdma_unaligned_sg (Amir Vadai) [1107622]
- [infiniband] iser: Replace fastreg descriptor valid bool with indicators container (Amir Vadai) [1107622]
- [infiniband] iser: Keep IB device attributes under iser_device (Amir Vadai) [1107622]
- [infiniband] iser: Move fast_reg_descriptor initialization to a function (Amir Vadai) [1107622]
- [infiniband] iser: Push the decision what memory key to use into fast_reg_mr routine (Amir Vadai) [1107622]
- [infiniband] iser: Avoid FRWR notation, use fastreg instead (Amir Vadai) [1107622]
- [infiniband] iser: Suppress completions for fast registration work requests (Amir Vadai) [1107622]
- [infiniband] iser: Fix use after free in iser_snd_completion() (Amir Vadai) [1107622]
- [scsi] libiscsi: Add check_protection callback for transports (Amir Vadai) [1107622]
- [mm] mem-hotplug: reset node present pages when hot-adding a new pgdat (Motohiro Kosaki) [1156396]
- [mm] mem-hotplug: reset node managed pages when hot-adding a new pgdat (Motohiro Kosaki) [1156396]
- [mm] make __free_pages_bootmem() only available at boot time (Motohiro Kosaki) [1156396]
- [mm] use a dedicated lock to protect totalram_pages and zone->managed_pages (Motohiro Kosaki) [1156396]
- [mm] accurately calculate zone->managed_pages for highmem zones (Motohiro Kosaki) [1156396]
- [md] dm-cache: fix spurious cell_defer when dealing with partial block at end of device (Mike Snitzer) [1165050]
- [md] dm-cache: dirty flag was mistakenly being cleared when promoting via overwrite (Mike Snitzer) [1165050]
- [md] dm-cache: only use overwrite optimisation for promotion when in writeback mode (Mike Snitzer) [1165050]
- [md] dm-cache: discard block size must be a multiple of cache block size (Mike Snitzer) [1165050]
- [md] dm-cache: fix a harmless race when working out if a block is discarded (Mike Snitzer) [1165050]
- [md] dm-cache: when reloading a discard bitset allow for a different discard block size (Mike Snitzer) [1165050]
- [md] dm-cache: fix some issues with the new discard range support (Mike Snitzer) [1165050]
- [md] dm-array: if resizing the array is a noop set the new root to the old one (Mike Snitzer) [1165050]
- [md] dm-bufio: fix memleak when using a dm_buffer's inline bio (Mike Snitzer) [1165050]
- [md] dm: use rcu_dereference_protected instead of rcu_dereference (Mike Snitzer) [1165246]
- [md] dm-thin: suspend/resume active thin devices when reloading thin-pool (Mike Snitzer) [1165246]
- [md] dm-thin: do not allow thin device activation while pool is suspended (Mike Snitzer) [1165246]
- [md] dm-thin: fix a race in thin_dtr (Mike Snitzer) [1165246]
- [md] dm-thin: remove stale 'trim' message in block comment above pool_message (Mike Snitzer) [1165246]
- [md] dm: update wait_on_bit calls for RHEL (Mike Snitzer) [1165246]
- [md] dm: enhance internal suspend and resume interface (Mike Snitzer) [1165246]
- [md] dm: add presuspend_undo hook to target_type (Mike Snitzer) [1165246]
- [md] dm: return earlier from dm_blk_ioctl if target doesn't implement .ioctl (Mike Snitzer) [1165246]
- [md] dm: do not call dm_sync_table() when creating new devices (Mike Snitzer) [1165246]
- [md] dm: sparse - Annotate field with __rcu for checking (Mike Snitzer) [1165246]
- [md] dm: Use rcu_dereference() for accessing rcu pointer (Mike Snitzer) [1165246]
- [md] dm: allow active and inactive tables to share dm_devs (Mike Snitzer) [1165246]
- [md] dm-mpath: stop queueing IO when no valid paths exist (Mike Snitzer) [1165246]

* Mon Dec 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-215.el7]
- [net] vxlan: Do not reuse sockets for a different address family (Marcelo Leitner) [1146107]
- [net] vti: Fix kernel panic due to tunnel not being removed on link deletion (Panu Matilainen) [1167725]
- [net] sctp: test if association is dead in sctp_wake_up_waiters (Daniel Borkmann) [1166467]
- [net] sctp: wake up all assocs if sndbuf policy is per socket (Daniel Borkmann) [1166467]
- [net] ip: better estimate tunnel header cut for correct ufo handling (Alexander Duyck) [1159577]
- [net] ipv6: gso: remove redundant locking (Alexander Duyck) [1159577]
- [net] ipv6: Do not treat a GSO_TCPV4 request from UDP tunnel over IPv6 as invalid (Alexander Duyck) [1159577]
- [net] ipv6: fib: fix fib dump restart (Panu Matilainen) [1163605]
- [net] ipv6: drop unused fib6_clean_all_ro() function and rt6_proc_arg struct (Panu Matilainen) [1163605]
- [net] ipv6: avoid high order memory allocations for /proc/net/ipv6_route (Panu Matilainen) [1163605]
- [net] ipv4: Fix incorrect error code when adding an unreachable route (Panu Matilainen) [1165552]
- [net] sctp: replace seq_printf with seq_puts (Daniel Borkmann) [1164214]
- [net] sctp: add transport state in /proc/net/sctp/remaddr (Daniel Borkmann) [1164214]
- [IB] isert: Adjust CQ size to HW limits (Andy Grover) [1166314]
- [ib_isert] Add max_send_sge=2 minimum for control PDU responses (Andy Grover) [1166314]
- [scsi] megaraid_sas: do not process IOCTLs and SCSI commands during driver removal (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: dndinaness related bug fixes (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: corrected return of wait_event from abort frame path (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: make HBA operational after LD_MAP_SYNC DCMD in OCR path (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: online Firmware upgrade support for Extended VD feature (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: update MAINTAINERS and copyright information for megaraid drivers (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: driver version upgrade and remove some meta data of driver (06.805.06.01-rc1) (Tomas Henzl) [1162645]

* Mon Dec 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-214.el7]
- [powerpc] Drop useless warning in eeh_init() (Gustavo Duarte) [1156651]
- [powerpc] pseries: Decrease message level on EEH initialization (Gustavo Duarte) [1156651]
- [net] ceph: fixup includes in pagelist.h (Ilya Dryomov) [1165232]
- [net] ceph: change from BUG to WARN for __remove_osd() asserts (Ilya Dryomov) [1165232]
- [net] ceph: clear r_req_lru_item in __unregister_linger_request() (Ilya Dryomov) [1165232]
- [net] ceph: unlink from o_linger_requests when clearing r_osd (Ilya Dryomov) [1165232]
- [net] ceph: do not crash on large auth tickets (Ilya Dryomov) [1165232]
- [fs] ceph: fix flush tid comparision (Ilya Dryomov) [1165232]
- [net] ceph: eliminate unnecessary allocation in process_one_ticket() (Ilya Dryomov) [1165232]
- [block] rbd: Fix error recovery in rbd_obj_read_sync() (Ilya Dryomov) [1165232]
- [net] ceph: use memalloc flags for net IO (Ilya Dryomov) [1165232]
- [block] rbd: use a single workqueue for all devices (Ilya Dryomov) [1165232]
- [fs] ceph: fix divide-by-zero in __validate_layout() (Ilya Dryomov) [1165232]
- [block] rbd: rbd workqueues need a resque worker (Ilya Dryomov) [1165232]
- [net] ceph: ceph-msgr workqueue needs a resque worker (Ilya Dryomov) [1165232]
- [fs] ceph: fix bool assignments (Ilya Dryomov) [1165232]
- [net] ceph: separate multiple ops with commas in debugfs output (Ilya Dryomov) [1165232]
- [net] ceph: sync osd op definitions in rados.h (Ilya Dryomov) [1165232]
- [net] ceph: remove redundant declaration (Ilya Dryomov) [1165232]
- [fs] ceph: additional debugfs output (Ilya Dryomov) [1165232]
- [fs] ceph: export ceph_session_state_name function (Ilya Dryomov) [1165232]
- [fs] ceph: use pagelist to present MDS request data (Ilya Dryomov) [1165232]
- [net] ceph: reference counting pagelist (Ilya Dryomov) [1165232]
- [fs] ceph: fix llistxattr on symlink (Ilya Dryomov) [1165232]
- [fs] ceph: send client metadata to MDS (Ilya Dryomov) [1165232]
- [fs] ceph: remove redundant code for max file size verification (Ilya Dryomov) [1165232]
- [fs] ceph: move ceph_find_inode() outside the s_mutex (Ilya Dryomov) [1165232]
- [fs] ceph: request xattrs if xattr_version is zero (Ilya Dryomov) [1165232]
- [block] rbd: set the remaining discard properties to enable support (Ilya Dryomov) [1165232]
- [block] rbd: use helpers to handle discard for layered images correctly (Ilya Dryomov) [1165232]
- [block] rbd: extract a method for adding object operations (Ilya Dryomov) [1165232]
- [block] rbd: make discard trigger copy-on-write (Ilya Dryomov) [1165232]
- [block] rbd: tolerate -ENOENT for discard operations (Ilya Dryomov) [1165232]
- [block] rbd: fix snapshot context reference count for discards (Ilya Dryomov) [1165232]
- [block] rbd: read image size for discard check safely (Ilya Dryomov) [1165232]
- [block] rbd: initial discard bits (Ilya Dryomov) [1165232]
- [block] rbd: extend the operation type (Ilya Dryomov) [1165232]
- [block] rbd: skip the copyup when an entire object writing (Ilya Dryomov) [1165232]
- [block] rbd: add img_obj_request_simple() helper (Ilya Dryomov) [1165232]
- [block] rbd: access snapshot context and mapping size safely (Ilya Dryomov) [1165232]
- [block] rbd: do not return -ERANGE on auth failures (Ilya Dryomov) [1165232]
- [net] ceph: don't try checking queue_work() return value (Ilya Dryomov) [1165232]
- [fs] ceph: make sure request isn't in any waiting list when kicking request (Ilya Dryomov) [1165232]
- [fs] ceph: protect kick_requests() with mdsc->mutex (Ilya Dryomov) [1165232]
- [net] ceph: Convert pr_warning to pr_warn (Ilya Dryomov) [1165232]
- [fs] ceph: trim unused inodes before reconnecting to recovering MDS (Ilya Dryomov) [1165232]
- [net] ceph: fix a use after free issue in osdmap_set_max_osd (Ilya Dryomov) [1165232]
- [net] ceph: select CRYPTO_CBC in addition to CRYPTO_AES (Ilya Dryomov) [1165232]
- [net] ceph: resend lingering requests with a new tid (Ilya Dryomov) [1165232]
- [net] ceph: abstract out ceph_osd_request enqueue logic (Ilya Dryomov) [1165232]
- [block] rbd: fix error return code in rbd_dev_device_setup() (Ilya Dryomov) [1165232]
- [block] rbd: avoid format-security warning inside alloc_workqueue() (Ilya Dryomov) [1165232]
- [kernel] printk/register_console: prevent adding the same console twice (Artem Savkov) [1169766]
- [mm] hugetlb: add cond_resched_lock() in, return_unused_surplus_pages() (Motohiro Kosaki) [1142698]
- [mm] hugetlb: fix softlockup when a large number of, hugepages are freed (Motohiro Kosaki) [1142698]
- [kernel] sched: Use new KABI macros (Don Zickus) [1164383]
- [net] Use new KABI macros (Don Zickus) [1164383]
- [scsi] Use new KABI macros (Don Zickus) [1164383]
- [kernel] Use new KABI macros (Don Zickus) [1164383]
- [block] Use new KABI macros (Don Zickus) [1164383]
- [block] include: Use new KABI macros (Don Zickus) [1164383]
- [misc] Use new KABI macros (Don Zickus) [1164383]
- [x86] Use new KABI macros (Don Zickus) [1164383]
- [powerpc] Use new KABI macros (Don Zickus) [1164383]

* Wed Dec 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-213.el7]
- [scsi] ipr: don't log error messages when applications issues illegal requests (Gustavo Duarte) [1163019]
- [net] macvlan: Allow setting multicast filter on all macvlan types (Vlad Yasevich) [848197]
- [block] genhd: fix leftover might_sleep() in blk_free_devt() (Jeff Moyer) [1167728]
- [ethernet] mlx4: Add VXLAN ndo calls to the PF net device ops too (Florian Westphal) [1168212]
- [powerpc] xmon: le - Fix endiannes issue in RTAS call from xmon (Steve Best) [1160650]
- [mm] thp: close race between split and zap huge pages (Seth Jennings) [1165268]
- [mm] thp: close race between mremap() and split_huge_page() (Seth Jennings) [1165268]
- [mmc] rtsx: Change default tx phase (Don Zickus) [1106204]
- [mfd] rtsx: Copyright modifications (Don Zickus) [1106204]
- [mfd] rtsx: Configure to enter a deeper power-saving mode in S3 (Don Zickus) [1106204]
- [mfd] rtsx: Move some actions from rtsx_pci_init_hw to individual extra_init_hw (Don Zickus) [1106204]
- [mfd] rtsx: Add shutdown callback in rtsx_pci_driver (Don Zickus) [1106204]
- [mfd] rtsx: Read vendor setting from config space (Don Zickus) [1106204]
- [mfd] rtsx: Add support for RTL8411B (Don Zickus) [1106204]

* Mon Dec 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-212.el7]
- [fs] fsnotify: next_i is freed during fsnotify_unmount_inodes (Eric Sandeen) [1124997]
- [fs] btrfs: fix regression of btrfs device replace (Eric Sandeen) [1162983]
- [fs] ext4: don't count external journal blocks as overhead (Eric Sandeen) [1164366]
- [fs] Fix oops when creating symlinks on smb3 (Sachin Prabhu) [1161429]

* Wed Nov 26 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-211.el7]
- [net] sctp: fix memory leak in auth key management (Daniel Borkmann) [1160928]
- [net] sctp: fix NULL pointer dereference in af->from_addr_param on malformed packet (Daniel Borkmann) [1154002] {CVE-2014-7841}
- [net] tcp: zero retrans_stamp if all retrans were acked (Marcelo Leitner) [1162193]
- [net] netfilter: log: protect nf_log_register against double registering (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: ulog: compat with new structure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: nat expression must select CONFIG_NF_NAT (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: add explicit Kconfig for NETFILTER_XT_NAT (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: masquerading needs to be independent of x_tables in Kconfig (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: NFT_CHAIN_NAT_IPV* is independent of NFT_NAT (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: move NAT Kconfig switches out of the iptables scope (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: NETFILTER_XT_TARGET_LOG selects NF_LOG_* (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: fix several Kconfig problems in NF_LOG_* (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_masq: register/unregister notifiers on module init/exit (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: allow to filter from prerouting and postrouting (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_compat: remove incomplete 32/64 bits arch compat code (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: wait for call_rcu completion on module removal (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_reject: introduce icmp code abstraction for inet and bridge (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: store and dump set policy (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: export rule-set generation ID (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add NFTA_MASQ_UNSPEC to nft_masq_attributes (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add new nft_masq expression (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_nat: include a flag attribute (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: extend NFT_MSG_DELTABLE to support flushing the ruleset (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add helpers to schedule objects deletion (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add devgroup support in meta expresion (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: rename nf_table_delrule_by_chain() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add helper to unregister chain hooks (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: refactor rule deletion helper (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_chain_nat_ipv6: use generic IPv6 NAT code from core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nat: move specific NAT IPv6 to core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_rbtree: no need for spinlock from set destroy path (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_hash: no need for rcu in the hash set destroy path (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_nat: generalize IPv6 masquerading support for nf_tables (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_nat: generalize IPv4 masquerading support for nf_tables (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_chain_nat_ipv4: use generic IPv4 NAT code from core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nat: move specific NAT IPv4 to core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_meta: Add cpu attribute support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_meta: add pkttype support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix error return code (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: don't update chain with unset counters (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: uninitialize element key/data from the commit path (Marcelo Leitner) [1148041 1155088]
- [net] nftables: Convert nft_hash to use generic rhashtable (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Avoid duplicate call to nft_data_uninit() for same key (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: check for unset NFTA_SET_ELEM_LIST_ELEMENTS attribute (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: simplify set dump through netlink (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: bridge: add reject support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: 64bit stats need some extra synchronization (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: set NLM_F_DUMP_INTR if netlink dumping is stale (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: safe RCU iteration on list when dumping (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: skip transaction if no update flags in tables (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_log: fix coccinelle warnings (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_log: complete logging support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_log: request explicit logger when loading rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_nat: don't dump port information if unset (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: indicate family when dumping set elements (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_compat: call {target, match}->destroy() to cleanup entry (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix wrong type in transaction when replacing rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: decrement chain use counter when replacing rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use u32 for chain use counter (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use RCU-safe list insertion when replacing rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: atomic allocation in set notifications from rcu callback (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: allow to delete several objects from a batch (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_rbtree: introduce locking (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: release objects in reverse order in the abort path (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix wrong transaction ordering in set elements (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: defer all object release via rcu (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: remove skb and nlh from context structure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: simplify nf_tables_*_notify (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle elements (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle table (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: pass context to nf_tables_updtable() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: disabling table hooks always succeeds (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle chain (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: refactor chain statistic routines (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle sets (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add message type to transactions (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: relocate commit and abort routines in the source file (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: generalise transaction infrastructure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: deconstify table and chain in context structure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix trace of matching non-terminal rule (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix missing return trace at the end of non-base chain (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix bogus rulenum after goto action (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix tracing of the goto action (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix goto action (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: reset rule number counter after jump and goto (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: add helper for adding nat extension (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: relax string validation of NFTA_CHAIN_TYPE (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Add meta expression key for bridge interface name (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Make meta expression core functions public (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Stack expression type depending on their family (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix nft_cmp_fast failure on big endian for size < 4 (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: handle more than 8 * PAGE_SIZE set name allocations (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix wrong format in request_module() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: set names cannot be larger than 15 bytes (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add set_elem notifications (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_hash: use set global element counter instead of private one (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: implement proper set selection (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: split nft_ct_init() into two functions for get/set (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_meta: split nft_meta_init() into two functions for get/set (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: add missing ifdef for NFT_MARK setting (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: Add missing vmalloc.h include to nft_hash.c (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_nat: fix family validation (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: remove family from struct nft_ct (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: restore notifications for anonymous set destruction (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: restore context for expression destructors (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: clean up nf_tables_trans_add() argument order (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_hash: bug fixes and resizing (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add optional user data area to rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: accept QUEUE/DROP verdict parameters (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add nft_dereference() macro (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: labels get support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_nat: add full port randomization support (Marcelo Leitner) [1148041 1155088]
- [net] nf_tables: Include appropriate header file in netfilter/nft_lookup.c (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: xt_log: add missing string format in nf_log_packet() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: log: nf_log_packet() as real unified interface (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: log: split family specific code to nf_log_{ip, ip6, common}.c files (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_log: move log buffering to core logging (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_log: use an array of loggers instead of list (Marcelo Leitner) [1148041 1155088]
- [net] introduce netdev_alloc_pcpu_stats() for drivers (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nfnetlink: add rcu_dereference_protected() helpers (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: ip_set: rename nfnl_dereference()/nfnl_set() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: ipset: remove unused code (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: Remove extern from function prototypes (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: Remove extern from function prototypes (Marcelo Leitner) [1148041 1155088]
- [net] openvswitch: remove dup comment in vport.h (Jiri Benc) [1110384]
- [net] openvswitch: restore OVS_FLOW_CMD_NEW notifications (Jiri Benc) [1110384]
- [net] openvswitch: Add recirc and hash action (Jiri Benc) [1110384]
- [net] openvswitch: simplify sample action implementation (Jiri Benc) [1110384]
- [net] openvswitch: Use tun_key only for egress tunnel path (Jiri Benc) [1110384]
- [net] openvswitch: refactor ovs flow extract API (Jiri Benc) [1110384]
- [net] openvswitch: Remove pkt_key from OVS_CB (Jiri Benc) [1110384]
- [net] openvswitch: change the data type of error status to atomic_long_t (Jiri Benc) [1110384]
- [net] genetlink: add function genl_has_listeners() (Jiri Benc) [1110384]
- [net] vxlan: Call udp_flow_src_port (Jiri Benc) [1110384]
- [net] udp: Add function to make source port for UDP tunnels (Jiri Benc) [1110384]
- [net] openvswitch: distinguish between the dropped and consumed skb (Jiri Benc) [1110384]
- [net] openvswitch: fix a memory leak (Jiri Benc) [1110384]
- [net] openvswitch: Fix memory leak in ovs_vport_alloc() error path (Jiri Benc) [1110384]
- [net] openvswitch: fix duplicate #include headers (Jiri Benc) [1110384]
- [net] openvswitch: Remove unlikely() for WARN_ON() conditions (Jiri Benc) [1110384]
- [net] openvswitch: Use IS_ERR_OR_NULL (Jiri Benc) [1110384]
- [net] openvswitch: Add skb_clone NULL check for the sampling action (Jiri Benc) [1110384]
- [net] openvswitch: Sample action without side effects (Jiri Benc) [1110384]
- [net] openvswitch: Avoid memory corruption in queue_userspace_packet() (Jiri Benc) [1110384]
- [net] openvswitch: Enable tunnel GSO for OVS bridge (Jiri Benc) [1110384]
- [net] openvswitch: Allow each vport to have an array of 'port_id's (Jiri Benc) [1110384]
- [net] openvswitch: make generic netlink group const (Jiri Benc) [1110384]
- [net] openvswitch: introduce rtnl ops stub (Jiri Benc) [1110384]
- [net] openvswitch: Use exact lookup for flow_get and flow_del (Jiri Benc) [1110384]
- [net] openvswitch: Fix tracking of flags seen in TCP flows (Jiri Benc) [1110384]
- [net] openvswitch: supply a dummy err_handler of gre_cisco_protocol to prevent kernel crash (Jiri Benc) [1110384]
- [net] openvswitch: Fix a double free bug for the sample action (Jiri Benc) [1110384]
- [net] openvswitch: Simplify genetlink code (Jiri Benc) [1110384]
- [net] openvswitch: Minimize ovs_flow_cmd_new (Jiri Benc) [1110384]
- [net] openvswitch: Split ovs_flow_cmd_new_or_set() (Jiri Benc) [1110384]
- [net] openvswitch: Minimize ovs_flow_cmd_del critical section (Jiri Benc) [1110384]
- [net] openvswitch: Reduce locking requirements (Jiri Benc) [1110384]
- [net] openvswitch: Fix ovs_flow_stats_get/clear RCU dereference (Jiri Benc) [1110384]
- [net] openvswitch: Fix typo (Jiri Benc) [1110384]
- [net] openvswitch: Minimize dp and vport critical sections (Jiri Benc) [1110384]
- [net] openvswitch: Make flow mask removal symmetric (Jiri Benc) [1110384]
- [net] openvswitch: Build flow cmd netlink reply only if needed (Jiri Benc) [1110384]
- [net] openvswitch: Clarify locking (Jiri Benc) [1110384]
- [net] openvswitch: Avoid assigning a NULL pointer to flow actions (Jiri Benc) [1110384]
- [net] openvswitch: Compact sw_flow_key (Jiri Benc) [1110384]
- [net] net/openvswitch: Use with RCU_INIT_POINTER(x, NULL) in vport-gre.c (Jiri Benc) [1110384]
- [net] openvswitch: Use TCP flags in the flow key for stats (Jiri Benc) [1110384]
- [net] openvswitch: Fix output of SCTP mask (Jiri Benc) [1110384]
- [net] openvswitch: Per NUMA node flow stats (Jiri Benc) [1110384]
- [net] openvswitch: Remove 5-tuple optimization (Jiri Benc) [1110384]
- [net] openvswitch: Use ether_addr_copy (Jiri Benc) [1110384]
- [net] openvswitch: flow_netlink: Use pr_fmt to OVS_NLERR output (Jiri Benc) [1110384]
- [net] openvswitch: Use net_ratelimit in OVS_NLERR (Jiri Benc) [1110384]
- [net] openvswitch: Added (unsigned long long) cast in printf (Jiri Benc) [1110384]
- [net] openvswitch: avoid cast-qual warning in vport_priv (Jiri Benc) [1110384]
- [net] openvswitch: avoid warnings in vport_from_priv (Jiri Benc) [1110384]
- [net] openvswitch: use const in some local vars and casts (Jiri Benc) [1110384]
- [net] openvswitch: get rid of SET_ETHTOOL_OPS (Jiri Benc) [1110384]
- [net] openvswitch: Correctly report flow used times for first 5 minutes after boot (Jiri Benc) [1110384]
- [net] openvswitch: Fix race (Jiri Benc) [1110384]
- [net] openvswitch: Read tcp flags only then the tranport header is present (Jiri Benc) [1110384]
- [net] openvswitch: rename ->sync to ->syncp (Jiri Benc) [1110384]
- [net] openvswitch: make functions local (Jiri Benc) [1110384]
- [net] Add utility function to copy skb hash (Jiri Benc) [1110384]
- [net] Change skb_get_rxhash to skb_get_hash (Jiri Benc) [1110384]
- [net] netlink: Re-add locking to netlink_lookup() and seq walker (Jiri Benc) [1140661]
- [lib] rhashtable: remove second linux/log2.h inclusion (Jiri Benc) [1140661]
- [lib] rhashtable: allow user to set the minimum shifts of shrinking (Jiri Benc) [1140661]
- [lib] rhashtable: fix lockdep splat in rhashtable_destroy() (Jiri Benc) [1140661]
- [lib] rhashtable: Spelling s/compuate/compute/ (Jiri Benc) [1140661]
- [net] netlink: Annotate RCU locking for seq_file walker (Jiri Benc) [1140661]
- [net] netlink: hold nl_sock_hash_lock during diag dump (Jiri Benc) [1140661]
- [net] netlink: fix lockdep splats (Jiri Benc) [1140661]
- [net] netlink: Convert netlink_lookup() to use RCU protected hash table (Jiri Benc) [1140661]
- [net] netlink: make compare exist all the time (Jiri Benc) [1140661]
- [net] netlink: Add compare function for netlink_table (Jiri Benc) [1140661]
- [lib] rhashtable: fix annotations for rht_for_each_entry_rcu() (Jiri Benc) [1140661]
- [lib] rhashtable: unexport and make rht_obj() static (Jiri Benc) [1140661]
- [lib] rhashtable: RCU annotations for next pointers (Jiri Benc) [1140661]
- [lib] rhashtable: Resizable, Scalable, Concurrent Hash Table (Jiri Benc) [1140661]
- [mm] add kvfree() (Jiri Benc) [1140661]
- [net] netlink: Fix handling of error from netlink_dump() (Jiri Benc) [1140661]
- [net] netlink: autosize skb lengthes (Jiri Benc) [1140661]
- [net] netlink: Eliminate kmalloc in netlink dump operation (Jiri Benc) [1140661]

* Mon Nov 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-210.el7]
- [misc] kabi: revert two kabi additions that need updated ppc64 sums (Jarod Wilson)

* Mon Nov 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-209.el7]
- [fs] xfs: write failure beyond EOF truncates too much data (Brian Foster) [1032968]
- [fs] xfs: xfs_vm_write_end truncates too much on failure (Brian Foster) [1032968]
- [fs] xfs: use ->invalidatepage() length argument (Brian Foster) [1032968]
- [fs] xfs: change invalidatepage prototype to accept length (Brian Foster) [1032968]
- [fs] xfs: restore buffer_head unwritten bit on ioend cancel (Brian Foster) [1162953]
- [fs] xfs: allow inode allocations in post-growfs disk space (Eric Sandeen) [1115201]
- [scsi] pm8001: Update nvmd response data to request buffer (Rich Bono) [1110943]
- [scsi] pm8001: fix pm8001_store_update_fw (Rich Bono) [1110943]
- [scsi] pm8001: Fix erratic calculation in update_flash (Rich Bono) [1110943]
- [scsi] pm8001: Fix invalid return when request_irq() failed (Rich Bono) [1110943]
- [scsi] pm8001: fix a memory leak in nvmd_resp (Rich Bono) [1110943]
- [scsi] pm8001: fix update_flash (Rich Bono) [1110943]
- [scsi] pm8001: fix a memory leak in flash_update (Rich Bono) [1110943]
- [scsi] pm8001: Cleaning up uninitialized variables (Rich Bono) [1110943]
- [scsi] pm8001: Fix to remove null pointer checks that could never happen (Rich Bono) [1110943]
- [scsi] pm8001: more fixes to honor return value (Rich Bono) [1110943]
- [scsi] pm8001: add a new spinlock to protect the CCB (Rich Bono) [1110943]
- [scsi] pm8001: honor return value (Rich Bono) [1110943]
- [scsi] pm8001: clean bitmap management functions (Rich Bono) [1110943]
- [scsi] pm8001: Fix hibernation issue (Rich Bono) [1110943]
- [scsi] pm8001: Fix potential null pointer dereference and memory leak (Rich Bono) [1110943]
- [scsi] pm80xx: Fix missing NULL pointer checks and memory leaks (Rich Bono) [1110943]
- [scsi] drivers/scsi/pm8001/pm8001_ctl.c: avoid world-writable sysfs files (Rich Bono) [1110943]
- [scsi] pm80xx: fix problem of pm8001_work_fn reseting incorrect phy device (Rich Bono) [1110943]
- [scsi] pm80xx: Fix missing NULL pointer checks and memory leaks (Rich Bono) [1110943]
- [scsi] pm80xx: Enable BAR shift to avoid BIOS conflict with MPI space for ATTO pm8001 based HBAs (Rich Bono) [1110943]
- [scsi] pm80xx: Read saved WWN from NVMD for ATTO pm8001 based HBAs (Rich Bono) [1110943]
- [scsi] pm80xx: Fixed return value issue (Rich Bono) [1110943]
- [md] dm-thin: fix pool_io_hints to avoid looking at max_hw_sectors (Mike Snitzer) [1156164]
- [kernel] audit: keep inode pinned (Paul Moore) [1162261]
- [block] nvme: cleanup nvme_split_flush_data() (David Milburn) [1161766]
- [scsi] ibmvfc: fix little endian issues (Steve Best) [1159781]
- [scsi] ibmvfc: Fix for offlining devices during error recovery (Steve Best) [1159781]

* Sat Nov 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-208.el7]
- [scsi] cxgb4i: send abort_rpl correctly (Sai Vemuri) [1163467]
- [Documentation] cxgbi: add maintainer for cxgb3i/cxgb4i (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: FL Starvation Threshold needs to be larger than the SGE's Egress Congestion Threshold (Sai Vemuri) [1163467]
- [ethernet] cxgb4: For T5 use Packing and Padding Boundaries for SGE DMA transfers (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Move fl_starv_thres into adapter->sge data structure (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Replace repetitive pci device ID's with right ones (Sai Vemuri) [1163467]
- [infinband] cxgb4: Make c4iw_wr_log_size_order static (Sai Vemuri) [1163467]
- [infinband] cxgb4: Add missing neigh_release in find_route (Sai Vemuri) [1163467]
- [infinband] cxgb4: Fix ntuple calculation for ipv6 and remove duplicate line (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Fix FW flash logic using ethtool (Sai Vemuri) [1163467]
- [infiniband] cxgb4: Take IPv6 into account for best_mtu and set_emss (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Wait for device to get ready before reading any register (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Add 40G support for cxgb4vf driver (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Updated the LSO transfer length in CPL_TX_PKT_LSO for T5 (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Add support for adaptive rx (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Change default Interrupt Holdoff Packet Count Threshold (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Add Devicde ID for two more adapter (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Remove superfluous "idx" parameter of CH_DEVICE() macro (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Use BAR2 Going To Sleep (GTS) for T5 and later (Sai Vemuri) [1163467]
- [scsi] cxgbi: support ipv6 address host_param (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Fix -Wmaybe-uninitialized warning (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Remove duplicate call to dst_neigh_lookup() (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Fix -Wunused-function warning (Sai Vemuri) [1153834]
- [ethernet] cxgb4: Fix build failure in cxgb4 when ipv6 is disabled/not in-built (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Remove duplicated CLIP handling code (Sai Vemuri) [1153834]
- [ethernet] be2net: fix alignment on line wrap (Ivan Vecera) [1165755]
- [ethernet] be2net: remove multiple assignments on a single line (Ivan Vecera) [1165755]
- [ethernet] be2net: remove space after typecasts (Ivan Vecera) [1165755]
- [ethernet] be2net: remove unnecessary blank lines after an open brace (Ivan Vecera) [1165755]
- [ethernet] be2net: insert a blank line after function/struct//enum definitions (Ivan Vecera) [1165755]
- [ethernet] be2net: remove multiple blank lines (Ivan Vecera) [1165755]
- [ethernet] be2net: add blank line after declarations (Ivan Vecera) [1165755]
- [ethernet] be2net: remove return statements for void functions (Ivan Vecera) [1165755]
- [ethernet] be2net: add speed reporting for 20G-KR interface (Ivan Vecera) [1165755]
- [ethernet] be2net: add speed reporting for 40G/KR interface (Ivan Vecera) [1165755]
- [ethernet] be2net: fix sparse warnings in be_cmd_req_port_type{} (Ivan Vecera) [1165755]
- [ethernet] be2net: fix a sparse warning in be_cmd_modify_eqd() (Ivan Vecera) [1165755]
- [ethernet] be2net: enable PCIe error reporting on VFs too (Ivan Vecera) [1165755]
- [ethernet] be2net: send a max of 8 EQs to be_cmd_modify_eqd() on Lancer (Ivan Vecera) [1165755]
- [ethernet] be2net: fix port-type reporting in get_settings (Ivan Vecera) [1165755]
- [ethernet] be2net: add ethtool "-m" option support (Ivan Vecera) [1165755]
- [ethernet] be2net: fix RX fragment posting for jumbo frames (Ivan Vecera) [1165755]
- [ethernet] be2net: replace strcpy with strlcpy (Ivan Vecera) [1165755]
- [ethernet] be2net: fix some log messages (Ivan Vecera) [1165755]
- [ethernet] bna: fix skb->truesize underestimation (Ivan Vecera) [1165759]
- [ethernet] bna: allow transmit tagged frames (Ivan Vecera) [1165759]
- [ethernet] bna: use container_of to resolve bufdesc_ex from bufdesc (Ivan Vecera) [1165759]
- [ethernet] r8169: add support for RTL8168EP (Ivan Vecera) [1165764]
- [ethernet] r8169: add support for Byte Queue Limits (Ivan Vecera) [1165764]
- [ethernet] r8169: call "rtl8168_driver_start" "rtl8168_driver_stop" only when hardware dash function is enabled (Ivan Vecera) [1165764]
- [ethernet] r8169: modify the behavior of function "rtl8168_oob_notify" (Ivan Vecera) [1165764]
- [ethernet] r8169: change the name of function "r8168dp_check_dash" to "r8168_check_dash" (Ivan Vecera) [1165764]
- [ethernet] r8169: change the name of function"rtl_w1w0_eri" (Ivan Vecera) [1165764]
- [ethernet] r8169: for function "rtl_w1w0_phy" change its name and behavior (Ivan Vecera) [1165764]
- [ethernet] r8169: add more chips to support magic packet v2 (Ivan Vecera) [1165764]
- [ethernet] r8169: add support more chips to get mac address from backup mac address register (Ivan Vecera) [1165764]
- [ethernet] r8169: add disable/enable RTL8411B pll function (Ivan Vecera) [1165764]
- [ethernet] r8169: add disable/enable RTL8168G pll function (Ivan Vecera) [1165764]
- [ethernet] r8169: change uppercase number to lowercase number (Ivan Vecera) [1165764]
- [ethernet] r8169: fix an if condition (Ivan Vecera) [1165764]
- [ethernet] r8169: adjust __rtl8169_set_features (Ivan Vecera) [1165764]
- [ethernet] r8169: fix setting rx vlan (Ivan Vecera) [1165764]
- [ethernet] r8169: fix the default setting of rx vlan (Ivan Vecera) [1165764]

* Sat Nov 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-207.el7]
- [powerpc] use device_online/offline() instead of cpu_up/down() (Gustavo Duarte) [1157737]
- [ethernet] i40e: disable FCoE (Stefan Assmann) [1165175]
- [cpufreq] intel_pstate: Add CPUID for BDW-H CPU (Steve Best) [1164379]
- [mm] do not overwrite reserved pages counter at show_mem() (Rafael Aquini) [1125433]
- [alsa] Revert: Kconfig: rename HAS_IOPORT to HAS_IOPORT_MAP (Jarod Wilson) [1112200]
- [ethernet] enic: Do not call napi_disable when preemption is disabled (Stefan Assmann) [1145019]
- [ethernet] enic: fix possible deadlock in enic_stop/ enic_rfs_flw_tbl_free (Stefan Assmann) [1145019]
- [x86] uv_bau: Avoid NULL pointer reference in ptc_seq_show (Frank Ramsay) [1161183]
- [x86] uv_bau: Increase maximum CPUs per socket/hub (Frank Ramsay) [1161183]
- [mm] vmscan: do not throttle based on pfmemalloc reserves if node has no ZONE_NORMAL (Gustavo Duarte) [1148925]
- [char] hwrng/pseries: port to new read API and fix stack corruption (Gustavo Duarte) [1163659]
- [md] Revert: dm-cache: add call to mark_tech_preview (Mike Snitzer) [1159001]
- [md] dm-cache: emit a warning message if there are a lot of cache blocks (Mike Snitzer) [1159001]
- [md] dm-cache: improve discard support (Mike Snitzer) [1159001]
- [md] dm-cache: revert "prevent corruption caused by discard_block_size > cache_block_size" (Mike Snitzer) [1159001]
- [md] dm-cache: revert "remove remainder of distinct discard block size" (Mike Snitzer) [1159001]
- [md] dm-bio-prison: introduce support for locking ranges of blocks (Mike Snitzer) [1159001]
- [md] dm-btree: fix a recursion depth bug in btree walking code (Mike Snitzer) [1080894]
- [md] dm-cache-policy-mq: simplify ability to promote sequential IO to the cache (Mike Snitzer) [1159001]
- [md] dm-cache-policy-mq: tweak algorithm that decides when to promote a block (Mike Snitzer) [1159001]
- [security] selinux: fix inode security list corruption (Paul Moore) [1152274]

* Thu Nov 20 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-206.el7]
- [x86] quirks: Print the Intel graphics stolen memory range (Rob Clark) [1154053]
- [x86] quirks: Add Intel graphics stolen memory quirk for gen2 platforms (Rob Clark) [1154053]
- [x86] quirks: Add vfunc for Intel graphics stolen memory base address (Rob Clark) [1154053]
- [x86] quirks: use gen6 stolen detection for VLV (Rob Clark) [1154053]
- [x86] quirks: support GMS and GGMS changes on i915/bdw (Rob Clark) [1154053]
- [x86] quirks: add early quirk for reserving Intel graphics stolen memory v5 (Rob Clark) [1154053]
- [net] vmxnet3: fix netpoll race condition (Neil Horman) [1158001]
- [virt] virtio_balloon: update_balloon_size() - update correct field (Luiz Capitulino) [1163567]
- [firmware] memmap: don't create memmap sysfs of same firmware_map_entry (Takahiro MUNEDA) [1160173]
- [mm] memory-hotplug: clear pgdat which is allocated by bootmem in try_offline_node() (Larry Woodman) [1156393]
- [kernel] add panic_on_warn (Prarit Bhargava) [1163852]
- [virt] hyperv: Fix the total_data_buflen in send path (Jason Wang) [1156305]
- [virt] hyperv: Add handling of IP header with option field in netvsc_set_hash() (Jason Wang) [1156305]
- [virt] hyperv: Fix a bug in netvsc_start_xmit() (Jason Wang) [1156305]
- [virt] hyperv: Fix a bug in netvsc_send() (Jason Wang) [1156305]
- [powerpc] kexec: adjust crashkernel reservation for 2GB-4GB systems (Gustavo Duarte) [1074924]
- [virt] kvm/ioapic: conditionally delay irq delivery duringeoi broadcast (John Snow) [921526]
- [fs] file_table: get rid of s_files and files_lock (Gustavo Duarte) [1112805]
- [fs] super: uninline destroy_super(), consolidate alloc_super() (Gustavo Duarte) [1112805]
- [ethernet] mlx4: Advertize encapsulation offloads features only when VXLAN tunnel is set (Florian Westphal) [1097478]
- [ethernet] mlx4: Avoid leaking steering rules on flow creation error flow (Florian Westphal) [1097478]
- [ethernet] mlx4: Don't attempt to TX offload the outer UDP checksum for VXLAN (Florian Westphal) [1097478]
- [scsi] bnx2fc: fix tgt spinlock locking (Maurizio Lombardi) [1165169]
- [scsi] TUR path is down after adapter gets reset with multipath (Ewan Milne) [1153738]
- [scsi] call device handler for failed TUR command (Ewan Milne) [1153738]

* Sat Nov 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-205.el7]
- [mm] shmem: fix splicing from a hole while it's punched (Denys Vlasenko) [1118245] {CVE-2014-4171}
- [mm] shmem: fix faulting into a hole, not taking i_mutex (Denys Vlasenko) [1118245] {CVE-2014-4171}
- [mm] shmem: fix faulting into a hole while it's punched (Denys Vlasenko) [1118245] {CVE-2014-4171}
- [virt] kvm: detect LVTT changes under APICv (Radim Krcmar) [1151174]
- [virt] kvm: detect SPIV changes under APICv (Radim Krcmar) [1151174]
- [virt] kvm: recalculate_apic_map after enabling apic (Radim Krcmar) [1151174]
- [virt] kvm: trace kvm_ple_window grow/shrink (Radim Krcmar) [1163296]
- [virt] kvm/vmx: dynamise PLE window (Radim Krcmar) [1163296]
- [virt] kvm/vmx: make PLE window per-VCPU (Radim Krcmar) [1163296]
- [virt] kvm: introduce sched_in to kvm_x86_ops (Radim Krcmar) [1163296]
- [virt] kvm: add kvm_arch_sched_in (Radim Krcmar) [1163296]
- [kernel] uprobes: Don't assume that arch_uprobe->insn/ixol is u8[MAX_UINSN_BYTES] (Steve Best) [1159365]
- [drm] qxl: don't create too large primary surface (Dave Airlie) [1158233]
- [powerpc] pseries: Quieten ibm, pcie-link-speed-stats warning (Steve Best) [1162287]
- [md] dm-thin: fix potential for infinite loop in pool_io_hints (Mike Snitzer) [1156164]
- [virt] hyperv/vmbus: Increase the limit on the number of pfns we can handle (Jason Wang) [1160130]
- [virt] kvm: update masterclock values on TSC writes (Marcelo Tosatti) [1158039]
- [virt] kvm: emulate MOVNTDQ (Paolo Bonzini) [1117542]
- [crypto] af_alg: properly label AF_ALG socket (Ondrej Kozina) [1161148]
- [powerpc] vphn: NUMA node code expects big-endian (Steve Best) [1154673]

* Fri Nov 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-204.el7]
- [net] ip6_gre: Return an error when adding an existing tunnel (Alexander Duyck) [1151886 1152368]
- [net] ip6_tunnel: Return an error when adding an existing tunnel (Alexander Duyck) [1151886 1152368]
- [net] ip_tunnel: Don't allow to add the same tunnel multiple times (Alexander Duyck) [1151886 1152368]
- [net] gre: Use inner mac length when computing tunnel length (Alexander Duyck) [1151886 1152368]
- [net] gre: enable offloads for GRE (Alexander Duyck) [1151886 1152368]
- [net] ipv4: fix a potential use after free in gre_offload.c (Alexander Duyck) [1151886 1152368]
- [net] ipv4: fix a potential use after free in ip_tunnel_core.c (Alexander Duyck) [1151886 1152368]
- [net] gro: fix aggregation for skb using frag_list (Alexander Duyck) [1154239]
- [net] gro: make sure skb->cb[] initial content has not to be zero (Alexander Duyck) [1154239]
- [net] bridge: notify user space after fdb update (Alexander Duyck) [1109605]
- [net] bridge: Fix the way to find old local fdb entries in br_fdb_changeaddr (Alexander Duyck) [1109605]
- [net] handle encapsulation offloads when computing segment lengths (Jiri Benc) [1144571]
- [net] gso: make skb_gso_segment error handling more robust (Jiri Benc) [1144571]
- [net] gso: use feature flag argument in all protocol gso handlers (Jiri Benc) [1144571]
- [net] udp_offload: Use IS_ERR_OR_NULL (Jiri Benc) [1144571]
- [net] ipv4: Use IS_ERR_OR_NULL (Jiri Benc) [1144571]

* Wed Nov 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-203.el7]
- [fs] GFS2: If we use up our block reservation, request more next time (Robert S Peterson) [1142238]
- [fs] GFS2: Only increase rs_sizehint (Robert S Peterson) [1142238]
- [fs] GFS2: Set of distributed preferences for rgrps (Robert S Peterson) [1142238]
- [fs] autofs: fix symlinks aren't checked for expiry (Ian Kent) [1116182]
- [fs] GFS2: fix regression in dir_double_exhash (Robert S Peterson) [1160229]
- [fs] gfs2_atomic_open(): skip lookups on hashed dentry (Robert S Peterson) [1158150]
- [fs] splice: perform generic write checks (Eric Sandeen) [1155907]
- [fs] fs: seq_file: fallback to vmalloc allocation (Ian Kent) [1095623]
- [fs] fs: /proc/stat: convert to single_open_size() (Ian Kent) [1095623]
- [fs] fs: seq_file: always clear m->count when we free m->buf (Ian Kent) [1095623]

* Wed Nov 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-202.el7]
- [ethernet] mlx4: Use PTYS register to set ethtool settings (Speed) (Amir Vadai) [1060221]
- [ethernet] mlx4: Use PTYS register to query ethtool settings (Amir Vadai) [1060221]
- [ethernet] mlx4: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Amir Vadai) [1060221]
- [ethernet] mlx4: Add 100M, 20G, 56G speeds ethtool reporting support (Amir Vadai) [1060221]
- [ethernet] mlx4: Add ethernet backplane autoneg device capability (Amir Vadai) [1060221]
- [ethernet] mlx4: Introduce ACCESS_REG CMD and eth_prot_ctrl dev cap (Amir Vadai) [1060221]
- [ethernet] mlx4: Cable info, get_module_info/eeprom ethtool support (Amir Vadai) [1060221]
- [ethernet] mlx4: Introduce mlx4_get_module_info for cable module info reading (Amir Vadai) [1060221]
- [ethernet] mlx4: Enable CQE/EQE stride support (Amir Vadai) [1060221]
- [virt] kvm/vmx: defer load of APIC access page address during reset (Paolo Bonzini) [1140974]
- [virt] kvm: do not handle APIC access page if in-kernel irqchip is not in use (Paolo Bonzini) [1140974]
- [virt] kvm: Unpin and remove kvm_arch->apic_access_page (Paolo Bonzini) [1140974]
- [virt] kvm/vmx: Implement set_apic_access_page_addr (Paolo Bonzini) [1140974]
- [virt] kvm: Add request bit to reload APIC access page address (Paolo Bonzini) [1140974]
- [virt] kvm: Add arch specific mmu notifier for page invalidation (Paolo Bonzini) [1140974]
- [virt] kvm: Rename make_all_cpus_request() to kvm_make_all_cpus_request() and make it non-static (Paolo Bonzini) [1140974]
- [virt] kvm: Remove ept_identity_pagetable from struct kvm_arch (Paolo Bonzini) [1140974]
- [virt] kvm: Use APIC_DEFAULT_PHYS_BASE macro as the apic access page address (Paolo Bonzini) [1140974]
- [drm] vmwgfx: respect 'nomodeset' (Rob Clark) [1101381]
- [s390] qeth: don't query for info if hardware not ready (Hendrik Brueckner) [1147573]
- [block] Fix dev_t minor allocation lifetime (Jeff Moyer) [1139898]
- [md] dm-crypt: fix access beyond the end of allocated space (Mike Snitzer) [1135066]
- [fs] isofs: unbound recursion when processing relocated directories (Jacob Tanenbaum) [1142271] {CVE-2014-5471 CVE-2014-5472}
- [ethernet] be2net: use v1 of SET_FLOW_CONTROL command (Ivan Vecera) [1087128]
- [acpi] return 1 after successfully install cmos_rtc space handler (Amos Kong) [1159465]
- [x86] hyperv: Bypass the timer_irq_works() check (Jason Wang) [1058105]
- [mm] hugetlb: initialize PG_reserved for tail pages of gigantic compound pages (Luiz Capitulino) [1158506]
- [kernel] cpuset: PF_SPREAD_PAGE and PF_SPREAD_SLAB should be atomic flags (Aaron Tomlin) [1160360]
- [infiniband] qib: Correct reference counting in debugfs qp_stats (Rui Wang) [1150001]
- [x86] uv: Check for alloc_cpumask_var() failures properly in uv_nmi_setup() (George Beshers) [1155754]
- [powerpc] fadump: Fix endianess issues in firmware assisted dump handling (Steve Best) [1159773]

* Mon Nov 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-201.el7]
- [scsi] ipr: wait for aborted command responses (Gustavo Duarte) [1156530]
- [ethernet] mlx4: Protect port type setting by mutex (Amir Vadai) [1095345]
- [acpi] pm: Only set power states of devices that are power manageable (Amos Kong) [1142683]
- [x86] setup: Mark Intel Haswell ULT as supported (Prarit Bhargava) [1159006]
- [kernel] sched: Fix unreleased llc_shared_mask bit during CPU hotplug (Takahiro MUNEDA) [1116294]
- [mm] do not walk all of system memory during show_mem (Johannes Weiner) [1125433]
- [mm] remove noisy remainder of the scan_unevictable interface (Johannes Weiner) [1111215]
- [pci] Rename sysfs 'enabled' file back to 'enable' (Myron Stowe) [1159655]
- [kernel] sched/fair: Care divide error in update_task_scan_period() (Motohiro Kosaki) [1140979]
- [powerpc] numa: ensure per-cpu NUMA mappings are correct on topology update (Gustavo Duarte) [1150097]
- [powerpc] numa: use cached value of update->cpu in update_cpu_topology (Gustavo Duarte) [1150097]
- [powerpc] numa: Add ability to disable and debug topology updates (Gustavo Duarte) [1150097]
- [powerpc] numa: check error return from proc_create (Gustavo Duarte) [1150097]
- [powerpc] some changes in numa_setup_cpu() (Gustavo Duarte) [1150097]
- [powerpc] Only set numa node information for present cpus at boottime (Gustavo Duarte) [1150097]
- [powerpc] Fix warning reported by verify_cpu_node_mapping() (Gustavo Duarte) [1150097]
- [powerpc] reorder per-cpu NUMA information's initialization (Gustavo Duarte) [1150097]
- [powerpc] pseries: Make CPU hotplug path endian safe (Steve Best) [1159579]
- [powerpc] pseries: Fix endian issues in cpu hot-removal (Steve Best) [1159579]
- [powerpc] pseries: Fix endian issues in onlining cpu threads (Steve Best) [1159579]
- [x86] smpboot: Fix up typo in topology detection (Prarit Bhargava) [1156655]
- [x86] smpboot: Add new topology for multi-NUMA-node CPUs (Prarit Bhargava) [1158269]
- [kernel] sched: Rework sched_domain topology definition (Prarit Bhargava) [1158269]
- [usb] hub: take hub->hdev reference when processing from eventlist (Don Zickus) [1151508]
- [usb] ehci: unlink QHs even after the controller has stopped (Don Zickus) [1151491]
- [tools] testing/selftests/powerpc: Correct DSCR during TM context switch (Gustavo Duarte) [1134511]
- [tools] testing/selftests: Add infrastructure for powerpc selftests (Gustavo Duarte) [1134511]
- [scsi] ibmvscsi: Abort init sequence during error recovery (Gustavo Duarte) [1105496]
- [scsi] ibmvscsi: Add memory barriers for send / receive (Gustavo Duarte) [1105496]
- [x86] fpu: __restore_xstate_sig()->math_state_restore() needs preempt_disable() (Oleg Nesterov) [1121784]
- [x86] fpu: shift drop_init_fpu() from save_xstate_sig() to handle_signal() (Oleg Nesterov) [1121784]

* Fri Nov 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-200.el7]
- [fs] ext4: fix wrong assert in ext4_mb_normalize_request() (Lukas Czerner) [1146046]
- [mm] Remove false WARN_ON from pagecache_isize_extended() (Lukas Czerner) [1156096]
- [fs] ext4: check s_chksum_driver when looking for bg csum presence (Lukas Czerner) [1156096]
- [fs] ext4: move error report out of atomic context in ext4_init_block_bitmap() (Lukas Czerner) [1156096]
- [fs] ext4: Replace open coded mdata csum feature to helper function (Lukas Czerner) [1156096]
- [fs] ext4: fix reservation overflow in ext4_da_write_begin (Lukas Czerner) [1156096]
- [fs] ext4: add ext4_iget_normal() which is to be used for dir tree lookups (Lukas Czerner) [1156096]
- [fs] ext4: don't orphan or truncate the boot loader inode (Lukas Czerner) [1156096]
- [fs] ext4: grab missed write_count for EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1156096]
- [fs] ext4: get rid of code duplication (Lukas Czerner) [1156096]
- [fs] ext4: fix over-defensive complaint after journal abort (Lukas Czerner) [1156096]
- [fs] ext4: fix return value of ext4_do_update_inode (Lukas Czerner) [1156096]
- [fs] ext4: fix mmap data corruption when blocksize < pagesize (Lukas Czerner) [1156096]
- [fs] vfs: fix data corruption when blocksize < pagesize for mmaped data (Lukas Czerner) [1156096]
- [fs] ext4: don't check quota format when there are no quota files (Lukas Czerner) [1156096]
- [fs] jbd2: avoid pointless scanning of checkpoint lists (Lukas Czerner) [1156096]
- [fs] ext4: explicitly inform user about orphan list cleanup (Lukas Czerner) [1156096]
- [fs] jbd2: jbd2_log_wait_for_space improve error detetcion (Lukas Czerner) [1156096]
- [fs] jbd2: free bh when descriptor block checksum fails (Lukas Czerner) [1156096]
- [fs] ext4: check EA value offset when loading (Lukas Czerner) [1156096]
- [fs] ext4: don't keep using page if inline conversion fails (Lukas Czerner) [1156096]
- [fs] ext4: validate external journal superblock checksum (Lukas Czerner) [1156096]
- [fs] jbd2: fix journal checksum feature flag handling (Lukas Czerner) [1156096]
- [fs] ext4: provide separate operations for sysfs feature files (Lukas Czerner) [1156096]
- [fs] ext4: add sysfs entry showing whether the fs contains errors (Lukas Czerner) [1156096]
- [fs] ext4: renumber EXT4_EX_* flags to avoid flag aliasing problems (Lukas Czerner) [1156096]
- [fs] ext4: fix comments about get_blocks (Lukas Czerner) [1156096]
- [fs] ext4: fix accidental flag aliasing in ext4_map_blocks flags (Lukas Czerner) [1156096]
- [fs] ext4: fix ZERO_RANGE bug hidden by flag aliasing (Lukas Czerner) [1156096]
- [fs] ext4: use ext4_update_i_disksize instead of opencoded ones (Lukas Czerner) [1156096]
- [fs] ext4: remove a duplicate call in ext4_init_new_dir() (Lukas Czerner) [1156096]
- [fs] ext4: add missing BUFFER_TRACE before ext4_journal_get_write_access (Lukas Czerner) [1156096]
- [fs] ext4: check inline directory before converting (Lukas Czerner) [1156096]
- [fs] ext4: fix incorrect locking in move_extent_per_page (Lukas Czerner) [1156096]
- [fs] ext4: use correct depth value (Lukas Czerner) [1156096]
- [fs] ext4: add i_data_sem sanity check (Lukas Czerner) [1156096]
- [fs] ext4: fix wrong size computation in ext4_mb_normalize_request() (Lukas Czerner) [1156096]
- [fs] ext4: make ext4_has_inline_data() as a inline function (Lukas Czerner) [1156096]
- [fs] ext4: remove readpage() check in ext4_mmap_file() (Lukas Czerner) [1156096]
- [fs] ext4: remove metadata reservation checks (Lukas Czerner) [1156096]
- [fs] ext4: rearrange initialization to fix EXT4FS_DEBUG (Lukas Czerner) [1156096]
- [fs] ext4: fix potential null pointer dereference in ext4_free_inode (Lukas Czerner) [1156096]
- [fs] ext4: decrement free clusters/inodes counters when block group declared bad (Lukas Czerner) [1156096]
- [fs] ext4: handle symlink properly with inline_data (Lukas Czerner) [1156096]
- [fs] ext4: reduce contention on s_orphan_lock (Lukas Czerner) [1156096]
- [fs] ext4: use sbi in ext4_orphan_[add|del]() (Lukas Czerner) [1156096]
- [fs] ext4: remove unnecessary double parentheses (Lukas Czerner) [1156096]
- [fs] ext4: do not destroy ext4_groupinfo_caches if ext4_mb_init() fails (Lukas Czerner) [1156096]
- [fs] ext4: make local functions static (Lukas Czerner) [1156096]
- [fs] ext4: fix block bitmap validation when bigalloc, ^flex_bg (Lukas Czerner) [1156096]
- [fs] ext4: fix block bitmap initialization under sparse_super2 (Lukas Czerner) [1156096]
- [fs] ext4: find the group descriptors on a 1k-block bigalloc, meta_bg filesystem (Lukas Czerner) [1156096]
- [fs] ext4: avoid unneeded lookup when xattr name is invalid (Lukas Czerner) [1156096]
- [fs] ext4: remove obsoleted check (Lukas Czerner) [1156096]
- [fs] ext4: add a new spinlock i_raw_lock to protect the ext4's raw inode (Lukas Czerner) [1156096]
- [fs] ext4: revert Disable punch hole on non-extent mapped files (Lukas Czerner) [1150178]
- [fs] ext4: fix transaction issues for ext4_fallocate and ext_zero_range (Lukas Czerner) [1150171]
- [fs] ext4: move i_size, i_disksize update routines to helper function (Lukas Czerner) [1150171]
- [fs] ext4: fix incorect journal credits reservation in ext4_zero_range (Lukas Czerner) [1150171]
- [fs] ext4: fix COLLAPSE RANGE test for bigalloc file systems (Lukas Czerner) [1150171]
- [fs] ext4: fix punch hole on files with indirect mapping (Lukas Czerner) [1150171]
- [fs] ext4: Fix block zeroing when punching holes in indirect block files (Lukas Czerner) [1150171]
- [fs] ext4: fix ZERO_RANGE test failure in data journalling (Lukas Czerner) [1150171]
- [fs] ext4: use EXT_MAX_BLOCKS in ext4_es_can_be_merged() (Lukas Czerner) [1150171]
- [fs] ext4: rename uninitialized extents to unwritten (Lukas Czerner) [1150171]
- [fs] ext4: disable COLLAPSE_RANGE for bigalloc (Lukas Czerner) [1150171]
- [fs] ext4: fix COLLAPSE_RANGE failure with 1KB block size (Lukas Czerner) [1150171]
- [fs] ext4: use EINVAL if not a regular file in ext4_collapse_range() (Lukas Czerner) [1150171]
- [fs] ext4: enforce we are operating on a regular file in ext4_zero_range() (Lukas Czerner) [1150171]
- [fs] ext4: fix extent merging in ext4_ext_shift_path_extents() (Lukas Czerner) [1150171]
- [fs] ext4: discard preallocations after removing space (Lukas Czerner) [1150171]
- [fs] ext4: no need to truncate pagecache twice in collapse range (Lukas Czerner) [1150171]
- [fs] ext4: fix removing status extents in ext4_collapse_range() (Lukas Czerner) [1150171]
- [fs] ext4: use filemap_write_and_wait_range() correctly in collapse range (Lukas Czerner) [1150171]
- [fs] ext4: use truncate_pagecache() in collapse range (Lukas Czerner) [1150171]
- [fs] ext4: always check ext4_ext_find_extent result (Lukas Czerner) [1150171]
- [fs] ext4: COLLAPSE_RANGE only works on extent-based files (Lukas Czerner) [1150171]
- [fs] ext4: fix byte order problems introduced by the COLLAPSE_RANGE patches (Lukas Czerner) [1150171]
- [fs] ext4: disallow all fallocate operation on active swapfile (Lukas Czerner) [1150171]
- [fs] ext4: move falloc collapse range check into the filesystem methods (Lukas Czerner) [1150171]
- [fs] ext4: fix COLLAPSE_RANGE test failure in data journalling mode (Lukas Czerner) [1150171]
- [fs] ext4: remove unneeded test of ret variable (Lukas Czerner) [1150171]
- [fs] ext4: Introduce FALLOC_FL_ZERO_RANGE flag for fallocate (Lukas Czerner) [1150171]
- [fs] ext4: Introduce FALLOC_FL_ZERO_RANGE flag for fallocate (Lukas Czerner) [1150171]
- [fs] ext4: refactor ext4_fallocate code (Lukas Czerner) [1150171]
- [fs] ext4: Update inode i_size after the preallocation (Lukas Czerner) [1150171]
- [fs] ext4: Add new flag(FALLOC_FL_COLLAPSE_RANGE) for fallocate (Lukas Czerner) [1150171]
- [fs] ext4: Add support FALLOC_FL_COLLAPSE_RANGE for fallocate (Lukas Czerner) [1150171]

* Wed Nov 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-199.el7]
- [fs] quota: remove dqptr_sem (Lukas Czerner) [1053111]
- [fs] quota: simplify remove_inode_dquot_ref() (Lukas Czerner) [1053111]
- [fs] quota: avoid unnecessary dqget()/dqput() calls (Lukas Czerner) [1053111]
- [fs] quota: protect Q_GETFMT by dqonoff_mutex (Lukas Czerner) [1053111]
- [fs] xfs: add a few more verifier tests (Eric Sandeen) [1059330 1061656]
- [fs] pipe: skip file_update_time on frozen fs (Eric Sandeen) [1107499]
- [fs] xfs: don't sleep in xlog_cil_force_lsn on shutdown (Eric Sandeen) [1088240]
- [fs] buffer: increase the buffer-head per-CPU LRU size (Zach Brown) [1053108]
- [fs] fs: check bh blocknr earlier when searching lru (Zach Brown) [1053108]
- [fs] truncate: drop 'oldsize' truncate_pagecache() parameter (Lukas Czerner) [1150139]
- [fs] ext4: avoid trying to kfree an ERR_PTR pointer (Lukas Czerner) [1150139]
- [fs] ext4: fix same-dir rename when inline data directory overflows (Lukas Czerner) [1150139]
- [fs] jbd2: fix descriptor block size handling errors with journal_csum (Lukas Czerner) [1150139]
- [fs] jbd2: fix infinite loop when recovering corrupt journal blocks (Lukas Czerner) [1150139]
- [fs] ext4: update i_disksize coherently with block allocation on error path (Lukas Czerner) [1150139]
- [fs] ext4: fix BUG_ON in mb_free_blocks() (Lukas Czerner) [1150139]
- [fs] ext4: propagate errors up to ext4_find_entry()'s callers (Lukas Czerner) [1150139]
- [fs] ext4: fix ext4_discard_allocated_blocks() if we can't allocate the pa struct (Lukas Czerner) [1150139]
- [fs] ext4: fix a potential deadlock in __ext4_es_shrink() (Lukas Czerner) [1150139]
- [fs] ext4: revert commit which was causing fs corruption after journal replays (Lukas Czerner) [1150139]
- [fs] ext4: disable synchronous transaction batching if max_batch_time==0 (Lukas Czerner) [1150139]
- [fs] ext4: clarify ext4_error message in ext4_mb_generate_buddy_error() (Lukas Czerner) [1150139]
- [fs] ext4: clarify error count warning messages (Lukas Czerner) [1150139]
- [fs] ext4: fix unjournalled bg descriptor while initializing inode bitmap (Lukas Czerner) [1150139]
- [fs] ext4: Fix hole punching for files with indirect blocks (Lukas Czerner) [1150139]
- [fs] ext4: Fix buffer double free in ext4_alloc_branch() (Lukas Czerner) [1150139]
- [fs] ext4: fix zeroing of page during writeback (Lukas Czerner) [1150139]
- [fs] ext4: fix data integrity sync in ordered mode (Lukas Czerner) [1150139]
- [fs] ext4: get rid of EXT4_MAP_UNINIT flag (Lukas Czerner) [1150139]
- [fs] ext4: fix ext4_count_free_clusters() with EXT4FS_DEBUG and bigalloc enabled (Lukas Czerner) [1150139]
- [fs] ext4: silence sparse check warning for function ext4_trim_extent (Lukas Czerner) [1150139]
- [fs] ext4: use i_size_read in ext4_unaligned_aio() (Lukas Czerner) [1150139]
- [fs] ext4: move ext4_update_i_disksize() into mpage_map_and_submit_extent() (Lukas Czerner) [1150139]
- [fs] ext4: return ENOMEM rather than EIO when find_###_page() fails (Lukas Czerner) [1150139]
- [fs] ext4: update PF_MEMALLOC handling in ext4_write_inode() (Lukas Czerner) [1150139]
- [fs] ext4: fix jbd2 warning under heavy xattr load (Lukas Czerner) [1150139]
- [fs] ext4: note the error in ext4_end_bio() (Lukas Czerner) [1150139]
- [fs] ext4: initialize multi-block allocator before checking block descriptors (Lukas Czerner) [1150139]
- [fs] ext4: FIBMAP ioctl causes BUG_ON due to handle EXT_MAX_BLOCKS (Lukas Czerner) [1150139]
- [fs] ext4: fix 64-bit number truncation warning (Lukas Czerner) [1150139]
- [fs] ext4: fix premature freeing of partial clusters split across leaf blocks (Lukas Czerner) [1150139]
- [fs] ext4: rename: split out helper functions (Lukas Czerner) [1150139]
- [fs] ext4: rename: move EMLINK check up (Lukas Czerner) [1150139]
- [fs] ext4: rename: create ext4_renament structure for local vars (Lukas Czerner) [1150139]
- [fs] ext4: make ext4_block_zero_page_range static (Lukas Czerner) [1150139]
- [fs] ext4: atomically set inode->i_flags in ext4_set_inode_flags() (Lukas Czerner) [1150139]
- [fs] ext4: optimize Hurd tests when reading/writing inodes (Lukas Czerner) [1150139]
- [fs] ext4: kill i_version support for Hurd-castrated file systems (Lukas Czerner) [1150139]
- [fs] ext4: fix partial cluster handling for bigalloc file systems (Lukas Czerner) [1150139]
- [fs] ext4: delete path dealloc code in ext4_ext_handle_uninitialized_extents (Lukas Czerner) [1150139]
- [fs] jbd2: improve error messages for inconsistent journal heads (Lukas Czerner) [1150139]
- [fs] jbd2: minimize region locked by j_list_lock in jbd2_journal_forget() (Lukas Czerner) [1150139]
- [fs] jbd2: minimize region locked by j_list_lock in journal_get_create_access() (Lukas Czerner) [1150139]
- [fs] jbd2: check jh->b_transaction without taking j_list_lock (Lukas Czerner) [1150139]
- [fs] jbd2: add transaction to checkpoint list earlier (Lukas Czerner) [1150139]
- [fs] jbd2: calculate statistics without holding j_state_lock and j_list_lock (Lukas Czerner) [1150139]
- [fs] jbd2: don't hold j_state_lock while calling wake_up() (Lukas Czerner) [1150139]
- [fs] jbd2: don't unplug after writing revoke records (Lukas Czerner) [1150139]
- [fs] ext4: Speedup WB_SYNC_ALL pass called from sync(2) (Lukas Czerner) [1150139]
- [fs] ext4: translate fallocate mode bits to strings (Lukas Czerner) [1150139]
- [fs] ext4: merge uninitialized extents (Lukas Czerner) [1150139]
- [fs] ext4: avoid exposure of stale data in ext4_punch_hole() (Lukas Czerner) [1150139]
- [fs] ext4: silence warnings in extent status tree debugging code (Lukas Czerner) [1150139]
- [fs] ext4: remove unused ac_ex_scanned (Lukas Czerner) [1150139]
- [fs] ext4: avoid possible overflow in ext4_map_blocks() (Lukas Czerner) [1150139]
- [fs] ext4: make sure ex.fe_logical is initialized (Lukas Czerner) [1150139]
- [fs] ext4: don't calculate total xattr header size unless needed (Lukas Czerner) [1150139]
- [fs] ext4: add ext4_es_store_pblock_status() (Lukas Czerner) [1150139]
- [fs] ext4: fix error return from ext4_ext_handle_uninitialized_extents() (Lukas Czerner) [1150139]
- [fs] ext4: address a benign compiler warning (Lukas Czerner) [1150139]
- [fs] jbd2: mark file-local functions as static (Lukas Czerner) [1150139]
- [fs] ext4: remove an unneeded check in mext_page_mkuptodate() (Lukas Czerner) [1150139]
- [fs] ext4: clean up error handling in swap_inode_boot_loader() (Lukas Czerner) [1150139]
- [fs] ext4: Add __init marking to init_inodecache (Lukas Czerner) [1150139]
- [fs] ext4: don't leave i_crtime.tv_sec uninitialized (Lukas Czerner) [1150139]
- [fs] ext4: fix online resize with a non-standard blocks per group setting (Lukas Czerner) [1150139]
- [fs] ext4: fix online resize with very large inode tables (Lukas Czerner) [1150139]
- [fs] ext4: don't try to modify s_flags if the the file system is read-only (Lukas Czerner) [1150139]
- [fs] ext4: fix error paths in swap_inode_boot_loader() (Lukas Czerner) [1150139]
- [fs] ext4: fix xfstest generic/299 block validity failures (Lukas Czerner) [1150139]
- [fs] ext4: delete "set but not used" variables (Lukas Czerner) [1150139]
- [fs] ext4: don't pass freed handle to ext4_walk_page_buffers (Lukas Czerner) [1150139]
- [fs] ext4: avoid clearing beyond i_blocks when truncating an inline data file (Lukas Czerner) [1150139]
- [fs] ext4: ext4_inode_is_fast_symlink should use EXT4_CLUSTER_SIZE (Lukas Czerner) [1150139]
- [fs] ext4: fix a typo in extents.c (Lukas Czerner) [1150139]
- [fs] ext4: use pd printk specificer (Lukas Czerner) [1150139]
- [fs] ext4: standardize error handling in ext4_da_write_inline_data_begin() (Lukas Czerner) [1150139]
- [fs] ext4: retry allocation when inline->extent conversion failed (Lukas Czerner) [1150139]
- [fs] ext4: enable punch hole for bigalloc (Lukas Czerner) [1150139]
- [fs] ext4: fix bigalloc regression (Lukas Czerner) [1150139]
- [fs] ext4: add explicit casts when masking cluster sizes (Lukas Czerner) [1150139]
- [fs] ext4: fix deadlock when writing in ENOSPC conditions (Lukas Czerner) [1150139]
- [fs] jbd2: rename obsoleted msg JBD->JBD2 (Lukas Czerner) [1150139]
- [fs] jbd2: revise KERN_EMERG error messages (Lukas Czerner) [1150139]
- [fs] jbd2: don't BUG but return ENOSPC if a handle runs out of space (Lukas Czerner) [1150139]
- [fs] ext4: Do not reserve clusters when fs doesn't support extents (Lukas Czerner) [1150139]
- [fs] ext4: fix del_timer() misuse for ->s_err_report (Lukas Czerner) [1150139]
- [fs] ext4: check for overlapping extents in ext4_valid_extent_entries() (Lukas Czerner) [1150139]
- [fs] ext4: fix use-after-free in ext4_mb_new_blocks (Lukas Czerner) [1150139]
- [fs] ext4: call ext4_error_inode() if jbd2_journal_dirty_metadata() fails (Lukas Czerner) [1150139]
- [fs] ext4: add prototypes for macro-generated functions (Lukas Czerner) [1150139]
- [fs] ext4: return non-zero st_blocks for inline data (Lukas Czerner) [1150139]
- [fs] ext4: use prandom_u32() instead of get_random_bytes() (Lukas Czerner) [1150139]
- [fs] ext4: remove unreachable code after ext4_can_extents_be_merged() (Lukas Czerner) [1150139]
- [fs] ext4: remove unreachable code in ext4_can_extents_be_merged() (Lukas Czerner) [1150139]
- [fs] ext4: don't count free clusters from a corrupt block group (Lukas Czerner) [1150139]
- [fs] ext4: drop set but otherwise unused variable from ext4_add_dirent_to_inline() (Lukas Czerner) [1150139]
- [fs] ext4: change ext4_read_inline_dir() to return 0 on success (Lukas Czerner) [1150139]
- [fs] ext4: pair trace_ext4_writepages & trace_ext4_writepages_result (Lukas Czerner) [1150139]
- [fs] ext4: fix performance regression in ext4_writepages (Lukas Czerner) [1150139]
- [fs] ext4: fixup kerndoc annotation of mpage_map_and_submit_extent() (Lukas Czerner) [1150139]
- [fs] ext4: fix performance regression in writeback of random writes (Lukas Czerner) [1150139]
- [fs] ext4: allow specifying external journal by pathname mount option (Lukas Czerner) [1150139]
- [fs] ext4: mark group corrupt on group descriptor checksum (Lukas Czerner) [1150139]
- [fs] ext4: mark block group as corrupt on inode bitmap error (Lukas Czerner) [1150139]
- [fs] ext4: mark block group as corrupt on block bitmap error (Lukas Czerner) [1150139]
- [fs] jbd2: Fix endian mixing problems in the checksumming code (Lukas Czerner) [1150139]
- [fs] ext4: isolate ext4_extents.h file (Lukas Czerner) [1150139]
- [fs] ext4: Fix misspellings using 'codespell' tool (Lukas Czerner) [1150139]
- [fs] ext4: convert write_begin methods to stable_page_writes semantics (Lukas Czerner) [1150139]
- [fs] ext4: fix lost truncate due to race with writeback (Lukas Czerner) [1150139]
- [fs] ext4: fix ext4_writepages() in presence of truncate (Lukas Czerner) [1150139]
- [fs] ext4: move test whether extent to map can be extended to one place (Lukas Czerner) [1150139]
- [fs] ext4: avoid reusing recently deleted inodes in no journal mode (Lukas Czerner) [1150139]
- [fs] ext4: allocate delayed allocation blocks before rename (Lukas Czerner) [1150139]
- [fs] ext4: start handle at least possible moment when renaming files (Lukas Czerner) [1150139]
- [fs] ext4: add support for extent pre-caching (Lukas Czerner) [1150139]
- [fs] ext4: cache all of an extent tree's leaf block upon reading (Lukas Czerner) [1150139]
- [fs] ext4: use unsigned int for es_status values (Lukas Czerner) [1150139]
- [fs] ext4: print the block number of invalid extent tree blocks (Lukas Czerner) [1150139]
- [fs] ext4: refactor code to read the extent tree block (Lukas Czerner) [1150139]
- [fs] ext4: add WARN_ON to check the length of allocated blocks (Lukas Czerner) [1150139]
- [fs] ext4: call ext4_es_lru_add() after handling cache miss (Lukas Czerner) [1150139]
- [fs] ext4: make the extent_status code more robust against ENOMEM failures (Lukas Czerner) [1150139]
- [fs] ext4: simplify calculation of blocks to free on error (Lukas Czerner) [1150139]
- [fs] ext4: fix spelling errors and a comment in extent_status tree (Lukas Czerner) [1150139]
- [fs] ext4: fix warning in ext4_evict_inode() (Lukas Czerner) [1150139]
- [fs] ext4: optimize starting extent in ext4_ext_rm_leaf() (Lukas Czerner) [1150139]
- [fs] jbd2: invalidate handle if jbd2_journal_restart() fails (Lukas Czerner) [1150139]
- [fs] ext4: fix up error handling for mpage_map_and_submit_extent() (Lukas Czerner) [1150139]
- [fs] ext4: delete unnecessary C statements (Lukas Czerner) [1150139]
- [fs] ext4: pass inode pointer instead of file pointer to punch hole (Lukas Czerner) [1150139]
- [fs] ext4: improve free space calculation for inline_data (Lukas Czerner) [1150139]
- [fs] ext4: reduce object size when !CONFIG_PRINTK (Lukas Czerner) [1150139]
- [fs] ext4: improve extent cache shrink mechanism to avoid to burn CPU time (Lukas Czerner) [1150139]
- [fs] ext4: delete unused variables (Lukas Czerner) [1150139]
- [fs] jbd2: remove debug dependency on debug_fs and update Kconfig help text (Lukas Czerner) [1150139]
- [fs] jbd2: use a single printk for jbd_debug() (Lukas Czerner) [1150139]
- [fs] ext4: fix data integrity for ext4_sync_fs (Lukas Czerner) [1150139]
- [fs] jbd2: optimize jbd2_journal_force_commit (Lukas Czerner) [1150139]
- [fs] ext4: don't use EXT4_FREE_BLOCKS_FORGET unnecessarily (Lukas Czerner) [1150139]
- [fs] ext4: use ext4_da_writepages() for all modes (Lukas Czerner) [1150139]
- [fs] ext4: remove ext4_ioend_wait() (Lukas Czerner) [1150139]
- [fs] ext4: don't wait for extent conversion in ext4_punch_hole() (Lukas Czerner) [1150139]
- [fs] ext4: Remove wait for unwritten extents in ext4_ind_direct_IO() (Lukas Czerner) [1150139]
- [fs] ext4: remove i_mutex from ext4_file_sync() (Lukas Czerner) [1150139]
- [fs] ext4: use generic_file_fsync() in ext4_file_fsync() in nojournal mode (Lukas Czerner) [1150139]
- [fs] ext4: remove wait for unwritten extent conversion from ext4_truncate() (Lukas Czerner) [1150139]
- [fs] ext4: protect extent conversion after DIO with i_dio_count (Lukas Czerner) [1150139]
- [fs] ext4: defer clearing of PageWriteback after extent conversion (Lukas Czerner) [1150139]
- [fs] ext4: split extent conversion lists to reserved & unreserved parts (Lukas Czerner) [1150139]
- [fs] ext4: use transaction reservation for extent conversion in ext4_end_io (Lukas Czerner) [1150139]
- [fs] ext4: remove buffer_uninit handling (Lukas Czerner) [1150139]
- [fs] ext4: silence warning in ext4_writepages() (Lukas Czerner) [1150139]
- [fs] ext4: restructure writeback path (Lukas Czerner) [1150139]
- [fs] ext4: use io_end for multiple bios (Lukas Czerner) [1150139]
- [fs] ext4: better estimate credits needed for ext4_da_writepages() (Lukas Czerner) [1150139]
- [fs] ext4: improve writepage credit estimate for files with indirect blocks (Lukas Czerner) [1150139]
- [fs] ext4: deprecate max_writeback_mb_bump sysfs attribute (Lukas Czerner) [1150139]
- [fs] ext4: stop messing with nr_to_write in ext4_da_writepages() (Lukas Czerner) [1150139]
- [fs] ext4: provide wrappers for transaction reservation calls (Lukas Czerner) [1150139]
- [fs] jbd2: transaction reservation support (Lukas Czerner) [1150139]
- [fs] jbd2: cleanup needed free block estimates when starting a transaction (Lukas Czerner) [1150139]
- [fs] jbd2: remove outdated comment (Lukas Czerner) [1150139]
- [fs] jbd2: refine waiting for shadow buffers (Lukas Czerner) [1150139]
- [fs] jbd2: remove journal_head from descriptor buffers (Lukas Czerner) [1150139]
- [fs] jbd2: don't create journal_head for temporary journal buffers (Lukas Czerner) [1150139]
- [fs] ext4: suppress ext4 orphan messages on mount (Lukas Czerner) [1150139]
- [fs] jbd2: fix block tag checksum verification brokenness (Lukas Czerner) [1150139]
- [fs] jbd2: use kmem_cache_zalloc for allocating journal head (Lukas Czerner) [1150139]
- [fs] jbd2: Fix oops in jbd2_journal_file_inode() (Lukas Czerner) [1144326]
- [fs] ext4: only zero partial blocks in ext4_zero_partial_blocks() (Lukas Czerner) [1144326]
- [fs] ext4: make punch hole code path work with bigalloc (Lukas Czerner) [1144326]
- [fs] ext4: update ext4_ext_remove_space trace point (Lukas Czerner) [1144326]
- [fs] ext4: remove unused code from ext4_remove_blocks() (Lukas Czerner) [1144326]
- [fs] ext4: remove unused discard_partial_page_buffers (Lukas Czerner) [1144326]
- [fs] ext4: use ext4_zero_partial_blocks in punch_hole (Lukas Czerner) [1144326]
- [fs] ext4: truncate_inode_pages() in orphan cleanup path (Lukas Czerner) [1144326]
- [fs] Revert "ext4: fix fsx truncate failure" (Lukas Czerner) [1144326]
- [fs] ext4: Call ext4_jbd2_file_inode() after zeroing block (Lukas Czerner) [1144326]
- [fs] Revert "ext4: remove no longer used functions in inode.c" (Lukas Czerner) [1144326]
- [fs] mm: teach truncate_inode_pages_range() to handle non page aligned ranges (Lukas Czerner) [1144326]
- [fs] ext4: use ->invalidatepage() length argument (Lukas Czerner) [1144326]
- [fs] jbd2: change jbd2_journal_invalidatepage to accept length (Lukas Czerner) [1144326]
- [fs] mm: change invalidatepage prototype to accept length (Lukas Czerner) [1144326]
- [fs] nfs: Fix a bogus warning in nfs_generic_pgio (Steve Dickson) [1150227]
- [fs] nfs: Fix an uninitialised pointer Oops in the writeback error path (Steve Dickson) [1150227]

* Mon Nov 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-198.el7]
- [block] nvme: Clear QUEUE_FLAG_STACKABLE (David Milburn) [1155716]
- [md] dm-raid: ensure superblock's size matches device's logical block size (Mike Snitzer) [1112804]
- [md] dm-thin: refactor requeue_io to eliminate spinlock bouncing (Mike Snitzer) [1156164]
- [md] dm-thin: optimize retry_bios_on_resume (Mike Snitzer) [1156164]
- [md] dm-thin: sort the deferred cells (Mike Snitzer) [1156164]
- [md] dm-thin: direct dispatch when breaking sharing (Mike Snitzer) [1156164]
- [md] dm-thin: remap the bios in a cell immediately (Mike Snitzer) [1156164]
- [md] dm-thin: defer whole cells rather than individual bios (Mike Snitzer) [1156164]
- [md] dm-thin: factor out remap_and_issue_overwrite (Mike Snitzer) [1156164]
- [md] dm-thin: performance improvement to discard processing (Mike Snitzer) [1156164]
- [md] dm-thin: grab a virtual cell before looking up the mapping (Mike Snitzer) [1156164]
- [md] dm-thin: implement thin_merge (Mike Snitzer) [1156164]
- [md] dm: improve documentation and code clarity in dm_merge_bvec (Mike Snitzer) [1156164]
- [md] dm-thin: adjust max_sectors_kb based on thinp blocksize (Mike Snitzer) [1156164]
- [block] fix alignment_offset math that assumes io_min is a power-of-2 (Mike Snitzer) [1156164]
- [md] dm-thin: throttle incoming IO (Mike Snitzer) [1156161]
- [md] dm-thin: prefetch missing metadata pages (Mike Snitzer) [1156161]
- [md] dm-transaction-manager: add support for prefetching blocks of metadata (Mike Snitzer) [1156161]
- [md] dm-thin-metadata: change dm_thin_find_block to allow blocking, but not issuing, IO (Mike Snitzer) [1156161]
- [md] dm-bio-prison: switch to using a red black tree (Mike Snitzer) [1156161]
- [md] dm-bufio: evict buffers that are past the max age but retain some buffers (Mike Snitzer) [1156161]
- [md] dm-bufio: switch from a huge hash table to an rbtree (Mike Snitzer) [1156161]
- [md] dm-bufio: change __GFP_IO to __GFP_FS in shrinker callbacks (Mike Snitzer) [1156161]
- [md] dm-bufio: when done scanning return from __scan immediately (Mike Snitzer) [1156161]
- [md] dm-bufio: update last_accessed when relinking a buffer (Mike Snitzer) [1156161]
- [md] dm-bufio: fully initialize shrinker (Mike Snitzer) [1156161]
- [misc] genwqe: Remove unnecessary include (Gustavo Duarte) [1088491]
- [misc] genwqe: Increase driver version number (Gustavo Duarte) [1088491]
- [misc] genwqe: Improve hardware error recovery (Gustavo Duarte) [1088491]
- [misc] genwqe: Add support for EEH error recovery (Gustavo Duarte) [1088491]
- [misc] genwqe: Add sysfs interface for bitstream reload (Gustavo Duarte) [1088491]
- [misc] genwqe: fix uninitialized return value in genwqe_free_sync_sgl() (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix format string mismatch in card_debugfs.c (Gustavo Duarte) [1088491]
- [misc] genwqe: Increase driver version number (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix multithreading problems (Gustavo Duarte) [1088491]
- [misc] genwqe: Ensure rc is not returning an uninitialized value (Gustavo Duarte) [1088491]
- [misc] genwqe: Add wmb before DDCB is started (Gustavo Duarte) [1088491]
- [misc] genwqe: Enable access to VPD flash area (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix potential memory leak when pinning memory (Gustavo Duarte) [1088491]
- [misc] genwqe: delete non-required instances of include <linux/init.h> (Gustavo Duarte) [1088491]
- [misc] genwqe: fix return value check in genwqe_device_create() (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix warnings for sparc (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix compile problems for Alpha (Gustavo Duarte) [1088491]
- [misc] genwqe: Rework return code for flash-update ioctl (Gustavo Duarte) [1088491]
- [misc] genwqe: Accidently casting to u32 where u64 is required (Gustavo Duarte) [1088491]
- [misc] genwqe: Replace dynamic_hex_dump with print_hex_dump_debug (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix endian issues detected by sparse (Gustavo Duarte) [1088491]
- [misc] genwqe: Enable driver (Gustavo Duarte) [1088491]
- [misc] genwqe: Sysfs interfaces (Gustavo Duarte) [1088491]
- [misc] genwqe: Debugfs interfaces (Gustavo Duarte) [1088491]
- [misc] genwqe: Utility functions (Gustavo Duarte) [1088491]
- [misc] genwqe: Character device and DDCB queue (Gustavo Duarte) [1088491]
- [misc] genwqe: GenWQE PCI support, health monitoring and recovery (Gustavo Duarte) [1088491]
- [virt] kvm/vmx: handle invvpid vm exit gracefully (Petr  Matousek) [1144829] {CVE-2014-3646}
- [virt] kvm: fix PIT timer race condition (Petr  Matousek) [1144880] {CVE-2014-3611}

* Thu Oct 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-197.el7]
- [scsi] qla2xxx: Update version number to 8.07.00.08.07.1-k1 (Chad Dupuis) [1067179]
- [scsi] qla2xxx: Disable PCI device in shutdown handler (Chad Dupuis) [1067179]
- [wireless] rt2x00: Delete accidentally committed .rej file (Prarit Bhargava) [1158457]
- [ethernet] cxgb4: Allow T4/T5 firmware sizes up to 1MB (Sai Vemuri) [1147683]
- [ethernet] cxgb4i: avoid holding mutex in interrupt context (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Don't allocate adapter structure for all PF's (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Add device ID for new adapter and remove for dbg adapter (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Add warning msg when attaching to adapters which have FLASHes smaller than 2Mb (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Fix t4_flash_erase_sectors() to throw an error when requested to erase sectors which aren't in the FLASH (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Add support to S25FL032P flash (Sai Vemuri) [1147683]
- [ethernet] cxgb4vf: Call dev_kfree/consume_skb_any instead of [dev_]kfree_skb (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Turn off SGE RX/TX Callback Timers and interrupts in PCI shutdown routine (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Adds device ID for few more Chelsio T4 Adapters (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Check if rx checksum offload is enabled, while reading hardware calculated checksum (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Adds device Id for few more Chelsio adapters (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Use pci_enable_msix_range() instead of pci_enable_msix() (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Remove superfluous call to pci_disable_msix() (Sai Vemuri) [1070945]
- [kernel] printk: bump LOG_BUF_SHIFT (Jeff Moyer) [1156189]
- [net] cdc_ncm: fix control message ordering (Neil Horman) [1129796]
- [net] usb/huawei_cdc_ncm: add "subclass 3" devices (Neil Horman) [1129796]
- [net] usb/cdc_ncm: remove non-standard NCM device IDs (Neil Horman) [1129796]
- [net] usb/huawei_cdc_ncm: increase command buffer size (Neil Horman) [1129796]
- [net] usb: Introduce the huawei_cdc_ncm driver (Neil Horman) [1129796]
- [powerpc] perf/hv-24x7: Simplify catalog_read() (Steve Best) [1155924]
- [acpi] container: Fix error code path in container_device_attach() (Prarit Bhargava) [1128634]
- [kernel] timekeeping: Use cached ntp_tick_length when accumulating error (Prarit Bhargava) [1136839]
- [kernel] timekeeping: Rework frequency adjustments to work better w/ nohz (Prarit Bhargava) [1136839]
- [s390] zcrypt: Toleration of new crypto hardware (Hendrik Brueckner) [1136494]
- [s390] zcrypt: support for extended number of ap domains (Hendrik Brueckner) [1136494]
- [kernel] smp: flush any pending IPI callbacks before CPU offline (Gustavo Duarte) [1100093]
- [kernel] smp: print more useful debug info upon receiving IPI on an offline CPU (Gustavo Duarte) [1100093]

* Tue Oct 28 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-196.el7]
- [ethernet] mlx5: Add ConnectX-4 to list of supported devices (Amir Vadai) [1149439]
- [fs] cifs: NULL pointer dereference in SMB2_tcon (Jacob Tanenbaum) [1147529] {CVE-2014-7145}
- [x86] build: Add arch/x86/purgatory/ make generated files to gitignore (Prarit Bhargava) [1155577]
- [acpi] acpica: Add "Windows 2013" string to _OSI support (Lenny Szubowicz) [1087674]
- [pci] Export MSI message relevant functions (Myron Stowe) [1123366]
- [cpufreq] store_scaling_governor requires policy->rwsem to be held for duration of changing governors (Prarit Bhargava) [1089255]
- [edac] sb_edac: avoid INTERNAL ERROR message in EDAC with unspecified channel (Seth Jennings) [1056990]
- [kernel] module: lock around setting of MODULE_STATE_UNFORMED (Prarit Bhargava) [1127741]
- [acpi] Add container online uevent to acpi_bus_attach (Prarit Bhargava) [1140572]
- [scsi] fcoe: Convert uses of compare_ether_addr to ether_addr_equal (Neil Horman) [1087099]
- [scsi] fcoe: Fix missing mutex_unlock in fcoe_sysfs_fcf_add error path (Neil Horman) [1087099]
- [scsi] fcoe: Make fcoe_sysfs optional / fix fnic NULL exception (Neil Horman) [1087099]
- [scsi] fcoe: fix build error (Neil Horman) [1087099]
- [scsi] fcoe: convert bus code to use bus_groups (Neil Horman) [1087099]
- [scsi] fcoe: Reduce fcoe_sysfs_fcf_add() stack usage (Neil Horman) [1087099]
- [scsi] fcoe: Add missing newlines in debug messages (Neil Horman) [1087099]
- [scsi] fcoe: Declare fcoe_ctlr_mode_set() static (Neil Horman) [1087099]
- [fs] gfs2: Hash the negative dentry during inode lookup (Robert S Peterson) [1123986]

* Mon Oct 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-195.el7]
- [block] fix blk_abort_request on blk-mq (Jeff Moyer) [1146660]
- [block] blk-timeout: fix blk_add_timer (Jeff Moyer) [1146660]
- [block] blk-mq: limit memory consumption if a crash dump is active (Jeff Moyer) [1146660]
- [block] blk-mq: remove unnecessary blk_clear_rq_complete() (Jeff Moyer) [1146660]
- [block] blk-mq: pass a reserved argument to the timeout handler (Jeff Moyer) [1146660]
- [block] blk-mq: unshared timeout handler (Jeff Moyer) [1146660]
- [block] blk-mq: fix and simplify tag iteration for the timeout handler (Jeff Moyer) [1146660]
- [block] blk-mq: rename blk_mq_end_io to blk_mq_end_request (Jeff Moyer) [1146660]
- [block] blk-mq: call blk_mq_start_request from ->queue_rq (Jeff Moyer) [1146660]
- [block] blk-mq: remove REQ_END (Jeff Moyer) [1146660]
- [block] blk-mq: use blk_mq_start_hw_queues() when running requeue work (Jeff Moyer) [1146660]
- [block] blk-mq: fix potential oops on out-of-memory in __blk_mq_alloc_rq_maps() (Jeff Moyer) [1146660]
- [block] blk-mq: avoid infinite recursion with the FUA flag (Jeff Moyer) [1146660]
- [block] blk-mq: Avoid race condition with uninitialized requests (Jeff Moyer) [1146660]
- [block] blk-mq: request deadline must be visible before marking rq as started (Jeff Moyer) [1146660]
- [block] blk-mq: scale depth and rq map appropriate if low on memory (Jeff Moyer) [1146660]
- [block] blk-mq: cleanup after blk_mq_init_rq_map failures (Jeff Moyer) [1146660]
- [block] fix unbalanced bypass-disable in blk_register_queue (Jeff Moyer) [1146660]
- [block] bdi: an active gendisk always has a request_queue associated with it (Jeff Moyer) [1146660]
- [block] blk-mq: pass along blk_mq_alloc_tag_set return values (Jeff Moyer) [1146660]
- [block] blk-merge: fix blk_recount_segments (Jeff Moyer) [1146660]
- [block] blk-mq: correct a few wrong/bad comments (Jeff Moyer) [1146660]
- [block] blk-mq: don't allow merges if turned off for the queue (Jeff Moyer) [1146660]
- [block] blk-mq: fix WARNING "percpu_ref_kill() called more than once!" (Jeff Moyer) [1146660]
- [block] provide compat ioctl for BLKZEROOUT (Jeff Moyer) [1146660]
- [block] blkcg: don't call into policy draining if root_blkg is already gone (Jeff Moyer) [1146660]
- [block] don't assume last put of shared tags is for the host (Jeff Moyer) [1146660]
- [block] fix SG_[GS]ET_RESERVED_SIZE ioctl when max_sectors is huge (Jeff Moyer) [1146660]
- [block] fix BLKSECTGET ioctl when max_sectors is greater than USHRT_MAX (Jeff Moyer) [1146660]
- [block] blk-mq: collapse __blk_mq_drain_queue() into blk_mq_freeze_queue() (Jeff Moyer) [1146660]
- [block] blk-mq: decouble blk-mq freezing from generic bypassing (Jeff Moyer) [1146660]
- [block] blk-mq: draining can't be skipped even if bypass_depth was non-zero (Jeff Moyer) [1146660]
- [block] blk-mq: fix a memory ordering bug in blk_mq_queue_enter() (Jeff Moyer) [1146660]

* Fri Oct 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-194.el7]
- [fs] xfs: flush the range before zero range conversion (Eric Sandeen) [1145837]
- [fs] xfs: only set extent size hint when asked (Eric Sandeen) [1145837]
- [fs] xfs: project id inheritance is a directory only flag (Eric Sandeen) [1145837]
- [fs] xfs: use ranged writeback and invalidation for direct IO (Eric Sandeen) [1145837]
- [fs] xfs: don't zero partial page cache pages during O_DIRECT writes (Eric Sandeen) [1145837]
- [fs] xfs: don't zero partial page cache pages during O_DIRECT reads (Eric Sandeen) [1130294 1145837]
- [fs] xfs: don't dirty buffers beyond EOF (Eric Sandeen) [1145837]
- [fs] xfs: fix coccinelle warnings (Eric Sandeen) [1145837]
- [fs] xfs: flush both inodes in xfs_swap_extents (Eric Sandeen) [1145837]
- [fs] xfs: fix swapext ilock deadlock (Eric Sandeen) [1145837]
- [fs] xfs: dquot recovery needs verifiers (Eric Sandeen) [1145837]
- [fs] xfs: quotacheck leaves dquot buffers without verifiers (Eric Sandeen) [1145837]
- [fs] xfs: ensure verifiers are attached to recovered buffers (Eric Sandeen) [1145837]
- [fs] xfs: catch buffers written without verifiers attached (Eric Sandeen) [1145837]
- [fs] xfs: avoid false quotacheck after unclean shutdown (Eric Sandeen) [1145837]
- [fs] xfs: fix rounding error of fiemap length parameter (Eric Sandeen) [1145837]
- [fs] xfs: fix uflags detection at xfs_fs_rm_xquota (Eric Sandeen) [1145837]
- [fs] xfs: fix cil push sequence after log recovery (Eric Sandeen) [1145837]
- [fs] xfs: squash prealloc while over quota free space as well (Eric Sandeen) [1145837]
- [fs] xfs: run an eofblocks scan on ENOSPC/EDQUOT (Eric Sandeen) [1145837]
- [fs] xfs: support a union-based filter for eofblocks scans (Eric Sandeen) [1145837]
- [fs] xfs: add scan owner field to xfs_eofblocks (Eric Sandeen) [1145837]
- [fs] xfs: fix a couple error sequence jumps in xfs_mountfs() (Eric Sandeen) [1145837]
- [fs] xfs: null unused quota inodes when quota is on (Eric Sandeen) [1145837]
- [fs] xfs: refine the allocation stack switch (Eric Sandeen) [1145837]
- [fs] xfs: Fix rounding in xfs_alloc_fix_len() (Eric Sandeen) [1145837]
- [fs] xfs: tone down writepage/releasepage WARN_ONs (Eric Sandeen) [1145837]
- [fs] xfs: remove redundant checks from xfs_da_read_buf (Eric Sandeen) [1145837]
- [fs] xfs: keep sb_bad_features2 the same a sb_features2 (Eric Sandeen) [1145837]
- [fs] xfs: negate xfs_icsb_init_counters error value (Eric Sandeen) [1145837]
- [fs] xfs: negate mount workqueue init error value (Eric Sandeen) [1145837]
- [fs] xfs: fix wrong errno from xfs_initxattrs (Eric Sandeen) [1145837]
- [fs] xfs: xfs_commit_metadata returns wrong errno (Eric Sandeen) [1145837]
- [fs] xfs: fix incorrect error sign in xfs_file_aio_read (Eric Sandeen) [1145837]
- [fs] xfs: xfs_dir_fsync() returns positive errno (Eric Sandeen) [1145837]
- [fs] xfs: fix directory readahead offset off-by-one (Eric Sandeen) [1145837]
- [fs] xfs: remote attribute overwrite causes transaction overrun (Eric Sandeen) [1145837]
- [fs] xfs: Fix wrong error codes being returned (Eric Sandeen) [1145837]
- [fs] xfs: bulletfproof xfs_qm_scall_trunc_qfiles() (Eric Sandeen) [1145837]
- [fs] xfs: fix Q_XQUOTARM ioctl (Eric Sandeen) [1145837]
- [fs] xfs: fully support v5 format filesystems (Eric Sandeen) [1145837]
- [fs] xfs: wrong error sign conversion during failed DIO writes (Eric Sandeen) [1145837]
- [fs] xfs: unmount does not wait for shutdown during unmount (Eric Sandeen) [1145837]
- [fs] xfs: don't map ranges that span EOF for direct IO (Eric Sandeen) [1145837]
- [fs] xfs: zeroing space needs to punch delalloc blocks (Eric Sandeen) [1145837]
- [fs] xfs: kill buffers over failed write ranges properly (Eric Sandeen) [1145837]
- [fs] xfs: extra semi-colon breaks a condition (Eric Sandeen) [1145837]
- [fs] xfs: xfs_check_page_type buffer checks need help (Eric Sandeen) [1145837]
- [wireless] Backport mwl8k driver from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport mwifiex driver from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport brcm80211 drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport rtlwifi drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport rt2x00 driver from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport ath drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport iwlegacy drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport iwlwifi driver from linux 3.16 (Stanislaw Gruszka) [1085079 1107878 1136324]
- [wireless] Backport mac80211 from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport wireless core from linux 3.16 (Stanislaw Gruszka) [1136324]
- [kernel] if_ether: add IEEE 802.21 Ethertype (Stanislaw Gruszka) [1136324]
- [kernel] PTR_RET is now PTR_ERR_OR_ZERO (Stanislaw Gruszka) [1136324]
- [net] etherdevice: Add ether_addr_equal_unaligned (Stanislaw Gruszka) [1136324]

* Thu Oct 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-193.el7]
- [net] ipv4: fix a race in update_or_create_fnhe() (Hannes Frederic Sowa) [1155155]
- [net] ipv4: irq safe sk_dst_[re]set() and ipv4_sk_update_pmtu() fix (Hannes Frederic Sowa) [1155155]
- [net] ipv4: fix dst race in sk_dst_get() (Hannes Frederic Sowa) [1155155]
- [net] ipv4: fix a race in ip4_datagram_release_cb() (Hannes Frederic Sowa) [1155155]
- [net] sctp: fix remote memory pressure from excessive queueing (Daniel Borkmann) [1152755] {CVE-2014-3688}
- [net] sctp: fix panic on duplicate ASCONF chunks (Daniel Borkmann) [1152755] {CVE-2014-3687}
- [net] sctp: fix skb_over_panic when receiving malformed ASCONF chunks (Daniel Borkmann) [1152755] {CVE-2014-3673}
- [net] sctp: handle association restarts when the socket is closed (Daniel Borkmann) [1152755]
- [net] ipv4: fix nexthop attlen check in fib_nh_match (Jiri Pirko) [1153654]
- [net] packet: handle too big packets for PACKET_V3 (Hannes Frederic Sowa) [1152248]
- [net] sendmsg: fix NULL pointer dereference (Hannes Frederic Sowa) [1152251]
- [net] ipv6: remove rt6i_genid (Hannes Frederic Sowa) [1150017]
- [net] ipv6: remove prune parameter for fib6_clean_all (Hannes Frederic Sowa) [1150017]
- [net] ipv6: bump genid when delete/add address (Hannes Frederic Sowa) [1150017]
- [net] split rt_genid for ipv4 and ipv6 (Hannes Frederic Sowa) [1150017]
- [net] ipv4: use separate genid for next hop exceptions (Hannes Frederic Sowa) [1150017]
- [net] ipv4: properly refresh rtable entries on pmtu/redirect events (Hannes Frederic Sowa) [1150017]
- [net] bridge: Don't include NDA_VLAN for FDB entries with vid 0 (Vlad Yasevich) [1139809]
- [net] bridge: Prevent insertion of FDB entry with disallowed vlan (Vlad Yasevich) [1139809]
- [net] bridge: Fix double free and memory leak around br_allowed_ingress (Vlad Yasevich) [1139809]
- [net] bridge: Fix crash with vlan filtering and tcpdump (Vlad Yasevich) [1139809]
- [net] bridge: Fix handling stacked vlan tags (Vlad Yasevich) [1139809]
- [net] bridge: Fix inabillity to retrieve vlan tags when tx offload is disabled (Vlad Yasevich) [1139809]
- [net] bridge: Use RCU_INIT_POINTER(x, NULL) in br_vlan.c (Vlad Yasevich) [1139809]
- [net] bridge: Remove unnecessary vlan_put_tag in br_handle_vlan (Vlad Yasevich) [1139809]
- [net] bridge: use list_for_each_entry_continue_reverse (Vlad Yasevich) [896669]
- [net] bridge: Fix incorrect judgment of promisc (Vlad Yasevich) [896669]
- [net] bridge: fix the unbalanced promiscuous count when add_if failed (Vlad Yasevich) [896669]
- [net] bridge: fix spelling of promiscuous (Vlad Yasevich) [896669]
- [net] bridge: fix build (Vlad Yasevich) [896669]
- [net] bridge: Automatically manage port promiscuous mode (Vlad Yasevich) [896669]
- [net] bridge: Add addresses from static fdbs to non-promisc ports (Vlad Yasevich) [896669]
- [net] bridge: Introduce BR_PROMISC flag (Vlad Yasevich) [896669]
- [net] bridge: Add functionality to sync static fdb entries to hw (Vlad Yasevich) [896669]
- [net] bridge: Keep track of ports capable of automatic discovery (Vlad Yasevich) [896669]
- [net] bridge: Turn flag change macro into a function (Vlad Yasevich) [896669]
- [net] bridge: Add a flag to control unicast packet flood (Vlad Yasevich) [896669]
- [net] bridge: Add flag to control mac learning (Vlad Yasevich) [896669]

* Thu Oct 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-192.el7]
- [infiniband] ocrdma: convert kernel va to pa for mmap in user (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: use right macro in query ah (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: resolve L2 address when creating user AH (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: get vlan tag from ib_qp_attrs (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: add default gid at index 0 (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: do not skip setting deffered_arm (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Report actual value of max_fast_reg_page_list_len (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: report asic-id in query device (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Update sli data structure for endianness (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Obtain SL from device structure (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Update the ocrdma module version string (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix a sparse warning (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Initialize the GID table while registering the device (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Increase the size of STAG array in dev structure to 16K (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Add missing adapter mailbox opcodes (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Return proper value for max_mr_size (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Do proper cleanup even if FW is in error state (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Allow only SEND opcode in case of UD QPs (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Avoid reporting wrong completions in case of error CQEs (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Delete AH table if ocrdma_init_hw fails after AH table creation (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Remove hardcoding of the max DPP QPs supported (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Handle shutdown event from be2net driver (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Add hca_type and fixing fw_version string in device atrributes (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Query and initalize the PFC SL (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Avoid posting DPP requests for RDMA READ (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Convert to use simple_open() (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Unregister inet notifier when unloading ocrdma (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix warnings about pointer <-> integer casts (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Code clean-up (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Display FW version (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Query controller information (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Support non-embedded mailbox commands (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Handle CQ overrun error (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Display proper value for max_mw (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Use non-zero tag in SRQ posting (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Memory leak fix in ocrdma_dereg_mr() (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Increment abi version count (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Update version string (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: ABI versioning between ocrdma and be2net (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Allow DPP QP creation (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Read ASIC_ID register to select asic_gen (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: SQ and RQ doorbell offset clean up (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: EQ full catastrophe avoidance (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix load time panic during GID table init (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix traffic class shift (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Add dependency on INET (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Move ocrdma_inetaddr_event outside of "#if CONFIG_IPV6" (Doug Ledford) [1081067 1088577]
- [mm] thp: do not allow thp faults to avoid cpuset restrictions (Frank Ramsay) [1149786]
- [mm] thp: add VM_INIT_DEF_MASK and PRCTL_THP_DISABLE (Frank Ramsay) [1149786]
- [fs] exec: kill the unnecessary mm->def_flags setting in load_elf_binary() (Frank Ramsay) [1149786]
- [mm] Revert: thp: make MADV_HUGEPAGE check for mm->def_flags (Frank Ramsay) [1149786]
- [block] disable entropy contributions for nonrot devices (Mike Snitzer) [852425]
- [crypto] qat: Enforce valid numa configuration (Nikolay Aleksandrov) [1152642]
- [crypto] qat: Prevent dma mapping zero length assoc data (Nikolay Aleksandrov) [1152642]
- [pci] Add ACS quirk for Intel 10G NICs (Alex Williamson) [1141399]
- [pci] Add ACS quirk for Solarflare SFC9120 & SFC9140 (Alex Williamson) [1131552]
- [infiniband] ipoib: validate struct ipoib_cb size (Doug Ledford) [1107621 1140601]
- [infiniband] ipoib: No longer use flush as a parameter (Doug Ledford) [1107621]
- [infiniband] ipoib: Make ipoib_mcast_stop_thread flush the workqueue (Doug Ledford) [1107621]
- [infiniband] ipoib: Use dedicated workqueues per interface (Doug Ledford) [1107621]
- [infiniband] ipoib: change init sequence ordering (Doug Ledford) [1107621]
- [infiniband] ipoib: fix mcast_dev_flush/mcast_restart_task race (Doug Ledford) [1107621]
- [infiniband] ipoib: fix MCAST_FLAG_BUSY usage (Doug Ledford) [1107621]
- [infiniband] ipoib: Make the carrier_on_task race aware (Doug Ledford) [1107621]
- [infiniband] ipoib: Consolidate rtnl_lock tasks in workqueue (Doug Ledford) [1107621]
- [infiniband] ipoib: Remove unnecessary test for NULL before debugfs_remove() (Doug Ledford) [1107621]
- [infiniband] ipoib: Avoid multicast join attempts with invalid P_key (Doug Ledford) [1107621]
- [infiniband] ipoib: Avoid flushing the workqueue from worker context (Doug Ledford) [1107621]
- [infiniband] ipoib: Use P_Key change event instead of P_Key polling mechanism (Doug Ledford) [1107621]
- [infiniband] ipoib: Report operstate consistently when brought up without a link (Doug Ledford) [1107621]
- [net] svcrdma: remove rdma_create_qp() failure recovery logic (Doug Ledford) [1107621]
- [net] svcrdma: send_write() must not overflow the device's max sge (Doug Ledford) [1107621]
- [net] svcrdma: Fence LOCAL_INV work requests (Doug Ledford) [1107621]
- [net] svcrdma: refactor marshalling logic (Doug Ledford) [1107621]
- [net] sunrpc: Fix regression in NFSRDMA server (Doug Ledford) [1107621]
- [net] svcrdma: fix printk when memory allocation fails (Doug Ledford) [1107621]
- [kernel] uapi: Include socket.h in rdma_user_cm.h (Doug Ledford) [1107621]
- [infiniband] Return error for unsupported QP creation flags (Doug Ledford) [1107621]
- [infiniband] Allow build of hw/ and ulp/ subdirectories independently (Doug Ledford) [1107621]
- [infiniband] ehca: Returns an error on ib_copy_to_udata() failure (Doug Ledford) [1107621]
- [net] sched: shrink struct qdisc_skb_cb to 28 bytes (Doug Ledford) [1107621 1140601]

* Tue Oct 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-191.el7]
- [fs] fuse: ignore entry-timeout LOOKUP_REVAL (Carlos Maiolino) [1124880]
- [fs] fuse: Timeout comparison fix (Carlos Maiolino) [1128802]
- [fs] lockd: Try to reconnect if statd has moved (Benjamin Coddington) [1120850]
- [fs] sunrpc: Don't wake tasks during connection abort (Benjamin Coddington) [1120850]
- [fs] Revert: writeback: do not sync data dirtied after sync start (Brian Foster [1085828]
- [fs] nfsd4: fix corruption of NFSv4 read data ("J. Bruce Fields") [1148055]
- [fs] gfs2: revert "GFS2: d_splice_alias() can't return error" (Robert S Peterson) [1141899]

* Mon Oct 20 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-190.el7]
- [scsi] mpt3sas: Use pci_enable_msix_exact() instead of pci_enable_msix() (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Use pci_enable_msix_exact() instead of pci_enable_msix() (Tomas Henzl) [1088524]
- [scsi] mpt2sas: fix undefined reference to `__udivdi3' compilation errors (Tomas Henzl) [1088524]
- [scsi] mpt3sas, mpt2sas: fix scsi_add_host error handling problems in _scsih_probe (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Bump mpt3sas driver version to 04.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Added Reply Descriptor Post Queue (RDPQ) Array support (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Added OEM branding Strings (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Copyright in driver sources is updated for year the 2014 (Tomas Henzl) [1088524]
- [scsi] mpt3sas: MPI2.5 Rev H (2.5.3) specifications (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Bump mpt3sas driver version to 03.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Clear PFA Status on SGPIO when PFA Drive is Removed or Replaced (Tomas Henzl) [1088524]
- [scsi] mpt3sas: MPI2.5 Rev G (2.5.2) specifications (Tomas Henzl) [1088524]
- [scsi] mpt3sas: delay scsi_add_host call to work with scsi-mq (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Rework the MSI-X grouping code (Tomas Henzl) [1088524]
- [scsi] mpt3sas: combine fw_event_work and its event_data (Tomas Henzl) [1088524]
- [scsi] mpt3sas: correct scsi_(target, device) hostdata allocation (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Remove phys on topology change (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Bump mpt2sas driver version to 18.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Get IOC_FACTS information using handshake protocol only after HBA card gets into READY or Operational state (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Added Reply Descriptor Post Queue (RDPQ) Array support (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Avoid type casting for direct I/O commands (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Bump mpt2sas driver version to 17.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Clear PFA Status on SGPIO when PFA Drive is Removed or Replaced (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Copyright in driver sources is updated for year the 2014 (Tomas Henzl) [1088524]
- [scsi] mpt2sas: MPI2 Rev Y (2.00.17) and Rev Z (2.00.18) specifications (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Added driver module parameter max_msix_vectors (Tomas Henzl) [1088524]
- [scsi] mpt2sas: delay scsi_add_host call to work with scsi-mq (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Rework the MSI-X grouping code (Tomas Henzl) [1088524]
- [scsi] mpt2sas: annotate ioc->reply_post_host_index as __iomem (Tomas Henzl) [1088524]
- [scsi] mpt2sas: combine fw_event_work and its event_data (Tomas Henzl) [1088524]
- [scsi] mpt2sas: correct scsi_(target, device) hostdata allocation (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Don't disable device twice at suspend (Tomas Henzl) [1088524]

* Fri Oct 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-189.el7]
- [scsi] lpfc: driver release 10.2.8021.1 for RHEL7 (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fixed crash from page fault caused by use after rport delete (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix locking issues with abort data paths (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix race between LOGO/PLOGI handling causing NULL pointer (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix IP Reset processing - wait for RDY before proceeding (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix quarantined XRI recovery qualifier state in link bounce (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix discovery timeout during nameserver login (Rob Evers) [1149846]
- [net] ipv6: mld: answer mldv2 queries with mldv1 reports in mldv1 fallback (Daniel Borkmann) [1143429]
- [net] team: avoid race condition in scheduling delayed work (Jiri Pirko) [1149239]
- [net] fix UDP tunnel GSO of frag_list GRO packets (Jiri Benc) [1119392]
- [net] vxlan: fix incorrect initializer in union vxlan_addr (Daniel Borkmann) [1130643]
- [net] vxlan: fix crash when interface is created with no group (Daniel Borkmann) [1130643]
- [net] vxlan: fix nonfunctional neigh_reduce() (Daniel Borkmann) [1130643]
- [net] vxlan: fix potential NULL dereference in arp_reduce() (Daniel Borkmann) [1130643]
- [net] vxlan: remove unused port variable in vxlan_udp_encap_recv() (Daniel Borkmann) [1130643]
- [net] vxlan: remove extra newline after function definition (Daniel Borkmann) [1130643]

* Mon Oct 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-188.el7]
- [kernel] workqueue: Add quiescent state between work items (Jiri Pirko) [1149250]
- [crypto] qat: Enable interrupts from all 32 bundles (Nikolay Aleksandrov) [1091130]
- [char] ipmi: Clear drvdata when interface is removed (Tony Camuso) [1136589]
- [md] raid5: disable 'DISCARD' by default due to safety concerns (Jes Sorensen) [1149931]
- [md] raid1: fix_read_error should act on all non-faulty devices (Jes Sorensen) [1149931]
- [virt] hyperv: NULL dereference on error (Jason Wang) [1146357]
- [virt] hyperv: Increase the buffer length for netvsc_channel_cb() (Jason Wang) [1146357]
- [virt] hyperv: Adjust the size of sendbuf region to support ws2008r2 (Jason Wang) [1146357]
- [virt] hyperv/net: Increase the size of the sendbuf region (Jason Wang) [1146357]
- [virt] hyperv: Fix error return code in netvsc_init_buf() (Jason Wang) [1146357]
- [virt] hyperv: Add netpoll support (Jason Wang) [1146357]
- [virt] hyperv/net: remove unnecessary null test before kfree (Jason Wang) [1146357]
- [virt] hyperv: Add handler for RNDIS_STATUS_NETWORK_CHANGE event (Jason Wang) [1146357]
- [virt] hyperv: fix apparent cut-n-paste error in send path teardown (Jason Wang) [1146357]
- [virt] hyperv: Add hash value into RNDIS Per-packet info (Jason Wang) [1146357]
- [virt] hyperv/net: Add support for netvsc build without CONFIG_SYSFS flag (Jason Wang) [1146357]
- [virt] hyperv: Properly handle checksum offload (Jason Wang) [1146357]
- [virt] hyperv: Enable sendbuf mechanism on the send path (Jason Wang) [1146357]
- [virt] hyperv: Simplify the send_completion variables (Jason Wang) [1146357]
- [virt] hyperv: Remove recv_pkt_list and lock (Jason Wang) [1146357]
- [virt] hyperv: Add support for virtual Receive Side Scaling (vRSS) (Jason Wang) [1146357]
- [virt] hyperv/net: Address UDP checksum issues (Jason Wang) [1146357]
- [virt] hyperv/net: Negotiate suitable ndis version for offload support (Jason Wang) [1146357]
- [virt] hyperv/net: Allocate memory for all possible per-pecket information (Jason Wang) [1146357]
- [virt] hyperv/net: Enable large send offload (Jason Wang) [1146357]
- [virt] hyperv/net: Enable send side checksum offload (Jason Wang) [1146357]
- [virt] hyperv/net: Enable receive side IP checksum offload (Jason Wang) [1146357]
- [virt] hyperv/net: Enable offloads on the host (Jason Wang) [1146357]
- [virt] hyperv/net: Cleanup the send path (Jason Wang) [1146357]
- [virt] hyperv/net: Enable scatter gather I/O (Jason Wang) [1146357]
- [virt] hyperv: Move state setting for link query (Jason Wang) [1146357]
- [virt] hyperv: Add latest NetVSP versions to auto negotiation (Jason Wang) [1146357]
- [virt] hyperv/net: Cleanup the netvsc receive callback functio (Jason Wang) [1146357]
- [virt] hyperv/net: Cleanup the receive path (Jason Wang) [1146357]
- [virt] hyperv/net: Get rid of the rndis_filter_packet structure (Jason Wang) [1146357]
- [virt] hyperv: Fix the carrier status setting (Jason Wang) [1146357]
- [virt] hyperv/util: Fix a bug in the KVP code (Jason Wang) [1102584]
- [virt] hyperv/vmbus: Fix a bug in the channel callback dispatch code (Jason Wang) [1146357]
- [virt] hyperv: remove meaningless pr_err() in vmbus_recvpacket_raw() (Jason Wang) [1146357]
- [virt] tools/hyperv: Handle the case when the target file exists correctly (Jason Wang) [1146358]
- [virt] hyperv/hv_fcopy: fix a race condition for SMP guest (Jason Wang) [1146358]
- [virt] hyperv: fcopy_open() can be static (Jason Wang) [1146358]
- [virt] hyperv: Implement the file copy service (Jason Wang) [1146358]
- [virt] hyperv: Add hyperv.h to uapi headers (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Fix a bug in vmbus_open() (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Properly protect calls to smp_processor_id() (Jason Wang) [1146358]
- [virt] hyperv: Remove unnecessary comparison of unsigned against 0 (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Implement per-CPU mapping of relid to channel (Jason Wang) [1146358]
- [virt] hyperv: Eliminate the channel spinlock in the callback path (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Support per-channel driver state (Jason Wang) [1146358]

* Fri Oct 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-187.el7]
- [ethernet] qlcnic: Remove duplicate object file from Makefile (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Initialize dcbnl_ops before register_netdev (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Set driver version before registering netdev (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix update of ethtool stats (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.61 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance Tx timeout debug data collection (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.60 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Optimize ring count validations (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Pre-allocate DMA buffer used for minidump collection (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove duplicate QLC_83XX_GET_LSO_CAPABILITY define (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Initialize mailbox cmd structure to zero (Chad Dupuis) [1089352]
- [ethernet] qlcnic: info leak in qlcnic_dcb_peer_app_info() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Use time_before() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: get rid of SET_ETHTOOL_OPS (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.59 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Collect firmware dump using DMA on 82xx adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add mac learning support to SR-IOV VF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add support to process commands in atomic context (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow SR-IOV VF probe in hypervisor (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Set real_num_{tx|rx}_queues properly (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix panic while dumping TX queues on TX timeout (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.58 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Limit vNIC support in legacy interrupt mode (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add driver logs in error path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow setting TX interrupt coalescing parameters from VF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add hwmon interface to export board temperature (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Optimize MAC learning code (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix memory leak (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Reset firmware API lock at driver load time (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix MSI-X initialization code (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do not disable SR-IOV when VFs are assigned to VMs (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix QLogic application/driver interface for virtual NIC configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix PVID configuration on eSwitch port (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix max ring count calculation (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix to send INIT_NIC_FUNC as first mailbox (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix panic due to uninitialzed delayed_work struct in use (Chad Dupuis) [1089352]
- [ethernet] qlcnic: include irq.h for irq definitions (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix build failure due to undefined reference to `vxlan_get_rx_port' (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Remove casts of pointer to same type (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.57 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add VXLAN Rx offload support (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add VXLAN Tx offload support (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, a couple off by one bugs (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix number of rings when we fall back from msix to legacy (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow any VLAN to be configured from VF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix usage of use_msi and use_msi_x module parameters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix function return error check (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.56 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance semaphore lock access failure error message (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow vlan0 traffic (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance driver message in failed state (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Updates to QLogic application/driver interface for virtual NIC configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Re-factor firmware minidump template header handling (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Cleanup qlcnic_enable_msix() return values (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.55 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix loopback test failure (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix initialization of vlan list (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Correct off-by-one errors in bounds checks (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance logic to calculate msix vectors (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Refactor interrupt coalescing code for all adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update poll controller code path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Interrupt code cleanup (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance Tx timeout debugging (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Use bool for rx_mac_learn (Chad Dupuis) [1089352]
- [ethernet] qlcnic: fix sparse warnings (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove unused code (Chad Dupuis) [1089352]
- [ethernet] qlcnic: make local functions static (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.54 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable IPv6 LRO even if IP address is not programmed (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix SR-IOV cleanup code path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable beaconing for 83xx/84xx Series adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do MAC learning for SRIOV PF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Turn on promiscous mode for SRIOV PF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable VF flood bit on PF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Restrict VF from configuring any VLAN mode (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Convert vmalloc/memset to kcalloc (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix ethtool statistics length calculation (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix bug in TX statistics (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix resource allocation for TX queues (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix loopback diagnostic test (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Mark functions as static in qlcnic_83xx_hw.c (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Mark functions as static in qlcnic_io.c (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.53 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Support for 16 virtual NIC functions (Chad Dupuis) [1089352]
- [ethernet] qlcnic: VLAN enhancement for 84XX adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow single Tx/Rx queue for all adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Refactor initialize nic code path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Issue INIT_NIC command only once (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Disable DCB operations from SR-IOV VFs (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Dump mailbox registers when mailbox command times out (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix mailbox processing during diagnostic test (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow firmware dump collection when auto firmware recovery is disabled (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix memory allocation (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix TSS/RSS validation for 83xx/84xx series adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix TSS/RSS ring validation logic (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix typo in printk (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.52 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable multiple Tx queue support for 83xx/84xx Series adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: refactor Tx/SDS ring calculation and validation in driver (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance ethtool Statistics for Multiple Tx queue (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Register netdev in FAILED state for 83xx/84xx (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do not read QLCNIC_FW_CAPABILITY_MORE_CAPS bit for 83xx adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do not force adapter to perform LRO without destination IP check (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove unnecessary pci_set_drvdata() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Validate Tx queue only for 82xx adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.51 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Skip unknown entry type while collecting firmware dump (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb code cleanup and refactoring (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Remove redundant eSwitch enable commands (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update ethtool standard pause settings (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Firmware dump collection when auto recovery is disabled (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance ethtool to display ring indices and interrupt mask (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Print informational messages only once during driver load (Chad Dupuis) [1089352]
- [ethernet] qlcnic: add missing destroy_workqueue() on error path in qlcnic_probe() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Miscellaneous conversions to ETH_ALEN (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix SR-IOV configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix register device in FAILED state for 82xx (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix warning reported by kbuild test robot (Chad Dupuis) [1089352]
- [ethernet] qlcnic: use standard NAPI weights (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove a stray semicolon (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix sparse warning (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Convert uses of compare_ether_addr to ether_addr_equal (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.50 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add support for per port eswitch configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Restructuring of qlc_83xx_fw_info structure (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add AER support for 83xx adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add AER callback handlers (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Store firmware dump state in CAMRAM register (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Use firmware recommended dump capture mask as default (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Remove inline keyword (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance PVID handling for 84xx adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.49 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, Add support for CEE Netlink interface (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb: Register DCB AEN handler (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, Get DCB parameters from the adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, Query adapter DCB capabilities (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Back off patch for the upstream commit "d6e9c89a8d3cf0a5184badbcd50169179af27721" (Chad Dupuis) [1089352]
- [ethernet] be2net: query max_tx_qs for BE3 super-nic profile from FW (Ivan Vecera) [1088575]
- [ethernet] be2net: define macro for_all_tx_queues_on_eq() (Ivan Vecera) [1088575]
- [ethernet] be2net: get rid of TX budget (Ivan Vecera) [1088575]
- [ethernet] be2net: make be_cmd_get_regs() return a status (Ivan Vecera) [1088575]
- [ethernet] be2net: define BE_MAX_MTU (Ivan Vecera) [1088575]
- [ethernet] be2net: remove unncessary gotos (Ivan Vecera) [1088575]
- [ethernet] be2net: fix log messages in lancer FW download path (Ivan Vecera) [1088575]
- [ethernet] be2net: Add a dma_mapping_error counter in ethtool (Ivan Vecera) [1088575]
- [ethernet] be2net: Add TX completion error statistics in ethtool (Ivan Vecera) [1088575]
- [ethernet] be2net: add a description for counter rx_input_fifo_overflow_drop (Ivan Vecera) [1088575]
- [ethernet] be2net: shorten AMAP_GET/SET_BITS() macro calls (Ivan Vecera) [1088575]
- [ethernet] be2net: add a few log messages (Ivan Vecera) [1088575]
- [ethernet] be2net: Set skb->csum_level for encapsulated checksum (Ivan Vecera) [1088575]
- [ethernet] be2net: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1088575]
- [ethernet] be2net: support deleting FW dump via ethtool (only for Lancer) (Ivan Vecera) [1088575]
- [ethernet] be2net: ignore VF mac address setting for the same mac (Ivan Vecera) [1088575]
- [ethernet] be2net: ignore get/set profile FW cmd failures (Ivan Vecera) [1088575]
- [ethernet] be2net: Issue shutdown event to ocrdma driver (Ivan Vecera) [1088575]
- [ethernet] be2net: update driver version to 10.4 (Ivan Vecera) [1088575]
- [ethernet] be2net: use adapter->flags to track SRIOV state (Ivan Vecera) [1088575]
- [ethernet] be2net: avoid SRIOV config for BE2 chip (Ivan Vecera) [1088575]
- [ethernet] be2net: use be_max_vfs() macro to access max-vfs (Ivan Vecera) [1088575]
- [ethernet] be2net: use "if (!foo)" test style (Ivan Vecera) [1088575]
- [ethernet] be2net: remove unused structures in be_cmds.h (Ivan Vecera) [1088575]
- [ethernet] be2net: reduce arguments passed to FW-cmd routines (Ivan Vecera) [1088575]
- [ethernet] be2net: update UE bit description strings (Ivan Vecera) [1088575]
- [ethernet] be2net: fix return status of some ndo methods (Ivan Vecera) [1088575]
- [ethernet] be2net: fix return status of some ethtool methods (Ivan Vecera) [1088575]
- [ethernet] be2net: return -ENOMEM for memory allocation failures (Ivan Vecera) [1088575]
- [ethernet] be2net: return -ETIMEDOUT when a FW-cmd times out (Ivan Vecera) [1088575]
- [ethernet] be2net: fix error status for FW-download (Ivan Vecera) [1088575]
- [ethernet] be2net: use -ENETDOWN error status when interface is down (Ivan Vecera) [1088575]
- [ethernet] be2net: set EQ DB clear-intr bit in be_open() (Ivan Vecera) [1088575]
- [ethernet] be2net: re-enable vlan filtering mode asap (Ivan Vecera) [1088575]
- [ethernet] be2net: create optimal number of queues on SR-IOV config (Ivan Vecera) [1088575]
- [ethernet] be2net: read VF's capabilities from GET_PROFILE_CONFIG cmd (Ivan Vecera) [1088575]
- [ethernet] be2net: remove be_cmd_get_profile_config_mbox/mccq() variants (Ivan Vecera) [1088575]
- [ethernet] be2net: fix qnq mode detection on VFs (Ivan Vecera) [1088575]
- [ethernet] be2net: cleanup MCC async event processing code (Ivan Vecera) [1088575]
- [ethernet] be2net: move async cmd processing to a separate routine (Ivan Vecera) [1088575]
- [ethernet] be2net: re-factor MCCQ error status handling code (Ivan Vecera) [1088575]
- [ethernet] be2net: support flashing new regions on Skyhawk-R (Ivan Vecera) [1088575]
- [ethernet] be2net: fixup TX-rate setting code for Skyhawk-R (Ivan Vecera) [1088575]
- [ethernet] be2net: skip multicast promiscuos setting in already set (Ivan Vecera) [1088575]
- [ethernet] be2net: Add support to configure SR-IOV VF minimum and maximum Tx rate through ip tool (Ivan Vecera) [1088575]
- [ethernet] be2net: get rid of SET_ETHTOOL_OPS (Ivan Vecera) [1088575]
- [ethernet] be2net: use MCCQ instead of MBOX in be_cmd_rss_config() (Ivan Vecera) [1088575]
- [ethernet] be2net: include rx-compl error counter in ethtool stats (Ivan Vecera) [1088575]
- [ethernet] be2net: remove unused code in be_cmd_vlan_config() (Ivan Vecera) [1088575]
- [ethernet] be2net: covert vlan array to bit-map (Ivan Vecera) [1088575]
- [ethernet] be2net: fix line wrap and function call indentation in be_ethtool.c (Ivan Vecera) [1088575]
- [ethernet] be2net: fix function call indentation in be_cmds.c (Ivan Vecera) [1088575]
- [ethernet] be2net: fix line wrap and function call indentation in be_main.c (Ivan Vecera) [1088575]
- [ethernet] be2net: Support for configurable RSS hash key (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix to reap TX compls till HW doesn't respond for some time (Ivan Vecera) [1088575]
- [ethernet] be2net: Add abi version between be2net and ocrdma (Ivan Vecera) [1088575]
- [ethernet] be2net: fix build dependency on VxLAN (Ivan Vecera) [1088575 1093399 1099545]
- [ethernet] be2net: csum, tso and rss steering offload support for VxLAN (Ivan Vecera) [1088575 1093399 1099545]
- [ethernet] be2net: add FW cmds needed for VxLAN offloads (Ivan Vecera) [1088575 1093399 1099545]
- [ethernet] be2net: Call dev_kfree_skby_any instead of kfree_skb (Ivan Vecera) [1088575]
- [ethernet] be2net: update driver version to 10.2 (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix vlans_added counter (Ivan Vecera) [1088575]
- [ethernet] be2net: Create multiple TXQs on RSS capable multi-channel BE3-R interfaces (Ivan Vecera) [1088575]
- [ethernet] be2net: fix pmac_id[] allocation size (Ivan Vecera) [1088575]
- [ethernet] be2net: log LPVID used in multi-channel configs (Ivan Vecera) [1088575]
- [ethernet] be2net: Add link state control for VFs (Ivan Vecera) [1088575]
- [ethernet] be2net: Use GET_PROFILE_CONFIG cmd for BE3-R to query max-vfs (Ivan Vecera) [1088575]
- [ethernet] be2net: dma_sync each RX frag before passing it to the stack (Ivan Vecera) [1088575]
- [ethernet] be2net: isolate TX workarounds not applicable to Skyhawk-R (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix skb double free in be_xmit_wrokarounds() failure path (Ivan Vecera) [1088575]
- [ethernet] be2net: clear promiscuous bits in adapter->flags while disabling promiscuous mode (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix to reset transparent vlan tagging (Ivan Vecera) [1088575]
- [ethernet] be2net: Use pci_enable_msix_range() instead of pci_enable_msix() (Ivan Vecera) [1088575]
- [ethernet] be2net: refactor multi-channel config code for Skyhawk-R chip (Ivan Vecera) [1088575]
- [ethernet] be2net: Update copyright year (Ivan Vecera) [1088575]
- [ethernet] be2net: Log a kernel message when UE is detected in BE & Skyhawk (Ivan Vecera) [1088575]
- [ethernet] be2net: Explicitly initialize u64_stats_sync structures for lockdep (Ivan Vecera) [1088575]
- [drm] bochs: changes from 3.14..3.15 for bochs (Gerd Hoffmann) [1043379]
- [drm] bochs: replace ALIGN(PAGE_SIZE) by PAGE_ALIGN (Gerd Hoffmann) [1043379]
- [drm] bochs: Remove unecessary NULL check in gem_free (Gerd Hoffmann) [1043379]
- [drm] bochs: Remove unnecessary NULL check in bo_unref (Gerd Hoffmann) [1043379]
- [drm] bochs: drop unused struct fields (Gerd Hoffmann) [1043379]
- [drm] bochs: add power management support (Gerd Hoffmann) [1043379]
- [drm] bochs: fix bochs kconfig dependencies (Gerd Hoffmann) [1043379]
- [drm] bochs: new driver (Gerd Hoffmann) [1043379]
- [iommu] amd: Split init_iommu_group() from iommu_init_device() (Myron Stowe) [1141937]
- [iommu] Rework iommu_group_get_for_pci_dev() (Myron Stowe) [1141937]

* Thu Oct 09 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-186.el7]
- [kernel] sched/balancing: Reduce the rate of needless idle load balancing (Larry Woodman) [1120318]
- [kernel] sched/fair: Implement fast idling of CPUs when the system is partially loaded (Larry Woodman) [1120318]
- [kernel] sched: Skip double execution of pick_next_task_fair() (Larry Woodman) [1120318]
- [md] Revert: dm: change sector_count member in clone_info from sector_t to unsigned (Mike Snitzer) [1147574]
- [md] Revert: dm: introduce dm_accept_partial_bio (Mike Snitzer) [1147574]
- [md] Revert: dm-snapshot: allocate a per-target structure for snapshot-origin target (Mike Snitzer) [1147574]
- [md] Revert: dm-snapshot: do not split read bios sent to snapshot-origin target (Mike Snitzer) [1147574]
- [virt] kvm: nested vmx - disable perf cpuid reporting (Marcelo Tosatti) [1083969]
- [mm] slub: Handle NULL parameter in kmem_cache_flags (Ilya Dryomov) [1143028]
- [crypto] algif: avoid excessive use of socket buffer in skcipher (Ondrej Kozina) [1136075]
- [kernel] time/clocksource: Move cycle_last validation to core code (Prarit Bhargava) [1148398]
- [kernel] time/clocksource: Make delta calculation a function (Prarit Bhargava) [1148398]
- [mm] vmscan: clear kswapd's special reclaim powers before exiting (Motohiro Kosaki) [810042]
- [x86] mm/numa: fix array index overflow when synchronizing nid to memblock.reserved (Motohiro Kosaki) [810042]
- [x86] mm/numa: initialize numa_kernel_nodes in numa_clear_kernel_node_hotplug() (Motohiro Kosaki) [810042]
- [mm] page_alloc: make movable_node have higher priority (Motohiro Kosaki) [810042]
- [x86] memblock, mem_hotplug: make memblock skip hotpluggable regions if needed (Motohiro Kosaki) [810042]
- [x86] mm: mark all nodes the kernel resides un-hotpluggable (Motohiro Kosaki) [810042]
- [x86] mm: mark hotpluggable memory in memblock (Motohiro Kosaki) [810042]
- [mm] memblock: make memblock_set_node() support different memblock_type (Motohiro Kosaki) [810042]
- [mm] memblock/mem_hotplug: introduce MEMBLOCK_HOTPLUG flag to mark hotpluggable regions (Motohiro Kosaki) [810042]
- [mm] memblock: numa - introduce flags field into memblock (Motohiro Kosaki) [810042]
- [mm] memblock: debug - correct displaying of upper memory boundary (Motohiro Kosaki) [810042]
- [x86] mm: get pg_data_t's memory from other node (Motohiro Kosaki) [810042]
- [mm] mem-hotplug: introduce movable_node boot option (Motohiro Kosaki) [810042]
- [x86] kernel/setup: do reserve_crashkernel() after SRAT is parsed (Motohiro Kosaki) [810042]
- [x86] mem-hotplug: support initialize page tables in bottom-up (Motohiro Kosaki) [810042]
- [x86] mm: factor out of top-down direct mapping setup (Motohiro Kosaki) [810042]
- [mm] memblock: introduce bottom-up allocation mode (Motohiro Kosaki) [810042]
- [mm] memblock: factor out of top-down allocation (Motohiro Kosaki) [810042]
- [x86] mm: Add 'step_size' comments to init_mem_mapping() (Motohiro Kosaki) [810042]
- [x86] srat: Print Hot-Pluggable Field in SRAT (Motohiro Kosaki) [810042]

* Thu Oct 09 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-185.el7]
- [fs] udf: Avoid infinite loop when processing indirect ICBs (Jacob Tanenbaum) [1142322] {CVE-2014-6410}
- [fs] eliminate BUG() call when there's an unexpected lock on file close (Frank Sorenson) [1148130]
- [hid] fix off by one error in various _report_fixup routines (Jacob Tanenbaum) [1141394] {CVE-2014-3184}
- [hid] logitech-dj: fix OOB array access (Jacob Tanenbaum) [1141212] {CVE-2014-3182}
- [hid] picolcd: fix memory corruption via OOB write (Jacob Tanenbaum) [1141409] {CVE-2014-3186}
- [usb] serial/whiteheat: fix memory corruption flaw (Jacob Tanenbaum) [1141404] {CVE-2014-3185}
- [hid] fix OOB write in magicmouse driver (Jacob Tanenbaum) [1141177] {CVE-2014-3181}
- [x86] uv/nmi: Fix UV NMI handler when KDB not configured (George Beshers) [1138519]
- [x86] uv/nmi: Fix Sparse warnings (George Beshers) [1138519]
- [kernel] debug: Fix no KDB config problem (George Beshers) [1138519]
- [x86] uv: Add call to KGDB/KDB from NMI handler (George Beshers) [1138519]
- [kernel] debug: Add support for external NMI handler to call KGDB/KDB (George Beshers) [1138519]
- [x86] uv: Add kdump to UV NMI handler (George Beshers) [1138519]
- [x86] uv: Add summary of cpu activity to UV NMI handler (George Beshers) [1138519]
- [x86] uv: Update UV support for external NMI signals (George Beshers) [1138519]
- [x86] uv: Move NMI support (George Beshers) [1138519]
- [infiniband] ipath: Add P_Key change event support (Doug Ledford) [1085961]
- [infiniband] qib: Additional Intel branding changes (Doug Ledford) [1085961]
- [infiniband] ipath: Use time_before()/_after() (Doug Ledford) [1085961]
- [infiniband] ipath: Translate legacy diagpkt into newer extended diagpkt (Doug Ledford) [1085961]
- [infiniband] qib: Fix port in pkey change event (Doug Ledford) [1085961]
- [infiniband] qib: Use pci_enable_msix_range() instead of pci_enable_msix() (Doug Ledford) [1085961]
- [infiniband] qib: Cleanup qib_register_observer() (Doug Ledford) [1085961]
- [infiniband] qib: Change SDMA progression mode depending on single- or multi-rail (Doug Ledford) [1085961]
- [infiniband] qib: Remove duplicate check in get_a_ctxt() (Doug Ledford) [1085961]
- [infiniband] qib: Fix memory leak of recv context when driver fails to initialize (Doug Ledford) [1085961]
- [infiniband] qib: fixup indentation in qib_ib_rcv() (Doug Ledford) [1085961]
- [infiniband] qib: add missing braces in do_qib_user_sdma_queue_create() (Doug Ledford) [1085961]
- [infiniband] qib: Modify software pma counters to use percpu variables (Doug Ledford) [1085961]
- [infiniband] qib: Add percpu counter replacing qib_devdata int_counter (Doug Ledford) [1085961]
- [infiniband] qib: Fix debugfs ordering issue with multiple HCAs (Doug Ledford) [1085961]
- [infiniband] ipath: Fix potential buffer overrun in sending diag packet routine (Doug Ledford) [1085961]
- [infiniband] qib: Fix potential buffer overrun in sending diag packet routine (Doug Ledford) [1085961]
- [infiniband] qib: Add missing serdes init sequence (Doug Ledford) [1085961]
- [infiniband] qib: Fix QP check when looping back to/from QP1 (Doug Ledford) [1085961]
- [kernel] audit: drop arch from __audit_syscall_entry() interface (Richard Guy Briggs) [1053921]
- [kernel] audit: fix build error when asm/syscall.h does not exist (Richard Guy Briggs) [1053921]
- [kernel] audit: add arch field to seccomp event log (Richard Guy Briggs) [1053921]
- [kernel] audit: __audit_syscall_entry - ignore arch arg and call syscall_get_arch() directly (Richard Guy Briggs) [1053921]
- [kernel] audit: audit_syscall_entry() should not require the arch (Richard Guy Briggs) [1053921]
- [kernel] audit: implement syscall_get_arch for all arches (Richard Guy Briggs) [1053921]
- [kernel] syscall.h: fix doc text for syscall_get_arch() (Richard Guy Briggs) [1053921]
- [kernel] audit: use uapi/linux/audit.h for AUDIT_ARCH declarations (Richard Guy Briggs) [1053921]
- [kernel] syscall_get_arch: remove useless function arguments (Richard Guy Briggs) [1053921]

* Wed Oct 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-184.el7]
- [scsi] cxgb4i: Fix ipv6 build failure caught with randconfig (Sai Vemuri) [1126539]
- [scsi] cxgb4i: remove spurious use of rcu (Sai Vemuri) [1126539]
- [scsi] cxgb4i Guard ipv6 code with a config check (Sai Vemuri) [1126539]
- [scsi] cxgb4i: Add ipv6 code to driver, call into libcxgbi ipv6 api (Sai Vemuri) [1126539]
- [scsi] libcxgbi: Add ipv6 api to driver (Sai Vemuri) [1126539]
- [scsi] cxgb4i: Use cxgb4_select_ntuple to correctly calculate ntuple fields (Sai Vemuri) [1126539]
- [ethernet] cxgb4: Issue mbox commands on correct mbox (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Avoid dumping Write-only registers in register dump (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Detect and display firmware reported errors (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix T5 adapter accessing T4 adapter registers (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fixed the code to use correct length for part number (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix for handling 1Gb/s SFP+ Transceiver Modules (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Free completed tx skbs promptly (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix race condition in cleanup (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Update FW version string to match FW binary version (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix for SR-IOV VF initialization (Sai Vemuri) [1124947]
- [scsi] cxgb4i: Move stray CPL definitions to cxgb4 driver (Sai Vemuri) [1124947]
- [ethernet] cxgb4: only free allocated fls (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Only call CQ completion handler if it is armed (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fixed incorrect check for memory operation in t4_memory_rw (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Don't limit TPTE count to 32KB (Sai Vemuri) [1124947]
- [infiniband] cxgb4: advertise the correct device max attributes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Support query_qp() verb (Sai Vemuri) [1124947]
- [infiniband] cxgb4: log detailed warnings for negative advice (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add the MC1 registers to read in the interrupt handler (Sai Vemuri) [1124947]
- [infiniband] cxgb4: fix for 64-bit integer division (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Export symbols required by cxgb4i for ipv6 support and required defines (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Move common defines to cxgb4 (Sai Vemuri) [1124947]
- [infiniband] cxgb4: work request logging feature (Sai Vemuri) [1124947]
- [ethernet] cxgb4: display TPTE on errors (Sai Vemuri) [1124947]
- [ethernet] cxgb4: use firmware ord/ird resource limits (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Detect Ing. Padding Boundary at run-time (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Call iwpm_init() only once (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Initialize the device status page (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Clean up connection on ARP error (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix skb_leak in reject_cr() (Sai Vemuri) [1124947]
- [ethernet] cxgb4: remove unnecessary null test before debugfs_remove_recursive (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Adds device ID for few more Chelsio T4 Adapters (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Replaced the backdoor mechanism to access the HW memory with PCIe Window method (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Use FW interface to get BAR0 value (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fixes cxgb4 probe failure in VM when PF is exposed through PCI Passthrough (Sai Vemuri) [1124947]
- [ethernet] cxgb4: use dev_port to identify ports (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Not need to hold the adap_rcu_lock lock when read adap_rcu_list (Sai Vemuri) [1124947]
- [infiniband] cxgb4: don't truncate the recv window size (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Choose appropriate hw mtu index and ISS for iWARP connections (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Allocate and use IQs specifically for indirect interrupts (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add support for iWARP Port Mapper user space service (Sai Vemuri) [1124947]
- [infiniband] cxgb4: add missing padding at end of struct c4iw_alloc_ucontext_resp (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add missing padding at end of struct c4iw_create_cq_resp (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix vlan support (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix memory leaks in c4iw_alloc() error paths (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Check if rx checksum offload is enabled, while reading hardware calculated checksum (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Decode the firmware port and module type a bit more for ethtool (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Decode PCIe Gen3 link speed (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Update Kconfig to include Chelsio T5 adapter (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Only allow kernel db ringing for T4 devs (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Force T5 connections to use TAHOE congestion control (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix endpoint mutex deadlocks (Sai Vemuri) [1124947]
- [ethernet] cxgb4: use the correct max size for firmware flash (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Save the correct mac addr for hw-loopback connections in the L2T (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix over-dereference when terminating (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Use uninitialized_var() (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add missing debug stats (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Initialize reserved fields in a FW work request (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Use pr_warn_ratelimited (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Max fastreg depth depends on DSGL support (Sai Vemuri) [1124947]
- [infiniband] cxgb4: SQ flush fix (Sai Vemuri) [1124947]
- [infiniband] cxgb4: rmb() after reading valid gen bit (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Endpoint timeout fixes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Use the BAR2/WC path for kernel QPs and T5 devices (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Disable DSGL use by default (Sai Vemuri) [1124947]
- [infiniband] cxgb4: rx_data() needs to hold the ep mutex (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Drop RX_DATA packets if the endpoint is gone (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Lock around accept/reject downcalls (Sai Vemuri) [1124947]
- [infiniband] cxgb4: set error code on kmalloc() failure (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Adds device ID for few more Chelsio Adapters (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Remove addressof casts to same type (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Call dev_kfree/consume_skb_any instead of [dev_]kfree_skb (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Update snd_seq when sending MPA messages (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Connect_request_upcall fixes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Ignore read reponse type 1 CQEs (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix possible memory leak in RX_PKT processing (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Don't leak skb in c4iw_uld_rx_handler() (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Save the correct map length for fast_reg_page_lists (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Default peer2peer mode to 1 (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Mind the sq_sig_all/sq_sig_type QP attributes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix incorrect BUG_ON conditions (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Always release neigh entry (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Allow loopback connections (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Cap CQ size at T4_MAX_IQ_SIZE (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix four byte info leak in c4iw_create_cq() (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix underflows in c4iw_create_qp() (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Doorbell Drop Avoidance Bug Fixes (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Treat CPL_ERR_KEEPALV_NEG_ADVICE as negative advice (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Calculate len properly for LSO path (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Updates for T5 SGE's Egress Congestion Threshold (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Rectify emitting messages about SGE Ingress DMA channels being potentially stuck (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add code to dump SGE registers when hitting idma hangs (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix some small bugs in t4_sge_init_soft() when our Page Size is 64KB (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Stop using ethtool SPEED_* constants (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add more PCI device ids (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Don't assume LSO only uses SGL path in t4_eth_xmit() (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Remove unused registers and add missing ones (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Query firmware for T5 ULPTX MEMWRITE DSGL capabilities (Sai Vemuri) [1124947]
- [ethernet] cxgb4: LE-Workaround is not atomic in firmware (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Allow >10G ports to have multiple queues (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Print adapter VPD Part Number instead of Engineering Change field (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add support to recognize 40G links (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add missing neigh_release in LE-Workaround path (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix gcc warning on 32-bit arch (Sai Vemuri) [1124947]
- [ethernet] cxgb4: silence shift wrapping static checker warning (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Changed FW check version to match FW binary version (Sai Vemuri) [1124947]
- [ethernet] cxgb4: make functions static and remove dead code (Sai Vemuri) [1124947]
- [tools] perf: Disable kernel symbol demangling by default (Jiri Olsa) [1140522]
- [tools] perf/symbols: Don't demangle parameters and such by default (Jiri Olsa) [1140522]
- [powerpc] pseries: Fix endian issues in memory hotplug (Steve Best) [1142244]
- [powerpc] pseries/hvcserver: Fix endian issue in hvcs_get_partner_info (Steve Best) [1142244]
- [powerpc] powernv: Interface to register/unregister opal dump region (Steve Best) [1142244]
- [kernel] printk: Add function to return log buffer address and size (Steve Best) [1142244]
- [acpi] hotplug: Check scan handlers in acpi_scan_hot_remove() (Prarit Bhargava) [1141846]
- [acpi] hotplug: Simplify acpi_set_hp_context() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Eliminate acpiphp_dev_to_bridge() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Add hotplug contexts to PCI host bridges (Prarit Bhargava) [1141846]
- [acpi] Remove duplicate definitions of PREFIX (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Use pci_device_is_present() (Prarit Bhargava) [1141846]
- [acpi] hotplug: Rework deferred execution of acpi_device_hotplug() (Prarit Bhargava) [1141846]
- [ata] libata-acpi: Add hotplug contexts to ACPI companions of SATA devices (Prarit Bhargava) [1141846]
- [acpi] dock: Add .uevent() callback to struct acpi_hotplug_context (Prarit Bhargava) [1141846]
- [acpi] dock: Use callback pointers from devices' ACPI hotplug contexts (Prarit Bhargava) [1141846]
- [acpi] dock: Use ACPI device object pointers instead of ACPI handles (Prarit Bhargava) [1141846]
- [acpi] hotplug: Add .fixup() callback to struct acpi_hotplug_context (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Do not clear event callback pointer for docks (Prarit Bhargava) [1141846]
- [acpi] Drop acpi_evaluate_hotplug_ost() and ACPI_HOTPLUG_OST (Prarit Bhargava) [1141846]
- [acpi] rename acpi_evaluate_hotplug_ost() to acpi_evaluate_ost() (Prarit Bhargava) [1141846]
- [acpi] dock: Dispatch dock notifications from the global notify handler (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Add ACPIPHP contexts to devices handled by PCIeHP (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rename register_slot() to acpiphp_add_context() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Relax the checking of _STA return values (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Execute _EJ0 under the ACPI scan lock (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Hotplug notifications from acpi_bus_notify() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify acpi_install_hotplug_notify_handler() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rework acpiphp_check_host_bridge() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rework the handling of eject requests (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Consolidate ACPIPHP with ACPI core hotplug (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Define hotplug context lock in the core (Prarit Bhargava) [1141846]
- [acpi] hotplug: Fix potential race in acpi_bus_notify() (Prarit Bhargava) [1141846]
- [acpi] acpica: Introduce acpi_get_data_full() and rework acpi_get_data() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Do not pass ACPI handle to hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Use acpi_handle_debug() in hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Drop crit_sect locking (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Drop acpiphp_bus_add() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Store acpi_device pointer in acpiphp_context (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rework acpiphp_no_hotplug() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Drop acpiphp_bus_trim() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify register_slot() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Proper kerneldoc comments for enumeration/removal (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify disable_slot() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Fix bridge removal race vs dock events (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Fix bridge removal race in handle_hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Scan root bus under the PCI rescan-remove lock (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Move PCI rescan-remove locking to hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Remove entries from bus->devices in reverse order (Prarit Bhargava) [1141846]
- [acpi] acpiphp: Fix radeon/nouveau VGA switcheroo problem related to hotplug (Prarit Bhargava) [1141846]
- [acpi] hotplug: Handle containers in a special way (Prarit Bhargava) [1141846]
- [acpi] hotplug: Add demand_offline hotplug profile flag (Prarit Bhargava) [1141846]
- [acpi] bind: Move acpi_get_child() to drivers/ide/ide-acpi.c (Prarit Bhargava) [1141846]
- [acpi] bind: Pass struct acpi_device pointer to acpi_bind_one() (Prarit Bhargava) [1141846]
- [acpi] bind: Rework struct acpi_bus_type (Prarit Bhargava) [1141846]
- [acpi] bind: Redefine acpi_preset_companion() (Prarit Bhargava) [1141846]
- [acpi] bind: Redefine acpi_get_child() (Prarit Bhargava) [1141846]
- [pci] acpi: Use acpi_find_child_device() for child devices lookup (Prarit Bhargava) [1141846]
- [acpi] bind: Simplify child device lookups (Prarit Bhargava) [1141846]
- [acpi] libata: Store an ACPI device pointer in struct acpi_dev_node (Prarit Bhargava) [1141846]
- [ata] libata: remove power dependent device handling (Prarit Bhargava) [1141846]
- [acpi] bind: Prefer device objects with _STA to those without it (Prarit Bhargava) [1141846]
- [drm] nouveau/nouveau_acpi: convert acpi_get_handle() to acpi_has_method() (Prarit Bhargava) [1141846]
- [acpi] libata: Remove ata_dev_acpi_handle stub in libata.h (Prarit Bhargava) [1141846]
- [ata] libata-acpi: rework the ata acpi bind support (Prarit Bhargava) [1141846]
- [acpi] Cleanup sparse warning on acpi_os_initialize1() (Prarit Bhargava) [1141846]

* Tue Oct 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-183.el7]
- [infiniband] usnic: backport to older netdev notifier arguments (Doug Ledford) [916382]
- [infiniband] usnic: Fix source file missing copyright and license (Doug Ledford) [916382]
- [infiniband] usnic: Remove '0x' when using pa format (Doug Ledford) [916382]
- [infiniband] usnic: Fix smatch endianness error (Doug Ledford) [916382]
- [infiniband] usnic: Remove unused includes of <linux/version.h> (Doug Ledford) [916382]
- [infiniband] usnic: Use GFP_ATOMIC under spinlock (Doug Ledford) [916382]
- [infiniband] usnic: Remove unused variable in usnic_debugfs_exit() (Doug Ledford) [916382]
- [infiniband] usnic: Set userspace/kernel ABI ver to 4 (Doug Ledford) [916382]
- [infiniband] usnic: Advertise usNIC devices as RDMA_NODE_USNIC_UDP (Doug Ledford) [916382]
- [infiniband] usnic: Add dependency on CONFIG_INET (Doug Ledford) [916382]
- [infiniband] usnic: Fix endianness-related warnings (Doug Ledford) [916382]
- [infiniband] usnic: Append documentation to usnic_transport.h and cleanup (Doug Ledford) [916382]
- [infiniband] usnic: Fix typo "Ignorning" -> "Ignoring" (Doug Ledford) [916382]
- [infiniband] usnic: Expose flows via debugfs (Doug Ledford) [916382]
- [infiniband] usnic: Use for_each_sg instead of a for-loop (Doug Ledford) [916382]
- [infiniband] usnic: Remove superflous parentheses (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support in usnic_ib_qp_grp.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support in u*verbs.c, u*main.c and u*util.h (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support to usnic_transport.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support to usnic_fwd.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Update ABI and Version file for UDP support (Doug Ledford) [916382]
- [infiniband] usnic: Port over sysfs to new usnic_fwd.h (Doug Ledford) [916382]
- [infiniband] usnic: Port over usnic_ib_qp_grp.[hc] to new usnic_fwd.h (Doug Ledford) [916382]
- [infiniband] usnic: Port over main.c and verbs.c to the usnic_fwd.h (Doug Ledford) [916382]
- [infiniband] usnic: Push all forwarding state to usnic_fwd.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Add struct usnic_transport_spec (Doug Ledford) [916382]
- [infiniband] usnic: Change WARN_ON to lockdep_assert_held (Doug Ledford) [916382]
- [infiniband] usnic: Add Cisco VIC low-level hardware driver (Doug Ledford) [916382]
- [md] dm-table: propagate QUEUE_FLAG_NO_SG_MERGE (Jeff Moyer) [1105698]
- [virt] virtio_blk: support multi virt queues per virtio-blk device (Jeff Moyer) [1105698]
- [virt] virtio_blk: introduce feature of VIRTIO_BLK_F_MQ (Jeff Moyer) [1105698]
- [virt] virtio_blk: don't hold spin lock during world switch (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: remove alloc_hctx and free_hctx methods (Jeff Moyer) [1105698]
- [virt] virtio_blk: fix race between start and stop queue (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: add async parameter to blk_mq_start_stopped_hw_queues (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: split out tag initialization, support shared tags (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: add ->init_request and ->exit_request methods (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: do not initialize req->special (Jeff Moyer) [1105698]
- [virt] virtio_blk: base queue-depth on virtqueue ringsize or module param (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: allow blk_mq_init_commands() to return failure (Jeff Moyer) [1105698]
- [virt] virtio_blk: don't crash, report error if virtqueue is broken (Jeff Moyer) [1105698]
- [virt] virtio_blk: use blk_mq_complete_request (Jeff Moyer) [1105698]
- [virt] virtio_blk: virtqueue_kick() must be ordered with other virtqueue operations (Jeff Moyer) [1105698]
- [virt] virtio_blk: blk-mq support (Jeff Moyer) [1105698]
- [virt] virtio: use size-based config accessors (Jeff Moyer) [1105698]
- [virt] virtio_config: introduce size-based accessors (Jeff Moyer) [1105698]
- [virt] virtio_blk: Add missing 'static' qualifiers (Jeff Moyer) [1105698]
- [block] cfq-iosched: Add comments on update timing of weight (Vivek Goyal) [1116126]
- [block] cfq-iosched: Fix wrong children_weight calculation (Vivek Goyal) [1116126]
- [fs] aio: block exit_aio() until all context requests are completed (Jeff Moyer) [1122092]
- [fs] aio: add missing smp_rmb() in read_events_ring (Jeff Moyer) [1131312]
- [fs] aio: fix reqs_available handling (Jeff Moyer) [1122092]
- [fs] aio: report error from io_destroy() when threads race in io_destroy() (Jeff Moyer) [1122092]
- [fs] aio: block io_destroy() until all context requests are completed (Jeff Moyer) [1122092]
- [fs] aio: v4 ensure access to ctx->ring_pages is correctly serialised for migration (Jeff Moyer) [1122092]
- [fs] aio/migratepages: make aio migrate pages sane (Jeff Moyer) [1122092]
- [fs] aio: clean up and fix aio_setup_ring page mapping (Jeff Moyer) [1122092]
- [md] dm-cache: fix race affecting dirty block count (Mike Snitzer) [1140362]
- [md] dm-cache: fix race causing dirty blocks to be marked as clean (Mike Snitzer) [1140362]
- [infiniband] mlx4: Fix wrong endianess access with QP context flags (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set vlan stripping policy by the right command (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Avoid dealing with MAC index in UPDATE_QP wrapper if not needed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use the correct VSD mask in UPDATE_QP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Correctly configure single ported VFs from the host (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: do not ignore autoneg in mlx4_en_set_pauseparam() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Set user-space raw Ethernet QPs to properly handle VXLAN traffic (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Move the tunnel steering helper function to mlx4_core (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set skb->csum_level for encapsulated checksum (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Avoid executing gid task when device is being removed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix lockdep splat for the iboe lock (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Get upper dev addresses as RoCE GIDs when port comes up (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Reorder steps in RoCE GID table initialization (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Don't duplicate the default RoCE GID (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Avoid null pointer dereference in mlx4_ib_scan_netdevs() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use is_kdump_kernel() to detect kdump kernel (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Use ARRAY_SIZE instead of sizeof/sizeof[0] (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Use ARRAY_SIZE instead of sizeof/sizeof[0] (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add support for secure-host and SMP firewall (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4_ib: Add support for user MR re-registration (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add helper functions to support MR re-registration (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Adjust events to use unsigned long param instead of void ptr (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: minor fixes (mainly avoidance of hidden casts) (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Move pci device handling from mlx5_ib to mlx5_core (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mlx4_en_[gs]et_priv_flags() can be static (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Reduce memory consumption on kdump kernel (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use low memory profile on kdump kernel (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Disable blueflame using ethtool private flags (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: current_mac isn't updated in port up (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: cq->irq_desc wasn't set in legacy EQ's (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Remove MCG in case it is attached to promiscuous QPs only (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: In SR-IOV mode host should add promisc QP to default entry only (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Make sure the max number of QPs per MCG isn't exceeded (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Make sure that negative array index isn't used (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix leakage of SW multicast entries (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Enable "block multicast loopback" for kernel consumers (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mark napi id for gro_skb (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx5: Fix possible race between mr tree insert/delete (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Ignore budget on TX napi polling (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix mac_hash database inconsistency (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Do not count LLC/SNAP in MTU calculation (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Do not disable vlan filter during promiscuous mode (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Verify port number in __mlx4_unregister_mac (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Run loopback test only when port is up (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix set port ratelimit for 40GE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't configure the HW vxlan parser when vxlan offloading isn't set (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: IRQ affinity hint is not cleared on port down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't use irq_affinity_notifier to track changes in IRQ affinity map (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix the error flow when probing with invalid VF configuration (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use affinity hint (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Keep only one driver entry release mlx4_priv (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix SRIOV free-pool management when enforcing resource quotas (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix gfp passing in create_qp_common() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix GFP flags parameters to be gfp_t (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Implement IB_QP_CREATE_USE_GFP_NOIO (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Reset RoCE VF gids when guest driver goes down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add interface for selecting VFs to enable QP0 via MLX proxy QPs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add infrastructure for selecting VFs to enable QP0 via MLX proxy QPs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Preparation for VFs to issue/receive SMI (QP0) requests/responses (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: SET_PORT called by mlx4_ib_modify_port should be wrapped (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix incorrect FLAGS1 bitmap test in mlx4_QUERY_FUNC_CAP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix memory leaks in SR-IOV error paths (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: fix unitialised variable is_mcast (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Fix warning about cast of wr_id back to pointer on 32 bits (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: add missing padding at end of struct mlx5_ib_create_srq (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: add missing padding at end of struct mlx5_ib_create_cq (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Refactor UMR to have its own context struct (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Set QP offsets and parameters for user QPs and not just for kernel QPs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Store MR attributes in mlx5_mr_core during creation and after UMR (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Add MR to radix tree in reg_mr_callback (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Fix error handling in reg_umr (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Copy DIF fields only when input and output space values match (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Simplify signature handover wqe for interleaved buffers (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Fix signature handover operation for interleaved buffers (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Replace pr_warning() with pr_warn() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Deprecate use_prio module parameter (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix uninitialized use of 'port_up' in mlx4_en_set_channels() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Invoke UPDATE_QP for proxy QP1 on MAC changes (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add UPDATE_QP SRIOV wrapper support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix inaccurate return value of mlx4_flow_attach() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Using positive error value for unsigned (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Protect MAC address modification with the state_lock mutex (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Removed unnecessary bit operation condition (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix smatch error - possible access to a null variable (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix errors in MAC address changing when port is down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: User prio mapping gets corrupted when changing number of channels (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Enforce irq affinity changes immediatly (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mellanox: Logging message cleanups (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't issue PCIe speed/width checks for VFs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Load the Eth driver first (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix slave id computation for single port VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Adjust port number in qp_attach wrapper when detaching (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: don't use napi_synchronize inside mlx4_en_netpoll (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Defer VF initialization till PF is fully initialized (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Preserve pci_dev_data after __mlx4_remove_one() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Add block multicast loopback support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mthca: Use pci_enable_msix_exact() instead of pci_enable_msix() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set proper build dependancy with vxlan (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Make buffer larger to avoid overflow warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix some indenting in mlx4_ib_add() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mthca: Return an error on ib_copy_to_udata() failure (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Implement vxlan ndo calls (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add support for CONFIG_DEV command (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: USe one wrapper that returns -EPERM (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: pass pci_device_id.driver_data to __mlx4_init_one during reset (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Use actual number of PCI functions (PF + VFs) for alias GUID logic (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Adapt num_vfs/probed_vf params for single port VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Adapt code for N-Port VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add utils for N-Port VFs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add data structures to support N-Ports per VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4_ib: Adapt code to use caps.num_ports instead of a constant (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix a sparse endianness warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't receive packets when the napi budget == 0 (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Deregister multicast vxlan steering rules when going down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Call dev_kfree_skb_any instead of dev_kfree_skb (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Load the IB driver when the device supports IBoE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Handle vxlan steering rules for mac address changes (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix wrong dump of the vxlan offloads device capability (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Activate RoCE/SRIOV (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix SIDR support of for UD QPs under SRIOV/RoCE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Implement IP based gids support for RoCE/SRIOV (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add ref counting to port MAC table for RoCE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: In RoCE allow guests to have multiple GIDS (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: For RoCE, allow slaves to set the GID entry at that slave's index (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Adjust QP1 multiplexing for RoCE/SRIOV (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5_core: remove unreachable function call in module init (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Expose support for signature MR feature (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Collect signature error completion (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Support IB_WR_REG_SIG_MR (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Keep mlx5 MRs in a radix tree under device (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Remove MTT access mode from umr flags helper function (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Break up wqe handling into begin & finish routines (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Initialize mlx5_ib_qp signature-related members (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Implement create_mr and destroy_mr (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mlx4_en_verify_params() can be static (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Change Connect-X description in kconfig (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use union for BlueFlame WQE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix sparse warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix selftest failing on non 10G link speed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Replace mlx4_en_mac_to_u64() with mlx4_mac_to_u64() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Move queue stopped/waked counters to be per ring (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Pad ethernet packets smaller than 17 bytes (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Verify mlx4_en module parameters (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix UP limit in ieee_ets->prio_tc (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix bad use of dev_id (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Expose port number through sysfs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx: Bump all Mellanox driver versions (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix limiting number of IRQ's instead of RSS queues (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set number of RX rings in a utility function (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx5: Use pci_enable_msix_range() instead of pci_enable_msix() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use pci_enable_msix_range() instead of pci_enable_msix() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Use IS_ENABLED(CONFIG_IPV6) (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add dependency INET (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix error return code (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: call gro handler for encapsulated frames (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Select PTP_1588_CLOCK (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: fix error return code in mlx4_en_get_qp() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: slight optimization of addr compare (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mlx4 calls skb_set_hash (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Implement the SIOCGHWTSTAMP ioctl (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: When marsheling uverbs path, clear unused fields (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Add user space RMPP support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: add new ioctl to ABI to support new registration options (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Add dev_notice messages for various umad/mad registration failures (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Update module to [pr|dev]_* style print messages (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] umad: Update module to [pr|dev]_* style print messages (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] iwcm: Use a default listen backlog if needed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Add user MR re-registration support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] rdma/core: Add support for iWARP Port Mapper user space service (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] umad: Fix use-after-free on close (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] umad: Fix error handling (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix kobject leak on device register error flow (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix port kobject deletion during error flow (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Remove unneeded kobject_get/put calls (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix sparse warnings about redeclared functions (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Fix sparse warning about gfp_t use (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] Add a QP creation flag to use GFP_NOIO allocations (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Remove overload in ib_sg_dma* (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] ehca: Remove ib_sg_dma_address() and ib_sg_dma_len() overloads (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] ipath: Remove ib_sg_dma_address() and ib_sg_dma_len() overloads (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] qib: Remove ib_sg_dma_address() and ib_sg_dma_len() overloads (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Check and handle potential DMA mapping errors (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Introduce signature verbs API (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Introduce protected memory regions (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] Refactor umem to use linear SG table (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix unused variable warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] cma: Handle global/non-linklocal IPv6 addresses in cma_check_linklocal() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] cm: Fix missing unlock on error in cm_init_qp_rtr_attr() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Make ib_addr a core IB module (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Add support for RDMA_NODE_USNIC_UDP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Add RDMA_TRANSPORT_USNIC_UDP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [kernel] genirq: Allow forcing cpu affinity of interrupts (Amir Vadai) [1107617 1107618 1107619 1107620]
- [lib] cpumask: cpumask_set_cpu_local_first to use all cores when numa node is not defined (Amir Vadai) [1107617 1107618 1107619 1107620]
- [lib] cpumask: Utility function to set n'th cpu - local cpu first (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx: Convert ethernet mac address declarations to use ETH_ALEN (Amir Vadai) [1107617 1107618 1107619 1107620]
- [net] core: Add sysfs file for port number (Amir Vadai) [1107617 1107618 1107619 1107620]

* Tue Oct 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-182.el7]
- [ethernet] qlge: Remove DEFINE_PCI_DEVICE_TABLE macro use (Chad Dupuis) [1089357]
- [ethernet] qlge: get rid of SET_ETHTOOL_OPS (Chad Dupuis) [1089357]
- [ethernet] qlge: Convert /n to \n (Chad Dupuis) [1089357]
- [ethernet] qlge: remove open-coded skb_cow_head (Chad Dupuis) [1089357]
- [ethernet] qlge: Do not propaged vlan tag offloads to vlans (Chad Dupuis) [1089357]
- [ethernet] qlge: Get rid of an redundant assignment (Chad Dupuis) [1089357]
- [ethernet] qlge: delete non-required instances of include <linux/init.h> (Chad Dupuis) [1089357]
- [ethernet] qlge: Fix vlan netdev features (Chad Dupuis) [1089357]
- [ethernet] qlge: make local function static (Chad Dupuis) [1089357]
- [ethernet] qlge: Update version to 1.00.00.34 (Chad Dupuis) [1089357]
- [ethernet] qlge: Allow enable/disable rx/tx vlan acceleration independently (Chad Dupuis) [1089357]
- [ethernet] qlge: Fix ethtool statistics (Chad Dupuis) [1089357]
- [ethernet] qlge: remove unnecessary pci_set_drvdata() (Chad Dupuis) [1089357]
- [ethernet] qlge: Update version to 1.00.00.33 (Chad Dupuis) [1089357]
- [ethernet] qlge: Enhance nested VLAN (Q-in-Q) handling (Chad Dupuis) [1089357]
- [ethernet] qlge: call ql_core_dump() only if dump memory was allocated (Chad Dupuis) [1089357]
- [kernel] audit: allow user processes to log from another PID namespace (Richard Guy Briggs) [1010455]
- [kernel] audit: anchor all pid references in the initial pid namespace (Richard Guy Briggs) [1010455]
- [kernel] audit: convert PPIDs to the inital PID namespace (Richard Guy Briggs) [1010455]
- [kernel] sched: declare pid_alive as inline (Richard Guy Briggs) [1010455]
- [kernel] pid: get pid_t ppid of task in init_pid_ns (Richard Guy Briggs) [1010455]
- [net] netlabel: shorter names for the NetLabel catmap funcs/structs (Paul Moore) [1119662]
- [net] netlabel: fix the catmap walking functions (Paul Moore) [1119662]
- [net] netlabel: fix the horribly broken catmap functions (Paul Moore) [1119662]
- [net] netlabel: fix a problem when setting bits below the previously lowest bit (Paul Moore) [1119662]
- [kernel] sched/time: fix lock inversion in thread_group_cputime (Rik van Riel) [1120307]
- [kernel] seqlock: add irqsave variant of read_seqbegin_or_lock (Rik van Riel) [1120307]
- [kernel] sched: make lockless sys_times kABI-friendly (Rik van Riel) [1120307]
- [kernel] sched/cputime: atomically increment stime & utime (Rik van Riel) [1120307]
- [kernel] time, signal: protect resource use statistics with seqlock (Rik van Riel) [1120307]
- [kernel] exit: always reap resource stats in __exit_signal (Rik van Riel) [1120307]
- [kernel] seqcount: Provide raw_read_seqcount() (Rik van Riel) [1120307]
- [kernel] take read_seqbegin_or_lock() and friends to seqlock.h (Rik van Riel) [1120307]
- [kernel] sched: change thread_group_cputime() to use for_each_thread() (Rik van Riel) [1120307]
- [usb] usb3503: Fix a warning for using an uninitialized variable (Don Zickus) [1148954]
- [ethernet] tg3: prevent ifup/ifdown during PCI error recovery (Ivan Vecera) [1088637]
- [ethernet] tg3: fix return value in tg3_get_stats64 (Ivan Vecera) [1088637]
- [ethernet] tg3: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1088637]
- [ethernet] tg3: Modify tg3_tso_bug() to handle multiple TX rings (Ivan Vecera) [1088637]
- [ethernet] tg3: Clear NETIF_F_TSO6 flag before doing software GSO (Ivan Vecera) [1088637]
- [ethernet] tg3: Replace ethtool_ops::{get, set}_rxfh_indir() with {get, set}_rxfh() (Ivan Vecera) [1088637]
- [ethernet] tg3: Update copyright and version to 3.137 (Ivan Vecera) [1088637]
- [ethernet] tg3: Prevent page allocation failure during TSO workaround (Ivan Vecera) [1088637]
- [ethernet] tg3: Don't modify ip header fields when doing GSO (Ivan Vecera) [1088637]
- [ethernet] tg3: update rx_jumbo_pending ring param only when jumbo frames are enabled (Ivan Vecera) [1088637]
- [ethernet] tg3: remove open-coded skb_cow_head (Ivan Vecera) [1088637]
- [ethernet] tg3: remove empty MDIO bus reset function (Ivan Vecera) [1088637]
- [ethernet] tg3: Do not include vlan acceleration features in vlan_features (Ivan Vecera) [1088637]
- [ethernet] tg3: Call dev_kfree_skby_any instead of dev_kfree_skb (Ivan Vecera) [1088637]
- [ethernet] tg3: Use pci_enable_msix_range() instead of pci_enable_msix() (Ivan Vecera) [1088637]
- [ethernet] tg3: Fix deadlock in tg3_change_mtu() (Ivan Vecera) [1088637]
- [ethernet] tg3: cleanup an error path in tg3_phy_reset_5703_4_5() (Ivan Vecera) [1088637]
- [ethernet] tg3: delete non-required instances of include <linux/init.h> (Ivan Vecera) [1088637]
- [ethernet] tg3: Implement the SIOCGHWTSTAMP ioctl (Ivan Vecera) [1088637]

* Mon Oct 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-181.el7]
- [tools] perf/powerpc: Adjust callchain based on DWARF debug info (Jiri Olsa) [1113736]
- [tools] perf: Allow to specify lib compile variable for spec usage (Jiri Olsa) [879133]
- [tools] perf/symbols: Get kernel start address by symbol name (Jiri Olsa) [1134356]
- [tools] perf: Fix segfault in cumulative.callchain report (Jiri Olsa) [1134356]
- [tools] perf/tests: Add test for closing dso objects on EMFILE error (Jiri Olsa) [1134356]
- [tools] perf/tests: Add test for caching dso file descriptors (Jiri Olsa) [1134356]
- [tools] perf/tests: Allow reuse of test_file function (Jiri Olsa) [1134356]
- [tools] perf/tests: Spawn child for each test (Jiri Olsa) [1134356]
- [tools] perf: Add dso__data_* interface descriptons (Jiri Olsa) [1134356]
- [tools] perf: Allow to close dso fd in case of open failure (Jiri Olsa) [1134356]
- [tools] perf: Add file size check and factor dso__data_read_offset (Jiri Olsa) [1134356]
- [tools] perf: Cache dso data file descriptor (Jiri Olsa) [1134356]
- [tools] perf: Add global count of opened dso objects (Jiri Olsa) [1134356]
- [tools] perf: Add global list of opened dso objects (Jiri Olsa) [1134356]
- [tools] perf: Add data_fd into dso object (Jiri Olsa) [1134356]
- [tools] perf: Separate dso data related variables (Jiri Olsa) [1134356]
- [tools] perf: Cache register accesses for unwind processing (Jiri Olsa) [1134356]
- [tools] perf/record: Fix to honor user freq/interval properly (Jiri Olsa) [1134356]
- [tools] perf/timechart: Reflow documentation (Jiri Olsa) [1134356]
- [tools] perf/probe: Improve error messages in --line option (Jiri Olsa) [1134356]
- [tools] perf/probe: Improve an error message of perf probe --vars mode (Jiri Olsa) [1134356]
- [tools] perf/probe: Show error code and description in verbose mode (Jiri Olsa) [1134356]
- [tools] perf/probe: Improve error message for unknown member of data structure (Jiri Olsa) [1134356]
- [tools] perf/tests: Show the inner make output when an error happens (Jiri Olsa) [1134356]
- [tools] perf: Emit more precise message for missing glibc static library (Jiri Olsa) [1134356]
- [tools] perf: Add dcacheline sort (Jiri Olsa) [1134356]
- [tools] perf: Add support to dynamically get cacheline size (Jiri Olsa) [1134356]
- [tools] perf: Add cpumode to struct hist_entry (Jiri Olsa) [1134356]
- [tools] perf/report: Add mem-mode documentation to report command (Jiri Olsa) [1134356]
- [tools] perf: Update mmap2 interface with protection and flag bits (Jiri Olsa) [1134356]
- [tools] perf/script/python: Print array argument as string (Jiri Olsa) [1134356]
- [tools] perf: Prettify the tags/TAGS/cscope targets output (Jiri Olsa) [1134356]
- [tools] perf: Fix pipe check regression in attr event callback (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Added support for __get_bitmask() macro (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Add options to function plugin (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Add options to plugins (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Add flag to not load event plugins (Jiri Olsa) [1134356]
- [tools] perf/documentation: Add description for conditional branch filter (Jiri Olsa) [1134356]
- [tools] Revert: perf: Disable PERF_RECORD_MMAP2 support (Jiri Olsa) [1134356]
- [tools] perf: Add conditional branch filter 'cond' to perf record (Jiri Olsa) [1134356]
- [tools] perf: Fix 'make help' message error (Jiri Olsa) [1134356]
- [tools] perf/record: Fix poll return value propagation (Jiri Olsa) [1134356]
- [tools] perf: Move elide bool into perf_hpp_fmt struct (Jiri Olsa) [1134356]
- [tools] perf: Remove elide setup for SORT_MODE__MEMORY mode (Jiri Olsa) [1134356]
- [tools] perf: Fix "==" into "=" in ui_browser__warning assignment (Jiri Olsa) [1134356]
- [tools] perf: Allow overriding sysfs and proc finding with env var (Jiri Olsa) [1134356]
- [tools] perf: Consider header files outside perf directory in tags target (Jiri Olsa) [1134356]
- [tools] perf: Add warning when disabling perl scripting support due to missing devel files (Jiri Olsa) [1134356]
- [tools] perf/trace: Warn the user when not available (Jiri Olsa) [1134356]
- [tools] perf/tests: Add a test case for cumulating callchains (Jiri Olsa) [1134356]
- [tools] perf/tests: Define and use symbolic names for fake symbols (Jiri Olsa) [1134356]
- [tools] perf: Reset output/sort order to default (Jiri Olsa) [1134356]
- [tools] perf/ui/gtk: Fix callchain display (Jiri Olsa) [1134356]
- [tools] perf/ui/stdio: Fix invalid percentage value of cumulated hist entries (Jiri Olsa) [1134356]
- [tools] perf: Enable --children option by default (Jiri Olsa) [1134356]
- [tools] perf/top: Add top.children config option (Jiri Olsa) [1134356]
- [tools] perf/top: Add --children option (Jiri Olsa) [1134356]
- [tools] perf/top: Convert to hist_entry_iter (Jiri Olsa) [1134356]
- [tools] perf: Add callback function to hist_entry_iter (Jiri Olsa) [1134356]
- [tools] perf: Do not auto-remove Children column if --fields given (Jiri Olsa) [1134356]
- [tools] perf/report: Add report.children config option (Jiri Olsa) [1134356]
- [tools] perf/report: Add --children option (Jiri Olsa) [1134356]
- [tools] perf: Add more hpp helper functions (Jiri Olsa) [1134356]
- [tools] perf: Apply percent-limit to cumulative percentage (Jiri Olsa) [1134356]
- [tools] perf/ui/gtk: Add support to accumulated hist stat (Jiri Olsa) [1134356]
- [tools] perf/ui/browser: Add support to accumulated hist stat (Jiri Olsa) [1134356]
- [tools] perf/ui/hist: Add support to accumulated hist stat (Jiri Olsa) [1134356]
- [tools] perf: Save callchain info for each cumulative entry (Jiri Olsa) [1134356]
- [tools] perf/callchain: Add callchain_cursor_snapshot() (Jiri Olsa) [1134356]
- [tools] perf/report: Cache cumulative callchains (Jiri Olsa) [1134356]
- [tools] perf: Update cpumode for each cumulative entry (Jiri Olsa) [1134356]
- [tools] perf/hists: Accumulate hist entry stat based on the callchain (Jiri Olsa) [1134356]
- [tools] perf/hists: Check if accumulated when adding a hist entry (Jiri Olsa) [1134356]
- [tools] perf/hists: Add support for accumulated stat of hist entry (Jiri Olsa) [1134356]
- [tools] perf: Introduce struct hist_entry_iter (Jiri Olsa) [1134356]
- [tools] perf: Introduce hists__inc_nr_samples() (Jiri Olsa) [1134356]
- [tools] perf: Add automatic remapping of Android libraries (Jiri Olsa) [1134356]
- [tools] perf: Add cat as fallback pager (Jiri Olsa) [1134356]
- [tools] perf/tests: Add a testcase for histogram output sorting (Jiri Olsa) [1134356]
- [tools] perf/tests: Factor out print_hists_*() (Jiri Olsa) [1134356]
- [tools] perf: Introduce reset_output_field() (Jiri Olsa) [1134356]
- [tools] perf: Get rid of obsolete hist_entry__sort_list (Jiri Olsa) [1134356]
- [tools] perf/hists: Reset width of output fields with header length (Jiri Olsa) [1134356]
- [tools] perf: Skip elided sort entries (Jiri Olsa) [1134356]
- [tools] perf/top: Add --fields option to specify output fields (Jiri Olsa) [1134356]
- [tools] perf/report/tui: Fix a bug when --fields/sort is given (Jiri Olsa) [1134356]
- [tools] perf: Add ->sort() member to struct sort_entry (Jiri Olsa) [1134356]
- [tools] perf/report: Add -F option to specify output fields (Jiri Olsa) [1134356]
- [tools] perf: Call perf_hpp__init() before setting up GUI browsers (Jiri Olsa) [1134356]
- [tools] perf: Consolidate management of default sort orders (Jiri Olsa) [1134356]
- [tools] perf: Allow hpp fields to be sort keys (Jiri Olsa) [1134356]
- [tools] perf/ui: Get rid of callback from __hpp__fmt() (Jiri Olsa) [1134356]
- [tools] perf: Consolidate output field handling to hpp format routines (Jiri Olsa) [1134356]
- [tools] perf: Use hpp formats to sort final output (Jiri Olsa) [1134356]
- [tools] perf: Support event grouping in hpp ->sort() (Jiri Olsa) [1134356]
- [tools] perf: Use hpp formats to sort hist entries (Jiri Olsa) [1134356]
- [tools] perf: Convert sort entries to hpp formats (Jiri Olsa) [1134356]
- [tools] perf: Add ->cmp(), ->collapse() and ->sort() to perf_hpp_fmt (Jiri Olsa) [1134356]
- [tools] perf: Add libdw DWARF post unwind support for ARM (Jiri Olsa) [1134356]
- [tools] perf/tests: Add dwarf unwind test on ARM (Jiri Olsa) [1134356]
- [tools] perf/tests: Introduce perf_regs_load function on ARM (Jiri Olsa) [1134356]
- [tools] perf: Consolidate types.h for ARM and ARM64 (Jiri Olsa) [1134356]
- [tools] perf/session: Fix possible null pointer dereference in session.c (Jiri Olsa) [1134356]
- [tools] perf/sched: Cleanup, remove unused variables in map_switch_event() (Jiri Olsa) [1134356]
- [tools] perf/sched: Remove nr_state_machine_bugs in perf latency (Jiri Olsa) [1134356]
- [tools] perf: Remove usage of trace_sched_wakeup(.success) (Jiri Olsa) [1134356]
- [tools] perf: Use tid for finding thread (Jiri Olsa) [1134356]
- [tools] perf: Get rid of on_exit() feature test (Jiri Olsa) [1134356]
- [tools] perf/record: Propagate exit status of a command line workload (Jiri Olsa) [1134356]
- [tools] perf: Clarify the output of perf sched map (Jiri Olsa) [1134356]
- [tools] perf: Adapt the TASK_STATE_TO_CHAR_STR to new value in kernel space (Jiri Olsa) [1134356]
- [tools] perf: Add missing event for perf sched record (Jiri Olsa) [1134356]
- [tools] perf: Move ACCESS_ONCE from perf.h header (Jiri Olsa) [1134356]
- [tools] perf: Move sys_perf_event_open function from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Move syscall and arch specific defines from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Move perf_call_graph_mode enum from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Move sample data structures from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove PR_TASK_PERF_EVENTS_* from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove asmlinkage define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove min define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove unlikely define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove MAX_COUNTERS define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Consolidate types.h (Jiri Olsa) [1134356]
- [tools] perf: Unify export.h (Jiri Olsa) [1134356]
- [tools] perf/arm64: Wire up perf_regs and unwind support (Jiri Olsa) [1134356]
- [tools] perf: Move u64_swap union (Jiri Olsa) [1134356]
- [tools] perf/tests: add a test of kvm-390 trace event (Jiri Olsa) [1134356]
- [tools] perf/tests: Add numeric identifier to evlist_test (Jiri Olsa) [1134356]
- [tools] perf: Parse tracepoints with '-' in system name (Jiri Olsa) [1134356]
- [tools] perf: Handle EINTR error for readn/writen (Jiri Olsa) [1134356]
- [tools] perf/tests: Add map groups sharing with thread object test (Jiri Olsa) [1134356]
- [tools] perf: Share map_groups among threads of the same group (Jiri Olsa) [1134356]
- [tools] perf: Reference count map_groups objects (Jiri Olsa) [1134356]
- [tools] perf: Allocate thread map_groups's dynamically (Jiri Olsa) [1134356]
- [tools] perf/tests: Add thread maps lookup automated tests (Jiri Olsa) [1134356]
- [tools] perf/tests: Add a test case for hists filtering (Jiri Olsa) [1134356]
- [tools] perf/tests: Factor out fake_setup_machine() (Jiri Olsa) [1134356]
- [tools] perf/hists/tui: Count callchain rows separately (Jiri Olsa) [1134356]
- [tools] perf/top/tui: Update nr_entries properly after a filter is applied (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Rename hist_browser__update_nr_entries() (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Fix off-by-one in hist_browser__update_nr_entries() (Jiri Olsa) [1134356]
- [tools] perf/hists: Add missing update on filtered stats in hists__decay_entries() (Jiri Olsa) [1134356]
- [tools] perf: Account entry stats when it's added to the output tree (Jiri Olsa) [1134356]
- [tools] perf/hists: Collapse expanded callchains after filter is applied (Jiri Olsa) [1134356]
- [tools] perf/hists: Add a couple of hists stat helper functions (Jiri Olsa) [1134356]
- [tools] perf/hists: Move column length calculation out of hists__inc_stats() (Jiri Olsa) [1134356]
- [tools] perf/hists: Rename hists__inc_stats() (Jiri Olsa) [1134356]
- [tools] perf/report: Count number of entries separately (Jiri Olsa) [1134356]
- [tools] perf/callchain: Add generic report parse callchain callback function (Jiri Olsa) [1134356]
- [tools] perf/kmem: Utilize the new generic cpunode_map (Jiri Olsa) [1134356]
- [tools] perf: Use cpu/possible instead of cpu/kernel_max (Jiri Olsa) [1134356]
- [tools] perf: Allow ability to map cpus to nodes easily (Jiri Olsa) [1134356]
- [tools] perf: Fix pmu object compilation error (Jiri Olsa) [1134356]
- [tools] perf/sched: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/lock: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/mem: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/kmem: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf: Show absolute percentage by default (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Add 'F' hotkey to toggle percentage output (Jiri Olsa) [1134356]
- [tools] perf: Add hist.percentage config option (Jiri Olsa) [1134356]
- [tools] perf/diff: Add --percentage option (Jiri Olsa) [1134356]
- [tools] perf/top: Add --percentage option (Jiri Olsa) [1134356]
- [tools] perf/report: Add --percentage option (Jiri Olsa) [1134356]
- [tools] perf/hists: Add support for showing relative percentage (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix perf probe to find correct variable DIE (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix a segfault if asked for variable it doesn't find (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Fix stack map lookup in dwarf unwind test (Jiri Olsa) [1134356]
- [tools] perf/x86: Fix perf to use non-executable stack, again (Jiri Olsa) [1134356]
- [tools] perf: Remove extra '/' character in events file path (Jiri Olsa) [1134356]
- [tools] perf/machine: Search for modules in s/lib/modules/s (Jiri Olsa) [1134356]
- [tools] perf/tests: Add static build make test (Jiri Olsa) [1134356]
- [tools] perf: Fix bfd dependency libraries detection (Jiri Olsa) [1134356]
- [tools] perf: Use LDFLAGS instead of ALL_LDFLAGS (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Fix memory leak in pretty_print() (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Fix backward compatibility macros for pevent filter enums (Jiri Olsa) [1134356]
- [tools] perf: Disable libdw unwind for all but x86 arch (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Fix memory leak in sample_ustack() (Jiri Olsa) [1134356]
- [tools] perf: Improve error reporting (Jiri Olsa) [1134356]
- [tools] perf: Adjust symbols in VDSO (Jiri Olsa) [1134356]
- [tools] perf/kvm: Fix 'Min time' counting in report command (Jiri Olsa) [1134356]
- [tools] perf: Instead of redirecting flex output, use -o (Jiri Olsa) [1134356]
- [tools] perf: Fix double free in perf test 21 (code-reading.c) (Jiri Olsa) [1134356]
- [tools] perf/stat: Initialize statistics correctly (Jiri Olsa) [1134356]
- [tools] perf/bench: Set more defaults in the 'numa' suite (Jiri Olsa) [1134356]
- [tools] perf/bench: Update manpage to mention numa and futex (Jiri Olsa) [1134356]
- [tools] perf/probe: Use dwarf_getcfi_elf() instead of dwarf_getcfi() (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix to handle errors in line_range searching (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix --line option behavior (Jiri Olsa) [1134356]
- [tools] perf: Pick up libdw without explicit LIBDW_DIR (Jiri Olsa) [1134356]
- [tools] perf/callchains: Disable unwind libraries when libelf isn't found (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Do not call warning() directly (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Print event name when show warning if possible (Jiri Olsa) [1134356]
- [tools] perf/top: Fix documentation of invalid -s option (Jiri Olsa) [1134356]
- [tools] perf: Allow building for tile (Jiri Olsa) [1134356]
- [tools] perf: Remove unused simple_strtoul() function (Jiri Olsa) [1134356]
- [tools] perf: Update some code references in design.txt (Jiri Olsa) [1134356]
- [tools] perf/evsel: Update function names in debug messages (Jiri Olsa) [1134356]
- [tools] perf: Remove thread__find_map function (Jiri Olsa) [1134356]
- [tools] perf/annotate: Print the evsel name in the stdio output (Jiri Olsa) [1134356]
- [tools] perf/report: Use ui__has_annotation() (Jiri Olsa) [1134356]
- [tools] perf: Fix memory leak when synthesizing thread records (Jiri Olsa) [1134356]
- [tools] perf: Use tid in mmap/mmap2 events to find maps (Jiri Olsa) [1134356]
- [tools] perf/report: Merge al->filtered with hist_entry->filtered (Jiri Olsa) [1134356]
- [tools] perf/symbols: Apply all filters to an addr_location (Jiri Olsa) [1134356]
- [tools] perf/symbols: Record the reason for filtering an address_location (Jiri Olsa) [1134356]
- [tools] perf/sched: Fixup header alignment in 'latency' output (Jiri Olsa) [1134356]
- [tools] perf/timechart: Fix off-by-one error in 'record' argv handling (Jiri Olsa) [1134356]
- [tools] perf/machine: Factor machine__find_thread to take tid argument (Jiri Olsa) [1134356]
- [tools] perf: Speed up thread map generation (Jiri Olsa) [1134356]
- [tools] perf/kvm: introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/ui/hists: Pass evsel to hpp->header/width functions explicitly (Jiri Olsa) [1134356]
- [tools] perf/symbols: Introduce thread__find_cpumode_addr_location (Jiri Olsa) [1134356]
- [tools] perf/session: Change header.misc dump from decimal to hex (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Reuse generic __hpp__fmt() code (Jiri Olsa) [1134356]
- [tools] perf/ui/hists: Pass struct hpp to print functions (Jiri Olsa) [1134356]
- [tools] perf/ui/gtk: Reuse generic __hpp__fmt() code (Jiri Olsa) [1134356]
- [tools] perf/ui/stdio: Fix invalid output on event group report (Jiri Olsa) [1134356]
- [tools] perf: Fix synthesizing mmaps for threads (Jiri Olsa) [1134356]
- [tools] perf/probe: Clarify x86 register naming for perf probe (Jiri Olsa) [1134356]
- [tools] perf/mem: Clarify load-latency in documentation (Jiri Olsa) [1134356]
- [tools] perf/bench: Add futex-requeue microbenchmark (Jiri Olsa) [1134356]
- [tools] perf/bench: Add futex-wake microbenchmark (Jiri Olsa) [1134356]
- [tools] perf/bench: Add futex-hash microbenchmark (Jiri Olsa) [1134356]
- [tools] perf: Disable user-space callchain/stack dumps for function trace events (Jiri Olsa) [1134356]
- [tools] perf/symbols: Check compatible symtab type before loading dso (Jiri Olsa) [1134356]
- [tools] perf/symbols: Check return value of filename__read_debuglink() (Jiri Olsa) [1134356]
- [tools] perf/tests: Add NO_LIBDW_DWARF_UNWIND make test (Jiri Olsa) [1134356]
- [tools] perf: Setup default dwarf post unwinder (Jiri Olsa) [1134356]
- [tools] perf: Add libdw DWARF post unwind support (Jiri Olsa) [1134356]
- [tools] perf: Add feature check for libdw dwarf unwind (Jiri Olsa) [1134356]
- [tools] perf: Warn the user about how to enable libunwind support (Jiri Olsa) [1134356]
- [tools] perf: Add variable display for VF make output (Jiri Olsa) [1134356]
- [tools] perf: Factor features display code (Jiri Olsa) [1134356]
- [tools] perf: Fix bison OUTPUT directories dependency (Jiri Olsa) [1134356]
- [tools] perf/tests: Add pmu-bison.o make test (Jiri Olsa) [1134356]
- [tools] perf/tests: Fix *.o make tests (Jiri Olsa) [1134356]
- [tools] perf/probe: Support distro-style debuginfo for uprobe (Jiri Olsa) [1134356]
- [tools] perf/probe: Allow to add events on the local functions (Jiri Olsa) [1134356]
- [tools] perf/probe: Show source-level or symbol-level info for uprobes (Jiri Olsa) [1134356]
- [tools] perf/probe: Show appropriate symbol for ref_reloc_sym based kprobes (Jiri Olsa) [1134356]
- [tools] perf/probe: Find given address from offline dwarf (Jiri Olsa) [1134356]
- [tools] perf/probe: Use ref_reloc_sym based address instead of the symbol name (Jiri Olsa) [1134356]
- [tools] perf/probe: Show in what binaries/modules probes are set (Jiri Olsa) [1134356]
- [tools] perf/probe: Unify show_available_functions for uprobes/kprobes (Jiri Olsa) [1134356]
- [tools] perf/probe: Replace line_list with intlist (Jiri Olsa) [1134356]
- [tools] perf/probe: Remove incorrect symbol check for --list (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix to do exit call for symbol maps (Jiri Olsa) [1134356]
- [tools] perf/symbols: No need to export dso__first_symbol (Jiri Olsa) [1134356]
- [tools] perf: Drop prefetch.h (Jiri Olsa) [1134356]
- [tools] perf: Move hash.h header (Jiri Olsa) [1134356]
- [tools] perf: Move fs.* to lib/api/fs/ (Jiri Olsa) [1134356]
- [tools] perf/callchain: Separate perf_reg_value function in perf_regs object (Jiri Olsa) [1134356]
- [tools] perf/callchain: Introduce HAVE_DWARF_UNWIND_SUPPORT macro (Jiri Olsa) [1134356]
- [tools] perf/callchain: Rename unwind__arch_reg_id into libunwind__arch_reg_id (Jiri Olsa) [1134356]
- [tools] perf/callchain: Separate libunwind code to special object (Jiri Olsa) [1134356]
- [tools] perf/callchain: Add mask into struct regs_dump (Jiri Olsa) [1134356]
- [tools] perf/callchain: Do not report zero address in unwind (Jiri Olsa) [1134356]
- [tools] perf: Fix dwarf unwind max_stack processing (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Add dwarf unwind test (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Introduce perf_regs_load function (Jiri Olsa) [1134356]
- [tools] perf: Fix memory leak in event_format__print function (Jiri Olsa) [1134356]
- [tools] perf/record: Add readable output for callchain debug (Jiri Olsa) [1134356]
- [tools] perf: Add call-graph option support into .perfconfig (Jiri Olsa) [1134356]
- [tools] perf: Put proper period for for samples without PERIOD sample_type (Jiri Olsa) [1134356]
- [tools] perf/report: Remove some needless container_of usage (Jiri Olsa) [1134356]
- [tools] perf: Shorten sample symbol resolving function signature (Jiri Olsa) [1134356]
- [tools] perf: Shorten sample symbol resolving function signature (Jiri Olsa) [1134356]
- [tools] perf/report: Use al->cpumode where applicable (Jiri Olsa) [1134356]
- [x86] perf/intel: Avoid spamming kernel log for BTS buffer failure (Jiri Olsa) [1134356]
- [x86] perf/intel: Protect LBR and extra_regs against KVM lying (Jiri Olsa) [1134356]
- [kernel] perf: Fix lockdep warning on process exit (Jiri Olsa) [1134356]
- [x86] perf/intel: Use proper dTLB-load-misses event on IvyBridge (Jiri Olsa) [1134356]
- [kernel] Revert: perf: Always destroy groups on exit (Jiri Olsa) [1134356]
- [kernel] perf: Do not allow optimized switch for non-cloned events (Jiri Olsa) [1134356]
- [kernel] perf: Pass protection and flags bits through mmap2 interface (Jiri Olsa) [1134356]
- [kernel] perf: Differentiate exec() and non-exec() comm events (Jiri Olsa) [1134356]
- [kernel] perf: Fix perf_event_comm() vs. exec() assumption (Jiri Olsa) [1134356]
- [x86] perf: Add conditional branch filtering support (Jiri Olsa) [1134356]
- [kernel] perf: Add new conditional branch filter 'PERF_SAMPLE_BRANCH_COND' (Jiri Olsa) [1134356]
- [x86] perf: Use common PMU interrupt disabled code (Jiri Olsa) [1134356]
- [kernel] perf: Disable sampled events if no PMU interrupt (Jiri Olsa) [1134356]
- [kernel] perf: Fix use after free in perf_remove_from_context() (Jiri Olsa) [1134356]
- [kernel] perf/events/core: Drop unused variable after cleanup (Jiri Olsa) [1134356]
- [x86] perf/intel: fix Haswell precise store data source encoding (Jiri Olsa) [1134356]
- [kernel] perf: Fix perf_event_open(.flags) test (Jiri Olsa) [1134356]
- [kernel] perf: Simplify perf_event_exit_task_context() (Jiri Olsa) [1134356]
- [kernel] perf: Rework free paths (Jiri Olsa) [1134356]
- [kernel] perf: Validate locking assumption (Jiri Olsa) [1134356]
- [kernel] perf: Always destroy groups on exit (Jiri Olsa) [1134356]
- [kernel] perf: Ensure consistent inherit state in groups (Jiri Olsa) [1134356]
- [x86] perf: Export perf_assign_events() (Jiri Olsa) [1134356]
- [kernel] perf: Allow building PMU drivers as modules (Jiri Olsa) [1134356]
- [kernel] perf: Prevent false warning in perf_swevent_add (Jiri Olsa) [1134356]
- [kernel] perf: Limit perf_event_attr::sample_period to 63 bits (Jiri Olsa) [1134356]
- [kernel] perf: Fix perf_event_init_context() (Jiri Olsa) [1134356]
- [kernel] perf: Fix race in removing an event (Jiri Olsa) [1134356]
- [x86] perf: Fix RAPL rdmsrl_safe() usage (Jiri Olsa) [1134356]
- [x86] perf/intel: Use rdmsrl_safe() when initializing RAPL PMU (Jiri Olsa) [1134356]
- [x86] perf/intel/rapl: Fix CPU hotplug callback registration (Jiri Olsa) [1134356]
- [x86] perf: Enable DRAM RAPL support on Intel Haswell (Jiri Olsa) [1134356]
- [kernel] perf: Optimize group_sched_in() (Jiri Olsa) [1134356]
- [x86] perf: Add a few more comments (Jiri Olsa) [1134356]
- [kernel] perf: Remove redundant PMU assignment (Jiri Olsa) [1134356]
- [kernel] perf: Fix prototype of find_pmu_context() (Jiri Olsa) [1134356]
- [x86] perf: Warn to early_printk() in case irq_work is too slow (Jiri Olsa) [1134356]
- [x86] perf/p4: Block PMIs on init to prevent a stream of unkown NMIs (Jiri Olsa) [1134356]
- [x86] perf/p4: Fix counter corruption when using lots of perf groups (Jiri Olsa) [1134356]
- [x86] perf: Push the duration-logging printk() to IRQ context (Jiri Olsa) [1134356]
- [kernel] workqueue: apply __WQ_ORDERED to create_singlethread_workqueue() (Tomas Henzl) [1131563]
- [md] raid10: always initialise ->state on newly allocated r10_bio (Jes Sorensen) [1085530]
- [md] raid10: avoid memory leak on error path during reshape (Jes Sorensen) [1085530]
- [md] raid10: Fix memory leak when raid10 reshape completes (Jes Sorensen) [1085530]
- [md] raid10: fix memory leak when reshaping a RAID10 (Jes Sorensen) [1085530]
- [md] raid5: avoid livelock caused by non-aligned writes (Jes Sorensen) [1085530]
- [md] don't allow bitmap file to be added to raid0/linear (Jes Sorensen) [1085530]
- [md] raid0: check for bitmap compatability when changing raid levels (Jes Sorensen) [1085530 1126348]
- [md] Recovery speed is wrong (Jes Sorensen) [1085530 1128517]
- [md] disable probing for md devices 512 and over (Jes Sorensen) [1085530]
- [md] raid1, raid10: always abort recover on write error (Jes Sorensen) [1085530]
- [md] flush writes before starting a recovery (Jes Sorensen) [1085530 1115749]
- [md] make sure GET_ARRAY_INFO ioctl reports correct "clean" status (Jes Sorensen) [1085530]
- [md] raid5: speedup sync_request processing (Jes Sorensen) [1085530]
- [md] raid5: deadlock between retry_aligned_read with barrier io (Jes Sorensen) [1085530]
- [md] raid5: add an option to avoid copy data from bio to stripe cache (Jes Sorensen) [1085530]
- [md] bitmap: remove confusing code from filemap_get_page (Jes Sorensen) [1085530]
- [md] raid5: avoid release list until last reference of the stripe (Jes Sorensen) [1085530]
- [md] md_clear_badblocks should return an error code on failure (Jes Sorensen) [1085530]
- [md] raid56: Don't perform reads to support writes until stripe is ready (Jes Sorensen) [1085530]
- [md] refuse to change shape of array if it is active but read-only (Jes Sorensen) [1085530]
- [md] always set MD_RECOVERY_INTR when interrupting a reshape thread (Jes Sorensen) [1085530]
- [md] always set MD_RECOVERY_INTR when aborting a reshape or other "resync" (Jes Sorensen) [1085530]
- [md] avoid possible spinning md thread at shutdown (Jes Sorensen) [1085530]
- [md] raid5: fix a race of stripe count check (Jes Sorensen) [1085530]
- [md] raid5: get_active_stripe avoids device_lock (Jes Sorensen) [1085530]
- [md] raid5: make_request does less prepare wait (Jes Sorensen) [1085530]
- [md] avoid oops on unload if some process is in poll or select (Jes Sorensen) [1085530]
- [md] raid1: r1buf_pool_alloc, free allocate pages when subsequent allocation fails (Jes Sorensen) [1085530]
- [md] bitmap: don't abuse i_writecount for bitmap files (Jes Sorensen) [1085530]
- [md] raid5: Fix CPU hotplug callback registration (Jes Sorensen) [1085530]
- [md] raid1: restore ability for check and repair to fix read errors (Jes Sorensen) [1085530]
- [md] raid5: close recently introduced race in stripe_head management (Jes Sorensen) [1085530]
- [md] raid5: fix long-standing problem with bitmap handling on write failure (Jes Sorensen) [1085530]
- [md] check command validity early in md_ioctl() (Jes Sorensen) [1085530]
- [md] ensure metadata is writen after raid level change (Jes Sorensen) [1085530]
- [md] raid10: avoid fullsync when not necessary (Jes Sorensen) [1085530]
- [md] allow a partially recovered device to be hot-added to an array (Jes Sorensen) [1085530]
- [md] fix problem when adding device to read-only array with bitmap (Jes Sorensen) [1085530]
- [md] raid10: fix bug when raid10 recovery fails to recover a block (Jes Sorensen) [1085530]
- [md] raid5: fix a recently broken BUG_ON() (Jes Sorensen) [1085530]
- [md] raid10: fix two bugs in handling of known-bad-blocks (Jes Sorensen) [1085530]
- [md] raid5: Fix possible confusion when multiple write errors occur (Jes Sorensen) [1085530]
- [Documentation] fix some typos in md documentation (Jes Sorensen) [1085530]
- [md] raid5: fix newly-broken locking in get_active_stripe (Jes Sorensen) [1085530]
- [md] test mddev->flags more safely in md_check_recovery (Jes Sorensen) [1085530]
- [md] raid5: fix new memory-reference bug in alloc_thread_groups (Jes Sorensen) [1085530]
- [block] submit_bio_wait() conversions (Jes Sorensen) [1085530]
- [md] raid5: Use conf->device_lock protect changing of multi-thread resources (Jes Sorensen) [1085530]
- [md] raid5: Before freeing old multi-thread worker, it should flush them (Jes Sorensen) [1085530]
- [md] raid5: For stripe with R5_ReadNoMerge, we replace REQ_FLUSH with REQ_NOMERGE (Jes Sorensen) [1085530]
- [md] raid1: Add some macros to make code clearly (Jes Sorensen) [1085530]
- [md] raid1: Replace raise_barrier/lower_barrier with freeze_array/unfreeze_array when reconfiguring the array (Jes Sorensen) [1085530]
- [md] raid1: Add a field array_frozen to indicate whether raid in freeze state (Jes Sorensen) [1085530]
- [md] Convert use of typedef ctl_table to struct ctl_table (Jes Sorensen) [1085530]
- [md] raid5: avoid deadlock when raid5 array has unack badblocks during md_stop_writes (Jes Sorensen) [1085530]
- [md] use MD_RECOVERY_INTR instead of kthread_should_stop in resync thread (Jes Sorensen) [1085530]
- [md] fix some places where mddev_lock return value is not checked (Jes Sorensen) [1085530]
- [md] raid5: Retry R5_ReadNoMerge flag when hit a read error (Jes Sorensen) [1085530]
- [md] raid5: relieve lock contention in get_active_stripe() (Jes Sorensen) [1085530]
- [md] raid5: relieve lock contention in get_active_stripe() (Jes Sorensen) [1085530]
- [md] raid5: add proper locking to error path of raid5_start_reshape (Jes Sorensen) [1085530]
- [kernel] wait: add wait_event_cmd() (Jes Sorensen) [1085530]
- [md] raid5: Use slow_path to release stripe when mddev->thread is null (Jes Sorensen) [1085530]
- [block] Consolidate duplicated bio_trim() implementations (Jes Sorensen) [1085530]
- [md] raid5: fix "distingush" typo (Jes Sorensen) [1085530]
- [md] raid5: only wakeup necessary threads (Jes Sorensen) [1085530]
- [md] raid5: flush out all pending requests before proceeding with reshape (Jes Sorensen) [1085530]
- [md] raid5: use seqcount to protect access to shape in make_request (Jes Sorensen) [1085530]
- [md] raid5: sysfs entry to control worker thread number (Jes Sorensen) [1085530]
- [md] raid5: offload stripe handle to workqueue (Jes Sorensen) [1085530]
- [md] raid5: fix stripe release order (Jes Sorensen) [1085530]
- [md] raid5: make release_stripe lockless (Jes Sorensen) [1085530]
- [md] Don't test all of mddev->flags at once (Jes Sorensen) [1085530]
- [md] Fix apparent cut-and-paste error in super_90_validate (Jes Sorensen) [1085530]
- [md] fix safe_mode buglet (Jes Sorensen) [1085530]
- [md] don't call md_allow_write in get_bitmap_file (Jes Sorensen) [1085530]
- [lib] raid6: add ARM-NEON accelerated syndrome calculation (Jes Sorensen) [1085530]
- [kernel] wait: Make the __wait_event*() interface more friendly (Jes Sorensen) [1085530]
- [kernel] sched/wait: Introduce ___wait_event() (Jes Sorensen) [1085530]

* Fri Oct 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-180.el7]
- [net] ethtool: Check that reserved fields of struct ethtool_rxfh are 0 (Ivan Vecera) [1138823]
- [net] ethtool: Replace ethtool_ops::{get, set}_rxfh_indir() with {get, set}_rxfh() (Ivan Vecera) [1138823]
- [net] ethtool: constify array pointer parameters to ethtool_ops::set_rxfh (Ivan Vecera) [1138823]
- [net] ethtool: Disallow ETHTOOL_SRSSH with both indir table and hash key unchanged (Ivan Vecera) [1138823]
- [net] ethtool: Expand documentation of ethtool_ops::{get, set}_rxfh() (Ivan Vecera) [1138823]
- [net] ethtool: Improve explanation of the two arrays following struct ethtool_rxfh (Ivan Vecera) [1138823]
- [net] ethtool: Name the 'no change' value for setting RSS hash key but not indir table (Ivan Vecera) [1138823]
- [net] ethtool: Return immediately on error in ethtool_copy_validate_indir() (Ivan Vecera) [1138823]
- [net] ethtool: exit the loop when invalid index occurs (Ivan Vecera) [1138823]
- [net] ethtool: Support for configurable RSS hash key (Ivan Vecera) [1138823]
- [lib] reciprocal_divide: update/correction of the algorithm (Jiri Benc) [1140665]
- [net] introduce reciprocal_scale helper and convert users (Jiri Benc) [1140665]
- [net] random32: add prandom_u32_max and convert open coded users (Jiri Benc) [1140665]
- [net] bpf: do not use reciprocal divide (Jiri Benc) [1140665]
- [net] genetlink: remove superfluous assignment (Jiri Benc) [1140656]
- [scsi] pmcraid: use proper genetlink multicast API (Jiri Benc) [1140656]
- [net] genetlink: Fix uninitialized variable in genl_validate_assign_mc_groups() (Jiri Benc) [1140656]
- [net] genetlink: fix genlmsg_multicast() bug (Jiri Benc) [1140656]
- [net] genetlink: make multicast groups const, prevent abuse (Jiri Benc) [1140656]
- [net] genetlink: pass family to functions using groups (Jiri Benc) [1140656]
- [net] genetlink: add and use genl_set_err() (Jiri Benc) [1140656]
- [net] genetlink: remove family pointer from genl_multicast_group (Jiri Benc) [1140656]
- [net] genetlink: remove genl_unregister_mc_group() (Jiri Benc) [1140656]
- [fs] quota: use proper genetlink multicast APIs (Jiri Benc) [1140656]
- [net] drop_monitor: use proper genetlink multicast APIs (Jiri Benc) [1140656]
- [net] genetlink: only pass array to genl_register_family_with_ops() (Jiri Benc) [1140656]
- [net] genetlink: rename shadowed variable (Jiri Benc) [1140656]
- [net] genetlink: unify registration functions (Jiri Benc) [1140656]
- [net] genetlink: make genl_ops flags a u8 and move to end (Jiri Benc) [1140656]
- [net] genetlink: make all genl_ops users const (Jiri Benc) [1140656]
- [net] genetlink: allow making ops const (Jiri Benc) [1140656]
- [net] genetlink: register family ops as array (Jiri Benc) [1140656]
- [net] genetlink: remove genl_register_ops/genl_unregister_ops (Jiri Benc) [1140656]
- [net] ieee802154: use genl_register_family_with_ops() (Jiri Benc) [1140656]
- [kernel] taskstats: use genl_register_family_with_ops() (Jiri Benc) [1140656]
- [net] genetlink: Remove extern from function prototypes (Jiri Benc) [1140656]
- [net] genetlink: fix usage of NLM_F_EXCL or NLM_F_REPLACE (Jiri Benc) [1140656]
- [net] udp: Fix inverted NAPI_GRO_CB(skb)->flush test (Florian Westphal) [1131999]
- [net] gre: gro: Fix a bug that breaks the forwarding path (Florian Westphal) [1131999]
- [net] gro: reset skb->truesize in napi_reuse_skb() (Florian Westphal) [1131999]
- [net] netdev_features: work around NETIF_F kabi breakage (Florian Westphal) [1131999]
- [net] l2tp: Enable checksum unnecessary conversions for l2tp/UDP sockets (Florian Westphal) [1131999]
- [net] vxlan: Enable checksum unnecessary conversions for vxlan/UDP sockets (Florian Westphal) [1131999]
- [net] gre: Add support for checksum unnecessary conversions (Florian Westphal) [1131999]
- [net] udp: Add support for doing checksum unnecessary conversion (Florian Westphal) [1131999]
- [net] Infrastructure for checksum unnecessary conversions (Florian Westphal) [1131999]
- [net] Support for csum_bad in skbuff (Florian Westphal) [1131999]
- [net] sctp: Change sctp to implement csum_levels (Florian Westphal) [1131999]
- [net] Allow GRO to use and set levels of checksum unnecessary (Florian Westphal) [1131999]
- [net] Clarification of CHECKSUM_UNNECESSARY (Florian Westphal) [1131999]
- [net] skbuff: improve comment on checksumming (Florian Westphal) [1131999]
- [net] skbuff: Use ALIGN macro instead of open coding it (Florian Westphal) [1131999]
- [net] Allocate a new 16 bits for flags in skbuff (Florian Westphal) [1131999]
- [net] gre: When GRE csum is present count as encap layer wrt csum (Florian Westphal) [1131999]
- [net] udp: additional GRO support (Florian Westphal) [1131999]
- [net] tcp: Call skb_gro_checksum_validate (Florian Westphal) [1131999]
- [net] ipv6: gro: fix CHECKSUM_COMPLETE support (Florian Westphal) [1131999]
- [net] gre: call skb_gro_checksum_simple_validate (Florian Westphal) [1131999]
- [net] add gro_compute_pseudo functions (Florian Westphal) [1131999]
- [net] skb_gro_checksum_* functions (Florian Westphal) [1131999]
- [net] fix setting csum_start in skb_segment() (Florian Westphal) [1131999]
- [net] vxlan: Checksum fixes (Florian Westphal) [1131999]
- [net] add skb_pop_rcv_encapsulation (Florian Westphal) [1131999]
- [net] udp: call __skb_checksum_complete when doing full checksum (Florian Westphal) [1131999]
- [net] Fix save software checksum complete (Florian Westphal) [1131999]
- [net] Fix GSO constants to match NETIF flags (Florian Westphal) [1131999]
- [net] Add skb_gro_postpull_rcsum to udp and vxlan (Florian Westphal) [1131999]
- [net] Save software checksum complete (Florian Westphal) [1131999]
- [net] Preserve CHECKSUM_COMPLETE at validation (Florian Westphal) [1131999]
- [net] vxlan: Add support for UDP checksums (v4 sending, v6 zero csums) (Florian Westphal) [1131999]
- [net] gre: Call gso_make_checksum (Florian Westphal) [1131999]
- [net] gre: simplify GRE header length calculation in gre_gso_segment() (Florian Westphal) [1131999]
- [net] Add GSO support for UDP tunnels with checksum (Florian Westphal) [1131999]
- [net] tcp: Call gso_make_checksum (Florian Westphal) [1131999]
- [net] Support for multiple checksums with gso (Florian Westphal) [1131999]
- [net] l2tp: call udp{6}_set_csum (Florian Westphal) [1131999]
- [net] udp: Generic functions to set checksum (Florian Westphal) [1131999]
- [net] l2tp: Add support for zero IPv6 checksums (Florian Westphal) [1131999]
- [net] udp: Make enabling of zero UDP6 csums more restrictive (Florian Westphal) [1131999]
- [net] Split sk_no_check into sk_no_check_{rx, tx} (Florian Westphal) [1131999]
- [net] Eliminate no_check from protosw (Florian Westphal) [1131999]
- [net] sunrpc: Remove sk_no_check setting (Florian Westphal) [1131999]
- [net] l2tp: Remove UDP checksum verification (Florian Westphal) [1131999]
- [net] udp: Verify UDP checksum before handoff to encap (Florian Westphal) [1131999]
- [net] icmp6: Call skb_checksum_validate (Florian Westphal) [1131999]
- [net] icmp: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] igmp: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] gre6: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] gre: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] ipv6: Need to sock_put on csum error (Florian Westphal) [1131999]
- [net] ipv6: Implmement RFC 6936 (zero RX csums for UDP/IPv6) (Florian Westphal) [1131999]
- [net] udp: Only allow busy read/poll on connected sockets (Florian Westphal) [1078978 1131999]
- [net] ipv6: log src and dst along with "udp checksum is 0" (Florian Westphal) [1131999]
- [net] ipv6: Call skb_checksum_init in IPv6 (Florian Westphal) [1131999]
- [net] ipv4: Call skb_checksum_init in IPv4 (Florian Westphal) [1131999]
- [net] Generalize checksum_init functions (Florian Westphal) [1131999]
- [net] Change x86_64 add32_with_carry to allow memory operand (Florian Westphal) [1131999]
- [x86_64] csum_add for x86_64 (Florian Westphal) [1131999]
- [net] Allow csum_add to be provided in arch (Florian Westphal) [1131999]
- [net] ipv4: add a sock pointer to dst->output() path (Jiri Pirko) [1081956]
- [net] iptunnels: remove net arg from iptunnel_xmit() (Jiri Pirko) [1081956]
- [net] vti: Use the tunnel mark for lookup in the error handlers (Jiri Pirko) [1091561]
- [net] xfrm4: Remove duplicate semicolon (Jiri Pirko) [1091561]
- [net] xfrm4: Properly handle unsupported protocols (Jiri Pirko) [1091561]
- [net] vti4: Don't count header length twice (Jiri Pirko) [1091561]
- [net] vti4: don't allow to add the same tunnel twice (Jiri Pirko) [1091561]
- [net] vti4: Enable namespace changing (Jiri Pirko) [1091561]
- [net] vti4: Check the tunnel endpoints of the xfrm state and the vti interface (Jiri Pirko) [1091561]
- [net] vti4: Support inter address family tunneling (Jiri Pirko) [1091561]
- [net] vti4: Use the on xfrm_lookup returned dst_entry directly (Jiri Pirko) [1091561]
- [net] vti4: Update the ipv4 side to use it's own receive hook (Jiri Pirko) [1091561]
- [net] skb: allow skb_scrub_packet() to be used by tunnels (Jiri Pirko) [1091561]
- [net] ipv4: xfrm: Introduce xfrm_tunnel_notifier for xfrm tunnel mode callback (Jiri Pirko) [1091561]
- [net] ip_tunnel: Remove double unregister of the fallback device (Jiri Pirko) [1091561]
- [net] ipip: add x-netns support (Jiri Pirko) [1091561]
- [net] vti4: switch to new ip tunnel code (Jiri Pirko) [1091561]
- [net] ip_tunnel: Make vti work with i_key set (Jiri Pirko) [1091561]
- [net] xfrm: Add xfrm_tunnel_skb_cb to the skb common buffer (Jiri Pirko) [1091561]
- [net] ipcomp4: Use the IPsec protocol multiplexer API (Jiri Pirko) [1091561]
- [net] ah4: Use the IPsec protocol multiplexer API (Jiri Pirko) [1091561]
- [net] esp4: Use the IPsec protocol multiplexer API (Jiri Pirko) [1091561]
- [net] xfrm4: Add IPsec protocol multiplexer (Jiri Pirko) [1091561]

* Fri Oct 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-179.el7]
- [drm] i915: don't crash if unable to setup stolen (Rob Clark) [1128939]
- [fs] nfs: Don't reset pg_moreio in __nfs_pageio_add_request (Steve Dickson) [1120728]
- [fs] nfs: Remove 2 unused variables (Steve Dickson) [1120728]
- [fs] nfs: handle multiple reqs in nfs_wb_page_cancel (Steve Dickson) [1120728]
- [fs] nfs: nfs_page should take a ref on the head req (Steve Dickson) [1120728]
- [fs] nfsv4: test SECINFO RPC_AUTH_GSS pseudoflavors for support (Steve Dickson) [1120728]
- [fs] nfs: Return -EPERM if no supported or matching SECINFO flavor (Steve Dickson) [1120728]
- [fs] nfs: check the return of nfs4_negotiate_security in nfs4_submount (Steve Dickson) [1120728]

* Fri Oct 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-178.el7]
- [crypto] drbg: fix maximum value checks on 32 bit systems (Herbert Xu) [1138311]
- [crypto] drbg: remove configuration of fixed values (Herbert Xu) [1138311]
- [crypto] drbg: fix failure of generating multiple of 2**16 bytes (Herbert Xu) [1011562]
- [crypto] drbg: drbg_exit() can be static (Herbert Xu) [1011562]
- [crypto] drbg: HMAC-SHA1 DRBG has crypto strength of 128 bits (Herbert Xu) [1011562]
- [crypto] drbg: Mix a time stamp into DRBG state (Herbert Xu) [1011562]
- [crypto] drbg: Select correct DRBG core for stdrng (Herbert Xu) [1011562]
- [crypto] drbg: Call CTR DRBG DF function only once (Herbert Xu) [1011562]
- [crypto] drbg: Fix format string for debugging statements (Herbert Xu) [1011562]
- [crypto] drbg: cleanup of preprocessor macros (Herbert Xu) [1011562]
- [crypto] drbg: Use Kconfig to ensure at least one RNG option is set (Herbert Xu) [1011562]
- [crypto] drbg: use of kernel linked list (Herbert Xu) [1011562]
- [crypto] drbg: fix memory corruption for AES192 (Herbert Xu) [1011562]
- [crypto] drbg: simplify ordering of linked list in drbg_ctr_df (Herbert Xu) [1011562]
- [crypto] drbg: Add DRBG test code to testmgr (Herbert Xu) [1011562]
- [crypto] drbg: DRBG testmgr test vectors (Herbert Xu) [1011562]
- [crypto] drbg: compile the DRBG code (Herbert Xu) [1011562]
- [crypto] drbg: DRBG kernel configuration options (Herbert Xu) [1011562]
- [crypto] drbg: header file for DRBG (Herbert Xu) [1011562]
- [crypto] drbg: SP800-90A Deterministic Random Bit Generator (Herbert Xu) [1011562]
- [virt] virtio_scsi: avoid cancelling uninitialized work items (Paolo Bonzini) [1050834]
- [net] macvtap: Fix race between device delete and open (Vlad Yasevich) [1075904]
- [video] offb: Little endian fixes (David Gibson) [1144937]
- [cpufreq] release policy->rwsem on error (Prarit Bhargava) [1140184]
- [char] ipmi: Turn off all activity on an idle ipmi interface (Tony Camuso) [1111214]
- [char] ipmi: Turn off default probing of interfaces (Tony Camuso) [1111214]
- [char] ipmi: Reset the KCS timeout when starting error recovery (Tony Camuso) [1111214]
- [char] ipmi: Fix a race restarting the timer (Tony Camuso) [1111214]
- [char] ipmi: ipmi_bt_sm, fix infinite loop (Tony Camuso) [1111214]
- [char] ipmi: delete non-required instances of include <linux/init.h> (Tony Camuso) [1111214]
- [char] ipmi: Cleanup error return (Tony Camuso) [1111214]
- [char] ipmi: fix timeout calculation when bmc is disconnected (Tony Camuso) [1111214]
- [char] ipmi: use USEC_PER_SEC instead of 1000000 for more meaningful (Tony Camuso) [1111214]
- [char] ipmi: remove deprecated IRQF_DISABLED (Tony Camuso) [1111214]
- [char] ipmi: Initialize locals to avoid warning (Tony Camuso) [1111214]
- [char] ipmi: info leak in compat_ipmi_ioctl() (Tony Camuso) [1111214]
- [char] ipmi: Convert use of typedef ctl_table to struct ctl_table (Tony Camuso) [1111214]

* Tue Sep 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-177.el7]
- [x86] uv: Set n_lshift based on GAM_GR_CONFIG MMR for UV3 (George Beshers) [1098325]
- [kernel] audit: correct AUDIT_GET_FEATURE return message type (Richard Guy Briggs) [1141791]
- [mm] fix the theoretical compound_lock() vs prep_new_page() race (Andrea Arcangeli) [1135506]
- [mm] hugetlb: call MMU notifiers when copying a hugetlb page range (Andrea Arcangeli) [1135506]
- [mm] page_alloc: convert hot/cold parameter and immediate callers to bool (Andrea Arcangeli) [1135506]
- [mm] introdule compound_head_by_tail() (Andrea Arcangeli) [1135506]
- [mm] swap: split put_compound_page() (Andrea Arcangeli) [1135506]
- [mm] slub: do not VM_BUG_ON_PAGE() for temporary on-stack pages (Andrea Arcangeli) [1135506]
- [mm] page_alloc: change mm debug routines back to EXPORT_SYMBOL (Andrea Arcangeli) [1135506]
- [mm] dump page when hitting a VM_BUG_ON using VM_BUG_ON_PAGE (Andrea Arcangeli) [1135506]
- [mm] thp: __get_page_tail_foll() can use get_huge_page_tail() (Andrea Arcangeli) [1135506]
- [mm] print more details for bad_page() (Andrea Arcangeli) [1135506]
- [mm] thp: turn compound_head() into BUG_ON(!PageTail) in get_huge_page_tail() (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: Add some VM_BUG_ON()s to catch non-hugetlbfs pages (Andrea Arcangeli) [1135506]
- [mm] swap: introduce put_[un]refcounted_compound_page helpers for splitting put_compound_page() (Andrea Arcangeli) [1135506]
- [mm] close PageTail race (Andrea Arcangeli) [1135506]
- [block] aoe: adjust ref of head for compound page tails (Andrea Arcangeli) [1135506]
- [mm] swap: reorganize put_compound_page() (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: use __compound_tail_refcounted in __get_page_tail too (Andrea Arcangeli) [1135506]
- [mm] tail page refcounting optimization for slab and hugetlbfs (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: move the put/get_page slab and hugetlbfs optimization in a faster path (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: fix hugetlbfs optimization (Andrea Arcangeli) [1135506]
- [mm] make lru_add_drain_all() selective (Andrea Arcangeli) [1135506]
- [mm] fix aio performance regression for database caused by THP (Andrea Arcangeli) [1135506]
- [powerpc] Add smp_mb()s to arch_spin_unlock_wait() (Gustavo Duarte) [1136528]
- [powerpc] Add smp_mb() to arch_spin_is_locked() (Gustavo Duarte) [1136528]
- [acpi] scan: not cache _SUN value in struct acpi_device_pnp (Prarit Bhargava) [1140567]
- [acpi] scan: ACPI device object sysfs attribute for _STA evaluation (Prarit Bhargava) [1140567]

* Tue Sep 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-176.el7]
- [alsa] hda: Set up initial pins for Acer Aspire V5 (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Replacing hex with #defines (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: fix broken user-visible string (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: prink replacement (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: ctpcm.c printk replacement (Jaroslav Kysela) [1112200]
- [alsa] pcm: Fix the silence data for DSD formats (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: ct20k1reg Fix typo in include guard (Jaroslav Kysela) [1112200]
- [alsa] hda: ca0132_regs.h Fix typo in include guard (Jaroslav Kysela) [1112200]
- [alsa] core: fix buffer overflow in snd_info_get_line() (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Use tables for batch COEF writes/updtes (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add alc_update_coef*_idx() helper (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Use alc_write_coef_idx() in alc269_quanta_automake() (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Optimize alc888_coef_init() (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove obsoleted EXPORT_SYMBOL_HDA() macro (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove obsoleted snd_hda_check_board_config() & co (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: apply Valleyview fix-ups to Cherryview display codec (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: set depop_delay for haswell plus (Jaroslav Kysela) [1112200]
- [alsa] hda: restore the gpio led after resume (Jaroslav Kysela) [1112200]
- [alsa] core: create write-only attribute macros for devices and drivers (Jaroslav Kysela) [1112200]
- [alsa] sysfs: create __ATTR_WO() (Jaroslav Kysela) [1112200]
- [alsa] dell-led: add mic mute led interface (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Avoid setting wrong COEF on ALC269 & co (Jaroslav Kysela) [1112200]
- [alsa] hda: Set TLV_DB_SCALE_MUTE bit for cx5051 vmaster (Jaroslav Kysela) [1112200]
- [alsa] pci: Remove DEFINE_PCI_DEVICE_TABLE macro use (Jaroslav Kysela) [1112200]
- [alsa] hda/ca0132: Don't try loading firmware at resume when already failed (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix pop noises on reboot for Dell XPS 13 9333 (Jaroslav Kysela) [1112200]
- [alsa] hda: Set internal mic as default input source on Dell XPS 13 9333 (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: fix BOSS ME-25 MIDI regression (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix parsing of CMI8888 codec (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix probing and stuttering on CMI8888 HD-audio controller (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fixed ALC286/ALC288 recording delay for Headset Mic (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Whitespace cleanups for sound/usb/midi.* (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Respond to suspend and resume callbacks for MIDI input (Jaroslav Kysela) [1112200]
- [alsa] virtuoso: add Xonar Essence STX II support (Jaroslav Kysela) [1112200]
- [alsa] riptide: fix d confusingly prefixed with 0x in format strings (Jaroslav Kysela) [1112200]
- [alsa] hda: add codec ID for Braswell display audio codec (Jaroslav Kysela) [1112200]
- [alsa] hda: add PCI IDs for Intel Braswell (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Adjust Gamecom 780 volume level (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: improve dmesg source grepability (Jaroslav Kysela) [1112200]
- [alsa] hda: add mic mute led hook for dell machines (Jaroslav Kysela) [1112200]
- [alsa] hda: fix an external mic jack problem on a HP machine (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix loopback noise on Dell XPS 15 (Jaroslav Kysela) [1112200]
- [alsa] hda: Make vendor quirks lowest prio for ALC2xx (Jaroslav Kysela) [1112200]
- [alsa] hda: Refactor quirk picking and change quirk priority (Jaroslav Kysela) [1112200]
- [alsa] hda: Add mic fixup for Gigabyte BXBT-2807 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add mute LED pin quirk for HP 15 touchsmart (Jaroslav Kysela) [1112200]
- [alsa] pcm: Add tstamp_type and proto to sw_params compat layer (Jaroslav Kysela) [1112200]
- [alsa] pcm: Introduce protocol version field to sw_params (Jaroslav Kysela) [1112200]
- [alsa] hda: Add NULL check to all PM ops in hda_intel.c (Jaroslav Kysela) [1112200]
- [alsa] hda: init_flag is in struct hda_intel (Jaroslav Kysela) [1112200]
- [alsa] compress: fix an integer overflow check (Jaroslav Kysela) [1112200]
- [alsa] hda: Add the pin fixup for HP Envy TS bass speaker (Jaroslav Kysela) [1112200]
- [alsa] control: Define SNDRV_CTL_TLV_OP_* constants (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix broken PM due to incomplete i915 initialization (Jaroslav Kysela) [1112200]
- [alsa] hda: Revert stream assignment order for Intel controllers (Jaroslav Kysela) [1112200]
- [alsa] pcm: Add timestamp type to sw_params (Jaroslav Kysela) [1112200]
- [alsa] pcm: simplify snd_pcm_tstamp() (Jaroslav Kysela) [1112200]
- [alsa] hda: add capture mute led support in led_power_filter (Jaroslav Kysela) [1112200]
- [alsa] hda: fix a typo by changing mute_led_nid to cap_mute_led_nid (Jaroslav Kysela) [1112200]
- [alsa] hda: Add new GPU codec ID 0x10de0070 to snd-hda (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix build warning (Jaroslav Kysela) [1112200]
- [alsa] hda: Add several entries for enabling HP mute led (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix and neaten print_nid_path/debug_badness (Jaroslav Kysela) [1112200]
- [alsa] pcm_dmaengine: Correct support for 24bits physical sample widths (Jaroslav Kysela) [1112200]
- [alsa] pcm_dmaengine: Use the available wrapper to get physical width (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Correcting/completing #defines for REGS (Jaroslav Kysela) [1112200]
- [alsa] hda: restore BCLK M/N value as per CDCLK for HSW/BDW display HDA controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove unused variable (Jaroslav Kysela) [1112200]
- [alsa] mixart: Remove unused variable (Jaroslav Kysela) [1112200]
- [alsa] echoaudio: Remove unused variable (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix build error in hda_tegra.c (Jaroslav Kysela) [1112200]
- [alsa] trident: Remove unused variable in trident_memory.c (Jaroslav Kysela) [1112200]
- [alsa] trident: Remove unused variable in trident_main.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix invalid function call in snd_hda_add_vmaster() (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a fixup for Thinkpad T540p (Jaroslav Kysela) [1112200]
- [alsa] hda: Add another headset pin quirk for some Dell machines (Jaroslav Kysela) [1112200]
- [alsa] hda: Replace ICH6_ prefix (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove obsoleted SFX definitions (Jaroslav Kysela) [1112200]
- [alsa] hda: Move SD nums definitions to hda_intel.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Use common reboot notifier (Jaroslav Kysela) [1112200]
- [alsa] hda: Move more PCI-controller-specific stuff from generic code (Jaroslav Kysela) [1112200]
- [alsa] hda: Make position_fix as generic callback (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove superfluous MAX_AZX_DEV (Jaroslav Kysela) [1112200]
- [alsa] hda: restore BCLK M/N values when resuming HSW/BDW display controller (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix races at disconnection and PCM closing (Jaroslav Kysela) [1112200]
- [alsa] hda: Adjust speaker HPF and add LED support for HP Spectre 13 (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove the obsoleted static quirk codes from patch_cmedia.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove the obsoleted static quirk codes from patch_conexant.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Kill the rest of snd_print*() usages (Jaroslav Kysela) [1112200]
- [alsa] hda: Kill snd_printd*() in HDMI debug / info prints (Jaroslav Kysela) [1112200]
- [alsa] hda: Make the pin quirk tables use the SND_HDA_PIN_QUIRK macro (Jaroslav Kysela) [1112200]
- [alsa] hda: Make a SND_HDA_PIN_QUIRK macro (Jaroslav Kysela) [1112200]
- [alsa] hda: Add pin quirk for Dell XPS 15 (Jaroslav Kysela) [1112200]
- [alsa] seq/seq_memory: Fix closing brace followed by if (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: call overridden init on resume (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix usage of "model" module parameter (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Support HP mute led for output and input (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more entry for enable HP mute led (Jaroslav Kysela) [1112200]
- [alsa] control: Make sure that id->index does not overflow (Jaroslav Kysela) [1112200 1117314] {CVE-2014-4656}
- [alsa] control: Handle numid overflow (Jaroslav Kysela) [1112200 1117314] {CVE-2014-4656}
- [alsa] control: Fix replacing user controls (Jaroslav Kysela) [1112200 1117324] {CVE-2014-4654 CVE-2014-4655}
- [alsa] control: Protect user controls against concurrent access (Jaroslav Kysela) [1112200 1117339] {CVE-2014-4652}
- [alsa] hd-audio: Don't continue probing i915 when nomodeset is given (Jaroslav Kysela) [1112200]
- [alsa] hda: Add quirk for external mic on Lifebook U904 (Jaroslav Kysela) [1112200]
- [alsa] hda: fix a fixup value for codec alc293 in the pin_quirk table (Jaroslav Kysela) [1112200]
- [alsa] intel8x0: Use ktime and ktime_get() (Jaroslav Kysela) [1112200]
- [alsa] core: Use ktime_get_ts() (Jaroslav Kysela) [1112200]
- [alsa] hda: verify pin-converter connection on unsol event for HSW and VLV (Jaroslav Kysela) [1112200]
- [alsa] hda: Add quirk for ABit AA8XE (Jaroslav Kysela) [1112200]
- [alsa] Revert: hda: mask buggy stream DMA0 for Broadwell display controller (Jaroslav Kysela) [1112200]
- [alsa] hda: using POS_FIX_LPIB on Broadwell HDMI Audio (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support of ALC667 codec (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more codec rename (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: New vendor ID for ALC233 (Jaroslav Kysela) [1112200]
- [alsa] hda: add two new pin tables (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support of ALC891 codec (Jaroslav Kysela) [1112200]
- [alsa] seq: Continue broadcasting events to ports if one of them fails (Jaroslav Kysela) [1112200]
- [alsa] seq: correctly detect input buffer overflow (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fix COEF widget NID for ALC260 replacer fixup (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Correction of fixup codes for PB V7900 laptop (Jaroslav Kysela) [1112200]
- [alsa] hda/analog: Fix silent output on ASUS A8JN (Jaroslav Kysela) [1112200]
- [alsa] hda: move some alc662 family machines to hda_pin_quirk table (Jaroslav Kysela) [1112200]
- [alsa] hda: move some alc269 family machines to hda_pin_quirk table (Jaroslav Kysela) [1112200]
- [alsa] Revert: hda: drop def association and sequence from pinconf comparing (Jaroslav Kysela) [1112200]
- [alsa] hda: fix tegra build (Jaroslav Kysela) [1112200]
- [alsa] hda: Pop noises fix for XPS13 9333 (Jaroslav Kysela) [1112200]
- [alsa] hda: add an instance to use snd_hda_pick_pin_fixup (Jaroslav Kysela) [1112200]
- [alsa] hda: drop def association and sequence from pinconf comparing (Jaroslav Kysela) [1112200]
- [alsa] hda: get subvendor from codec rather than pci_dev (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a new quirk match based on default pin configuration (Jaroslav Kysela) [1112200]
- [alsa] hda: Add fixup_forced flag (Jaroslav Kysela) [1112200]
- [alsa] snd-usb/mixer: remove error messages on failed kmalloc() (Jaroslav Kysela) [1112200]
- [alsa] snd-usb/mixer: coding style fixups (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix onboard audio on Intel H97/Z97 chipsets (Jaroslav Kysela) [1112200]
- [alsa] Replace DEFINE_PCI_DEVICE_TABLE macro use (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support headset mode for ALC233 (Jaroslav Kysela) [1112200]
- [alsa] lola: fix format type mismatch in sound/pci/lola/lola_proc.c (Jaroslav Kysela) [1112200]
- [alsa] hda: fix format type mismatch in sound/pci/hda/patch_sigmatel.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Disable AA-mix on Sony Vaio S13 (Jaroslav Kysela) [1112200]
- [alsa] hda: White noise fix for XPS13 9333 (Jaroslav Kysela) [1112200]
- [alsa] hda/tegra: Fix MODULE_DEVICE_TABLE typo (Jaroslav Kysela) [1112200]
- [alsa] hda: Add driver for Tegra SoC HDA (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: Add Nvidia Tegra124 HDMI support (Jaroslav Kysela) [1112200]
- [alsa] fm801: convert struct description to kernel-doc (Jaroslav Kysela) [1112200]
- [alsa] pcm_dmaengine: Add check during device suspend (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for three Dell laptops (Jaroslav Kysela) [1112200]
- [alsa] hda: Add new GPU codec ID to snd-hda (Jaroslav Kysela) [1112200]
- [alsa] hda: if statement not indented (Jaroslav Kysela) [1112200]
- [alsa] hda: mask buggy stream DMA0 for Broadwell display controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Add dock pin setups for Thinkpad T440 (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: Set infoframe and channel mapping even without sink (Jaroslav Kysela) [1112200]
- [alsa] fm801: introduce fm801_ac97_is_ready()/fm801_ac97_is_valid() helpers (Jaroslav Kysela) [1112200]
- [alsa] fm801: introduce macros to access the hardware (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: Set converter channel count even without sink (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: work around corrupted TEAC UD-H01 feedback data (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix deadlocks at resuming (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Save mixer status only once at suspend (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Prevent printk ratelimiting from spamming kernel log while DEBUG not defined (Jaroslav Kysela) [1112200]
- [alsa] hda: Suppress CORBRP clear on Nvidia controller chips (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more entry for enable HP mute led (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix format string mismatch in mixer.c (Jaroslav Kysela) [1112200]
- [alsa] core: Fix format string mismatch in seq_midi.c (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add new codec ALC293/ALC3235 UAJ supported (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add two codecs alias name for Dell (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Translate comments from french to english (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Remove useless #if 0 .. #endif (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Remove dead code (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Fix dev_dbg typo (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Switch to using BIT macro (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Remove unused defines (Jaroslav Kysela) [1112200]
- [alsa] pcm: BUG message unnecessarily triggers kerneloops (Jaroslav Kysela) [1112200]
- [alsa] MIDI driver for Behringer BCD2000 USB device (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add headset Mic support for Dell machine (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support of ALC288 codec (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Suppress repetitive debug messages from retire_playback_urb() (Jaroslav Kysela) [1112200]
- [alsa] hda: Make full_reset boolean (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] hda: Use runtime helper to check active state (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Fix boundary checks in PCM pointer ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Do not assign streams in reverse order (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add eapd shutup to ALC283 (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Change model name alias for ChromeOS (Jaroslav Kysela) [1112200]
- [alsa] Kconfig: rename HAS_IOPORT to HAS_IOPORT_MAP (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Improve HP depop when system change power state on Chromebook (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Save/restore routing and rate registers (Jaroslav Kysela) [1112200]
- [alsa] ice1712: restore AK4xxx volumes on resume (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Add S/PDIF suspend support for ICE1712-based M-Audio cards (Jaroslav Kysela) [1112200]
- [alsa] cs8427: separate HW initialization (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix silent speaker output due to mute LED fixup (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fixed single output machine get empty hp sense (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Add suspend support for M-Audio ICE1712-based cards (Jaroslav Kysela) [1112200]
- [alsa] ice1712: add suspend support for ICE1712 chip (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable beep for ASUS 1015E (Jaroslav Kysela) [1112200]
- [alsa] asihpi: fix some indenting in snd_card_asihpi_pcm_new() (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for three Dell laptops (Jaroslav Kysela) [1112200]
- [alsa] hda: Inform the unexpectedly ignored pins by auto-parser (Jaroslav Kysela) [1112200]
- [alsa] hda: verify pin-cvt connection on preparing a stream for Intel HDMI codec (Jaroslav Kysela) [1112200]
- [alsa] compress: Pass through return value of open ops callback (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Restore default value for ALC282 (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) fix Stereo Upmixing regression (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fix the noise after suspend and resume on ALC282 codec (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Restore default value for ALC283 (Jaroslav Kysela) [1112200]
- [alsa] sis7019: Simplify dependencies (Jaroslav Kysela) [1112200]
- [alsa] cs5535audio: Also needed on MIPS (Jaroslav Kysela) [1112200]
- [alsa] hda: initialize audio InfoFrame to be all zero (Jaroslav Kysela) [1112200]
- [alsa] cs553*: Fix dependencies (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix loud click noise with IdeaPad 410Y (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add quirk for Logitech Webcam C500 (Jaroslav Kysela) [1112200]
- [alsa] emu10k1: Fix possible NULL dereference (Jaroslav Kysela) [1112200]
- [alsa] echoaudio: use after free on error (Jaroslav Kysela) [1112200]
- [alsa] lola: NULL deref on allocation error (Jaroslav Kysela) [1112200]
- [alsa] hda: Use analog beep for Thinkpads with AD1984 codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: Add missing loopback merge path for AD1884/1984 codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: add automute fix for another dell AIO model (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add headset quirk for Dell DT (Jaroslav Kysela) [1112200]
- [alsa] hda: Added inverted digital-mic handling for Acer TravelMate 8371 (Jaroslav Kysela) [1112200]
- [alsa] hda: Mark reg op args as iomem (Jaroslav Kysela) [1112200]
- [alsa] hda: Rename reg access ops in hda_controller_ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Make azx_attach_pcm_stream static (Jaroslav Kysela) [1112200]
- [alsa] hda: remove PCI dependency in Kconfig (Jaroslav Kysela) [1112200]
- [alsa] hda: Move codec create to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Move azx_interrupt to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Add position_check op (Jaroslav Kysela) [1112200]
- [alsa] hda: Move low level functions to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: move alloc_cmd_io to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Relocate RIRB/CORB interface to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Move the dsp loader to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Pull pages allocation to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Add hda_controller.c and move pcm ops from hda_intel (Jaroslav Kysela) [1112200]
- [alsa] hda: Add pcm_mmap_prepare op (Jaroslav Kysela) [1112200]
- [alsa] hda: Move snd page allocation to ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Pass max_slots and power_save to codec_create (Jaroslav Kysela) [1112200]
- [alsa] hda: Add jackpoll_ms to struct azx (Jaroslav Kysela) [1112200]
- [alsa] hda: remove unused clear of STATESTS (Jaroslav Kysela) [1112200]
- [alsa] hda: Add function pointer for disabling MSI (Jaroslav Kysela) [1112200]
- [alsa] hda: Use device pointer from the card instead of pci (Jaroslav Kysela) [1112200]
- [alsa] hda: Keep pointer to bdl_pos_fix in chip struct (Jaroslav Kysela) [1112200]
- [alsa] hda: Allow different ops to read/write registers (Jaroslav Kysela) [1112200]
- [alsa] hda: Move some definitions to new hda_priv.h (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix CORB reset to follow specification (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix registration of beep input device (Jaroslav Kysela) [1112200]
- [alsa] hda/sigmatel: Allow auto-switching for dock line-in of HP laptops (Jaroslav Kysela) [1112200]
- [alsa] Move EXPORT_SYMBOL() in appropriate places (Jaroslav Kysela) [1112200]
- [alsa] hda: Make codec object as a parent for input beep devices (Jaroslav Kysela) [1112200]
- [alsa] 6fire: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ymfpci: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] vx222: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] trident: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme9652: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] hdspm: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] hdsp: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] pcxhr: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] nm256: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] mixart: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] lx6464es: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] lola: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ice17xx: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] emu10k1: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] emu10k1x: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] echoaudio: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs46xx: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs5535audio: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ca0106: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] aw2: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ali5451: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ac97: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] via82xx_modem: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] via82xx: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] sonicvibes: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme96: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme32: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] maestro3: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] intel8x0m: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] intel8x0: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] fm801: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] es1968: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] es1938: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ens137x: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs5530: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs4281: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cmipci: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] bt87x: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] azt3328: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] azt3328: Remove function debug prints (Jaroslav Kysela) [1112200]
- [alsa] atiixp-modem: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] atiixp: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] als4000: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] als300: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] als300: Remove function debug prints (Jaroslav Kysela) [1112200]
- [alsa] ad1889: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme96: Convert to the new pm_ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Replace with standard printk (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable sysfs attributes without CONFIG_SND_HDA_RECONFIG (Jaroslav Kysela) [1112200]
- [alsa] hda: Add sysfs to codec object, too (Jaroslav Kysela) [1112200]
- [alsa] hda: Create own device struct for each codec (Jaroslav Kysela) [1112200]
- [alsa] hda: Manage each codec instance individually (Jaroslav Kysela) [1112200]
- [alsa] Clean up snd_device_*() codes (Jaroslav Kysela) [1112200]
- [alsa] Use priority list for managing device list (Jaroslav Kysela) [1112200]
- [alsa] hwdep: Allow to assign the given parent (Jaroslav Kysela) [1112200]
- [alsa] hwdep: Take private_data as drvdata for sysfs (Jaroslav Kysela) [1112200]
- [alsa] Create sysfs attribute files via groups (Jaroslav Kysela) [1112200]
- [alsa] hda: Avoid codec D3 for keeping mute LED up on Lenovo Yxx0 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a fixup for HP Folio 13 mute LED (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more entry for enable HP mute led (Jaroslav Kysela) [1112200]
- [alsa] Export snd_pcm_constraint_mask64() (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable front audio jacks on one HP desktop model (Jaroslav Kysela) [1112200]
- [alsa] core: Fix missing card sysfs contents (Jaroslav Kysela) [1112200]
- [alsa] hda: Add QEMU codec vendor ID (Jaroslav Kysela) [1112200]
- [alsa] hda/ca0132: Fix recording from mode id 0x8 (Jaroslav Kysela) [1112200]
- [alsa] hda/ca0132: setup/cleanup streams (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for two Dell laptops (Jaroslav Kysela) [1112200]
- [alsa] usx2y: Don't peep the card internal object (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: work around KEF X300A firmware bug (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove superfluous inclusion of linux/pci.h (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Allow NULL bus->pci (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove dependency on bus->pci in hda_beep.c (Jaroslav Kysela) [1112200]
- [alsa] ak4117: Do not free priv until timer handler hasn't actually stopped using it (Jaroslav Kysela) [1112200]
- [alsa] Drop __bitwise and typedefs for snd_device attributes (Jaroslav Kysela) [1112200]
- [alsa] i2c/ak413x: Use SNDRV_DEV_CODEC for ak413x codec objects (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Use SNDRV_DEV_CODEC for mixer objects (Jaroslav Kysela) [1112200]
- [alsa] seq_oss: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] seq: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] timer: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] oss: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] hwdep: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rawmidi: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] core: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] pcm: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] control: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] seq_oss: Drop debug prints (Jaroslav Kysela) [1112200]
- [alsa] Use standard device refcount for card accounting (Jaroslav Kysela) [1112200]
- [alsa] Use static groups for id and number card sysfs attr files (Jaroslav Kysela) [1112200]
- [alsa] Embed card device into struct snd_card (Jaroslav Kysela) [1112200]
- [alsa] Mandate to pass a device pointer at card creation time (Jaroslav Kysela) [1112200]
- [alsa] usb: Convert to snd_card_new() with a device pointer (Jaroslav Kysela) [1112200]
- [alsa] pci: Convert to snd_card_new() with a device pointer (Jaroslav Kysela) [1112200]
- [alsa] drivers: Convert to snd_card_new() with a device pointer (Jaroslav Kysela) [1112200]
- [alsa] Mandate to pass a device pointer at card creation time (Jaroslav Kysela) [1112200]
- [alsa] Drop unused name argument in snd_register_oss_device() (Jaroslav Kysela) [1112200]
- [alsa] hda: Make snd_hda_gen_spec_free() static (Jaroslav Kysela) [1112200]
- [alsa] hda: Disable static quirks for C-Media codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: Move HDA_FIXUP_ACT_FREE call in snd_hda_gen_free() (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix undefined symbol due to builtin/module mixup (Jaroslav Kysela) [1112200]
- [alsa] Fix typos in alsa-driver-api.xml (Jaroslav Kysela) [1112200]
- [alsa] lx6464es: Remove unused function in pci/lx6464es/lx_core.c (Jaroslav Kysela) [1112200]
- [alsa] pcsp: Include appropriate header file in pcsp/pcsp_input.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Add subwoofer quirks for Asus UX51VZH and N55SF (Jaroslav Kysela) [1112200]
- [alsa] hda: Rename ASUS subwoofer quirks (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix mic capture on Sony VAIO Pro 11 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a headset quirk for Dell XPS 13 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix inconsistent Mic mute LED (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix leftover ifdef checks after modularization (Jaroslav Kysela) [1112200]
- [alsa] hda: Improve loopback path lookups for AD1983 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix missing VREF setup for Mac Pro 1,1 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add missing mixer widget for AD1983 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix silent output on Toshiba Satellite L40 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add mute LED support to Lenovo Ideapad (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Resume mixer values properly (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add missing kconfig dependecy (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: allow PIN_OUT to be dynamically enabled (Jaroslav Kysela) [1112200]
- [alsa] hda: Do not accept responses from non-existing codecs (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Disable static quirks (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Enable stereo mix input for CX20549 and CX20551 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Add analog loopback mixing to CX20549 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Apply cap of mix amp volume on CX20551 codec (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Use generic parser for HP 530 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Use generic parser for Toshiba P105 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Apply the amp cap override for CX20549 mixer (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Re-implement OLPC XO workarounds via fixup (Jaroslav Kysela) [1112200]
- [alsa] hda: Avoid unnecessary verbs write in snd_hda_activate_path() (Jaroslav Kysela) [1112200]
- [alsa] hda: Add fixup name lookup for CX5051 and 5066 codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for another Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) cleanup and minor changes (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify high-pass filter control (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify input select functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify capture volume functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) use headphone volume control (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify playback output select (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) capture from I2S channel 1, not 2 (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) move the mixer code into another file (Jaroslav Kysela) [1112200]
- [alsa] oxygen: modify CS4245 register dumping function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: modify adjust_dg_dac_routing function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify DAC/ADC parameters function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify initialization functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) add new CS4245 SPI functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: additional definitions for the Xonar DG/DGX card (Jaroslav Kysela) [1112200]
- [alsa] oxygen: change description of the xonar_dg.c file (Jaroslav Kysela) [1112200]
- [alsa] oxygen: export oxygen_update_dac_routing symbol (Jaroslav Kysela) [1112200]
- [alsa] oxygen: add mute mask for the OXYGEN_PLAY_ROUTING register (Jaroslav Kysela) [1112200]
- [alsa] oxygen: modify the SPI writing function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: add the separate SPI waiting function (Jaroslav Kysela) [1112200]
- [alsa] hda: Add parameter for dumping processing coefficients (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix silent output on MacBook Air 1,1 (Jaroslav Kysela) [1112200]
- [alsa] Refactor slot assignment code (Jaroslav Kysela) [1112200]
- [alsa] bits vs bytes bug in snd_card_create() (Jaroslav Kysela) [1112200]
- [alsa] hda: Apply +5dB output amp on ASUS Zenbook UX31A (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for some Dell machines (Jaroslav Kysela) [1112200]
- [alsa] Add helper function for intersecting two rate masks (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix endless vmaster hook call in thinkpad_helper.c (Jaroslav Kysela) [1112200]
- [alsa] snd-usb: re-order some quirk entries (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix Creative VF0420 rate (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add support for Focusrite Saffire 6 USB (Jaroslav Kysela) [1112200]
- [alsa] hda: automute via amp instead of pinctl on some AIO models (Jaroslav Kysela) [1112200]
- [alsa] hda: Apply codec power_filter to FG nodes (Jaroslav Kysela) [1112200]
- [alsa] hda: Don't set indep_hp flag for old AD codecs (Jaroslav Kysela) [1112200]
- [alsa] Enable CONFIG_ZONE_DMA for smaller PCI DMA masks (Jaroslav Kysela) [1112200]
- [alsa] pcm: Warn when buffer preallocation fails (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: Work around emu20k1 glitch to prevent buffered sound data loss (Jaroslav Kysela) [1112200]
- [alsa] Merge memalloc code into snd-pcm module (Jaroslav Kysela) [1112200]
- [alsa] Remove superfluous header inclusions in memalloc.c (Jaroslav Kysela) [1112200]
- [alsa] Remove memory reservation code from memalloc helper (Jaroslav Kysela) [1112200]
- [alsa] Remove memory accounting in memalloc helper (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: apply all Haswell fix-ups to Broadwell display codec (Jaroslav Kysela) [1112200]
- [alsa] hda: add codec ID for Broadwell display audio codec (Jaroslav Kysela) [1112200]
- [alsa] hda: add device ID for Broadwell display audio controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Split Thinkpad ACPI-related code (Jaroslav Kysela) [1112200]
- [alsa] hda: Don't create duplicated ctls for loopback paths (Jaroslav Kysela) [1112200]
- [alsa] hda: Correct AD1986A 3stack pin configs (Jaroslav Kysela) [1112200]
- [alsa] hda: Add consistent tag names for firmware patch (Jaroslav Kysela) [1112200]
- [alsa] hda: firmware patch code cleanup (Jaroslav Kysela) [1112200]
- [alsa] hda: Increment default stream numbers for AMD HDMI controllers (Jaroslav Kysela) [1112200]
- [alsa] hda: Minor code optimization for patch_realtek.c (Jaroslav Kysela) [1112200]
- [alsa] compress: remove the sample rate check (Jaroslav Kysela) [1112200]
- [alsa] rme9652: fix a missing comma in channel_map_9636_ds (Jaroslav Kysela) [1112200]
- [alsa] cs5535audio: use named constants for pci_power_t values (Jaroslav Kysela) [1112200]
- [alsa] hda: Disable Front HP jack detection on Gigabyte Z87X-UD3H (Jaroslav Kysela) [1112200]
- [alsa] hiface: Fix typo in 352800 rate definition (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add a quirk for Plantronics Gamecom 780 (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable subwoofer on Dell Vostro 5460/5470 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix wrong <acpi/acpi.h> inclusion in Thinkpad ACPI users (Jaroslav Kysela) [1112200]
- [alsa] hda: Add warning texts when codec driver Kconfig doesn't match (Jaroslav Kysela) [1112200]
- [alsa] hda: Kill EXPORT_SYMBOL_HDA() (Jaroslav Kysela) [1112200]
- [alsa] hda: Make CONFIG_SND_HDA_CODEC_* tristate (Jaroslav Kysela) [1112200]
- [alsa] hda: Explicitly keep codec powered up in hdmi_present_sense (Jaroslav Kysela) [1112200]
- [alsa] hda: Add Dell headset detection quirk for one more laptop model (Jaroslav Kysela) [1112200]
- [alsa] Add SNDRV_PCM_STATE_PAUSED case in wait_for_avail function (Jaroslav Kysela) [1112200]

* Tue Sep 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-175.el7]
- [misc] mei: ignore client writing state during cb completion (Prarit Bhargava) [1088953]
- [misc] mei: don't use deprecated DEFINE_PCI_DEVICE_TABLE macro (Prarit Bhargava) [1088953]
- [misc] mei: amthif: fix checkpatch error (Prarit Bhargava) [1088953]
- [misc] mei: fix Unnecessary space after function pointer name (Prarit Bhargava) [1088953]
- [misc] mei: use cl_dbg where appropriate (Prarit Bhargava) [1088953]
- [misc] mei: client.h fix checkpatch errors (Prarit Bhargava) [1088953]
- [misc] mei: report consistently copy_from/to_user failures (Prarit Bhargava) [1088953]
- [misc] mei: drop pr_fmt macros (Prarit Bhargava) [1088953]
- [misc] mei: make me hw headers private to me hw (Prarit Bhargava) [1088953]
- [misc] mei: fix memory leak of pending write cb objects (Prarit Bhargava) [1088953]
- [misc] mei: me: do not reset when less than expected data is received (Prarit Bhargava) [1088953]
- [misc] mei: fix regressions caused by removing ext_msg (Prarit Bhargava) [1088953]
- [misc] mei: wd: fix stop completion failure (Prarit Bhargava) [1088953]
- [misc] mei: wd: simplify wd_send command (Prarit Bhargava) [1088953]
- [misc] mei: make return values consistent across the driver (Prarit Bhargava) [1088953]
- [misc] mei: revamp writing slot counting (Prarit Bhargava) [1088953]
- [misc] mei: add mei_hbuf_acquire wrapper (Prarit Bhargava) [1088953]
- [misc] mei: txe: include irqreturn.h for irqreturn_t etc (Prarit Bhargava) [1088953]
- [misc] mei: set client's read_cb to NULL when flow control fails (Prarit Bhargava) [1088953]
- [misc] mei: txe: put pm callbacks under PM_SLEEP ifdef (Prarit Bhargava) [1088953]
- [misc] mei: me: put pm callbacks under PM_SLEEP ifdef (Prarit Bhargava) [1088953]
- [misc] mei: don't of list_for_each_entry_safe when not deleting (Prarit Bhargava) [1088953]
- [misc] mei: use helper function to find me client by id (Prarit Bhargava) [1088953]
- [misc] mei: fix potential read outside of array bounds (Prarit Bhargava) [1088953]
- [misc] mei: wd and amthif use mei_cl_ api for dis/connection (Prarit Bhargava) [1088953]
- [misc] mei: hbm: revamp client connect and disconnection status (Prarit Bhargava) [1088953]
- [misc] mei: Remove all bus devices from the mei_dev list when stopping the MEI (Prarit Bhargava) [1088953]
- [misc] mei: get rid of ext_msg (Prarit Bhargava) [1088953]
- [misc] mei: rename MEI_FOP_IOCTL to MEI_FOP_CONNECT (Prarit Bhargava) [1088953]
- [misc] mei: fix compilation error with missing WATCHDOG_CORE (Prarit Bhargava) [1088953]
- [misc] mei: allow multiple retries if the hw reset has failed (Prarit Bhargava) [1088953]
- [misc] mei: export active connections to debugfs (Prarit Bhargava) [1088953]
- [misc] mei: txe: add Kbuild for TXE device (Prarit Bhargava) [1088953]
- [misc] mei: txe: add pci-txe.c (Prarit Bhargava) [1088953]
- [misc] mei: txe: add hw-txe-regs.h header file (Prarit Bhargava) [1088953]
- [misc] mei: txe: add hw-txe.c (Prarit Bhargava) [1088953]
- [misc] mei: txe: add hw-txe.h header file (Prarit Bhargava) [1088953]
- [misc] mei: don't unset read cb ptr on reset (Prarit Bhargava) [1088953]
- [misc] mei: clear write cb from waiting list on reset (Prarit Bhargava) [1088953]
- [misc] mei: limit the number of consecutive resets (Prarit Bhargava) [1088953]
- [misc] mei: revamp mei reset state machine (Prarit Bhargava) [1088953]
- [misc] mei: fix syntax in comments and debug output (Prarit Bhargava) [1088953]
- [misc] mei: nfc: mei_nfc_free has to be called under lock (Prarit Bhargava) [1088953]
- [misc] mei: use hbm idle state to prevent spurious resets (Prarit Bhargava) [1088953]
- [misc] mei: do not run reset flow from the interrupt thread (Prarit Bhargava) [1088953]
- [misc] mei: enable marking internal commands (Prarit Bhargava) [1088953]
- [misc] mei: me: set dma mask using DMA mapping API (Prarit Bhargava) [1088953]
- [misc] mei: cleanup mei_irq_read_handler (Prarit Bhargava) [1088953]
- [misc] mei: remove flash_work_queue (Prarit Bhargava) [1088953]
- [misc] mei: drop redundant list_del_init (Prarit Bhargava) [1088953]
- [misc] mei: bus: propagate error code returned by mei_me_cl_by_id (Prarit Bhargava) [1088953]
- [misc] mei: mei_cl_link remove duplicated check for open_handle_count (Prarit Bhargava) [1088953]
- [misc] mei: replace stray pr_debug with dev_dbg (Prarit Bhargava) [1088953]
- [misc] mei: wd: host_init propagate error codes from called functions (Prarit Bhargava) [1088953]
- [misc] mei: print correct device state during unexpected reset (Prarit Bhargava) [1088953]
- [misc] mei: nfc: fix memory leak in error path (Prarit Bhargava) [1088953]
- [misc] mei: move host_clients_map cleanup to device init (Prarit Bhargava) [1088953]
- [misc] mei: me: downgrade two errors to debug level (Prarit Bhargava) [1088953]
- [misc] mei: amthif: mei_amthif_host_init: propagate errors from called functions (Prarit Bhargava) [1088953]
- [misc] mei: revamp open handler counts (Prarit Bhargava) [1088953]
- [misc] mei: simplify mei_open error handling (Prarit Bhargava) [1088953]
- [misc] mei: remove unnecessary pci_set_drvdata() (Prarit Bhargava) [1088953]
- [misc] mei: mei_cl_unlink: no need to loop over dev list (Prarit Bhargava) [1088953]
- [misc] mei: push credentials inside the irq write handler (Prarit Bhargava) [1088953]
- [misc] mei: propagate error from write routines instead of ENODEV (Prarit Bhargava) [1088953]
- [misc] mei: fix function names in debug prints (Prarit Bhargava) [1088953]
- [misc] mei: prefix client log messages with client me and host ids (Prarit Bhargava) [1088953]
- [misc] mei: mei_release: drop redundant check if cb is NULL (Prarit Bhargava) [1088953]
- [misc] mei: fix format compilation warrning on 32 bit architecture (Prarit Bhargava) [1088953]
- [misc] mei: revamp read and write length checks (Prarit Bhargava) [1088953]
- [misc] mei: mei_write correct checks for copy_from_user (Prarit Bhargava) [1088953]
- [misc] mei: mei_cl_link protect open_handle_count from overflow (Prarit Bhargava) [1088953]
- [misc] mei: make sure that me_clients_map big enough before copying (Prarit Bhargava) [1088953]
- [misc] mei: convert bus code to use dev_groups (Prarit Bhargava) [1088953]
- [misc] mei: client.h cleanup (Prarit Bhargava) [1088953]
- [ethernet] e1000e: Fix Runtime PM blocks EEE link negotiation in S5 (John Greene) [1091119]
- [ethernet] e1000e: Fix EEE in S5 w/ Runtime PM enabled (John Greene) [1091119]
- [ethernet] e1000e: Add support for EEE in Sx states (John Greene) [1091119]
- [ethernet] e1000e: Add code to check return values on NVM accesses (John Greene) [1091119]
- [ethernet] e1000e: Fix CRC errors with jumbo traffic (John Greene) [1091119]
- [ethernet] e1000e: remove unnecessary break after return (John Greene) [1091119]
- [ethernet] e1000e: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (John Greene) [1091119]
- [ethernet] e1000e: Out of line __ew32_prepare/__ew32 (John Greene) [1091119]
- [ethernet] e1000e: Fix expand setting EEE link info to all affected parts (John Greene) [1091119]
- [ethernet] e1000e: Failure to write SHRA turns on PROMISC mode (John Greene) [1091119]
- [ethernet] e1000e: Restrict MDIO Slow Mode workaround to relevant parts (John Greene) [1091119]
- [ethernet] e1000e: Fix issue with link flap on 82579 (John Greene) [1091119]
- [ethernet] e1000e: Expand workaround for 10Mb HD throughput bug (John Greene) [1091119]
- [ethernet] e1000e: Workaround for dropped packets in Gig/100 speeds on 82579 (John Greene) [1091119]
- [ethernet] e1000e: fix message terminations (John Greene) [1091119]
- [ethernet] e1000e: Enclose e1000e_pm_thaw() with CONFIG_PM_SLEEP (John Greene) [1091119]
- [ethernet] e1000e: Correctly include VLAN_HLEN when changing interface MTU (John Greene) [1091119]
- [ethernet] e1000e: Fix no connectivity when driver loaded with cable out (John Greene) [1091119]
- [ethernet] e1000e: add timeout for TX HW time stamping work (John Greene) [1091119]
- [ethernet] e1000e: Fix Explicitly set Transmit Control Register (John Greene) [1091119]
- [ethernet] e1000e: Fix Hardware Unit Hang (John Greene) [1091119]
- [ethernet] e1000e: fix the build error when PM is disabled (John Greene) [1091119]
- [ethernet] e1000e: Fix ethtool offline tests for 82579 parts (John Greene) [1091119]
- [ethernet] e1000e: Fix not generating an error on invalid load parameter (John Greene) [1091119]
- [ethernet] e1000e: Feature Enable PHY Ultra Low Power Mode (ULP) (John Greene) [1091119]
- [ethernet] e1000e: Refactor of Runtime Power Management (John Greene) [1091119]
- [ethernet] e1000e: calls skb_set_hash (John Greene) [1091119]
- [ethernet] e1000e: Refactor PM flows (John Greene) [1091119]
- [ethernet] e1000e: Fix compilation warning when !CONFIG_PM_SLEEP (John Greene) [1091119]
- [ethernet] e1000e: Fix a compile flag mis-match for suspend/resume (John Greene) [1091119]
- [ethernet] e1000e: Remove extern from function prototypes (John Greene) [1091119]
- [ethernet] e1000e: Cleanup - Update GPL header and Copyright (John Greene) [1091119]
- [ethernet] e1000e: Fix 82579 sets LPI too early (John Greene) [1091119]
- [ethernet] e1000e: 82574/82583 TimeSync errata for SYSTIM read (John Greene) [1091119]
- [kernel] sched/fair: Stop searching for tasks in idle_balance if there are runnable tasks (Larry Woodman) [1103828]
- [kernel] sched/numa: Initialize new idle_balance stats in sd_numa_init() (Larry Woodman) [1103828]

* Mon Sep 29 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-174.el7]
- [kernel] tty: Add C_CMSPAR(tty) (Don Zickus) [1110939]
- [usb] pl2303: fixed handling of CS5 setting (Don Zickus) [1110939]
- [usb] pl2303: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] pl2303: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] pl2303: clean up line-status handling (Don Zickus) [1110939]
- [usb] pl2303: make type data const (Don Zickus) [1110939]
- [usb] pl2303: use C_CMSPAR macro (Don Zickus) [1110939]
- [usb] pl2303: use direct baud-rate encoding when possible (Don Zickus) [1110939]
- [usb] pl2303: add helper function for direct baud-rate encoding (Don Zickus) [1110939]
- [usb] pl2303: refactor baud-rate divisor handling (Don Zickus) [1110939]
- [usb] pl2303: enforce baud-rate limits before lookup (Don Zickus) [1110939]
- [usb] pl2303: refactor baud-rate table lookup (Don Zickus) [1110939]
- [usb] pl2303: rename pl2303_encode_baud_rate (Don Zickus) [1110939]
- [usb] pl2303: add device-type abstraction (Don Zickus) [1110939]
- [usb] pl2303: add quirk for legacy devices (Don Zickus) [1110939]
- [usb] pl2303: clean up type handling (Don Zickus) [1110939]
- [usb] pl2303: use speed_t for baud rates (Don Zickus) [1110939]
- [usb] pl2303: add line-status quirk for Siemens phones (Don Zickus) [1110939]
- [usb] pl2303: remove redundant line-request call (Don Zickus) [1110939]
- [usb] pl2303: add error handling to line requests (Don Zickus) [1110939]
- [usb] pl2303: fix data corruption on termios updates (Don Zickus) [1110939]
- [usb] pl2303: add error handling to set_control_lines (Don Zickus) [1110939]
- [usb] pl2303: add error handling to vendor read and write functions (Don Zickus) [1110939]
- [usb] Revert: pl2303: restrict the divisor based baud rate encoding method to the "HX" chip type (Don Zickus) [1110939]
- [usb] Revert: pl2303: fix+improve the divsor based baud rate encoding method (Don Zickus) [1110939]
- [usb] Revert: pl2303: do not round to the next nearest standard baud rate for the divisor based baud rate encoding method (Don Zickus) [1110939]
- [usb] Revert: pl2303: remove 500000 baud from the list of standard baud rates (Don Zickus) [1110939]
- [usb] Revert: pl2303: move the two baud rate encoding methods to separate functions (Don Zickus) [1110939]
- [usb] Revert: pl2303: increase the allowed baud rate range for the divisor based encoding method (Don Zickus) [1110939]
- [usb] Revert: pl2303: also use the divisor based baud rate encoding method for baud rates < 115200 with HX chips (Don Zickus) [1110939]
- [usb] Revert: pl2303: add two comments concerning the supported baud rates with HX chips (Don Zickus) [1110939]
- [usb] Revert: pl2303: simplify the else-if contruct for type_1 chips in pl2303_startup() (Don Zickus) [1110939]
- [usb] Revert: pl2303: improve the chip type information output on startup
- [usb] Revert: pl2303: improve the chip type detection/distinction
- [usb] Revert: pl2303: distinguish between original and cloned HX chips
- [usb] pl2303: clean up driver somewhat (Don Zickus) [1110939]
- [usb] pl2303: remove bogus delta_msr_wait wake up (Don Zickus) [1110939]
- [usb] core: let dynamic ids override static ids (Don Zickus) [1110939]
- [usb] core: Fix potential memory leak adding dyn USBdevice IDs (Don Zickus) [1110939]
- [usb] core: add sanity checks when using bInterfaceClass with new_id (Don Zickus) [1110939]
- [usb] core: check for valid id_table when using the RefId feature (Don Zickus) [1110939]
- [usb] core: bail out if user gives an unknown RefId when using new_id (Don Zickus) [1110939]
- [usb] core: allow a reference device for new_id (Don Zickus) [1110939]
- [lib] radix-tree: make radix_tree_node_alloc() work correctly within interrupt (Don Zickus) [1110939]
- [usb] Check if port status is equal to RxDetect (Don Zickus) [1110939]
- [usb] serial/ftdi_sio: Add Infineon Triboard (Don Zickus) [1110939]
- [usb] ftdi_sio: Add extra PID (Don Zickus) [1110939]
- [usb] option: Add ID for Telewell TW-LTE 4G v2 (Don Zickus) [1110939]
- [usb] cp210x: add support for Corsair usb dongle (Don Zickus) [1110939]
- [usb] storage/scsi: Add broken_fua blacklist flag (Don Zickus) [1110939]
- [usb] xhci: Fix runtime suspended xhci from blocking system suspend (Don Zickus) [1110939]
- [usb] xhci: clear root port wake on bits if controller isn't wake-up capable (Don Zickus) [1110939]
- [usb] xhci: correct burst count field for isoc transfers on 1.0 xhci hosts (Don Zickus) [1110939]
- [usb] xhci: Use correct SLOT ID when handling a reset device command (Don Zickus) [1110939]
- [usb] option: add/modify Olivetti Olicard modems (Don Zickus) [1110939]
- [usb] ftdi_sio: fix null deref at port probe (Don Zickus) [1110939]
- [usb] option: add device ID for SpeedUp SU9800 usb 3g modem (Don Zickus) [1110939]
- [usb] usbtest: add a timeout for scatter-gather tests (Don Zickus) [1110939]
- [usb] ehci: avoid BIOS handover on the HASEE E200 (Don Zickus) [1110939]
- [usb] fix hub-port pm_runtime_enable() vs runtime pm transitions (Don Zickus) [1110939]
- [usb] quiet peer failure warning, disable poweroff (Don Zickus) [1110939]
- [usb] improve "not suspended yet" message in hub_suspend() (Don Zickus) [1110939]
- [usb] xhci: Fix sleeping with IRQs disabled in xhci_stop_device() (Don Zickus) [1110939]
- [usb] fix ->update_hub_device() vs hdev->maxchild (Don Zickus) [1110939]
- [usb] hub_handle_remote_wakeup() only exists for CONFIG_PM=y (Don Zickus) [821903]
- [usb] qcserial: add additional Sierra Wireless QMI devices (Don Zickus) [1110939]
- [usb] qcserial: add Netgear AirCard 341U (Don Zickus) [1110939]
- [usb] xhci: delete endpoints from bandwidth list before freeing whole device (Don Zickus) [1110939]
- [usb] host/xhci-plat: add xhci_plat_start() (Don Zickus) [1110939]
- [usb] pci-quirks: Prevent Sony VAIO t-series from switching usb ports (Don Zickus) [1110939]
- [usb] resume child device when port is powered on (Don Zickus) [1110939]
- [usb] hub_handle_remote_wakeup() depends on CONFIG_PM_RUNTIME=y (Don Zickus) [1110939]
- [usb] introduce port status lock (Don Zickus) [1110939]
- [usb] synchronize port poweroff and khubd (Don Zickus) [1110939]
- [usb] refactor port handling in hub_events() (Don Zickus) [1110939]
- [usb] usb3 ports do not support FEAT_C_ENABLE (Don Zickus) [1110939]
- [usb] don't clear FEAT_C_ENABLE on usb_port_runtime_resume failure (Don Zickus) [1110939]
- [usb] block suspension of superspeed port while hispeed peer is active (Don Zickus) [1110939]
- [usb] make usb_port flags atomic, rename did_runtime_put to child_usage (Don Zickus) [1110939]
- [usb] sysfs link peer ports (Don Zickus) [1110939]
- [usb] find internal hub tier mismatch via acpi (Don Zickus) [1110939]
- [usb] assign usb3 external hub port peers (Don Zickus) [1110939]
- [usb] assign default peer ports for root hubs (Don Zickus) [1110939]
- [usb] cleanup setting udev->removable from port_dev->connect_type (Don Zickus) [1110939]
- [usb] rename usb_port device objects (Don Zickus) [1110939]
- [usb] disable port power control if not supported in wHubCharacteristics (Don Zickus) [1110939]
- [usb] mutual exclusion for resetting a hub and power-managing a port (Don Zickus) [1110939]
- [usb] pci_quirks: fix sparse 'symbol not declared' warning (Don Zickus) [1110939]
- [usb] storage/ene_ub6250: Use kmemdup instead of kmalloc + memcpy (Don Zickus) [1110939]
- [usb] usbtest: add pattern check on pipe in phase of unlink read (Don Zickus) [1110939]
- [usb] usbtest: fix unlink write error with pattern 1 (Don Zickus) [1110939]
- [usb] usb5303: add support for reference clock specified in device tree (Don Zickus) [1110939]
- [usb] separate usb_address0 mutexes for each bus (Don Zickus) [1110939]
- [usb] xhci: Switch only Intel Lynx Point-LP ports to EHCI on shutdown (Don Zickus) [1110939]
- [usb] yurex: fix race between probe() and read() (Don Zickus) [1110939]
- [usb] appledisplay: fix race between reading and writing from the device (Don Zickus) [1110939]
- [usb] usbtmc: fix DMA on stack (Don Zickus) [1110939]
- [usb] cdc-acm: use BIT macro (Don Zickus) [1110939]
- [usb] xhci: unified loggig of RESET_ON_RESUME (Don Zickus) [1110939]
- [usb] xhci: avoid warning for !PM_SLEEP (Don Zickus) [1110939]
- [usb] host/xhci-plat: add clock support (Don Zickus) [1110939]
- [usb] host/xhci-plat: sort the headers in alphabetic order (Don Zickus) [1110939]
- [usb] move usb/usb-common.c to usb/common/usb-common.c (Don Zickus) [1110939]
- [usb] core: remove the Kconfig entry for USB_DEBUG (Don Zickus) [1110939]
- [usb] remove redundant D0 power state set (Don Zickus) [1110939]
- [usb] keyspan: fix potential null pointer dereference (Don Zickus) [1110939]
- [usb] serial/option: add support for Novatel E371 PCIe card (Don Zickus) [1110939]
- [usb] ftdi_sio: add NovaTech OrionLXm product ID (Don Zickus) [1110939]
- [usb] io_ti: fix firmware download on big-endian machines (part 2) (Don Zickus) [1110939]
- [usb] cdc-acm: use tty-port dtr_rts (Don Zickus) [1110939]
- [usb] cdc-acm: remove redundant usb_mark_last_busy (Don Zickus) [1110939]
- [usb] cdc-acm: do not update PM busy on read errors (Don Zickus) [1110939]
- [usb] cdc-acm: minimise no-suspend window during shutdown (Don Zickus) [1110939]
- [usb] cdc-acm: remove redundant disconnected test from shutdown (Don Zickus) [1110939]
- [usb] cdc-acm: simplify runtime PM locking (Don Zickus) [1110939]
- [usb] cdc-acm: fix runtime PM imbalance at shutdown (Don Zickus) [1110939]
- [usb] cdc-acm: fix I/O after failed open (Don Zickus) [1110939]
- [usb] cdc-acm: fix failed open not being detected (Don Zickus) [1110939]
- [usb] cdc-acm: fix open and suspend race (Don Zickus) [1110939]
- [usb] cdc-acm: fix potential urb leak and PM imbalance in write (Don Zickus) [1110939]
- [usb] cdc-acm: fix shutdown and suspend race (Don Zickus) [1110939]
- [usb] cdc-acm: fix runtime PM for control messages (Don Zickus) [1110939]
- [usb] cdc-acm: fix broken runtime suspend (Don Zickus) [1110939]
- [usb] cdc-acm: fix write and resume race (Don Zickus) [1110939]
- [usb] cdc-acm: fix write and suspend race (Don Zickus) [1110939]
- [usb] kobil_sct: fix control requests without data stage (Don Zickus) [1110939]
- [usb] serial: remove overly defensive port tests (Don Zickus) [1110939]
- [usb] serial: fix potential runtime pm imbalance at device remove (Don Zickus) [1110939]
- [usb] usb_wwan: do not resume I/O on closing ports (Don Zickus) [1110939]
- [usb] usb_wwan: report failed submissions as errors (Don Zickus) [1110939]
- [usb] usb_wwan: remove bogus function prototype (Don Zickus) [1110939]
- [usb] usb_wwan: remove some superfluous comments (Don Zickus) [1110939]
- [usb] usb_wwan: remove comment from close (Don Zickus) [1110939]
- [usb] usb_wwan: clean up delayed-urb submission (Don Zickus) [1110939]
- [usb] usb_wwan: use interface-data accessors (Don Zickus) [1110939]
- [usb] usb_wwan: make resume error messages uniform (Don Zickus) [1110939]
- [usb] usb_wwan: kill interrupt urb explicitly at suspend (Don Zickus) [1110939]
- [usb] usb_wwan: remove redundant urb kill from port remove (Don Zickus) [1110939]
- [usb] usb_wwan: remove unimplemented set_termios (Don Zickus) [1110939]
- [usb] usb_wwan: remove redundant modem-control request (Don Zickus) [1110939]
- [usb] usb_wwan: fix remote wakeup (Don Zickus) [1110939]
- [usb] usb_wwan: fix discarded writes on resume errors (Don Zickus) [1110939]
- [usb] usb_wwan: fix potential blocked I/O after resume (Don Zickus) [1110939]
- [usb] usb_wwan: fix potential NULL-deref at resume (Don Zickus) [1110939]
- [usb] usb_wwan: fix urb leak at shutdown (Don Zickus) [1110939]
- [usb] usb_wwan: fix write and suspend race (Don Zickus) [1110939]
- [usb] usb_wwan: fix race between write and resume (Don Zickus) [1110939]
- [usb] usb_wwan: fix urb leak in write error path (Don Zickus) [1110939]
- [usb] option: add missing usb_mark_last_busy (Don Zickus) [1110939]
- [usb] option: fix line-control pipe direction (Don Zickus) [1110939]
- [usb] option: fix runtime PM handling (Don Zickus) [1110939]
- [usb] sierra: do not resume I/O on closing ports (Don Zickus) [1110939]
- [usb] sierra: minimise no-suspend window during close (Don Zickus) [1110939]
- [usb] sierra: refactor delayed-urb submission (Don Zickus) [1110939]
- [usb] sierra: clean up suspend (Don Zickus) [1110939]
- [usb] sierra: use interface-data accessors (Don Zickus) [1110939]
- [usb] sierra: remove redundant modem-control requests (Don Zickus) [1110939]
- [usb] sierra: do not resume I/O on closed ports (Don Zickus) [1110939]
- [usb] sierra: remove disconnected test from close (Don Zickus) [1110939]
- [usb] sierra: remove unimplemented set_termios (Don Zickus) [1110939]
- [usb] sierra: remove unused variable (Don Zickus) [1110939]
- [usb] sierra: remove bogus endpoint test (Don Zickus) [1110939]
- [usb] sierra: fix line-control pipe direction (Don Zickus) [1110939]
- [usb] sierra: fix resume error reporting (Don Zickus) [1110939]
- [usb] sierra: fix urbs not being killed on shutdown (Don Zickus) [1110939]
- [usb] sierra: fix characters being dropped at close (Don Zickus) [1110939]
- [usb] sierra: fix remote wakeup (Don Zickus) [1110939]
- [usb] sierra: fix urb and memory leak on disconnect (Don Zickus) [1110939]
- [usb] sierra: fix urb and memory leak in resume error path (Don Zickus) [1110939]
- [usb] sierra: fix use after free at suspend/resume (Don Zickus) [1110939]
- [usb] sierra: fix AA deadlock in open error path (Don Zickus) [1110939]
- [usb] iowarrior: Convert local dbg macro to dev_dbg (Don Zickus) [1110939]
- [usb] appledisplay: Convert /n to n (Don Zickus) [1110939]
- [usb] qcserial: remove interface number matching (Don Zickus) [1110939]
- [usb] qcserial: define and use Sierra Wireless layout (Don Zickus) [1110939]
- [usb] qcserial: refactor device layout selection (Don Zickus) [1110939]
- [usb] qcserial: fix multiline comment coding style (Don Zickus) [1110939]
- [usb] Avoid runtime suspend loops for HCDs that can't handle suspend/resume (Don Zickus) [1110939]
- [usb] xhci: rework command timeout and cancellation, (Don Zickus) [1110939]
- [usb] Revert: xhci: replace xhci_read_64() with readq() (Don Zickus) [1110939]
- [usb] Revert: xhci: replace xhci_write_64() with writeq() (Don Zickus) [1110939]
- [usb] Revert: core: set lpm_capable field for LPM capable root hubs (Don Zickus) [1110939]
- [usb] xhci: Use completion and status in global command queue (Don Zickus) [1110939]
- [usb] xhci: Add a global command queue (Don Zickus) [1110939]
- [usb] xhci: Use command structures when queuing commands on the command ring (Don Zickus) [1110939]
- [usb] xhci: Report max device limit when Enable Slot command fails (Don Zickus) [1110939]
- [usb] xhci: Use pci_enable_msix_exact() instead of pci_enable_msix() (Don Zickus) [1110939]
- [usb] xhci: Use IS_ENABLED() macro (Don Zickus) [1110939]
- [usb] catch attempts to submit urbs with a vmalloc'd transfer buffer (Don Zickus) [1110939]
- [usb] xhci: fix wrong port number reported when setting USB2.0 hardware LPM (Don Zickus) [1110939]
- [usb] Nokia 5300 should be treated as unusual dev (Don Zickus) [1110939]
- [usb] Nokia 305 should be treated as unusual dev (Don Zickus) [1110939]
- [usb] fsl: do not test for PHY_CLK_VALID bit on controller version 1.6 (Don Zickus) [1110939]
- [usb] storage/shuttle_usbat: fix discs being detected twice (Don Zickus) [1110939]
- [usb] qcserial: add a number of Dell devices (Don Zickus) [1110939]
- [usb] ohci: fix problem with global suspend on ATI controllers (Don Zickus) [1110939]
- [usb] option: add and update a number of CMOTech devices (Don Zickus) [1110939]
- [usb] option: add Alcatel L800MA (Don Zickus) [1110939]
- [usb] option: add Olivetti Olicard 500 (Don Zickus) [1110939]
- [usb] qcserial: add Sierra Wireless MC7305/MC7355 (Don Zickus) [1110939]
- [usb] qcserial: add Sierra Wireless MC73xx (Don Zickus) [1110939]
- [usb] qcserial: add Sierra Wireless EM7355 (Don Zickus) [1110939]
- [usb] io_ti: fix firmware download on big-endian machines (Don Zickus) [1110939]
- [usb] xhci: fix compilation warning when !CONFIG_PCI && !CONFIG_PM (Don Zickus) [1110939]
- [usb] xhci: extend quirk for Renesas cards (Don Zickus) [1110939]
- [usb] xhci: Switch Intel Lynx Point ports to EHCI on shutdown (Don Zickus) [1110939]
- [usb] xhci: Prefer endpoint context dequeue pointer over stopped_trb (Don Zickus) [1110939]
- [usb] ftdi-elan: Use pr_<level> (Don Zickus) [1110939]
- [usb] ftdi-elan: Coalesce string fragment (Don Zickus) [1110939]
- [usb] ftdi-elan: Coalesce formats (Don Zickus) [1110939]
- [usb] ftdi-elan: Convert leading spaces to tabs (Don Zickus) [1110939]
- [usb] ftdi-elan: Fix format fragments (Don Zickus) [1110939]
- [usb] serial: fix sysfs-attribute removal deadlock (Don Zickus) [1110939]
- [usb] uas: fix deadlocky memory allocations (Don Zickus) [1110939]
- [usb] uas: fix error handling during scsi_scan() (Don Zickus) [1110939]
- [usb] uas: fix GFP_NOIO under spinlock (Don Zickus) [1110939]
- [usb] cdc-acm: Remove Motorola/Telit H24 serial interfaces from ACM driver (Don Zickus) [1110939]
- [usb] ehci-platform: Return immediately from suspend if ehci_suspend fails (Don Zickus) [1110939]
- [usb] ehci-exynos: Return immediately from suspend if ehci_suspend fails (Don Zickus) [1110939]
- [usb] fix crash during hotplug of PCI USB controller card (Don Zickus) [1110939]
- [usb] cdc-acm: fix double usb_autopm_put_interface() in acm_port_activate() (Don Zickus) [1110939]
- [usb] usb_wwan: fix handling of missing bulk endpoints (Don Zickus) [1110939]
- [usb] pl2303: add ids for Hewlett-Packard HP POS pole displays (Don Zickus) [1110939]
- [usb] cp210x: Add 8281 (Nanotec Plug & Drive) (Don Zickus) [1110939]
- [usb] option driver, add support for Telit UE910v2 (Don Zickus) [1110939]
- [usb] Revert: serial: add usbid for dell wwan card to sierra.c (Don Zickus) [1110939]
- [usb] serial/ftdi_sio: add id for Brainboxes serial cards (Don Zickus) [1110939]
- [net] usb: include wait queue head in device structure (Don Zickus) [1110939]
- [usb] disable reset-resume when USB_QUIRK_RESET is set (Don Zickus) [1110939]
- [usb] unbind all interfaces before rebinding any (Don Zickus) [1110939]
- [usb] keyspan: remove dead debugging code (Don Zickus) [1110939]
- [usb] serial: add missing newlines to dev_<level> messages (Don Zickus) [1110939]
- [usb] serial: add missing braces (Don Zickus) [1110939]
- [usb] serial: continue to write on errors (Don Zickus) [1110939]
- [usb] serial: continue to read on errors (Don Zickus) [1110939]
- [usb] serial: make bulk_out_size a lower limit (Don Zickus) [1110939]
- [usb] cypress_m8: fix potential scheduling while atomic (Don Zickus) [1110939]
- [usb] Revert: xhci: Limit arbitrarily-aligned scatter gather (Don Zickus) [1110939]
- [usb] Make DELAY_INIT quirk wait 100ms between Get Configuration requests (Don Zickus) [1110939]
- [usb] Add device quirk for Logitech HD Pro Webcams C920 and C930e (Don Zickus) [1110939]
- [usb] xhci: add the meaningful IRQ description if it is empty (Don Zickus) [1110939]
- [usb] xhci: Prevent runtime pm from autosuspending during initialization (Don Zickus) [1110939]
- [usb] storage: accept some UAS devices if streams are unavailable (Don Zickus) [1110939]
- [usb] xhci: Kill streams URBs when the host dies (Don Zickus) [1110939]
- [usb] xhci: Refactor command watchdog and fix split string (Don Zickus) [1110939]
- [usb] uas: Remove comment about registering a uas scsi controller for each usb bus (Don Zickus) [1110939]
- [usb] uas: Add Hans de Goede as uas maintainer (Don Zickus) [1110939]
- [usb] uas: remove BROKEN (Don Zickus) [1110939]
- [usb] uas: Make sure sg elements are properly aligned (Don Zickus) [1110939]
- [usb] uas: Add some data in/out ready iu sanity checks (Don Zickus) [1110939]
- [usb] uas: Improve error reporting (Don Zickus) [1110939]
- [usb] uas: Use the right error codes for different kinds of errors (Don Zickus) [1110939]
- [usb] uas: Clear cmdinfo on command queue-ing (Don Zickus) [1110939]
- [usb] uas: Fix memory management (Don Zickus) [1110939]
- [usb] uas: Fix command / task mgmt submission racing with disconnect (Don Zickus) [1110939]
- [usb] uas: cmdinfo - use only one list head (Don Zickus) [1110939]
- [usb] uas: add uas_mark_cmd_dead helper function (Don Zickus) [1110939]
- [usb] uas: Properly complete inflight commands on bus-reset or disconnect (Don Zickus) [1110939]
- [usb] uas: uas_alloc_data_urb - Remove unnecessary use_streams check (Don Zickus) [1110939]
- [usb] uas: Fix task-management not working when connected over USB-2 (Don Zickus) [1110939]
- [usb] uas: Reset device on reboot (Don Zickus) [1110939]
- [usb] uas: Add suspend/resume support (Don Zickus) [1110939]
- [usb] uas: Use GFP_NOIO rather then GFP_ATOMIC where possible (Don Zickus) [1110939]
- [usb] uas: Don't allow more then one task to run at the same time (Don Zickus) [1110939]
- [usb] uas: task_mgmt - Kill the sense-urb if we fail to submit the cmd urb (Don Zickus) [1110939]
- [usb] uas: Not being able to alloc streams when connected through usb-3 is an error (Don Zickus) [1110939]
- [usb] uas: Verify endpoint descriptors from uas_use_uas_driver() (Don Zickus) [1110939]
- [usb] uas: Drop fixed endpoint config handling (Don Zickus) [1110939]
- [usb] uas: Move uas_find_endpoints to uas-detect.h (Don Zickus) [1110939]
- [usb] uas: Fix bounds check in uas_find_endpoints (Don Zickus) [1110939]
- [usb] uas: Add uas_find_endpoints() helper function (Don Zickus) [1110939]
- [usb] uas: Honor no-uas quirk set in usb-storage's quirks module parameter (Don Zickus) [1110939]
- [usb] storage: Modify and export adjust_quirks so that it can be used by uas (Don Zickus) [1110939]
- [usb] storage: Don't bind to uas devices if the uas driver is enabled (Don Zickus) [1110939]
- [usb] uas: Add the posibilty to blacklist uas devices from using the uas driver (Don Zickus) [1110939]
- [usb] Reset USB-3 devices on USB-3 link bounce (Don Zickus) [1110939]
- [usb] Clear host_endpoint->streams when implicitly freeing streams (Don Zickus) [1110939]
- [usb] xhci: Handle MaxPSASize == 0 (Don Zickus) [1110939]
- [usb] xhci: The trb_address_map radix tree expects 1KB segment memory aligment (Don Zickus) [1110939]
- [usb] xhci: xhci_mem_cleanup - make sure cmd_ring_reserved_trbs really is 0 (Don Zickus) [1110939]
- [usb] uas: Move uas detect code to uas-detect.h (Don Zickus) [1110939]
- [usb] uas: Add a uas_find_uas_alt_setting helper function (Don Zickus) [1110939]
- [usb] uas: Use all available stream ids (Don Zickus) [1110939]
- [usb] uas: Pack iu struct definitions (Don Zickus) [1110939]
- [usb] uas: Fix response iu struct definition (Don Zickus) [1110939]
- [usb] uas: s/response_ui/response_iu/ (Don Zickus) [1110939]
- [usb] uas: Fix reset handling for externally triggered reset (Don Zickus) [1110939]
- [usb] uas: Fix reset locking (Don Zickus) [1110939]
- [usb] uas: Fix uas not working when plugged into an ehci port (Don Zickus) [1110939]
- [usb] uas: uas_alloc_cmd_urb - drop unused stream_id parameter (Don Zickus) [1110939]
- [usb] uas: Avoid unnecessary unlock / lock calls around unlink_data_urbs (Don Zickus) [1110939]
- [usb] uas: Properly set interface to altsetting 0 on probe failure (Don Zickus) [1110939]
- [usb] uas: Urbs must be anchored before submitting them (Don Zickus) [1110939]
- [usb] uas: replace BUG_ON() + WARN_ON() with WARN_ON_ONCE() (Don Zickus) [1110939]
- [usb] uas: add dead request list (Don Zickus) [1110939]
- [usb] uas: make work list per-device (Don Zickus) [1110939]
- [usb] uas: properly reinitialize in uas_eh_bus_reset_handler (Don Zickus) [1110939]
- [usb] fs: Add support for allocating / freeing streams (Don Zickus) [1110939]
- [usb] fs: Add ep_to_host_endpoint helper function (Don Zickus) [1110939]
- [usb] fs: Add support for bulk stream ids (Don Zickus) [1110939]
- [usb] fs: proc_do_submiturb use a local variable for number_of_packets (Don Zickus) [1110939]
- [usb] usbfs: Kill urbs on interface before doing a set_interface (Don Zickus) [1110939]
- [usb] core: Free bulk streams on interface release (Don Zickus) [1110939]
- [usb] core: Track if an endpoint has streams (Don Zickus) [1110939]
- [usb] core: Move USB_MAXENDPOINTS definitions to usb.h (Don Zickus) [1110939]
- [usb] core: Fix usb_free_streams return value documentation (Don Zickus) [1110939]
- [usb] xhci: Remove segments from radix tree on failed insert (Don Zickus) [1110939]
- [usb] xhci: use usb_ss_max_streams in xhci_check_streams_endpoint (Don Zickus) [1110939]
- [usb] xhci: For streams the dequeue ptr must be read from the stream ctx (Don Zickus) [1110939]
- [usb] xhci: Set SCT field for Set TR dequeue on streams (Don Zickus) [1110939]
- [usb] xhci: For streams the css flag most be read from the stream-ctx on ep stop (Don Zickus) [1110939]
- [usb] xhci: Check size rather then number of streams when allocating stream ctxs (Don Zickus) [1110939]
- [usb] xhci: Free streams when they are still allocated on a set_interface call (Don Zickus) [1110939]
- [usb] xhci: fix usb3 streams (Don Zickus) [1110939]
- [usb] xhci: make warnings greppable (Don Zickus) [1110939]
- [usb] xhci: Change how we indicate a host supports Link PM (Don Zickus) [1110939]
- [usb] sisusb: Use static const, fix typo (Don Zickus) [1110939]
- [usb] hub: usb_ext_cap_descriptor.bmAttributes is le32 (Don Zickus) [1110939]
- [usb] hub: debug message for failing to enable device (Don Zickus) [1110939]
- [usb] ehci: fix deadlock when threadirqs option is used (Don Zickus) [1110939]
- [usb] ftdi_sio: add Cressi Leonardo PID (Don Zickus) [1110939]
- [usb] complain if userspace resets an active endpoint (Don Zickus) [1110939]
- [usb] serial/option: blacklist interface 4 for Cinterion PHS8 and PXS8 (Don Zickus) [1110939]
- [usb] ehci: add delay during suspend to prevent erroneous wakeups (Don Zickus) [1110939]
- [usb] xhci: Change compatible string from xhci-platform to generic-xhci (Don Zickus) [1110939]
- [usb] uhci-platform: Change compatible string from platform-uhci to generic-uhci (Don Zickus) [1110939]
- [usb] option: blacklist ZTE MF667 net interface (Don Zickus) [1110939]
- [usb] misc/usbled: Add Riso Kagaku Webmail Notifier (Don Zickus) [1110939]
- [usb] elan: Remove useless "default M" lines (Don Zickus) [1110939]
- [usb] Revert: xhci: Link TRB must not occur within a USB payload burst (Don Zickus) [1110939]
- [usb] Revert: xhci: Avoid infinite loop when sg urb requires too many trbs (Don Zickus) [1110939]
- [usb] Revert: xhci: Set scatter-gather limit to avoid failed block writes (Don Zickus) [1110939]
- [usb] xhci: Limit arbitrarily-aligned scatter gather (Don Zickus) [1110939]
- [usb] delete non-required instances of include <linux/init.h> (Don Zickus) [1110939]
- [usb] hub set hub->change_bits when over-current happens (Don Zickus) [1110939]
- [usb] xhci: Set scatter-gather limit to avoid failed block writes (Don Zickus) [1110939]
- [usb] xhci: Avoid infinite loop when sg urb requires too many trbs (Don Zickus) [1110939]
- [usb] ftdi_sio: added CS5 quirk for broken smartcard readers (Don Zickus) [1110939]
- [usb] core: correct spelling mistakes in comments and warning (Don Zickus) [1110939]
- [usb] fix race between hub_disconnect and recursively_mark_NOTATTACHED (Don Zickus) [1110939]
- [usb] oti6858: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] oti6858: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] ch341: clean up interrupt handler (Don Zickus) [1110939]
- [usb] ch341: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] ch341: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] ch341: fix ignored TIOCMIWAIT mask (Don Zickus) [1110939]
- [usb] ch341: clean up line-status handling (Don Zickus) [1110939]
- [usb] ch341: refactor line-status handling (Don Zickus) [1110939]
- [usb] cypress_m8: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] cypress_m8: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] cypress_m8: clean up protocol definitions (Don Zickus) [1110939]
- [usb] cypress_m8: fix ring-indicator detection and reporting (Don Zickus) [1110939]
- [usb] Nokia 502 is an unusual device (Don Zickus) [1110939]
- [usb] serial: add support for iBall 3.5G connect usb modem (Don Zickus) [1110939]
- [usb] serial: correct spelling mistakes in comments (Don Zickus) [1110939]
- [usb] misc/idmouse: correct spelling mistake in error string (Don Zickus) [1110939]
- [usb] yurex: fix spelling mistake in comment (Don Zickus) [1110939]
- [usb] iowarrior: fix spelling mistake in comment (Don Zickus) [1110939]
- [usb] serial: remove redundant OOM messages (Don Zickus) [1110939]
- [usb] serial: clean up ioctl debugging (Don Zickus) [1110939]
- [usb] serial: constify device-id tables (Don Zickus) [1110939]
- [usb] core: remove CONFIG_USB_DEBUG usage (Don Zickus) [1110939]
- [usb] cdc-wdm: avoid hanging on zero length reads (Don Zickus) [1110939]
- [usb] xhci: Check for XHCI_PLAT in xhci_cleanup_msix() (Don Zickus) [1110939]
- [usb] Mark function as static in metro-usb.c (Don Zickus) [1110939]
- [usb] Mark function as static in usbsevseg.c (Don Zickus) [1110939]
- [usb] option: add new zte 3g modem pids to option driver (Don Zickus) [1110939]
- [usb] usbtest: Always clear halt else further tests will fail (Don Zickus) [1110939]
- [usb] usbtest: Add timetout to simple_io() (Don Zickus) [1110939]
- [usb] xhci: Remove unused variable 'addr' in inc_deq() and inc_enq() (Don Zickus) [1110939]
- [usb] usbtest: Fix BOS control test for USB 2.01 devices (Don Zickus) [1110939]
- [usb] xhci: Add quirks module option (Don Zickus) [1069460]
- [usb] xhci: clarify logging in xhci_setup_device (Don Zickus) [1110939]
- [usb] xhci: change enumeration scheme to 'new scheme' by default (Don Zickus) [1069460]
- [usb] xhci: Limit the spurious wakeup fix only to HP machines (Don Zickus) [1069461]
- [usb] core: get config and string descriptors for unauthorized devices (Don Zickus) [1110939]
- [usb] core: allow isoc URBs for wireless devices with an interval < 6 (Don Zickus) [1110939]
- [usb] serial/zte_ev: move support for ZTE AC2726 from zte_ev back to option (Don Zickus) [1110939]
- [usb] cdc-wdm: manage_power should always set needs_remote_wakeup (Don Zickus) [1110939]
- [usb] Revert: quirks: add touchscreen that is dazzeled by remote wakeup (Don Zickus) [1110939]
- [usb] Use dev_is_pci() to check whether it is pci device (Don Zickus) [1110939]
- [usb] usbtest: update bos test coverage to usb 2.1 device (Don Zickus) [1110939]
- [usb] usbtest: fix the bit mask of usb 2.0 extension descriptor (Don Zickus) [1110939]
- [usb] usbtest: add a test case to support bos for queue control (Don Zickus) [1110939]
- [usb] fix coccinelle warnings (Don Zickus) [1110939]
- [usb] hub: Use correct reset for wedged USB3 devices that are NOTATTACHED (Don Zickus) [1110939]
- [usb] remove DEFINE_PCI_DEVICE_TABLE macro (Don Zickus) [1110939]
- [usb] host: Remove superfluous name casts (Don Zickus) [1110939]
- [usb] core: Remove superfluous name casts (Don Zickus) [1110939]
- [usb] kill #undef VERBOSE_DEBUG (Don Zickus) [1110939]
- [usb] kill DEBUG compile option (Don Zickus) [1110939]
- [usb] uhci: compile debugfs conditional on CONFIG_DYNAMIC_DEBUG (Don Zickus) [1110939]
- [usb] uhci: change dependency for debug parameter (Don Zickus) [1110939]
- [usb] ehci: Remove debugging at every interrupt (Don Zickus) [1110939]
- [usb] ehci: no conditional compilation for interestingness (Don Zickus) [1110939]
- [usb] ohci: no conditional debugging in root hub hadling (Don Zickus) [1110939]
- [usb] ohci: always register debug files (Don Zickus) [1110939]
- [usb] ohci: kill ohci_vdbg (Don Zickus) [1110939]
- [usb] ohci: remove conditional compilation (Don Zickus) [1110939]
- [usb] net/cdc-acm: fix power management in ioctl (Don Zickus) [1110939]
- [net] usb/cdc-acm: add TIOCGICOUNT (Don Zickus) [1110939]
- [usb] net/cdc-acm: add TIOCMIWAIT (Don Zickus) [1110939]
- [usb] option: support new huawei devices (Don Zickus) [1110939]
- [usb] serial/option: blacklist interface 1 for Huawei E173s-6 (Don Zickus) [1110939]
- [usb] xhci: replace xhci_write_64() with writeq() (Don Zickus) [1110939]
- [usb] xhci: replace xhci_read_64() with readq() (Don Zickus) [1110939]
- [usb] xhci: replace xhci_writel() with writel() (Don Zickus) [1110939]
- [usb] xhci: replace xhci_readl() with readl() (Don Zickus) [1110939]
- [usb] xhci: remove conversion from generic to pci device in xhci_mem.c (Don Zickus) [1110939]
- [usb] xhci: fix incorrect type in assignment in xhci_count_num_dropped_endpoints() (Don Zickus) [1110939]
- [usb] xhci: fix incorrect type in assignment in xhci_count_num_new_endpoints() (Don Zickus) [1110939]
- [usb] xhci: remove unnecessary check in xhci_free_stream_info() (Don Zickus) [1110939]
- [usb] xhci: fix SCT_FOR_CTX(p) macro (Don Zickus) [1110939]
- [usb] xhci: replace USB_MAXINTERFACES with config->desc.bNumInterface (Don Zickus) [1110939]
- [usb] xhci: fix incorrect type in assignment in xhci_address_device() (Don Zickus) [1110939]
- [usb] xhci: fix sparse warning in xhci-trace.h (Don Zickus) [1110939]
- [usb] xhci: fix derivation of TRB's DMA address in xhci_log_event Trace Event Class (Don Zickus) [1110939]
- [usb] r8a66597-hcd: Convert to clk_prepare/unprepare (Don Zickus) [1110939]
- [usb] serial: fix write memory-allocation flag (Don Zickus) [1110939]
- [usb] serial: fix race in generic write (Don Zickus) [1110939]
- [net] usb/cdc_ncm: Export cdc_ncm_{tx, rx}_fixup functions for re-use (Don Zickus) [1110939]
- [net] usb/cdc_ncm: drop "extern" from header declarations (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove descriptor pointers (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove ncm_parm field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove tx_speed and rx_speed fields (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove unused udev field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove redundant netdev field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: simplify and optimize frame padding (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove redundant endpoint pointers (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove redundant "intf" field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: add include protection to cdc_ncm.h (Don Zickus) [1110939]
- [usb] ssb-hcd: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Don Zickus) [1110939]
- [usb] bcma: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Don Zickus) [1110939]
- [usb] usbtest: support container id descriptor test (Don Zickus) [1110939]
- [usb] usbtest: support superspeed device capbility descriptor test (Don Zickus) [1110939]
- [usb] usbtest: support usb2 extension descriptor test (Don Zickus) [1110939]
- [usb] ehci-atmel: add usb_clk for transition to CCF (Don Zickus) [1110939]
- [usb] cdc-wdm: ignore speed change notifications (Don Zickus) [1110939]
- [usb] cdc-wdm: support back-to-back USB_CDC_NOTIFY_RESPONSE_AVAILABLE notifications (Don Zickus) [1110939]
- [usb] usbtest: support bos descriptor test for usb 3.0 (Don Zickus) [1110939]
- [usb] wusbcore: fix control-pipe directions (Don Zickus) [1110939]
- [usb] wusbcore: fix panic in wusbhc_chid_set (Don Zickus) [1110939]
- [usb] wusbcore: convert nested lock to use spin_lock instead of spin_lock_irq (Don Zickus) [1110939]
- [usb] wusbcore: use multiple urbs for HWA iso transfer result frame reads (Don Zickus) [1110939]
- [usb] wusbcore: combine iso transfer result frame reads when possible (Don Zickus) [1110939]
- [usb] wusbcore: disable transfer notifications for Alereon HWAs (Don Zickus) [1110939]
- [usb] wusbcore: don't mark WA_SEG_DTI_PENDING segs as done in urb_dequeue (Don Zickus) [1110939]
- [usb] wusbcore: fix potential double list_del on urb dequeue (Don Zickus) [1110939]
- [usb] wusbcore: fix compile warnings (Don Zickus) [1110939]
- [usb] wusbcore: add info to HWA debug prints (Don Zickus) [1110939]
- [usb] wusbcore: read actual_length bytes isoc in segments (Don Zickus) [1110939]
- [usb] wusbcore: adjust iterator correctly when searching for ep comp descriptor (Don Zickus) [1110939]
- [usb] wusbcore: add a convenience function for completing a transfer segment (Don Zickus) [1110939]
- [usb] wusbcore: prevent urb dequeue and giveback race (Don Zickus) [1110939]
- [usb] wusbcore: fix stranded URB after HWA unplug (Don Zickus) [1110939]
- [usb] wusbcore: fix kernel panic on HWA unplug (Don Zickus) [1110939]
- [usb] wusbcore: fix up coding style issues in wa-nep.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up coding style issues in wa-rpipe.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up coding style issues in wusbhc.c and wusbhc.h (Don Zickus) [1110939]
- [usb] wusbcore: fix up line break coding style issues in mmc.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up line break coding style issues in security.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up line break coding style issues in wa-hc.h (Don Zickus) [1110939]
- [usb] wusbcore: fix up minor coding style issues in cbaf.c (Don Zickus) [1110939]
- [usb] wusbcore: correct spelling mistakes in comments and error string (Don Zickus) [1110939]
- [usb] wusbcore: add debug prints to reservation and channel change (Don Zickus) [1110939]
- [usb] wusbcore: add isochronous IN support to HWA (Don Zickus) [1110939]
- [usb] wusbcore: set packet count correctly on isoc transfers (Don Zickus) [1110939]
- [usb] wusbcore: move isoc_frame_index from wa_xfer to wa_seg (Don Zickus) [1110939]
- [usb] wusbcore: use USB_CTRL_SET_TIMEOUT and USB_CTRL_GET_TIMEOUT (Don Zickus) [1110939]
- [usb] wusbcore: fix short transfers (Don Zickus) [1110939]
- [usb] wusbcore: return -ENOENT for unlinked URBs (Don Zickus) [1110939]
- [usb] wusbcore: add more info to debug prints in urb_unlink path (Don Zickus) [1110939]
- [usb] wusbcore: add calls to usb_hcd_link_urb_to_ep, usb_hcd_unlink_urb_from_ep, and (Don Zickus) [1110939]
- [usb] wusbcore: fix deadlock in wusbhc_gtk_rekey (Don Zickus) [1110939]
- [usb] wusbcore: do device lookup while holding the hc mutex (Don Zickus) [1110939]
- [usb] wusbcore: send keepalives to unauthenticated devices (Don Zickus) [1110939]
- [usb] wusbcore: change WA_SEGS_MAX to a legal value (Don Zickus) [1110939]
- [usb] wusbcore: add a quirk for Alereon HWA device isoc behavior (Don Zickus) [1110939]
- [usb] wusbcore: combine multiple isoc frames in a single transfer request (Don Zickus) [1110939]
- [usb] wusbcore: set the RPIPE wMaxPacketSize value correctly (Don Zickus) [1110939]
- [usb] wusbcore: fix usb_dev leaks (Don Zickus) [1110939]
- [usb] wusbcore: serialize access to the HWA data out endpoint (Don Zickus) [1110939]
- [usb] wusbcore: fix string formatting warnings on 64-bit builds (Don Zickus) [1110939]
- [usb] wusbcore: add support for isoc out transfers (Don Zickus) [1110939]
- [usb] wusbcore: set the RPIPE bOverTheAirInterval for isoc endpoints (Don Zickus) [1110939]
- [usb] wusbcore: avoid stack overflow in URB enqueue error path (Don Zickus) [1110939]
- [usb] wusbcore: fix build warning on 64-bit builds (Don Zickus) [1110939]
- [usb] wusbcore: clean up urb dequeue process (Don Zickus) [1110939]
- [usb] wusbcore: include the xfer_id in debug prints (Don Zickus) [1110939]
- [usb] wusbcore: fix endianess issues when using dwTransferID (Don Zickus) [1110939]
- [usb] wusbcore: set pointers to NULL after freeing in error cases (Don Zickus) [1110939]
- [usb] wusbcore: clean up the sg list that was created for out transfers (Don Zickus) [1110939]
- [usb] wusbcore: resource cleanup fix in __wa_xfer_setup_segs (Don Zickus) [1110939]
- [usb] wusbcore: allow wa_xfer_destroy to clean up partially constructed xfers (Don Zickus) [1110939]
- [usb] wusbcore: rename fields in struct wahc (Don Zickus) [1110939]
- [usb] wusbcore: rename urb to tr_urb in struct wa_seg (Don Zickus) [1110939]
- [usb] wusbcore: use list_move_tail instead of list_del/list_add_tail (Don Zickus) [1110939]
- [usb] usbtest: fix checkpatch warning as sizeof code style (Don Zickus) [1110939]
- [usb] uhci: check for wakeup/suspend race (Don Zickus) [1110939]
- [usb] ehci: add check for wakeup/suspend race (Don Zickus) [1110939]
- [usb] change dev_warn about missing reset-resume to dev_dbg (Don Zickus) [1110939]
- [usb] ohci: fix and explain sparse errors (Don Zickus) [1110939]
- [usb] ehci: fix sparse errors (Don Zickus) [1110939]
- [usb] ehci: fix type mismatch in check_intr_schedule (Don Zickus) [1110939]
- [usb] wusbcore: preserve endianness of cached descriptors (Don Zickus) [1110939]
- [usb] xhci: remove the unused ->address field (Don Zickus) [1032371]
- [usb] xhci: kill a conditional when toggling cycle (Don Zickus) [1032371]
- [usb] hub_activate kill an 'else' (Don Zickus) [1032371]
- [usb] hub: Clear Port Reset Change during init/resume (Don Zickus) [1110939]
- [usb] core/devio: Spaces to tabs for proc_control_compat() (Don Zickus) [1110939]
- [usb] core/devio: Spaces to tabs for proc_reapurbnonblock() (Don Zickus) [1110939]
- [usb] xhci: replace 'event' with 'cmd_comp_code' in set_deq and reset_ep handlers (Don Zickus) [1032371]
- [usb] xhci: add argument 'slot_id' in stop_ep, set_deq and reset_ep cmd handlers (Don Zickus) [1032371]
- [usb] xhci: replace 'xhci->cmd_ring->dequeue' with 'trb' in stop_ep cmd handler (Don Zickus) [1032371]
- [usb] xhci: add variable 'cmd_type' in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: add variable 'cmd_trb' in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: add variable 'cmd_comp_code' in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_CONFIG_EP case into function (Don Zickus) [1032371]
- [usb] xhci: remove unused 'ep_ring' variable in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_EVAL_CONTEXT case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_NEC_GET_FW case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_RESET_DEV case into function (Don Zickus) [1032371]
- [usb] xhci: use completion event's slot id rather than dig it out of command (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_ADDR_DEV case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_DISABLE_SLOT case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_ENABLE_SLOT case into function (Don Zickus) [1032371]
- [usb] xhci: rename existing Command Completion Event handlers (Don Zickus) [1032371]
- [usb] xhci: remove unused argument from xhci_giveback_urb_in_irq() (Don Zickus) [1032371]
- [usb] xhci: correct the usage of USB_CTRL_SET_TIMEOUT (Don Zickus) [1032371]
- [usb] xhci: Staticize xhci_del_comp_mod_timer (Don Zickus) [1032371]
- [usb] Push USB2 LPM disable on disconnect into USB core (Don Zickus) [1032371]
- [usb] xhci: Enable LPM support only for hardwired or BESL devices (Don Zickus) [1032371]
- [usb] Don't enable USB 2.0 Link PM by default (Don Zickus) [1032371]
- [usb] xhci: Set L1 device slot on USB2 LPM enable/disable (Don Zickus) [1032371]
- [usb] Disable USB 2.0 Link PM before device reset (Don Zickus) [1110939]
- [usb] hcd: remove unnecessary local_irq_save (Don Zickus) [1110939]
- [usb] ehci: start new isochronous streams ASAP (Don Zickus) [1110939]
- [usb] ehci: create per-TT bandwidth tables (Don Zickus) [1110939]
- [usb] core/hub: Comments shouldnt be C99 // comment style (Don Zickus) [1110939]
- [usb] core/file: moved asterisk to variable name (Don Zickus) [1110939]
- [usb] core: {file, hub, sysfs, usb}.c - Whitespace fixes (Don Zickus) [1110939]
- [usb] mos7840: fix tiocmget error handling (Don Zickus) [1110939]
- [usb] serial: export usb_serial_generic_write_start (Don Zickus) [1110939]
- [usb] serial: add memory flags to usb_serial_generic_write_start (Don Zickus) [1110939]
- [usb] serial: clean up comments in generic driver (Don Zickus) [1110939]
- [usb] core/hcd: converted busmap from struct to bitmap (Don Zickus) [1110939]
- [usb] add a private-data pointer to struct usb_tt (Don Zickus) [1110939]
- [usb] ehci: use a bandwidth-allocation table (Don Zickus) [1110939]
- [usb] ehci: create a "periodic schedule info" struct (Don Zickus) [1110939]
- [usb] ehci: use consistent NO_FRAME value (Don Zickus) [1110939]
- [usb] ehci: change toggle only upon successful reset (Don Zickus) [1110939]
- [usb] ehci: No SSPLIT allowed in uframe 7 (Don Zickus) [1110939]
- [usb] ehci: compute full-speed bandwidth usage correctly (Don Zickus) [1110939]
- [usb] ehci: check the right uframes for CSPLIT (Don Zickus) [1110939]
- [usb] NS_TO_US should round up (Don Zickus) [1110939]
- [usb] anchor: Delay usb_wait_anchor_empty_timeout wake up till completion is done (Don Zickus) [1110939]
- [usb] anchor: Ensure poisened gets initialized to 0 (Don Zickus) [1110939]
- [usb] cyberjack: fix buggy integer overflow test (Don Zickus) [1110939]
- [usb] host: bugfix - Return length of copied buffer in uhci_hub_control() (Don Zickus) [1110939]
- [usb] host: uhci-platform - remove deprecated IRQF_DISABLED (Don Zickus) [1110939]
- [usb] core/hcd: if-else-braces fixed (Don Zickus) [1110939]
- [usb] core/hcd: removed braces for return statements (Don Zickus) [1110939]
- [usb] core/hcd: replaced C99 // comments (Don Zickus) [1110939]
- [usb] core/hcd: Whitespace fixes (Don Zickus) [1110939]
- [usb] core/hcd: moved asterix to variable (Don Zickus) [1110939]
- [usb] host: Use existing macros instead of hard-coded values in uhci-debug.c (Don Zickus) [1110939]
- [usb] remove intel_mid_otg.h (Don Zickus) [1110939]
- [usb] wusbcore: Add isoc transfer type enum and packet definitions (Don Zickus) [1110939]
- [usb] wusbcore: implement hwahc_op_get_frame_number (Don Zickus) [1110939]
- [usb] ohci: use amd_chipset_type to filter for SB800 prefetch (Don Zickus) [1110939]
- [usb] ehci: use amd_chipset_type to filter for usb subsystem hang bug (Don Zickus) [1110939]
- [usb] ohci: ohci_init_driver() - sanity check overrides (Don Zickus) [1110939]
- [usb] core: usb_amd_resume_quirk() can be static (Don Zickus) [1110939]
- [usb] pci-quirks: amd_chipset_sb_type_init() can be static (Don Zickus) [1110939]
- [usb] serial: invoke dcd_change ldisc's handler (Don Zickus) [1110939]
- [usb] serial: call handle_dcd_change in ftdi driver (Don Zickus) [1110939]
- [usb] correct the usb_disconnect() comment about usb_bus_list_lock (Don Zickus) [1110939]
- [usb] fix substandard locking for the sysfs files (Don Zickus) [1110939]
- [usb] usbtest: bmAttributes would better be masked (Don Zickus) [1110939]
- [usb] core: implement AMD remote wakeup quirk (Don Zickus) [1110939]
- [usb] pci-quirks: refactor AMD quirk to abstract AMD chipset types (Don Zickus) [1110939]
- [usb] host: delete chipidea dependency (Don Zickus) [1110939]
- [usb] ohci/uhci: add soft dependencies on ehci_pci (Don Zickus) [1110939]
- [usb] ehci: support running URB giveback in tasklet context"" (Don Zickus) [1110939]
- [usb] core: fix read of usbdevfs_ctrltransfer fields in proc_control() (Don Zickus) [1110939]
- [usb] core: fix incorrect type in assignment in usb_set_lpm_parameters() (Don Zickus) [1110939]
- [usb] core: Make usb_free_streams return an error (Don Zickus) [1110939]
- [usb] ehci: handle isochronous underruns with tasklets (Don Zickus) [1110939]
- [usb] ehci: code rearrangement in iso_stream_schedule() (Don Zickus) [1110939]
- [usb] see if URB comes from a completion handler (Don Zickus) [1110939]

* Mon Sep 29 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-173.el7]
- [crypto] pefile: Relax the check on the length of the PKCS#7 cert (Vivek Goyal) [852066]
- [kernel] kexec, purgatory: add clean-up for purgatory directory (Vivek Goyal) [852066]
- [x86] purgatory: use approprate -m64/-32 build flag for arch/x86/purgatory (Vivek Goyal) [852066]
- [kernel] kexec: remove CONFIG_KEXEC dependency on crypto (Vivek Goyal) [852066]
- [kernel] kexec: create a new config option CONFIG_KEXEC_FILE for new syscall (Vivek Goyal) [852066]
- [kernel] resource: fix the case of null pointer access (Vivek Goyal) [852066]
- [kernel] kexec: verify the signature of signed PE bzImage (Vivek Goyal) [852066]
- [kernel] kexec: support kexec/kdump on EFI systems (Vivek Goyal) [852066]
- [kernel] kexec: support for kexec on panic using new system call (Vivek Goyal) [852066]
- [x86] kexec-bzimage64: support for loading bzImage using 64bit entry (Vivek Goyal) [852066]
- [kernel] kexec: load and relocate purgatory at kernel load time (Vivek Goyal) [852066]
- [x86] purgatory: core purgatory functionality (Vivek Goyal) [852066]
- [x86] purgatory/sha256: provide implementation of sha256 in purgaotory context (Vivek Goyal) [852066]
- [kernel] kexec: implementation of new syscall kexec_file_load (Vivek Goyal) [852066]
- [kernel] kexec: new syscall kexec_file_load() declaration (Vivek Goyal) [852066]
- [kernel] kexec: make kexec_segment user buffer pointer a union (Vivek Goyal) [852066]
- [kernel] resource: provide new functions to walk through resources (Vivek Goyal) [852066]
- [kernel] kexec: use common function for kimage_normal_alloc() and kimage_crash_alloc() (Vivek Goyal) [852066]
- [kernel] kexec: move segment verification code in a separate function (Vivek Goyal) [852066]
- [kernel] kexec: rename unusebale_pages to unusable_pages (Vivek Goyal) [852066]
- [scripts] build bin2c based on config option CONFIG_BUILD_BIN2C (Vivek Goyal) [852066]
- [scripts] bin2c: move bin2c in scripts/basic (Vivek Goyal) [852066]
- [kernel] kexec: convert printk to pr_foo() (Vivek Goyal) [852066]
- [kernel] kexec/compat: convert to COMPAT_SYSCALL_DEFINE with changing parameter types (Vivek Goyal) [852066]
- [kernel] kexec: use vscnprintf() instead of vsnprintf() in vmcoreinfo_append_str() (Vivek Goyal) [852066]
- [kernel] kexec: add sysctl to disable kexec_load (Vivek Goyal) [852066]
- [kernel] kexec: Typo s/the/then/ (Vivek Goyal) [852066]
- [kernel] kexec: remove unnecessary return (Vivek Goyal) [852066]
- [asm] crash: Remove the original asm/crash.h files (Vivek Goyal) [852066]
- [asm] crash: Rename crash.h to crash-driver.h (Vivek Goyal) [852066]
- [x86] boot: Remove misc.h inclusion from compressed/string.c (Vivek Goyal) [852066]
- [x86] boot: Do not include boot.h in string.c (Vivek Goyal) [852066]
- [x86] boot: Move memset() definition in compressed/string.c (Vivek Goyal) [852066]
- [x86] boot: Move memcmp() into string.h and string.c (Vivek Goyal) [852066]
- [x86] boot: Move optimized memcpy() 32/64 bit versions to compressed/string.c (Vivek Goyal) [852066]
- [x86] boot: Create a separate string.h file to provide standard string functions (Vivek Goyal) [852066]
- [x86] boot: Undef memcmp before providing a new definition (Vivek Goyal) [852066]

* Mon Sep 29 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-172.el7]
- [fs] nfsd4: fix rd_dircount enforcement ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add some comments to the nfsd4 object definitions ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove the client_mutex and the nfs4_lock/unlock_state wrappers ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove nfs4_lock_state: nfs4_state_shutdown_net ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove nfs4_lock_state: nfs4_laundromat ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): reclaim_complete() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): setclientid, setclientid_confirm, renew ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): exchange_id, create/destroy_session() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_open and nfsd4_open_confirm ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_delegreturn() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_open_downgrade + nfsd4_close ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_lock/locku/lockt() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_release_lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_test_stateid/nfsd4_free_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfs4_preprocess_stateid_op() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove old fault injection infrastructure ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add more granular locking to *_delegations fault injectors ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add more granular locking to forget_openowners fault injector ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add more granular locking to forget_locks fault injector ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a list_head arg to nfsd_foreach_client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add nfsd_inject_forget_clients ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a forget_client set_clnt routine ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a forget_clients "get" routine with proper locking ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: abstract out the get and set routines into the fault injection ops ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: protect clid and verifier generation with client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't destroy clients that are busy ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Put the reference of nfs4_file when freeing stid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't destroy client if mark_client_expired_locked fails ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: move unhash_client_locked call into mark_client_expired_locked ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: protect the close_lru list and oo_last_closed_stid with client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add lockdep assertions to document the nfs4_client/session locking ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure lookup_clientid() takes client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect nfsd4_destroy_clientid using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect session creation and client confirm using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect unconfirmed client creation using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Move create_client() call outside the lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Don't require client_lock in free_client ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure that the laundromat unhashes the client before releasing locks ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure struct nfs4_client is unhashed before we try to destroy it ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: fix out of date comment ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Decrease nfsd_users in nfsd_startup_generic fail ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: rename unhash_generic_stateid to unhash_ol_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't thrash the cl_lock while freeing an open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: reduce cl_lock thrashing in release_openowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: close potential race in nfsd4_free_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: optimize destroy_lockowner cl_lock thrashing ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add locking to stateowner release ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up and reorganize release_lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Move the open owner hash table into struct nfs4_client ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect adding/removing lock owners using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect adding/removing open state owners using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't allow CLOSE to proceed until refcount on stateid drops ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: make openstateids hold references to their openowners ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up refcounting for lockowners ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Make lock stateid take a reference to the lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add an operation for unhashing a stateowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up lockowner refcounting when finding them ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add a mutex to protect the NFSv4.0 open owner replay cache ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to state owners ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Migrate the stateid reference into nfs4_find_stateid_by_type() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Migrate the stateid reference into nfs4_lookup_stateid() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Migrate the stateid reference into nfs4_preprocess_seqid_op ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to nfs4_preprocess_confirmed_seqid_op ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_open_confirm() must reference the open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Prepare nfsd4_close() for open stateid referencing ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_process_open2() must reference the open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_process_open2() must reference the delegation stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure that nfs4_open_delegation() references the delegation stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_locku() must reference the lock stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to lock stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: ensure atomicity in nfsd4_free_stateid and nfsd4_validate_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up races in lock stateid searching and creation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add locking to protect the state owner lists ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: do filp_close in sc_free callback for lock stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: use cl_lock to synchronize all stateid idr calls ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add a struct nfs4_file field to struct nfs4_stid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to the lock and open stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: print status when nfsd4_open fails to open file it just created ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc: Allow svc_reserve() to notify TCP socket that space has been freed ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc: svc_tcp_write_space: don't clear SOCK_NOSPACE prematurely ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc: Reduce contention in svc_xprt_enqueue() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove dl_fh field from struct nfs4_delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: give block_delegation and delegation_blocked its own spinlock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up nfs4_set_delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up arguments to nfs4_open_delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: drop unused stp arg to alloc_init_deleg ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Convert delegation counter to an atomic_long_t type ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: ensure that clp->cl_revoked list is protected by clp->cl_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fully unhash delegations when revoking them ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: simplify stateid allocation and file handling ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Do not let nfs4_file pin the struct inode ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfs4_check_fh - make it actually check the filehandle ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Use the filehandle to look up the struct nfs4_file instead of inode ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Store the filehandle with the struct nfs4_file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: convert comma to semicolon ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] svcrdma: Double the default credit limit ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: ensure that st_access_bmap and st_deny_bmap are initialized to 0 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: bump dl_time when unhashing delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Move the delegation reference counter into the struct nfs4_stid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix race that grants unrecallable delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: CREATE_SESSION should update backchannel immediately ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] svcrdma: Select NFSv4.1 backchannel transport based on forward channel ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: zero op arguments beyond the 8th compound op ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: silence sparse warning about accessing credentials ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure stateids remain unique until they are freed ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfs4_alloc_init_lease should take a nfs4_file arg ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Avoid taking state_lock while holding inode lock in nfsd_break_one_deleg ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: eliminate nfsd4_init_callback ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Fix bad checking of space for padding in splice read ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: cleanup and rename nfs4_check_open ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: make deny mode enforcement more efficient and close races in it ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: always hold the fi_lock when bumping fi_access refcounts ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up reset_union_bmap_deny ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: set stateid access and deny bits in nfs4_get_vfs_file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: shrink st_access_bmap and st_deny_bmap ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove nfs4_file_put_fd ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: refactor nfs4_file_get_access and nfs4_file_put_access ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up helper __release_lock_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add locking to the nfs4_file->fi_fds[] array ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add fine grained protection for the nfs4_file->fi_stateids list ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: reduce some spinlocking in put_client_renew ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: close potential race between delegation break and laundromat ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Fix crash encoding lock reply on 32-bit ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Convert nfs4_check_open_reclaim() to work with lookup_clientid() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Always use lookup_clientid() in nfsd4_process_open1 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Convert nfsd4_process_open1() to work with lookup_clientid() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Allow struct nfsd4_compound_state to cache the nfs4_client ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a nfserrno mapping for -E2BIG to nfserr_fbig ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: properly convert return from commit_metadata to __be32 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Cleanup - Let nfsd4_lookup_stateid() take a cstate argument ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Don't get a session reference without a client reference ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up nfsd4_release_lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: NFSv4 lock-owners are not associated to a specific file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Allow lockowners to hold several stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: lock owners are not per open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up nfsd4_close_open_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: declare v4.1+ openowners confirmed on creation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Cleanup nfs4svc_encode_compoundres ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfs4_preprocess_seqid_op should only set *stpp on success ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a new /proc/fs/nfsd/max_connections file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure that nfsd_create_setattr commits files to stable storage ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove iattr parameter from nfsd_symlink() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect addition to the file_hashtbl ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix file access refcount leak when nfsd4_truncate fails ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Avoid warning message when compile at i686 arch ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: replace defer_free by svcxdr_tmpalloc ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: remove nfs4_acl_new ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: define svcxdr_dupstr to share some common code ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: remove unused defer_free argument ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: rename cr_linkname->cr_data ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: let nfsd_symlink assume null-terminated data ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: make NFSv2 null terminate symlink data ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Fix bad reserving space for encoding rdattr_error ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfs: fix nfs4d readlink truncated packet ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix rare symlink decoding bug ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: properly handle embedded newlines in fault_injection input ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix return of nfs4_acl_write_who ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add appropriate __force directives to filehandle generation code ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd_splice_read and nfsd_readv should return __be32 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up sparse endianness warnings in nfscache.c ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add __force to opaque verifier field casts ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Using exp_get for export getting ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Using path_get when assigning path for export ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc/nfsd: Change to type of bool for rq_usedeferral and rq_splice_ok ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Using min/max/min_t/max_t for calculate ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsv4: Fix another bug in the close/open_downgrade code (Steve Dickson) [1111708]
- [fs] nfsv4: nfs4_state_manager() vs. nfs_server_remove_lists() (Steve Dickson) [1111708]
- [fs] nfs: remove BUG possibility in nfs4_open_and_get_state (Steve Dickson) [1111708]
- [fs] pnfs: fix filelayout_retry_commit when idx > 0 (Steve Dickson) [1111708]
- [fs] nfs: revert "nfs4: queue free_lock_state job submission to nfsiod" (Steve Dickson) [1111708]
- [fs] nfs: fix kernel warning when removing proc entry (Steve Dickson) [1111708]
- [fs] nfs: Fix /proc/fs/nfsfs/servers and /proc/fs/nfsfs/volumes (Steve Dickson) [1111708]
- [fs] nfsv3: Fix another acl regression (Steve Dickson) [1111708]
- [fs] nfsv4: Don't clear the open state when we just did an OPEN_DOWNGRADE (Steve Dickson) [1111708]
- [fs] nfsv4: Fix problems with close in the presence of a delegation (Steve Dickson) [1111708]
- [fs] nfs: Don't busy-wait on SIGKILL in __nfs_iocounter_wait (Steve Dickson) [1111708]
- [fs] nfs: can_coalesce_requests must enforce contiguity (Steve Dickson) [1111708]
- [fs] nfs: disallow duplicate pages in pgio page vectors (Steve Dickson) [1111708]
- [fs] nfs: don't sleep with inode lock in lock_and_join_requests (Steve Dickson) [1111708]
- [fs] nfs: fix error handling in lock_and_join_requests (Steve Dickson) [1111708]
- [fs] nfs: fix nonblocking calls to nfs_page_group_lock (Steve Dickson) [1111708]
- [fs] nfs: use blocking page_group_lock in add_request (Steve Dickson) [1111708]
- [fs] nfs: change nfs_page_group_lock argument (Steve Dickson) [1111708]
- [fs] nfs: reject changes to resvport and sharecache during remount (Steve Dickson) [1111708]
- [fs] nfs: Avoid infinite loop when RELEASE_LOCKOWNER getting expired error (Steve Dickson) [1111708]
- [fs] sunrpc: remove all refcounting of groupinfo from rpcauth_lookupcred (Steve Dickson) [1111708]
- [fs] nfs: fix two problems in lookup_revalidate in RCU-walk (Steve Dickson) [1111708]
- [fs] nfs: allow lockless access to access_cache (Steve Dickson) [1111708]
- [fs] nfs: teach nfs_lookup_verify_inode to handle LOOKUP_RCU (Steve Dickson) [1111708]
- [fs] nfs: teach nfs_neg_need_reval to understand LOOKUP_RCU (Steve Dickson) [1111708]
- [fs] nfs: support RCU_WALK in nfs_permission() (Steve Dickson) [1111708]
- [fs] sunrpc/auth: allow lockless (rcu) lookup of credential cache (Steve Dickson) [1111708]
- [fs] nfs: prepare for RCU-walk support but pushing tests later in code (Steve Dickson) [1111708]
- [fs] nfs: nfs4_lookup_revalidate: only evaluate parent if it will be used (Steve Dickson) [1111708]
- [fs] nfs: add checks for returned value of try_module_get() (Steve Dickson) [1111708]
- [fs] nfs: clear_request_commit while holding i_lock (Steve Dickson) [1111708]
- [fs] pnfs: add pnfs_put_lseg_async (Steve Dickson) [1111708]
- [fs] pnfs: find swapped pages on pnfs commit lists too (Steve Dickson) [1111708]
- [fs] nfs: fix comment and add warn_on for PG_INODE_REF (Steve Dickson) [1111708]
- [fs] nfs: mark nfs_page reqs with flag for extra ref (Steve Dickson) [1111708]
- [fs] nfs: check wait_on_bit_lock err in page_group_lock (Steve Dickson) [1111708]
- [fs] nfs: handle multiple reqs in nfs_page_async_flush (Steve Dickson) [1111708]
- [fs] nfs: change find_request to find_head_request (Steve Dickson) [1111708]
- [fs] sunrpc: remove "ec" argument from encrypt_v2 operation (Steve Dickson) [1111708]
- [fs] sunrpc: clean up sparse endianness warnings in gss_krb5_wrap.c (Steve Dickson) [1111708]
- [fs] sunrpc: clean up sparse endianness warnings in gss_krb5_seal.c (Steve Dickson) [1111708]
- [fs] sunrpc: fix RCU handling of gc_ctx field (Steve Dickson) [1111708]
- [fs] sunrpc: remove __rcu annotation from struct gss_cl_ctx->gc_gss_ctx (Steve Dickson) [1111708]
- [fs] nfs: nfs4_do_open should add negative results to the dcache (Steve Dickson) [1111708]
- [fs] xprtrdma: Handle additional connection events (Steve Dickson) [1111708]
- [fs] xprtrdma: Remove RPCRDMA_PERSISTENT_REGISTRATION macro (Steve Dickson) [1111708]
- [fs] xprtrdma: Make rpcrdma_ep_disconnect() return void (Steve Dickson) [1111708]
- [fs] xprtrdma: Schedule reply tasklet once per upcall (Steve Dickson) [1111708]
- [fs] xprtrdma: Allocate each struct rpcrdma_mw separately (Steve Dickson) [1111708]
- [fs] xprtrdma: Rename frmr_wr (Steve Dickson) [1111708]
- [fs] xprtrdma: Disable completions for LOCAL_INV Work Requests (Steve Dickson) [1111708]
- [fs] xprtrdma: Disable completions for FAST_REG_MR Work Requests (Steve Dickson) [1111708]
- [fs] xprtrdma: Don't post a LOCAL_INV in rpcrdma_register_frmr_external() (Steve Dickson) [1111708]
- [fs] xprtrdma: Reset FRMRs after a flushed LOCAL_INV Work Request (Steve Dickson) [1111708]
- [fs] xprtrdma: Reset FRMRs when FAST_REG_MR is flushed by a disconnect (Steve Dickson) [1111708]
- [fs] xprtrdma: Properly handle exhaustion of the rb_mws list (Steve Dickson) [1111708]
- [fs] xprtrdma: Chain together all MWs in same buffer pool (Steve Dickson) [1111708]
- [fs] xprtrdma: Back off rkey when FAST_REG_MR fails (Steve Dickson) [1111708]
- [fs] xprtrdma: Unclutter struct rpcrdma_mr_seg (Steve Dickson) [1111708]
- [fs] xprtrdma: Don't invalidate FRMRs if registration fails (Steve Dickson) [1111708]
- [fs] xprtrdma: On disconnect, don't ignore pending CQEs (Steve Dickson) [1111708]
- [fs] xprtrdma: Update rkeys after transport reconnect (Steve Dickson) [1111708]
- [fs] xprtrdma: Limit data payload size for ALLPHYSICAL (Steve Dickson) [1111708]
- [fs] xprtrdma: Protect ia->ri_id when unmapping/invalidating MRs (Steve Dickson) [1111708]
- [fs] xprtrdma: Fix panic in rpcrdma_register_frmr_external() (Steve Dickson) [1111708]
- [fs] xprtrdma: Fix DMA-API-DEBUG warning by checking dma_map result (Steve Dickson) [1111708]
- [fs] replace strict_strto calls (Steve Dickson) [1111708]
- [fs] nfs: use ARRAY_SIZE instead of sizeof/sizeof[0] (Steve Dickson) [1111708]
- [fs] nfsv4: Drop cast (Steve Dickson) [1111708]
- [fs] rpc_pipe: Drop memory allocation cast (Steve Dickson) [1111708]
- [fs] nfs_common/nfsacl: move EXPORT symbol after functions (Steve Dickson) [1111708]
- [fs] nfs4: copy acceptor name from context to nfs_client (Steve Dickson) [1111708]
- [fs] sunrpc: add a new "stringify_acceptor" rpc_credop (Steve Dickson) [1111708]
- [fs] auth_gss: fetch the acceptor name out of the downcall (Steve Dickson) [1111708]
- [fs] nfs4: turn free_lock_state into a void return operation (Steve Dickson) [1111708]
- [fs] nfs4: queue free_lock_state job submission to nfsiod (Steve Dickson) [1111708]
- [fs] nfs4: treat lock owners as opaque values (Steve Dickson) [1111708]
- [fs] nfs41: layout return on close in delegation return (Steve Dickson) [1111708]
- [fs] nfs41: return layout on last close (Steve Dickson) [1111708]
- [fs] nfs4: add nfs4_check_delegation (Steve Dickson) [1111708]
- [fs] pnfs/filelayout: retry ds commit if nfs_commitdata_alloc fails (Steve Dickson) [1111708]
- [fs] pnfs/filelayout: fix race between mark_request_commit and scan_commit_lists (Steve Dickson) [1111708]
- [fs] nfsv4: Fix OPEN w/create access mode checking (Steve Dickson) [1111708]
- [fs] nfs: check hostname in nfs_get_client (Steve Dickson) [1111708]
- [fs] nfsv4: set hostname when creating nfsv4 ds connection (Steve Dickson) [1111708]
- [fs] sunrpc: Handle EPIPE in xprt_connect_status (Steve Dickson) [1111708]
- [fs] sunrpc: Ensure that we handle ENOBUFS errors correctly (Steve Dickson) [1111708]
- [fs] nfs: replace count*size kzalloc by kcalloc (Steve Dickson) [1111708]
- [fs] nfs: get rid of duplicate dprintk (Steve Dickson) [1111708]
- [fs] nfs: Fix unused variable error (Steve Dickson) [1111708]
- [fs] nfs: remove unneeded EXPORTs (Steve Dickson) [1111708]
- [fs] pnfs: clean up *_resend_to_mds (Steve Dickson) [1111708]
- [fs] nfs: remove pgio_header refcount, related cleanup (Steve Dickson) [1111708]
- [fs] nfs: remove unused writeverf code (Steve Dickson) [1111708]
- [fs] nfs: merge nfs_pgio_data into _header (Steve Dickson) [1111708]
- [fs] nfs: rename members of nfs_pgio_data (Steve Dickson) [1111708]
- [fs] nfs: move nfs_pgio_data and remove nfs_rw_header (Steve Dickson) [1111708]

* Fri Sep 26 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-171.el7]
- [scsi] bnx2fc: Improve stats update mechanism (Neil Horman) [1096023]
- [security] have cap_dentry_init_security return error (Jeff Layton) [1070910]
- [mfd] lpc_ich: Change Avoton to iTCO v3 (Prarit Bhargava) [1084134]
- [watchdog] itco_wdt: Add support for v3 silicon (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Add support for iTCO v3 (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Remove lpc_ich_cfg struct use (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Fix ACPI enable bitmask (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Only configure watchdog or GPIO when present (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Add support for Intel Avoton GPIOs (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Convert ICH GPIOs IDs to enum (Prarit Bhargava) [1084134]
- [net] ceph: do not hard code max auth ticket len (Ilya Dryomov) [1142285] {CVE-2014-6416}
- [net] ceph: add process_one_ticket() helper (Ilya Dryomov) [1142285] {CVE-2014-6416}
- [net] ceph: gracefully handle large reply messages from the mon (Ilya Dryomov) [1142285] {CVE-2014-6416}
- [powercap] intel_rapl: add new CPU IDs (Steve Best) [1142597]
- [powercap] intel_rapl: spell out SoC names (Steve Best) [1142597]
- [powercap] intel_rapl: add support for ValleyView Soc (Steve Best) [1142597]
- [x86] smpboot: initialize secondary CPU only if master CPU will wait for it (Igor Mammedov) [968147]
- [x86] smpboot: Log error on secondary CPU wakeup failure at ERR level (Igor Mammedov) [968147]
- [x86] smpboot: Fix list/memory corruption on CPU hotplug (Igor Mammedov) [968147]
- [acpi] processor: do not mark present at boot but not onlined CPU as onlined (Igor Mammedov) [968147]
- [tools] thermal: Introduce tmon, a tool for thermal subsystem (Neil Horman) [1085101]
- [thermal] intel_powerclamp: add newer cpu ids (Steve Best) [1141895]
- [mm] swapfile: do not skip lowest_bit in scan_swap_map() scan loop (Seth Jennings) [1128277]
- [dma] ioatdma: disable RAID on non-Atom platforms and reenable unaligned copies (Prarit Bhargava) [1069441]
- [security] selinux: make the netif cache namespace aware (Paul Moore) [1112815]
- [kernel] sched: Fix clock_gettime(CLOCK_[PROCESS/THREAD]_CPUTIME_ID) monotonicity (Seth Jennings) [1113932]
- [kernel] hashtable: add hash_for_each_possible_rcu_notrace() (Steve Best) [1123126]
- [media] media-device: fix an information leakage (Jacob Tanenbaum) [1109777] {CVE-2014-1739}
- [fs] vfs: fix ref count leak in path_mountpoint() (Ian Kent) [1122376] {CVE-2014-5045}
- [kernel] ptrace: get_dumpable() incorrect tests (Jacob Tanenbaum) [1111606] {CVE-2013-2929}
- [fs] fanotify/compat: fix sys_fanotify_mark (Jan Stancek) [1119318]
- [target] rd: Refactor rd_build_device_space + rd_release_device_space (Denys Vlasenko) [1108755] {CVE-2014-4027}
- [ipc] fix compat msgrcv with negative msgtyp (Mateusz Guzik) [1042807]
- [Documentation] fix incorrect formula to calculate CommitLimit value (Petr Oros) [1060570]
- [acpi] apci_pad: in power_saving_thread(), call schedule() when need_resched is true (Tony Camuso) [1092076]

* Wed Sep 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-170.el7]
- [powerpc] Revert: Add iommu domain pointer to device archdata (David Gibson) [1123145 1123133 1123367]
- [powerpc] Enable IOMMU and VFIO for ppc64 (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s_32/pr - Access HTAB in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Rework SLB switching code (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Move little endian conflict to HV KVM (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Do dcbz32 patching with big endian instructions (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fill pvinfo hcall instructions in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - PAPR - Access RTAS in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - PAPR - Access HTAB in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s_64/pr - Access shadow slb in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s_64/pr - Access HTAB in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - ifdef on CONFIG_KVM_book3s_32_HANDLER for 32bit (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Disable AIL mode with OPAL (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Use SLB entry 0 (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Graciously fail broken LE hypercalls (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Remove open coded make_dsisr in alignment handler (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Always use the saved DAR value (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Make NX bit available with magic page (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Disable NX for old magic page using guests (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Expose TM registers (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Expose EBB registers (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Expose TAR facility to guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Handle Facility interrupt and FSCR (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Emulate TIR register (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Ignore PMU SPRs (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Default to big endian guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fix C/R bit setting (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fix WARN_ON with debug options on (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Enable Little Endian PR guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Enable interrupts earlier (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Make svcpu -> vcpu store preempt savvy (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Ignore DABR register (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Ignore PIR writes (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: add PR mode KVM (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Move more code under CONFIG_HAVE_KVM_IRQFD (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Enable IRQFD support for the XICS interrupt controller (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/s390: adapter interrupt sources (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Move irq notifier implementation into eventfd.c (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Move all accesses to kvm::irq_routing into irqchip.c (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/irqchip: Provide and use accessors for irq routing table (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Don't keep reference to irq routing table in irqfd struct (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: IRQ disabling cleanup (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: use fdget (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Put huge-page HPTEs in rmap chain for base address (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Move KVM_REG_PPC_WORT to an unused register number (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Add ONE_REG register names that were missed (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add missing code for transaction reclaim on guest exit (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - make _PAGE_NUMA take effect (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc/book3s: rename lookup_linux_pte() to lookup_linux_pte_and_update() (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix KVM hang with CONFIG_KVM_XICS=n (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix incorrect userspace exit on ioeventfd write (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Remove bogus duplicate code (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - use xics_wake_cpu only when defined (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: NULL return of kvmppc_mmu_hpte_cache_next should be handled (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Add devname:kvm aliases for modules (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Don't drop low-order page address bits (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Get rid of KVM_HPAGE defines (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Guard doorbell exception with CONFIG_PPC_DOORBELL (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Make shared struct aka magic page guest endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Use base page size when comparing against slb value (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix machine check delivery to guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add mixed page-size support for guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: fix couple of memory leaks in MPIC/XICS devices (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Don't clobber our exit handler id (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix physical address calculations (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Take SRCU read lock around RTAS kvm_read_guest() call (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add H_SET_MODE hcall handling (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Allow only implemented hcalls to be enabled or disabled (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Controls for in-kernel sPAPR hypercall handling (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Move vcore definition to end of kvm_arch struct (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Export kvmppc_copy_to (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Add CAP to indicate hcall fixes (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Prefer CMA region for hash page table allocation (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add software abort codes for transactional memory (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Unify kvmppc_get_last_inst and sc (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Load/save FP/VMX/VSX state directly to/from vcpu struct (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fix compilation without CONFIG_ALTIVEC (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Add per-vm capability enablement (David Gibson) [1123145 1123133 1123367]
- [iommu] vt-d: Exclude devices using RMRRs from IOMMU API domains (Myron Stowe) [1097907]
- [s390] uaccess: fix possible register corruption in strnlen_user_srst() (Hendrik Brueckner) [1099147]
- [s390] uaccess: rework uaccess code - fix locking issues (Hendrik Brueckner) [1099147]
- [s390] uaccess: introduce 'uaccesspt' kernel parameter (Hendrik Brueckner) [1099147]
- [s390] uaccess: remove dead kernel parameter 'user_mode=' (Hendrik Brueckner) [1099147]
- [s390] setup: get rid of MACHINE_HAS_MVCOS machine flag (Hendrik Brueckner) [1099147]
- [s390] uaccess: consistent types (Hendrik Brueckner) [1099147]
- [s390] uaccess: get rid of indirect function calls (Hendrik Brueckner) [1099147]
- [s390] uaccess: normalize order of parameters of indirect uaccess function calls (Hendrik Brueckner) [1099147]
- [s390] uaccess: remove dead extern declarations, make functions static (Hendrik Brueckner) [1099147]
- [s390] uaccess: test if current->mm is set before walking page tables (Hendrik Brueckner) [1099147]
- [s390] compat: fix PSW32_USER_BITS definition (Hendrik Brueckner) [1099147]
- [s390] compat: make psw32_user_bits a constant value again (Hendrik Brueckner) [1099147]
- [s390] uaccess: always run the kernel in home space (Hendrik Brueckner) [1099147]
- [s390] kernel: remove page table walk for user space accesses (Hendrik Brueckner) [1099147]
- [powerpc] start loop at section start of start in vmemmap_populated() (Gustavo Duarte) [1090174]
- [powerpc] implement vmemmap_free() (Gustavo Duarte) [1090174]
- [powerpc] implement vmemmap_remove_mapping() for BOOK3S (Gustavo Duarte) [1090174]
- [powerpc] implement vmemmap_list_free() (Gustavo Duarte) [1090174]
- [x86] Makefile: Add stack frame check (Prarit Bhargava) [1058753]
- [virt] kvm/x86: fix TSC matching (Marcelo Tosatti) [1115764]
- [drm] radeon: tweak ACCEL_WORKING2 query for hawaii (Jerome Glisse) [1140789]

* Tue Sep 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-169.el7]
- [lib] assoc_array: Fix termination condition in assoc array garbage collection (David Howells) [1139431] {CVE-2014-3631}
- [acpi] x86/ras: Fix build warnings in <linux/aer.h> (Rui Wang) [1085141]
- [acpi] ras/extlog: Adjust init flow (Rui Wang) [1085141]
- [acpi] trace/emca: Add a knob to adjust where to save event log (Rui Wang) [1085141]
- [ras] trace: Add eMCA trace event interface (Rui Wang) [1085141]
- [ras] debugfs: Add debugfs interface for RAS subsystem (Rui Wang) [1085141]
- [firmware] efi/cper: Adjust code flow of some functions (Rui Wang) [1085141]
- [trace] aer: Move trace into unified interface (Rui Wang) [1085141]
- [trace] ras: Add basic RAS trace event (Rui Wang) [1085141]
- [trace] Add __field_struct macro for TRACE_EVENT() (Rui Wang) [1085141]
- [trace] pci/aer: Fix severity usage in aer trace event (Rui Wang) [1085141]
- [acpi] emca: Combine eMCA/EDAC event reporting priority (Rui Wang) [1076655]
- [edac] sb_edac: Modify H/W event reporting policy (Rui Wang) [1076655]
- [edac] Add an edac_report parameter to EDAC (Rui Wang) [1076655]
- [acpi] Clean up inclusions of ACPI header files (Rui Wang) [1076655]
- [acpi] x86: Export 'boot_cpu_physical_apicid' to modules (Rui Wang) [1076655]
- [acpi] x86: Fix extended error log driver to depend on CONFIG_X86_LOCAL_APIC (Rui Wang) [1076655]
- [firmware] dmi: Avoid unaligned memory access in save_mem_devices() (Rui Wang) [1076655]
- [firmware] efi: Move cper.c from drivers/acpi/apei to drivers/firmware/efi (Rui Wang) [1076655]
- [edac] ghes: Update ghes error record info (Rui Wang) [1076655]
- [acpi] apei/cper: Cleanup CPER memory error output format (Rui Wang) [1076655]
- [acpi] apei/cper: Enhance memory reporting capability (Rui Wang) [1076655]
- [firmware] dmi: Parse memory device (type 17) in SMBIOS (Rui Wang) [1076655]
- [acpi] x86: Extended error log driver for x86 platform (Rui Wang) [1076655]
- [acpi] cper: Update cper info (Rui Wang) [1076655]
- [acpi] apei/cper: Fix status check during error printing (Rui Wang) [1076655]

* Tue Sep 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-168.el7]
- [ethernet] bnx2x: Configure device endianity on driver load and reset endianity on removal (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Be more forgiving toward SW GRO (Michal Schmidt) [1089402]
- [ethernet] bnx2x: VF clean statistics (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix stop-on-error (Michal Schmidt) [1089402]
- [ethernet] bnx2x: ethtool -d might cause timeout in log (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Use is_kdump_kernel() to detect kdump kernel (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: FW assertion changes (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Make BP_VF more robust (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Prevent pci_disable_sriov with assigned VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Prevent IOV if no entries in CAM (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix static checker warning regarding `txdata_ptr' (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Safe bnx2x_panic_dump() (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Update driver version to 1.710.51 (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Code cleanup (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix sparse warnings (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: Fix timesync endianity (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Add timestamping and PTP hardware clock support (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix tunneled GSO over IPv6 (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: prevent incorrect byte-swap in BE (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: Utilize FW 7.10.51 (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: Remove redundant #ifdef (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Revert UNDI flushing mechanism (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove DEFINE_PCI_DEVICE_TABLE macro use (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix set_setting for some PHYs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix possible panic under memory stress (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix the MSI flags (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fail probe of VFs using an old incompatible driver (Michal Schmidt) [1089402]
- [ethernet] bnx2x: enlarge minimal alignemnt of data offset (Michal Schmidt) [1089402]
- [ethernet] bnx2x: VF can report link speed (Michal Schmidt) [1089402]
- [ethernet] bnx2x: remove null test before kfree (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Enlarge the dorq threshold for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Check for UNDI in uncommon branch (Michal Schmidt) [1094099 1089402]
- [ethernet] bnx2x: Fix 1G-baseT link (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix link for KR with swapped polarity lane (Michal Schmidt) [1123867 1089402]
- [ethernet] bnx2x: Remove useless return variables (Michal Schmidt) [1089402]
- [ethernet] bnx2x: update MAINTAINERS for bnx2x and e-mail addresses (Michal Schmidt) [1089402]
- [ethernet] bnx2x: get rid of SET_ETHTOOL_OPS (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix build when BNX2X_SRIOV is not enabled (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Convert return 0 to return rc (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix UNDI driver unload (Michal Schmidt) [1094099 1089402]
- [ethernet] bnx2x: Memory leak during VF removal (Michal Schmidt) [1089402]
- [ethernet] bnx2x: include irq.h for irqreturn_t definitions (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix possible memory leak on iov error flow (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix compilation when CONFIG_BNX2X_SRIOV is not set (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Don't allow VFs to become promiscuous (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Don't show port statistics for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix failure to configure VF multicast filters (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix vlan credit issues for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove the sriov VFOP mechanism (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Create workqueue for IOV related tasks (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Support mng. request for driver version (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Don't receive packets when the napi budget == 0 (Michal Schmidt) [1089402]
- [ethernet] bnx2x: save RAM in kdump kernel by disabling TPA (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: save RAM in kdump kernel by using a single queue (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: clamp num_queues to prevent passing a negative value (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: Remove hidden flow control goto from BNX2X_ALLOC macros (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Use pci_enable_msix_range() instead of pci_enable_msix() (Michal Schmidt) [1089402]
- [ethernet] bnx2x: (semantic) revise scheduling of sp_rtnl (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix bnx2x_panic_dump for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Revise IOV vlan/mac validation (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Add support in PF driver for RSC (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Semantic Validate vlan/mac changes (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove unnecessary internal mem config (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove unused iov code (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Debug - change verbosity of some prints (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix L2-GRE TCP issues (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix sparse warning (Michal Schmidt) [1089402]
- [ethernet] bnx2x: prevent WARN during driver unload (Michal Schmidt) [1089402]
- [ethernet] bnx2x: slight optimization of addr compare (Michal Schmidt) [1089402]
- [kernel] crash_dump: Make is_kdump_kernel() accessible from modules (Michal Schmidt) [1089402 1059554]
- [ethernet] qlge: Fix TSO for non-accelerated vlan traffic (Vlad Yasevich) [1135619]
- [ethernet] mvneta: Fix TSO and checksum for non-acceleration vlan traffic (Vlad Yasevich) [1135619]
- [ethernet] i40evf: Fix TSO and hw checksums for non-accelerated vlan packets (Vlad Yasevich) [1135619]
- [ethernet] i40e: Fix TSO and hw checksums for non-accelerated vlan packets (Vlad Yasevich) [1135619]
- [ethernet] ehea: Fix TSO and hw checksums with non-accelerated vlan packets (Vlad Yasevich) [1135619]
- [ethernet] e1000: Fix TSO for non-accelerated vlan traffic (Vlad Yasevich) [1135619]
- [ethernet] e1000e: Fix TSO with non-accelerated vlans (Vlad Yasevich) [1135619]
- [net] macvlan: Initialize vlan_features to turn on offload support (Vlad Yasevich) [1135619]
- [net] macvtap: Fix checksum errors for non-gso packets in bridge mode (Vlad Yasevich) [1135619]
- [net] Revert: macvlan: fix checksums error when we are in bridge mode (Vlad Yasevich) [1135619]
- [net] Correctly set segment mac_len in skb_segment() (Vlad Yasevich) [1135619]
- [crypto] pkcs7: Fix the parser cleanup to drain parsed out X.509 certs (Vivek Goyal) [1129779]
- [crypto] pkcs7: Provide a single place to do signed info block freeing (Vivek Goyal) [1129779]
- [security] keys: Reinstate EPERM for a key type name beginning with a '.' (Vivek Goyal) [1129779]
- [crypto] pkcs7: Add a missing static (Vivek Goyal) [1129779]
- [crypto] x509: Need to export x509_request_asymmetric_key() (Vivek Goyal) [1129779]
- [crypto] pkcs7: X.509 certificate issuer and subject are mandatory fields in the ASN.1 (Vivek Goyal) [1129779]
- [crypto] pkcs7: Use x509_request_asymmetric_key() (Vivek Goyal) [1129779]
- [crypto] x509: x509_request_asymmetric_keys() doesn't need string length arguments (Vivek Goyal) [1129779]
- [crypto] pkcs7: fix sparse non static symbol warning (Vivek Goyal) [1129779]
- [crypto] pkcs7: Missing inclusion of linux/err.h (Vivek Goyal) [1129779]
- [security] ima: define '.ima' as a builtin 'trusted' keyring (Vivek Goyal) [1129779]
- [crypto] keys: validate certificate trust only with builtin keys (Vivek Goyal) [1129779]
- [crypto] keys: validate certificate trust only with selected key (Vivek Goyal) [1129779]
- [crypto] keys: make partial key id matching as a dedicated function (Vivek Goyal) [1129779]
- [crypto] keys: verify a certificate is signed by a 'trusted' key (Vivek Goyal) [1129779]
- [security] keys: special dot prefixed keyring name bug fix (Vivek Goyal) [1129779]
- [crypto] Revert: keys: verify a certificate is signed by a 'trusted' key (Vivek Goyal) [1129779]
- [crypto] pefile: Validate PKCS#7 trust chain (Vivek Goyal) [1129779]
- [crypto] pefile: Digest the PE binary and compare to the PKCS#7 data (Vivek Goyal) [1129779]
- [crypto] pefile: Handle pesign using the wrong OID (Vivek Goyal) [1129779]
- [crypto] pefile: Parse the "Microsoft individual code signing" data blob (Vivek Goyal) [1129779]
- [crypto] pefile: Parse the presumed PKCS#7 content of the certificate blob (Vivek Goyal) [1129779]
- [crypto] pefile: Strip the wrapper off of the cert data block (Vivek Goyal) [1129779]
- [crypto] pefile: Parse a PE binary to find a key and a signature contained therein (Vivek Goyal) [1129779]
- [misc] Provide PE binary definitions (Vivek Goyal) [1129779]
- [crypto] keys/x509: Fix a spelling mistake (Vivek Goyal) [1129779]
- [crypto] pkcs7: Provide a key type for testing PKCS#7 (Vivek Goyal) [1129779]
- [crypto] pkcs7: Find intersection between PKCS#7 message and known, trusted keys (Vivek Goyal) [1129779]
- [crypto] pkcs7: Verify internal certificate chain (Vivek Goyal) [1129779]
- [crypto] pkcs7: Find the right key in the PKCS#7 key list and verify the signature (Vivek Goyal) [1129779]
- [crypto] pkcs7: Digest the data in a signed-data message (Vivek Goyal) [1129779]
- [crypto] pkcs7: Implement a parser for RFC 2315 (Vivek Goyal) [1129779]
- [crypto] x509: Export certificate parse and free functions (Vivek Goyal) [1129779]
- [crypto] x509: Add bits needed for PKCS#7 (Vivek Goyal) [1129779]
- [crypto] keys: change asymmetric keys to use common hash definitions (Vivek Goyal) [1129779]
- [crypto] provide single place for hash algo information (Vivek Goyal) [1129779]

* Sun Sep 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-167.el7]
- [fs] ceph: remove extra definitions of U32_MAX (Sage Weil) [1122174]
- [fs] vfs: call d_op->d_prune() before unhashing dentry (Sage Weil) [1122174]
- [net] libceph: set last_piece in ceph_msg_data_pages_cursor_init() correctly (Sage Weil) [1122174]
- [block] rbd: remove extra newlines from rbd_warn() messages (Sage Weil) [1122174]
- [block] rbd: allocate img_request with GFP_NOIO instead GFP_ATOMIC (Sage Weil) [1122174]
- [block] rbd: rework rbd_request_fn() (Sage Weil) [1122174]
- [fs] ceph: fix kick_requests() (Sage Weil) [1122174]
- [fs] ceph: fix sizeof(struct tYpO *) typo (Sage Weil) [1122174]
- [fs] ceph: remove redundant memset(0) (Sage Weil) [1122174]
- [block] rbd: take snap_id into account when reading in parent info (Sage Weil) [1122174]
- [block] rbd: do not read in parent info before snap context (Sage Weil) [1122174]
- [block] rbd: update mapping size only on refresh (Sage Weil) [1122174]
- [block] rbd: harden rbd_dev_refresh() and callers a bit (Sage Weil) [1122174]
- [block] rbd: split rbd_dev_spec_update() into two functions (Sage Weil) [1122174]
- [block] rbd: remove unnecessary asserts in rbd_dev_image_probe() (Sage Weil) [1122174]
- [block] rbd: introduce rbd_dev_header_info() (Sage Weil) [1122174]
- [block] rbd: show the entire chain of parent images (Sage Weil) [1122174]
- [fs] ceph: replace comma with a semicolon (Sage Weil) [1122174]
- [block] rbd: use rbd_segment_name_free() instead of kfree() (Sage Weil) [1122174]
- [fs] ceph: check zero length in ceph_sync_read() (Sage Weil) [1122174]
- [fs] ceph: reset r_resend_mds after receiving -ESTALE (Sage Weil) [1122174]
- [fs] ceph: include time stamp in replayed MDS requests (Sage Weil) [1122174]
- [block] rbd: do not leak image_id in rbd_dev_v2_parent_info() (Sage Weil) [1122174]
- [fs] ceph: check unsupported fallocate mode (Sage Weil) [1122174]
- [net] libceph: drop osd ref when canceling con work (Sage Weil) [1122174]
- [net] libceph: nuke ceph_osdc_unregister_linger_request() (Sage Weil) [1122174]
- [block] rbd: use rbd_obj_watch_request_helper() helper (Sage Weil) [1122174]
- [block] rbd: add rbd_obj_watch_request_helper() helper (Sage Weil) [1122174]
- [block] rbd: rbd_obj_request_wait() should cancel the request if interrupted (Sage Weil) [1122174]
- [net] libceph: introduce ceph_osdc_cancel_request() (Sage Weil) [1122174]
- [net] libceph: fix linger request check in __unregister_request() (Sage Weil) [1122174]
- [net] libceph: unregister only registered linger requests (Sage Weil) [1122174]
- [net] libceph: assert both regular and lingering lists in __remove_osd() (Sage Weil) [1122174]
- [net] libceph: harden ceph_osdc_request_release() a bit (Sage Weil) [1122174]
- [net] libceph: move and add dout()s to ceph_osdc_request_{get, put}() (Sage Weil) [1122174]
- [net] libceph: move and add dout()s to ceph_msg_{get, put}() (Sage Weil) [1122174]
- [net] libceph: add maybe_move_osd_to_lru() and switch to it (Sage Weil) [1122174]
- [net] libceph: rename ceph_osd_request::r_linger_osd to r_linger_osd_item (Sage Weil) [1122174]
- [block] rbd: handle parent_overlap on writes correctly (Sage Weil) [1122174]
- [fs] ceph: remove bogus extern (Sage Weil) [1122174]
- [block] rbd: only set disk to read-only once (Sage Weil) [1122174]
- [block] rbd: move calls that may sleep out of spin lock range (Sage Weil) [1122174]
- [block] rbd: add ioctl for rbd (Sage Weil) [1122174]
- [fs] ceph: use truncate_pagecache() instead of truncate_inode_pages() (Sage Weil) [1122174]
- [fs] ceph: debugfs, replace seq_printf by seq_puts (Sage Weil) [1122174]
- [fs] ceph: replace pr_warning by pr_warn (Sage Weil) [1122174]
- [fs] ceph: include time stamp in every MDS request (Sage Weil) [1122174]
- [block] rbd: fix ida/idr memory leak (Sage Weil) [1122174]
- [block] rbd: use reference counts for image requests (Sage Weil) [1122174]
- [block] rbd: fix osd_request memory leak in __rbd_dev_header_watch_sync() (Sage Weil) [1122174]
- [block] rbd: make sure we have latest osdmap on 'rbd map' (Sage Weil) [1122174]
- [net] libceph: add ceph_monc_wait_osdmap() (Sage Weil) [1122174]
- [net] libceph: mon_get_version request infrastructure (Sage Weil) [1122174]
- [net] libceph: recognize poolop requests in debugfs (Sage Weil) [1122174]
- [fs] ceph: refactor readpage_nounlock() to make the logic clearer (Sage Weil) [1122174]
- [fs] ceph: mds - check cap ID when handling cap export message (Sage Weil) [1122174]
- [fs] ceph: remember subtree root dirfrag's auth MDS (Sage Weil) [1122174]
- [fs] ceph: introduce ceph_fill_fragtree() (Sage Weil) [1122174]
- [fs] ceph: handle cap import atomically (Sage Weil) [1122174]
- [fs] ceph: pre-allocate ceph_cap struct for ceph_add_cap() (Sage Weil) [1122174]
- [fs] ceph: update inode fields according to issued caps (Sage Weil) [1122174]
- [fs] ceph: queue vmtruncate if necessary when handing cap grant/revoke (Sage Weil) [1122174]
- [fs] ceph: ceph_get_parent() can be static (Sage Weil) [1122174]
- [net] crush: decode and initialize chooseleaf_vary_r (Sage Weil) [1122174]
- [net] libceph: fix corruption when using page_count 0 page in rbd (Sage Weil) [1122174]
- [fs] ceph: reserve caps for file layout/lock MDS requests (Sage Weil) [1122174]
- [fs] ceph: avoid releasing caps that are being used (Sage Weil) [1122174]
- [fs] ceph: clear directory's completeness when creating file (Sage Weil) [1122174]
- [net] libceph: fix non-default values check in apply_primary_affinity() (Sage Weil) [1122174]
- [fs] ceph: use fpos_cmp() to compare dentry positions (Sage Weil) [1122174]
- [fs] ceph: check directory's completeness before emitting directory entry (Sage Weil) [1122174]
- [fs] ceph: fix pr_fmt() redefinition (Sage Weil) [1122174]
- [fs] ceph: ceph_sync_{, direct_}write, fix an oops on ceph_osdc_new_request() failure (Sage Weil) [1122174]
- [fs] ceph: skip invalid dentry during dcache readdir (Sage Weil) [1122174]
- [net] libceph: dump pool {read,write}_tier to debugfs (Sage Weil) [1122174]
- [net] libceph: output primary affinity values on osdmap updates (Sage Weil) [1122174]
- [fs] ceph: flush cap release queue when trimming session caps (Sage Weil) [1122174]
- [fs] ceph: don't grabs open file reference for aborted request (Sage Weil) [1122174]
- [fs] ceph: drop extra open file reference in ceph_atomic_open() (Sage Weil) [1122174]
- [fs] ceph: preallocate buffer for readdir reply (Sage Weil) [1122174]
- [net] libceph: enable PRIMARY_AFFINITY feature bit (Sage Weil) [1122174]
- [net] libceph: redo ceph_calc_pg_primary() in terms of ceph_calc_pg_acting() (Sage Weil) [1122174]
- [net] libceph: add support for osd primary affinity (Sage Weil) [1122174]
- [net] libceph: add support for primary_temp mappings (Sage Weil) [1122174]
- [net] libceph: return primary from ceph_calc_pg_acting() (Sage Weil) [1122174]
- [net] libceph: switch ceph_calc_pg_acting() to new helpers (Sage Weil) [1122174]
- [net] libceph: introduce apply_temps() helper (Sage Weil) [1122174]
- [net] libceph: introduce pg_to_raw_osds() and raw_to_up_osds() helpers (Sage Weil) [1122174]
- [net] libceph: ceph_can_shift_osds(pool) and pool type defines (Sage Weil) [1122174]
- [net] libceph: ceph_osd_{exists, is_up, is_down}(osd) definitions (Sage Weil) [1122174]
- [net] libceph: enable OSDMAP_ENC feature bit (Sage Weil) [1122174]
- [net] libceph: primary_affinity decode bits (Sage Weil) [1122174]
- [net] libceph: primary_affinity infrastructure (Sage Weil) [1122174]
- [net] libceph: primary_temp decode bits (Sage Weil) [1122174]
- [net] libceph: primary_temp infrastructure (Sage Weil) [1122174]
- [net] libceph: generalize ceph_pg_mapping (Sage Weil) [1122174]
- [net] libceph: introduce get_osdmap_client_data_v() (Sage Weil) [1122174]
- [net] libceph: introduce decode{, _new}_pg_temp() and switch to them (Sage Weil) [1122174]
- [net] libceph: switch osdmap_set_max_osd() to krealloc() (Sage Weil) [1122174]
- [net] libceph: introduce decode{, _new}_pools() and switch to them (Sage Weil) [1122174]
- [net] libceph: rename __decode_pool{, _names}() to decode_pool{, _names}() (Sage Weil) [1122174]
- [net] libceph: fix and clarify ceph_decode_need() sizes (Sage Weil) [1122174]
- [net] libceph: nuke bogus encoding version check in osdmap_apply_incremental() (Sage Weil) [1122174]
- [net] libceph: fixup error handling in osdmap_apply_incremental() (Sage Weil) [1122174]
- [net] libceph: fix crush_decode() call site in osdmap_decode() (Sage Weil) [1122174]
- [net] libceph: check length of osdmap osd arrays (Sage Weil) [1122174]
- [net] libceph: safely decode max_osd value in osdmap_decode() (Sage Weil) [1122174]
- [net] libceph: fixup error handling in osdmap_decode() (Sage Weil) [1122174]
- [net] libceph: split osdmap allocation and decode steps (Sage Weil) [1122174]
- [net] libceph: dump osdmap and enhance output on decode errors (Sage Weil) [1122174]
- [net] libceph: dump pg_temp mappings to debugfs (Sage Weil) [1122174]
- [net] libceph: do not prefix osd lines with t in debugfs output (Sage Weil) [1122174]
- [net] libceph: refer to osdmap directly in osdmap_show() (Sage Weil) [1122174]
- [net] crush: support chooseleaf_vary_r tunable (tunables3) by default (Sage Weil) [1122174]
- [net] crush: add SET_CHOOSELEAF_VARY_R step (Sage Weil) [1122174]
- [net] crush: add chooseleaf_vary_r tunable (Sage Weil) [1122174]
- [net] crush: allow crush rules to set (re)tries counts to 0 (Sage Weil) [1122174]
- [net] crush: fix off-by-one errors in total_tries refactor (Sage Weil) [1122174]
- [fs] ceph: don't include ceph.{file, dir}.layout vxattr in listxattr() (Sage Weil) [1122174]
- [fs] ceph: check buffer size in ceph_vxattrcb_layout() (Sage Weil) [1122174]
- [fs] ceph: fix null pointer dereference in discard_cap_releases() (Sage Weil) [1122174]
- [net] libceph: fix oops in ceph_msg_data_{pages, pagelist}_advance() (Sage Weil) [1122174]
- [fs] ceph: set mds_wanted when MDS reply changes a cap to auth cap (Sage Weil) [1122174]
- [fs] ceph: use fl->fl_file as owner identifier of flock and posix lock (Sage Weil) [1122174]
- [fs] ceph: forbid mandatory file lock (Sage Weil) [1122174]
- [fs] ceph: use fl->fl_type to decide flock operation (Sage Weil) [1122174]
- [fs] ceph: update i_max_size even if inode version does not change (Sage Weil) [1122174]
- [fs] ceph: make sure write caps are registered with auth MDS (Sage Weil) [1122174]
- [fs] ceph: print inode number for LOOKUPINO request (Sage Weil) [1122174]
- [fs] ceph: add get_name() NFS export callback (Sage Weil) [1122174]
- [fs] ceph: fix ceph_fh_to_parent() (Sage Weil) [1122174]
- [fs] ceph: add get_parent() NFS export callback (Sage Weil) [1122174]
- [fs] ceph: simplify ceph_fh_to_dentry() (Sage Weil) [1122174]
- [fs] ceph: do not set r_old_dentry_dir on link() (Sage Weil) [1122174]
- [fs] ceph: do not assume r_old_dentry[_dir] always set together (Sage Weil) [1122174]
- [fs] ceph: do not chain inode updates to parent fsync (Sage Weil) [1122174]
- [fs] ceph: avoid useless ceph_get_dentry_parent_inode() in ceph_rename() (Sage Weil) [1122174]
- [fs] ceph: let MDS adjust readdir 'frag' (Sage Weil) [1122174]
- [block] rbd: prefix rbd writes with CEPH_OSD_OP_SETALLOCHINT osd op (Sage Weil) [1122174]
- [block] rbd: num_ops parameter for rbd_osd_req_create() (Sage Weil) [1122174]
- [net] libceph: bump CEPH_OSD_MAX_OP to 3 (Sage Weil) [1122174]
- [net] libceph: add support for CEPH_OSD_OP_SETALLOCHINT osd op (Sage Weil) [1122174]
- [net] libceph: encode CEPH_OSD_OP_FLAG_* op flags (Sage Weil) [1122174]
- [block] rbd: fix error paths in rbd_img_request_fill() (Sage Weil) [1122174]
- [block] rbd: remove out_partial label in rbd_img_request_fill() (Sage Weil) [1122174]
- [net] libceph: a per-osdc crush scratch buffer (Sage Weil) [1122174]
- [block] rbd: drop an unsafe assertion (Sage Weil) [1122174]
- [fs] ceph: fix reset_readdir() (Sage Weil) [1122174]
- [fs] ceph: fix ceph_dir_llseek() (Sage Weil) [1122174]
- [fs] ceph: fix __dcache_readdir() (Sage Weil) [1122174]
- [fs] ceph: fix ceph_removexattr() (Sage Weil) [1122174]
- [fs] ceph: remove xattr when null value is given to setxattr() (Sage Weil) [1122174]
- [fs] ceph: properly handle XATTR_CREATE and XATTR_REPLACE (Sage Weil) [1122174]
- [net] libceph: take map_sem for read in handle_reply() (Sage Weil) [1122174]
- [net] libceph: factor out logic from ceph_osdc_start_request() (Sage Weil) [1122174]
- [net] libceph: fix error handling in ceph_osdc_init() (Sage Weil) [1122174]
- [fs] ceph: cast PAGE_SIZE to size_t in ceph_sync_write() (Sage Weil) [1122174]
- [fs] ceph: fix dout() compile warnings in ceph_filemap_fault() (Sage Weil) [1122174]
- [net] libceph: support CEPH_FEATURE_OSD_CACHEPOOL feature (Sage Weil) [1122174]
- [net] libceph: follow redirect replies from osds (Sage Weil) [1122174]
- [net] libceph: rename ceph_osd_request::r_{oloc, oid} to r_base_{oloc, oid} (Sage Weil) [1122174]
- [net] libceph: follow {read, write}_tier fields on osd request submission (Sage Weil) [1122174]
- [net] libceph: add ceph_pg_pool_by_id() (Sage Weil) [1122174]
- [net] libceph: CEPH_OSD_FLAG_* enum update (Sage Weil) [1122174]
- [net] libceph: replace ceph_calc_ceph_pg() with ceph_oloc_oid_to_pg() (Sage Weil) [1122174]
- [net] libceph: introduce and start using oid abstraction (Sage Weil) [1122174]
- [net] libceph: move ceph_file_layout helpers to ceph_fs.h (Sage Weil) [1122174]
- [net] libceph: rename MAX_OBJ_NAME_SIZE to CEPH_MAX_OID_NAME_LEN (Sage Weil) [1122174]
- [net] libceph: start using oloc abstraction (Sage Weil) [1122174]
- [net] libceph: dout() is missing a newline (Sage Weil) [1122174]
- [net] libceph: add ceph_kv{malloc, free}() and switch to them (Sage Weil) [1122174]
- [net] libceph: support CEPH_FEATURE_EXPORT_PEER (Sage Weil) [1122174]
- [fs] ceph: add imported caps when handling cap export message (Sage Weil) [1122174]
- [fs] ceph: add open export target session helper (Sage Weil) [1122174]
- [fs] ceph: remove exported caps when handling cap import message (Sage Weil) [1122174]
- [fs] ceph: handle session flush message (Sage Weil) [1122174]
- [fs] ceph: check inode caps in ceph_d_revalidate (Sage Weil) [1122174]
- [fs] ceph: handle -ESTALE reply (Sage Weil) [1122174]
- [fs] ceph: fix trim caps (Sage Weil) [1122174]
- [fs] ceph: fix cache revoke race (Sage Weil) [1122174]
- [fs] ceph: use ceph_seq_cmp() to compare migrate_seq (Sage Weil) [1122174]
- [fs] ceph: handle cap export race in try_flush_caps() (Sage Weil) [1122174]
- [fs] ceph: trivial comment fix (Sage Weil) [1122174]
- [net] libceph: fix preallocation check in get_reply() (Sage Weil) [1122174]
- [net] libceph: rename front to front_len in get_reply() (Sage Weil) [1122174]
- [net] libceph: rename ceph_msg::front_max to front_alloc_len (Sage Weil) [1122174]
- [net] libceph: use CEPH_MON_PORT when the specified port is 0 (Sage Weil) [1122174]
- [net] crush: support new indep mode and SET_* steps (crush v2) by default (Sage Weil) [1122174]
- [net] crush: fix crush_choose_firstn comment (Sage Weil) [1122174]
- [net] crush: attempts -> tries (Sage Weil) [1122174]
- [net] crush: add set_choose_local_[fallback_]tries steps (Sage Weil) [1122174]
- [net] crush: generalize descend_once (Sage Weil) [1122174]
- [net] crush: CHOOSE_LEAF -> CHOOSELEAF throughout (Sage Weil) [1122174]
- [net] crush: add SET_CHOOSE_TRIES rule step (Sage Weil) [1122174]
- [net] crush: apply chooseleaf_tries to firstn mode too (Sage Weil) [1122174]
- [net] crush: new SET_CHOOSE_LEAF_TRIES command (Sage Weil) [1122174]
- [net] crush: pass parent r value for indep call (Sage Weil) [1122174]
- [net] crush: clarify numrep vs endpos (Sage Weil) [1122174]
- [net] crush: strip firstn conditionals out of crush_choose, rename (Sage Weil) [1122174]
- [net] crush: add note about r in recursive choose (Sage Weil) [1122174]
- [net] crush: use breadth-first search for indep mode (Sage Weil) [1122174]
- [net] crush: return CRUSH_ITEM_UNDEF for failed placements with indep (Sage Weil) [1122174]
- [net] crush: eliminate CRUSH_MAX_SET result size limitation (Sage Weil) [1122174]
- [net] crush: fix some comments (Sage Weil) [1122174]
- [net] crush: reduce scope of some local variables (Sage Weil) [1122174]
- [net] crush: factor out (trivial) crush_destroy_rule() (Sage Weil) [1122174]
- [net] crush: pass weight vector size to map function (Sage Weil) [1122174]
- [net] libceph: update ceph_features.h (Sage Weil) [1122174]
- [net] libceph: all features fields must be u64 (Sage Weil) [1122174]
- [block] rbd: tear down watch request if rbd_dev_device_setup() fails (Sage Weil) [1122174]
- [block] rbd: introduce rbd_dev_header_unwatch_sync() and switch to it (Sage Weil) [1122174]
- [block] rbd: enable extended devt in single-major mode (Sage Weil) [1122174]
- [fs] ceph: check caps in filemap_fault and page_mkwrite (Sage Weil) [1122174]
- [block] rbd: add support for single-major device number allocation scheme (Sage Weil) [1122174]
- [block] rbd: add 'minor' sysfs rbd device attribute (Sage Weil) [1122174]
- [block] rbd: switch to ida for rbd id assignments (Sage Weil) [1122174]
- [block] rbd: refactor rbd_init() a bit (Sage Weil) [1122174]
- [block] rbd: tweak "loaded" message and module description (Sage Weil) [1122174]
- [block] rbd: rbd_device::dev_id is an int, format it as such (Sage Weil) [1122174]
- [net] libceph: resend all writes after the osdmap loses the full flag (Sage Weil) [1122174]
- [net] libceph: block I/O when PAUSE or FULL osd map flags are set (Sage Weil) [1122174]
- [fs] ceph: new helper, file_inode(file) (Sage Weil) [1122174]
- [fs] ceph: Add necessary clean up if invalid reply received in handle_reply() (Sage Weil) [1122174]
- [fs] ceph: Clean up if error occurred in finish_read() (Sage Weil) [1122174]
- [fs] ceph: implement readv/preadv for sync operation (Sage Weil) [1122174]
- [fs] ceph: Implement writev/pwritev for sync operation (Sage Weil) [1122174]
- [fs] ceph: drop unconnected inodes (Sage Weil) [1122174]
- [fs] ceph: Avoid data inconsistency due to d-cache aliasing in readpage() (Sage Weil) [1122174]
- [fs] ceph: initialize inode before instantiating dentry (Sage Weil) [1122174]
- [fs] ceph: allocate non-zero page to fscache in readpage() (Sage Weil) [1122174]
- [fs] ceph: wake up 'safe' waiters when unregistering request (Sage Weil) [1122174]
- [fs] ceph: cleanup aborted requests when re-sending requests (Sage Weil) [1122174]
- [fs] ceph: handle race between cap reconnect and cap release (Sage Weil) [1122174]
- [fs] ceph: set caps count after composing cap reconnect message (Sage Weil) [1122174]
- [fs] ceph: queue cap release in __ceph_remove_cap() (Sage Weil) [1122174]
- [fs] ceph: handle frag mismatch between readdir request and reply (Sage Weil) [1122174]
- [fs] ceph: remove outdated frag information (Sage Weil) [1122174]
- [block] rbd: fix error handling from rbd_snap_name() (Sage Weil) [1122174]
- [block] rbd: ignore unmapped snapshots that no longer exist (Sage Weil) [1122174]
- [block] rbd: fix use-after free of rbd_dev->disk (Sage Weil) [1122174]
- [block] rbd: make rbd_obj_notify_ack() synchronous (Sage Weil) [1122174]
- [block] rbd: complete notifies before cleaning up osd_client and rbd_dev (Sage Weil) [1122174]
- [net] libceph: add function to ensure notifies are complete (Sage Weil) [1122174]
- [fs] ceph: use d_invalidate() to invalidate aliases (Sage Weil) [1122174]
- [fs] ceph: remove ceph_lookup_inode() (Sage Weil) [1122174]
- [block] rbd: fix null dereference in dout (Sage Weil) [1122174]
- [block] rbd: fix buffer size for writes to images with snapshots (Sage Weil) [1122174]
- [fs] ceph: use vfs __set_page_dirty_nobuffers interface instead of doing it inside filesystem (Sage Weil) [1122174]
- [fs] ceph: allow sync_read/write return partial successed size of read/write (Sage Weil) [1122174]
- [fs] ceph: fix bugs about handling short-read for sync read mode (Sage Weil) [1122174]
- [fs] ceph: remove useless variable revoked_rdcache (Sage Weil) [1122174]
- [net] libceph: create_singlethread_workqueue() doesn't return ERR_PTRs (Sage Weil) [1122174]
- [net] libceph: potential NULL dereference in ceph_osdc_handle_map() (Sage Weil) [1122174]
- [net] libceph: fix error handling in handle_reply() (Sage Weil) [1122174]
- [fs] ceph: fix fallocate division (Sage Weil) [1122174]
- [fs] ceph: punch hole support (Sage Weil) [1122174]
- [fs] ceph: fix request max size (Sage Weil) [1122174]
- [fs] ceph: introduce i_truncate_mutex (Sage Weil) [1122174]
- [fs] ceph: cleanup the logic in ceph_invalidatepage (Sage Weil) [1122174]
- [fs] ceph: Remove bogus check in invalidatepage (Sage Weil) [1122174]
- [fs] ceph: replace hold_mutex flag with goto (Sage Weil) [1122174]
- [fs] ceph: Move the place for EOLDSNAPC handle in ceph_aio_write to easily understand (Sage Weil) [1122174]
- [block] rbd: use NULL instead of 0 (Sage Weil) [1122174]
- [fs] ceph: fix freeing inode vs removing session caps race (Sage Weil) [1122174]
- [fs] ceph: Add check returned value on func ceph_calc_ceph_pg (Sage Weil) [1122174]
- [fs] ceph: Don't use ceph-sync-mode for synchronous-fs (Sage Weil) [1122174]
- [fs] ceph: cleanup types in striped_read() (Sage Weil) [1122174]
- [fs] ceph: trim deleted inode (Sage Weil) [1122174]
- [fs] ceph: wake up writer if vmtruncate work get blocked (Sage Weil) [1122174]
- [fs] ceph: drop CAP_LINK_SHARED when sending "link" request to MDS (Sage Weil) [1122174]
- [fs] ceph: fix null pointer dereference (Sage Weil) [1122174]
- [net] libceph: call r_unsafe_callback when unsafe reply is received (Sage Weil) [1122174]
- [fs] ceph: fix race between cap issue and revoke (Sage Weil) [1122174]
- [fs] ceph: fix cap revoke race (Sage Weil) [1122174]
- [fs] ceph: fix pending vmtruncate race (Sage Weil) [1122174]
- [fs] ceph: avoid accessing invalid memory (Sage Weil) [1122174]
- [fs] ceph: Reconstruct the func ceph_reserve_caps (Sage Weil) [1122174]
- [fs] ceph: Free mdsc if alloc mdsc->mdsmap failed (Sage Weil) [1122174]
- [fs] ceph: remove sb_start/end_write in ceph_aio_write (Sage Weil) [1122174]
- [fs] ceph: avoid meaningless calling ceph_caps_revoking if sync_mode == WB_SYNC_ALL (Sage Weil) [1122174]
- [fs] ceph: move inode to proper flushing list when auth MDS changes (Sage Weil) [1122174]
- [block] rbd: fix a couple warnings (Sage Weil) [1122174]
- [fs] ceph: clear migrate seq when MDS restarts (Sage Weil) [1122174]
- [fs] ceph: check migrate seq before changing auth cap (Sage Weil) [1122174]
- [fs] ceph: fix race between page writeback and truncate (Sage Weil) [1122174]
- [fs] ceph: reset iov_len when discarding cap release messages (Sage Weil) [1122174]
- [fs] ceph: fix cap release race (Sage Weil) [1122174]
- [net] libceph: fix truncate size calculation (Sage Weil) [1122174]
- [net] libceph: fix safe completion (Sage Weil) [1122174]
- [block] rbd: take a little credit (Sage Weil) [1122174]
- [block] rbd: use rwsem to protect header updates (Sage Weil) [1122174]
- [block] rbd: don't hold ctl_mutex to get/put device (Sage Weil) [1122174]
- [block] rbd: protect against concurrent unmaps (Sage Weil) [1122174]
- [block] rbd: set removing flag while holding list lock (Sage Weil) [1122174]
- [net] libceph: print more info for short message header (Sage Weil) [1122174]
- [block] rbd: protect against duplicate client creation (Sage Weil) [1122174]
- [block] rbd: clean up a few things in the refresh path (Sage Weil) [1122174]
- [block] rbd: flush dcache after zeroing page data (Sage Weil) [1122174]
- [net] libceph: add lingering request reference when registered (Sage Weil) [1122174]
- [fs] ceph: tidy ceph_mdsmap_decode() a little (Sage Weil) [1122174]
- [fs] ceph: improve error handling in ceph_mdsmap_decode (Sage Weil) [1122174]
- [block] rbd: drop original request earlier for existence check (Sage Weil) [1122174]
- [fs] ceph: fix up comment for ceph_count_locks() as to which lock to hold (Sage Weil) [1122174]
- [block] rbd: Use min_t() to fix comparison of distinct pointer types warning (Sage Weil) [1122174]

* Sun Sep 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-166.el7]
- [scsi] megaraid_sas: Driver version update (06.805.06.00-rc1) (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: MFI MPT linked list corruption fix (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: N-drive primary raid level 1 load balancing (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Add module parameter to disable IRQ-CPU affinity hint (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Round down max sge supported by controller to power of two (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Host lock less mode to enabled asynchronous IO submission (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Extended VD support (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Firmware crash dump feature support (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Update threshold based reply post host index register (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Use writeq for 64bit pci write to avoid spinlock overhead (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Do not scan non syspd drives (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Fix reset_mutex leak (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Remove unused variables in megasas_instance (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Add missing initial call to megasas_get_ld_vf_affiliation() (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Fix LD/VF affiliation parsing (Tomas Henzl) [1088523]
- [scsi] megaraid: Fail resume if MSI-X re-initialization failed (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Add Dell PowerEdge VRTX SR-IOV VF support (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Return leaked MPT frames to MPT frame pool (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Fix megasas_ioc_init_fusion (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Load correct raid context timeout (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: check return value for megasas_get_pd_list() (Tomas Henzl) [1088523]
- [scsi] megaraid_sas_fusion: Return correct error value in megasas_get_ld_map_info() (Tomas Henzl) [1088523]
- [scsi] megaraid_sas_fusion: correctly pass queue info pointer (Tomas Henzl) [1088523]
- [scsi] megaraid: Use resource_size_t for PCI resources, not long (Tomas Henzl) [1088523]
- [scsi] megaraid: minor cut and paste error fixed (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: fix a bug for 64 bit arches (Tomas Henzl) [1088523]

* Fri Sep 19 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-165.el7]
- [virt] virtio_scsi: fix various bad behavior on aborted requests (Paolo Bonzini) [1098506]
- [x86] perf/intel: ignore CondChgd bit to avoid false NMI handling (Don Zickus) [1110264]
- [lib] cmdline: add size unit t/p/e to memparse (Eric Sandeen) [1058608]
- [virt] virtio_net: fix packets dropping issue (Marcel Apfelbaum) [1131733]
- [pci] hotplug: Prevent NULL dereference during pciehp probe (Myron Stowe) [1133107]
- [security] selinux: fix a problem with IPv6 traffic denials in selinux_ip_postroute() (Paul Moore) [1102641]
- [platform] toshiba: re-enable acpi hotkeys after suspend to disk (Benjamin Tissoires) [1107814]
- [ethernet] cxgb4: use remove handler as shutdown handler (Steve Best) [1123146]
- [idle] intel_idle: Broadwell support (Steve Best) [1086453]
- [s390] dasd: fix unresponsive device during format (Hendrik Brueckner) [1132370]
- [s390] dasd: validate request size before building CCW/TCW request (Hendrik Brueckner) [1132386]
- [s390] dasd: fix error recovery for alias devices during format (Hendrik Brueckner) [1132372]
- [s390] pci: introduce lazy IOTLB flushing for DMA unmap (Hendrik Brueckner) [1132382]
- [s390] dasd: use aliases for formatted devices during format (Hendrik Brueckner) [1132369]
- [s390] dasd: fix list_del corruption during format (Hendrik Brueckner) [1132371]
- [s390] con3215: fix hanging console issue (Hendrik Brueckner) [1132345]
- [mm] hugetlb: improve page-fault scalability (Larry Woodman) [1087955]
- [s390] spinlock: fix system hang with spin_retry <= 0 (Hendrik Brueckner) [1096329]
- [s390] qeth: Accurate ethtool output (Hendrik Brueckner) [1088581]
- [s390] smp: limit number of cpus in possible cpu mask (Hendrik Brueckner) [1103711]
- [scsi] isci: fix needless ata reset escalation (David Milburn) [1074984]
- [idle] intel_idle: close avn_cstates array with correct marker (Steve Best) [1048050]
- [idle] intel_idle: Fixed C6 state on Avoton/Rangeley processors (Steve Best) [1048050]
- [idle] intel_idle: Support Intel Atom Processor C2000 Product Family (Steve Best) [1048050]
- [ethernet] i40e: Bump i40e/i40evf versions (Stefan Assmann) [1140994]
- [ethernet] i40e: fix panic due to too-early Tx queue enable (Stefan Assmann) [1140994]
- [ethernet] i40e: Fix an issue when PF reset fails (Stefan Assmann) [1140994]
- [ethernet] i40e: make warning less verbose (Stefan Assmann) [1140994]
- [ethernet] i40e: Tell OS link is going down when calling set_phy_config (Stefan Assmann) [1140994]
- [ethernet] i40e: Remove unnecessary assignment (Stefan Assmann) [1140994]
- [ethernet] i40e: Change wording to be more consistent (Stefan Assmann) [1140994]
- [ethernet] i40e: Allow user to change link settings if link is down (Stefan Assmann) [1140994]
- [ethernet] i40e: Add dual speed module support (Stefan Assmann) [1140994]
- [mm] memory-failure: support use of a dedicated thread to handle SIGBUS(BUS_MCEERR_AO) (Rui Wang) [1108357]
- [mm] memory-failure: don't let collect_procs() skip over processes for MF_ACTION_REQUIRED (Rui Wang) [1108357]
- [mm] memory-failure: send right signal code to correct thread (Rui Wang) [1108357]
- [crypto] qat: Use pci_enable_msix_exact() instead of pci_enable_msix() (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix return value check in adf_chr_drv_create() (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fixed SKU1 dev issue (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Use hweight for bit counting (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Updated print outputs (Nikolay Aleksandrov) [1091130]
- [crypto] qat: change ae_num to ae_id (Nikolay Aleksandrov) [1091130]
- [crypto] qat: change slice->regions to slice->region (Nikolay Aleksandrov) [1091130]
- [crypto] qat: use min_t macro (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove unnecessary parentheses (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove unneeded header (Nikolay Aleksandrov) [1091130]
- [crypto] qat: checkpatch blank lines (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove unnecessary return codes (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove an unneeded cast (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix error path crash when no firmware is present (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fixed new checkpatch warnings (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Updated Firmware Info Metadata (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix random config build warnings (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix build problem with O= (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Update to makefiles (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT DH895xcc accelerator (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT accelengine part of fw loader (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT ucode part of fw loader (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT crypto interface (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT FW interface (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT transport code (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT driver framework (Nikolay Aleksandrov) [1091130]
- [crypto] Sort drivers/crypto/Makefile (Nikolay Aleksandrov) [1091130]
- [crypto] authenc: Export key parsing helper function (Nikolay Aleksandrov) [1091130]

* Thu Sep 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-164.el7]
- [drm] mst: rework payload table allocation to conform better (Dave Airlie) [1140440]
- [drm] dp: Staticize a couple of DP utility functions (Dave Airlie) [1140440]
- [drm] dp-mst-helper: Don't use uninitialized fields of the sideband message header (Dave Airlie) [1140440]
- [drm] dp-mst-helper: Avoid reading uninitialized value (Dave Airlie) [1140440]
- [drm] mst: fix build with debugfs off (Dave Airlie) [1140440]
- [drm] i915: handle G45/GM45 pulse detection connected state (Dave Airlie) [1140440]
- [drm] i915: take display port power domain in DP HPD handler (Dave Airlie) [1140440]
- [drm] i915: only hook up hpd pulse for DP outputs (Dave Airlie) [1140440]
- [drm] i915: lock around link status and link training (Dave Airlie) [1140440]
- [drm] i915: mst topology dumper in debugfs (v0.2) (Dave Airlie) [1140440]
- [drm] i915: add DP 1.2 MST support (v0.7) (Dave Airlie) [1140440]
- [drm] i915: split some conversion functions out into separate functions (Dave Airlie) [1140440]
- [drm] i915: check connector->encoder before using it (Dave Airlie) [1140440]
- [drm] i915: split some DP modesetting code into a separate function (Dave Airlie) [1140440]
- [drm] helper: add Displayport multi-stream helper (v0.6) (Dave Airlie) [1140440]
- [drm] i915: rework digital port IRQ handling (v2) (Dave Airlie) [1140440]
- [drm] add a path blob property (Dave Airlie) [1140440]
- [drm] fb_helper: allow adding/removing connectors later (Dave Airlie) [1140440]
- [drm] crtc: add interface to reinitialise the legacy mode group (Dave Airlie) [1140440]
- [drm] i915: add some registers need for displayport MST support (Dave Airlie) [1140440]
- [drm] i915: silence some scary new warnings (Rob Clark) [1128915]
- [drm] upstream sync to v3.16.0 (Rob Clark) [1128915]
- [drm] upstream sync to v3.15.0 (Rob Clark) [1101269]
- [lib] Export interval_tree (Rob Clark) [1101269]
- [mm] introduce helper function mem_init_print_info() to simplify mem_init() (Rob Clark) [1101269]
- [kernel] bitops: Introduce a more generic BITMASK macro (Rob Clark) [1101269]
- [drm] upstream sync to v3.14.2 (Rob Clark) [1119341]
- [drm] upstream sync to v3.13.11 (Rob Clark) [1119339]
- [fs] dcache: missing EXPORT_SYMBOL(simple_dname) (Rob Clark) [1119339]
- [kernel] define u8, s8, u32, etc. limits (Rob Clark) [1119339]
- [fs] consolidate the reassignments of ->f_op in ->open() instances (Rob Clark) [1119339]
- [kernel] sched: replace INIT_COMPLETION with reinit_completion (Rob Clark) [1119339]

* Wed Sep 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-163.el7]
- [fs] gfs2: Request demote when a "try" flock fails (Robert S Peterson) [1132154]
- [fs] gfs2: Change maxlen variables to size_t (Robert S Peterson) [1127251]
- [fs] gfs2: Fix return value in slot_get() (Abhijith Das) [1026406]
- [fs] gfs2: replace kmalloc - __vmalloc / memset 0 (Abhijith Das) [1026406]
- [fs] gfs2: Fix kbuild test robot reported warning (Abhijith Das) [1026406]
- [fs] gfs2: Move quota bitmap operations under their own lock (Abhijith Das) [1026406]
- [fs] gfs2: Clean up quota slot allocation (Abhijith Das) [1026406]
- [fs] gfs2: Only run logd and quota when mounted read/write (Abhijith Das) [1026406]
- [fs] gfs2: Use RCU/hlist_bl based hash for quotas (Abhijith Das) [1026406]
- [fs] gfs2: Remove gfs2_quota_change_host structure (Abhijith Das) [1026406]
- [fs] gfs2: Use generic list_lru for quota (Abhijith Das) [1026406]
- [fs] list: add a new LRU list type (Abhijith Das) [1026406]
- [fs] gfs2: Rename quota qd_lru_lock qd_lock (Abhijith Das) [1026406]
- [fs] gfs2: Use reflink for quota data cache (Abhijith Das) [1026406]
- [fs] gfs2: Protect quota sync generation (Abhijith Das) [1026406]
- [fs] gfs2: Inline qd_trylock into gfs2_quota_unlock (Abhijith Das) [1026406]
- [fs] gfs2: Make two similar quota code fragments into a function (Abhijith Das) [1026406]
- [fs] gfs2: Remove obsolete quota tunable (Abhijith Das) [1026406]
- [fs] gfs2: Move gfs2_icbit_munge into quota.c (Abhijith Das) [1026406]

* Wed Sep 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-162.el7]
- [powerpc] powernv: Fix permissions on sysparam sysfs entries (Don Zickus) [1127366]
- [pci] rphahp: Fix endianess issues (Don Zickus) [1127366]
- [scripts] modpost: handle non ABS crc symbols (Don Zickus) [1127366]
- [ethernet] ibmveth: Fix endian issues with MAC addresses (Don Zickus) [1127366]
- [ethernet] ibmveth: Fix little endian issues (Don Zickus) [1127366]
- [scsi] ibmvscsi: Fix little endian issues (Don Zickus) [1127366]
- [powerpc] pseries: Add H_SET_MODE to change exception endianness (Don Zickus) [1127366]
- [powerpc] Move precessing of MCE queued event out from syscall exit path (Don Zickus) [1127366]
- [powerpc] of: compiles fixes (Don Zickus) [1127366]
- [fs] pstore: Introduce new argument 'compressed' in the read callback (Don Zickus) [1127366]
- [cpufreq] powernv: make local function static (Don Zickus) [1127366]
- [cpufreq] powernv: Fix build failure on UP (Don Zickus) [1127366]
- [cpufreq] powernv: Use cpufreq_frequency_table.driver_data to store pstate ids (Don Zickus) [1127366]
- [cpufreq] powernv: cpufreq driver for powernv platform (Don Zickus) [1127366]
- [fs] pstore: Add new argument 'compressed' in pstore write callback (Don Zickus) [1127366]
- [powerpc] of: implement pci_address_to_pio as weak function (Don Zickus) [1127366]
- [kernel] panic: Make panic_timeout configurable (Don Zickus) [1127366]
- [pci] Add new pci_is_bridge() interface (Don Zickus) [1127366]
- [pci] Rename pci_is_bridge() to pci_has_subordinate() (Don Zickus) [1127366]
- [powerpc] of: device_node kobject lifecycle fixes (Don Zickus) [1127366]
- [powerpc] Fix endianness of flash_block_list in rtas_flash (Don Zickus) [1127366]
- [powerpc] powernv: Change BUG_ON to WARN_ON in elog code (Don Zickus) [1127366]
- [powerpc] perf: Fix MMCR2 handling for EBB (Don Zickus) [1127366]
- [powerpc] use _GLOBAL_TOC for memmove (Don Zickus) [1127366]
- [powerpc] pseries: dynamically added OF nodes need to call of_node_init (Don Zickus) [1127366]
- [powerpc] subpage_protect: Increase the array size to take care of 64TB (Don Zickus) [1127366]
- [powerpc] Fix bugs in emulate_step() (Don Zickus) [1127366]
- [powerpc] Disable doorbells on Power8 DD1.x (Don Zickus) [1127366]
- [powerpc] perf: Never program book3s PMCs with values >= 0x80000000 (Don Zickus) [1127366]
- [powerpc] perf: Clear MMCR2 when enabling PMU (Don Zickus) [1127366]
- [powerpc] perf: Add PPMU_ARCH_207S define (Don Zickus) [1127366]
- [powerpc] kvm: Remove redundant save of SIER AND MMCR2 (Don Zickus) [1127366]
- [powerpc] powernv: Check for IRQHAPPENED before sleeping (Don Zickus) [1127366]
- [powerpc] bpf: Fix the broken LD_VLAN_TAG_PRESENT test (Don Zickus) [1127366]
- [powerpc] bpf: Use correct mask while accessing the VLAN tag (Don Zickus) [1127366]
- [powerpc] module: Fix TOC symbol CRC (Don Zickus) [1127366]
- [powerpc] powernv: Remove OPAL v1 takeover (Don Zickus) [1127366]
- [powerpc] kprobes: Fix jprobes on ABI v2 (LE) (Don Zickus) [1127366]
- [powerpc] ftrace: Use pr_fmt() to namespace error messages (Don Zickus) [1127366]
- [powerpc] ftrace: Fix nop of modules on 64bit LE (ABIv2) (Don Zickus) [1127366]
- [powerpc] ftrace: Fix inverted check of create_branch() (Don Zickus) [1127366]
- [powerpc] ftrace: Fix typo in mask of opcode (Don Zickus) [1127366]
- [powerpc] Add ppc_global_function_entry() (Don Zickus) [1127366]
- [powerpc] Remove __arch_swab* (Don Zickus) [1127366]
- [powerpc] Remove ancient DEBUG_SIG code (Don Zickus) [1127366]
- [powerpc] kerenl: Enable EEH for IO accessors (Don Zickus) [1127366]
- [powerpc] Avoid circular dependency with zImage. (Don Zickus) [1127366]
- [powerpc] book3s: Fix some ABIv2 issues in machine check code (Don Zickus) [1127366]
- [powerpc] book3s: Fix guest MC delivery mechanism to avoid soft lockups in guest (Don Zickus) [1127366]
- [powerpc] book3s: Increment the mce counter during machine_check_early call (Don Zickus) [1127366]
- [powerpc] book3s: Add stack overflow check in machine check handler (Don Zickus) [1127366]
- [powerpc] book3s: Fix machine check handling for unhandled errors (Don Zickus) [1127366]
- [powerpc] eeh: Dump PE location code (Don Zickus) [1127366]
- [powerpc] powernv: Enable POWER8 doorbell IPIs (Don Zickus) [1127366]
- [powerpc] powernv: Fix killed EEH event (Don Zickus) [1127366]
- [powerpc] fix typo 'CONFIG_PMAC' (Don Zickus) [1127366]
- [powerpc] fix typo 'CONFIG_PPC_CPU' (Don Zickus) [1127366]
- [powerpc] powernv: Don't escalate non-existing frozen PE (Don Zickus) [1127366]
- [powerpc] eeh: Report frozen parent PE prior to child PE (Don Zickus) [1127366]
- [powerpc] eeh: Clear frozen state for child PE (Don Zickus) [1127366]
- [powerpc] powernv: Reduce panic timeout from 180s to 10s (Don Zickus) [1127366]
- [powerpc] xmon: avoid format string leaking to printk (Don Zickus) [1127366]
- [powerpc] perf: Ensure all EBB register state is cleared on fork() (Don Zickus) [1127366]
- [powerpc] powernv: Fix reading of OPAL msglog (Don Zickus) [1127366]
- [powerpc] powernv: Fix endianness problems in EEH (Don Zickus) [1127366]
- [powerpc] powernv: Disable subcore for UP configs (Don Zickus) [1127366]
- [powerpc] powernv: Include asm/smp.h to fix UP build failure (Don Zickus) [1127366]
- [powerpc] Don't setup CPUs with bad status (Don Zickus) [1127366]
- [powerpc] Add AT_HWCAP2 to indicate V.CRYPTO category support (Don Zickus) [1127366]
- [powerpc] update comments for generic idle conversion (Don Zickus) [1127366]
- [powerpc] powernv: Add missing include to LPC code (Don Zickus) [1127366]
- [powerpc] powernv: Pass buffer size to OPAL validate flash call (Don Zickus) [1127366]
- [powerpc] pseries: hcall functions are exported to modules, need _GLOBAL_TOC() (Don Zickus) [1127366]
- [powerpc] Exported functions __clear_user and copy_page use r2 so need _GLOBAL_TOC() (Don Zickus) [1127366]
- [powerpc] powernv: Set memory_block_size_bytes to 256MB (Don Zickus) [1127366]
- [powerpc] Allow ppc_md platform hook to override memory_block_size_bytes (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issues in memory error handling code (Don Zickus) [1127366]
- [powerpc] eeh: Skip eeh sysfs when eeh is disabled (Don Zickus) [1127366]
- [powerpc] powernv: Provide debugfs access to the LPC bus via OPAL (Don Zickus) [1127366]
- [powerpc] serial: Use saner flags when creating legacy ports (Don Zickus) [1127366]
- [powerpc] Add cpu family documentation (Don Zickus) [1127366]
- [powerpc] xmon: Fix up xmon format strings (Don Zickus) [1127366]
- [powerpc] powernv: Add calls to support little endian host (Don Zickus) [1127366]
- [powerpc] Document sysfs DSCR interface (Don Zickus) [1127366]
- [powerpc] Fix regression of per-CPU DSCR setting (Don Zickus) [1127366]
- [powerpc] Split __SYSFS_SPRSETUP macro (Don Zickus) [1127366]
- [powerpc] fadump: Cleaning up inconsistent NULL checks (Don Zickus) [1127366]
- [powerpc] powernv: Add support for POWER8 split core on powernv (Don Zickus) [1127366]
- [powerpc] kvm/book3s_hv: Use threads_per_subcore in KVM (Don Zickus) [1127366]
- [powerpc] Check cpu_thread_in_subcore() in __cpu_up() (Don Zickus) [1127366]
- [powerpc] Add threads_per_subcore (Don Zickus) [1127366]
- [powerpc] powernv: Make it possible to skip the IRQHAPPENED check in power7_nap() (Don Zickus) [1127366]
- [powerpc] kvm/book3s_hv: Rework the secondary inhibit code (Don Zickus) [1127366]
- [powerpc] numa: Enable CONFIG_HAVE_MEMORYLESS_NODES (Don Zickus) [1127366]
- [powerpc] numa: Enable USE_PERCPU_NUMA_NODE_ID (Don Zickus) [1127366]
- [powerpc] Fix 64 bit builds with binutils 2.24 (Don Zickus) [1127366]
- [powerpc] pci: Use pci_is_bridge() to simplify code (Don Zickus) [1127366]
- [powerpc] module: Fix stubs for BE (Don Zickus) [1127366]
- [powerpc] Clear ELF personality flag if ELFv2 is not requested (Don Zickus) [1127366]
- [powerpc] Fix smp_processor_id() in preemptible splat in set_breakpoint (Don Zickus) [1127366]
- [powerpc] Drop return value from set_breakpoint as it is unused (Don Zickus) [1127366]
- [powerpc] Remove non-uapi linkage.h export (Don Zickus) [1127366]
- [powerpc] irq work racing with timer interrupt can result in timer interrupt hang (Don Zickus) [1127366]
- [powerpc] mm: use macro PGTABLE_EADDR_SIZE instead of digital (Don Zickus) [1127366]
- [powerpc] le: Show the endianess of the LPAR under PowerVM (Don Zickus) [1127366]
- [powerpc] Use 64k io pages when we never see an HEA (Don Zickus) [1127366]
- [powerpc] use libfdt accessors for header data (Don Zickus) [1127366]
- [powerpc] memcpy optimization for 64bit LE (Don Zickus) [1127366]
- [powerpc] tm: Add checking to treclaim/trechkpt (Don Zickus) [1127366]
- [powerpc] tm: Remove unnecessary r1 save (Don Zickus) [1127366]
- [powerpc] powernv: Implement ppc_md.get_proc_freq() (Don Zickus) [1127366]
- [cpuidle] powernv: Remove redundant cpuidle_idle_call() (Don Zickus) [1127366]
- [powerpc] powernv: Framework to show the correct clock in /proc/cpuinfo (Don Zickus) [1127366]
- [powerpc] powernv: Return secondary CPUs to firmware before FW update (Don Zickus) [1127366]
- [powerpc] boot: Add support for 64bit little endian wrapper (Don Zickus) [1127366]
- [powerpc] boot: Add a global entry point for pseries (Don Zickus) [1127366]
- [powerpc] boot: Modify entry point for 64bit (Don Zickus) [1127366]
- [powerpc] boot: Define a routine to enter prom (Don Zickus) [1127366]
- [powerpc] boot: Add little endian support to elf utils (Don Zickus) [1127366]
- [powerpc] boot: Add 64bit and little endian support to addnote (Don Zickus) [1127366]
- [powerpc] boot: Define byteswapping routines for little endian (Don Zickus) [1127366]
- [powerpc] boot: Fix compile warning in 64bit (Don Zickus) [1127366]
- [powerpc] boot: Define typedef ihandle as u32 (Don Zickus) [1127366]
- [powerpc] boot: Rework of_claim() to make it 64bit friendly (Don Zickus) [1127366]
- [powerpc] boot: Add PROM_ERROR define in oflib (Don Zickus) [1127366]
- [powerpc] boot: Add byteswapping routines in oflib (Don Zickus) [1127366]
- [powerpc] boot: Use prom_arg_t in oflib (Don Zickus) [1127366]
- [powerpc] boot: Use a common prom_args struct in oflib (Don Zickus) [1127366]
- [powerpc] boot: Fix do_div for 64bit wrapper (Don Zickus) [1127366]
- [powerpc] prom: Stop scanning dev-tree for fdump early (Don Zickus) [1127366]
- [powerpc] powernv: Don't use pe->pbus to get the domain number (Don Zickus) [1127366]
- [powerpc] powernv: Fix VFIO support with PHB3 (Don Zickus) [1127366]
- [powerpc] powernv: Missed IOMMU table type (Don Zickus) [1127366]
- [powerpc] eeh: Can't recover from non-PE-reset case (Don Zickus) [1127366]
- [powerpc] pci: Mask linkDown on resetting PCI bus (Don Zickus) [1127366]
- [powerpc] powernv: Reset root port in firmware (Don Zickus) [1127366]
- [powerpc] pseries: Fix overwritten PE state (Don Zickus) [1127366]
- [powerpc] powernv: Fix endless reporting frozen PE (Don Zickus) [1127366]
- [powerpc] eeh: No hotplug on permanently removed dev (Don Zickus) [1127366]
- [powerpc] eeh: Allow to disable EEH (Don Zickus) [1127366]
- [powerpc] eeh: Cleanup EEH subsystem variables (Don Zickus) [1127366]
- [powerpc] eeh: Use cached capability for log dump (Don Zickus) [1127366]
- [powerpc] eeh: Cleanup eeh_gather_pci_data() (Don Zickus) [1127366]
- [powerpc] eeh: Avoid I/O access during PE reset (Don Zickus) [1127366]
- [powerpc] powernv: Use EEH PCI config accessors (Don Zickus) [1127366]
- [powerpc] eeh: Block PCI-CFG access during PE reset (Don Zickus) [1127366]
- [powerpc] eeh: EEH_PE_ISOLATED not reflect HW state (Don Zickus) [1127366]
- [powerpc] powernv: Remove fields in PHB diag-data dump (Don Zickus) [1127366]
- [powerpc] powernv: Move PNV_EEH_STATE_ENABLED around (Don Zickus) [1127366]
- [powerpc] powernv: Remove PNV_EEH_STATE_REMOVED (Don Zickus) [1127366]
- [powerpc] eeh: Remove EEH_PE_PHB_DEAD (Don Zickus) [1127366]
- [powerpc] pseries: Protect remove_memory() with device hotplug lock (Don Zickus) [1127366]
- [powerpc] Fix error return in rtas_flash module init (Don Zickus) [1127366]
- [powerpc] Bump BOOT_COMMAND_LINE_SIZE to 2048 (Don Zickus) [1127366]
- [powerpc] Bump COMMAND_LINE_SIZE to 2048 (Don Zickus) [1127366]
- [powerpc] Rename duplicate COMMAND_LINE_SIZE define (Don Zickus) [1127366]
- [powerpc] mm: Fix tlbie to add AVAL fields for 64K pages (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues in OPAL dump code (Don Zickus) [1127366]
- [powerpc] powernv: Create OPAL sglist helper functions and fix endian issues (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues in OPAL error log code (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues with opal_do_notifier calls (Don Zickus) [1127366]
- [powerpc] powernv: Remove some OPAL function declaration duplication (Don Zickus) [1127366]
- [powerpc] powernv: Use uint64_t instead of size_t in OPAL APIs (Don Zickus) [1127366]
- [powerpc] powernv: Release the refcount for pci_dev (Don Zickus) [1127366]
- [powerpc] powernv: Reduce multi-hit of iommu_add_device() (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues in OPAL flash code (Don Zickus) [1127366]
- [powerpc] powernv: Fix kexec races going back to OPAL (Don Zickus) [1127366]
- [powerpc] powernv: Check sysparam size before creation (Don Zickus) [1127366]
- [powerpc] powernv: Fix typos in sysparam code (Don Zickus) [1127366]
- [powerpc] powernv: Check sysfs size before copying (Don Zickus) [1127366]
- [powerpc] powernv: Use ssize_t for sysparam return values (Don Zickus) [1127366]
- [powerpc] powernv: Fix sysparam sysfs error handling (Don Zickus) [1127366]
- [powerpc] Fix Oops in rtas_stop_self() (Don Zickus) [1127366]
- [powerpc] Export flush_icache_range (Don Zickus) [1127366]
- [powerpc] Build little endian ppc64 kernel with ABIv2 (Don Zickus) [1127366]
- [powerpc] ftrace: Fix ABIv2 issues with __ftrace_make_call (Don Zickus) [1127366]
- [powerpc] ftrace: Use module loader helpers to parse trampolines (Don Zickus) [1127366]
- [powerpc] modules: Create module_trampoline_target() (Don Zickus) [1127366]
- [powerpc] modules: Create is_module_trampoline() (Don Zickus) [1127366]
- [powerpc] kprobes: Fix ABIv2 issues with kprobe_lookup_name (Don Zickus) [1127366]
- [powerpc] ftrace_caller, _mcount is exported to modules so needs _GLOBAL_TOC() (Don Zickus) [1127366]
- [powerpc] Add _GLOBAL_TOC for ABIv2 assembly functions exported to modules (Don Zickus) [1127366]
- [powerpc] modules: implement stubs for ELFv2 ABI (Don Zickus) [1127366]
- [powerpc] modules: skip r2 setup for ELFv2 (Don Zickus) [1127366]
- [powerpc] modules: use r12 for stub jump address (Don Zickus) [1127366]
- [powerpc] modules: change r2 save/restore offset for ELFv2 ABI (Don Zickus) [1127366]
- [powerpc] modules: comment about de-dotifying symbols when using the ELFv2 ABI (Don Zickus) [1127366]
- [powerpc] Handle new ELFv2 module relocations (Don Zickus) [1127366]
- [powerpc] Fix up TOC. for modules (Don Zickus) [1127366]
- [powerpc] module: handle MODVERSION for .TOC (Don Zickus) [1127366]
- [powerpc] EXPORT_SYMBOL(.TOC.) (Don Zickus) [1127366]
- [powerpc] modules implement R_PPC64_TOCSAVE relocation (Don Zickus) [1127366]
- [powerpc] make module stub code endian independent (Don Zickus) [1127366]
- [powerpc] Fix ABIv2 issue with dereference_function_descriptor (Don Zickus) [1127366]
- [powerpc] Fix SMP issues with ppc64le ABIv2 (Don Zickus) [1127366]
- [powerpc] tracing: TRACE_WITH_FRAME_BUFFER creates invalid stack frames (Don Zickus) [1127366]
- [powerpc] tm: Fix GOT save offset for ABIv2 (Don Zickus) [1127366]
- [powerpc] tm: Use STK_PARAM (Don Zickus) [1127366]
- [powerpc] Fix unsafe accesses to parameter area in ELFv2 (Don Zickus) [1127366]
- [powerpc] Fix ABIv2 issues with stack offsets in assembly code (Don Zickus) [1127366]
- [powerpc] Fix kernel thread creation on ABIv2 (Don Zickus) [1127366]
- [powerpc] Fix branch patching code for ABIv2 (Don Zickus) [1127366]
- [powerpc] Use ppc_function_entry instead of open coding it (Don Zickus) [1127366]
- [powerpc] Add ABIv2 support to ppc_function_entry (Don Zickus) [1127366]
- [powerpc] Ignore .TOC. relocations (Don Zickus) [1127366]
- [powerpc] ABIv2 function calls must place target address in r12 (Don Zickus) [1127366]
- [powerpc] Remove function descriptors and dot symbols on new ABI (Don Zickus) [1127366]
- [powerpc] Create DOTSYM to wrap dot symbol usage (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Introduce hypervisor call H_GET_TCE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add support for DABRX register on POWER7 (Don Zickus) [1127366]
- [powerpc] Remove dot symbol usage in exception macros (Don Zickus) [1127366]
- [powerpc] Remove _INIT_GLOBAL(), _STATIC() and _INIT_STATIC() (Don Zickus) [1127366]
- [powerpc] Remove some unnecessary uses of _GLOBAL() and _STATIC() (Don Zickus) [1127366]
- [powerpc] Don't use a function descriptor for system call table (Don Zickus) [1127366]
- [powerpc] Remove superflous function descriptors in assembly only code (Don Zickus) [1127366]
- [powerpc] No need to use dot symbols when branching to a function (Don Zickus) [1127366]
- [powerpc] Don't build assembly files with ABIv2 (Don Zickus) [1127366]
- [powerpc] Don't try to set LPCR unless we're in hypervisor mode (Don Zickus) [1127366]
- [powerpc] le: Avoid creatng R_PPC64_TOCSAVE relocations for modules (Don Zickus) [1127366]
- [powerpc] opal: Add missing include (Don Zickus) [1127366]
- [powerpc] Convert last uses of __FUNCTION__ to __func__ (Don Zickus) [1127366]
- [powerpc] Add lq/stq emulation (Don Zickus) [1127366]
- [powerpc] powernv: Add invalid OPAL call (Don Zickus) [1127366]
- [powerpc] powernv: Add OPAL message log interface (Don Zickus) [1127366]
- [powerpc] book3s: Fix mc_recoverable_range buffer overrun issue (Don Zickus) [1127366]
- [powerpc] Remove dead code in sycall entry (Don Zickus) [1127366]
- [powerpc] Use of_node_init() for the fakenode in msi_bitmap.c (Don Zickus) [1127366]
- [powerpc] of: Make device nodes kobjects so they show up in sysfs (Don Zickus) [1127366]
- [powerpc] mm: NUMA pte should be handled via slow path in get_user_pages_fast() (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issues with sensor code (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issues with OPAL async code (Don Zickus) [1127366]
- [powerpc] powernv: Add opal_notifier_unregister() and export to modules (Don Zickus) [1127366]
- [powerpc] ppc64: Do not turn AIL (reloc-on interrupts) too early (Don Zickus) [1127366]
- [powerpc] ppc64: Gracefully handle early interrupts (Don Zickus) [1127366]
- [powerpc] prom: early_init_dt_scan_cpus() updates cpu features only once (Don Zickus) [1127366]
- [powerpc] Make boot_cpuid common between 32 and 64-bit (Don Zickus) [1127366]
- [powerpc] Adjust CPU_FTR_SMT on all platforms (Don Zickus) [1127366]
- [powerpc] le: Enable RTAS events support (Don Zickus) [1127366]
- [powerpc] book3s: Fix CFAR clobbering issue in machine check handler (Don Zickus) [1127366]
- [powerpc] compat: 32-bit little endian machine name is ppcle, not ppc (Don Zickus) [1127366]
- [powerpc] le: Big endian arguments for ppc_rtas() (Don Zickus) [1127366]
- [powerpc] mm: Make sure a local_irq_disable prevent a parallel THP split (Don Zickus) [1127366]
- [powerpc] Rate-limit users spamming kernel log buffer (Don Zickus) [1127366]
- [powerpc] perf: Fix handling of L3 events with bank == 1 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Work around POWER8 performance monitor bugs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Make sure we don't miss dirty pages (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add transactional memory support (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix dirty map for hugepages (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix check for running inside guest in global_invalidates() (Don Zickus) [1127366]
- [powerpc] powernv: Reset PHB in kdump kernel (Don Zickus) [1127366]
- [powerpc] eeh: Make the delay for PE reset unified (Don Zickus) [1127366]
- [virt] kvm/ppc: Clear the runlatch bit of a vcpu before napping (Don Zickus) [1127366]
- [virt] kvm/ppc: Set the runlatch bit of a CPU just before starting guest (Don Zickus) [1127366]
- [powerpc] powernv: Set the runlatch bits correctly for offline cpus (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Save/restore host PMU registers that are new in POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix decrementer timeouts with non-zero TB offset (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Don't use kvm_memslots() in real mode (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Return ENODEV error rather than EIO (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Trim top 4 bits of physical address in RTAS code (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add get/set_one_reg for new TM state (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Basic little-endian guest support (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix register usage when loading/saving VRSAVE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Cope with doorbell interrupts (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add new state for transactional memory (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Prepare for host using hypervisor doorbells (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Handle new LPCR bits on POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Handle guest using doorbells for IPIs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Consolidate code that checks reason for wake from nap (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Implement architecture compatibility modes for POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add handler for HV facility unavailable (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Flush the correct number of TLB sets on POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Context-switch new POWER8 SPRs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Align physical and virtual CPU thread numbers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Don't set DABR on POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - MMIO emulation support for little endian guests (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Use load/store_fp_state functions in HV guest entry/exit (Don Zickus) [1127366]
- [virt] kvm/ppc: Store FP/VSX/VMX state in thread_fp/vr_state structures (Don Zickus) [1127366]
- [virt] kvm/ppc: Use load_fp/vr_state rather than load_up_fpu/altivec (Don Zickus) [1127366]
- [powerpc] powernv/eeh: Add buffer for P7IOC hub error data (Don Zickus) [1127366]
- [powerpc] powernv: Remove get/set_rtc_time when they are not present (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Take SRCU read lock around kvm_read_guest() call (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Make tbacct_lock irq-safe (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Refine barriers in guest entry/exit (Don Zickus) [1127366]
- [virt] kvm: Add struct kvm arg to memslot APIs (Don Zickus) [1127366]
- [powerpc] perf: Define perf_event_print_debug() to print PMU register values (Don Zickus) [1127366]
- [powerpc] perf: Make some new raw event codes available in sysfs (Don Zickus) [1127366]
- [powerpc] powernv: Enable fetching of platform sensor data (Don Zickus) [1127366]
- [powerpc] powernv: Enable reading and updating of system parameters (Don Zickus) [1127366]
- [powerpc] powernv: Infrastructure to support OPAL async completion (Don Zickus) [1127366]
- [powerpc] powernv Platform dump interface (Don Zickus) [1127366]
- [powerpc] powernv: Read OPAL error log and export it through sysfs (Don Zickus) [1127366]
- [powerpc] Add "force config cmd line" Kconfig option (Don Zickus) [1127366]
- [powerpc] pseries: Use remove_memory() to remove memory (Don Zickus) [1127366]
- [powerpc] book3s: Recover from MC in sapphire on SCOM read via MMIO (Don Zickus) [1127366]
- [powerpc] pseries: Don't try to register pseries cpu hotplug on non-pseries (Don Zickus) [1127366]
- [powerpc] Fix xmon disassembler for little-endian (Don Zickus) [1127366]
- [powerpc] Revert c6102609 and replace it with the correct fix for vio dma mask setting (Don Zickus) [1127366]
- [powerpc] Kill CONFIG_MTD_PARTITIONS (Don Zickus) [1127366]
- [powerpc] Align p_dyn, p_rela and p_st symbols (Don Zickus) [1127366]
- [powerpc] powernv: Add OPAL call to resync timebase on wakeup (Don Zickus) [1127366]
- [powerpc] powernv: Add context management for Fast Sleep (Don Zickus) [1127366]
- [powerpc] Split timer_interrupt() into timer handling and interrupt handling routines (Don Zickus) [1127366]
- [powerpc] Implement tick broadcast IPI as a fixed IPI message (Don Zickus) [1127366]
- [powerpc] Free up the slot of PPC_MSG_CALL_FUNC_SINGLE IPI message (Don Zickus) [1127366]
- [powerpc] eeh: Fixup the brown paperbag fallout of the "cleanup" (Don Zickus) [1127366]
- [powerpc] eeh: Kill another abuse of irq_desc (Don Zickus) [1127366]
- [powerpc] irq: Use generic_handle_irq (Don Zickus) [1127366]
- [powerpc] powernv: Fix indirect XSCOM unmangling (Don Zickus) [1127366]
- [powerpc] powernv: Fix opal_xscom_{read, write} prototype (Don Zickus) [1127366]
- [powerpc] powernv: Refactor PHB diag-data dump (Don Zickus) [1127366]
- [powerpc] powernv: Dump PHB diag-data immediately (Don Zickus) [1127366]
- [powerpc] Increase stack redzone for 64-bit userspace to 512 bytes (Don Zickus) [1127366]
- [powerpc] ftrace: bugfix for test_24bit_addr (Don Zickus) [1127366]
- [powerpc] crashdump: Fix page frame number check in copy_oldmem_page (Don Zickus) [1127366]
- [powerpc] le: Ensure that the 'stop-self' RTAS token is handled correctly (Don Zickus) [1127366]
- [powerpc] eeh: Disable EEH on reboot (Don Zickus) [1127366]
- [powerpc] eeh: Cleanup on eeh_subsystem_enabled (Don Zickus) [1127366]
- [powerpc] powernv: Rework EEH reset (Don Zickus) [1127366]
- [powerpc] powernv: Add iommu DMA bypass support for IODA2 (Don Zickus) [1127366]
- [powerpc] Fix endian issues in kexec and crash dump code (Don Zickus) [1127366]
- [powerpc] perf: Configure BHRB filter before enabling PMU interrupts (Don Zickus) [1127366]
- [powerpc] pseries: Select ARCH_RANDOM on pseries (Don Zickus) [1127366]
- [powerpc] perf: Add Power8 cache & TLB events (Don Zickus) [1127366]
- [powerpc] relocate fix relocate processing in LE mode (Don Zickus) [1127366]
- [powerpc] hugetlb: Replace __get_cpu_var with get_cpu_var (Don Zickus) [1127366]
- [powerpc] Make sure "cache" directory is removed when offlining cpu (Don Zickus) [1127366]
- [powerpc] powernv/cpuidle: Back-end cpuidle driver for powernv platform (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: smt-snooze-delay cleanup (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Remove MAX_IDLE_STATE macro (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Make cpuidle-pseries backend driver a non-module (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Use cpuidle_register() for initialisation (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Move processor_idle.c to drivers/cpuidle (Don Zickus) [1127366]
- [powerpc] numa: Fix decimal permissions (Don Zickus) [1127366]
- [powerpc] Fix hw breakpoints on !HAVE_HW_BREAKPOINT configurations (Don Zickus) [1127366]
- [powerpc] Implement arch_spin_is_locked() using arch_spin_value_unlocked() (Don Zickus) [1127366]
- [powerpc] Add support for the optimised lockref implementation (Don Zickus) [1127366]
- [powerpc] Kconfig: Make TM select VSX and VMX (Don Zickus) [1127366]
- [powerpc] powernv: Call OPAL sync before kexec'ing (Don Zickus) [1127366]
- [powerpc] eeh: Escalate error on non-existing PE (Don Zickus) [1127366]
- [powerpc] eeh: Handle multiple EEH errors (Don Zickus) [1127366]
- [powerpc] Fix races with irq_work (Don Zickus) [1127366]
- [powerpc] Make add_system_ram_resources() __init (Don Zickus) [1127366]
- [powerpc] add SATA_MV to ppc64_defconfig (Don Zickus) [1127366]
- [powerpc] powernv: Increase candidate fw image size (Don Zickus) [1127366]
- [powerpc] iommu: Don't detach device without IOMMU group (Don Zickus) [1127366]
- [powerpc] eeh: Hotplug improvement (Don Zickus) [1127366]
- [powerpc] eeh: Call opal_pci_reinit() on powernv for restoring config space (Don Zickus) [1127366]
- [powerpc] eeh: Add restore_config operation (Don Zickus) [1127366]
- [powerpc] powernv: Remove unnecessary assignment (Don Zickus) [1127366]
- [powerpc] Delete non-required instances of include <linux/init.h> (Don Zickus) [1127366]
- [powerpc] Add vr save/restore functions (Don Zickus) [1127366]
- [powerpc] Check return value of instance-to-package OF call (Don Zickus) [1127366]
- [powerpc] add barrier after writing kernel PTE (Don Zickus) [1127366]
- [powerpc] introduce macro LOAD_REG_ADDR_PIC (Don Zickus) [1127366]
- [virt] kvm/ppc: define a linux pte lookup function (Don Zickus) [1127366]
- [powerpc] Fix endian issues in power7/8 machine check handler (Don Zickus) [1127366]
- [powerpc] iommu: Update the generic code to use dynamic iommu page sizes (Don Zickus) [1127366]
- [powerpc] iommu: Add it_page_shift field to determine iommu page size (Don Zickus) [1127366]
- [powerpc] iommu: Update constant names to reflect their hardcoded page size (Don Zickus) [1127366]
- [powerpc] powernv: move iommu_add_device earlier (Don Zickus) [1127366]
- [powerpc] vfio: Enable on pSeries platform (Don Zickus) [1127366]
- [powerpc] vfio: Implement IOMMU driver for VFIO (Don Zickus) [1127366]
- [powerpc] vfio: Enable on PowerNV platform (Don Zickus) [1127366]
- [powerpc] Fix "attempt to move .org backwards" error (Don Zickus) [1127366]
- [powerpc] Fix alignment of secondary cpu spin vars (Don Zickus) [1127366]
- [powerpc] Align p_end (Don Zickus) [1127366]
- [powerpc] Make 64-bit non-VMX __copy_tofrom_user bi-endian (Don Zickus) [1127366]
- [powerpc] Make unaligned accesses endian-safe for powerpc (Don Zickus) [1127366]
- [powerpc] Fix bad stack check in exception entry (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Don't abuse host r2 in exit path (Don Zickus) [1127366]
- [powerpc] Full barrier for smp_mb__after_unlock_lock() (Don Zickus) [1127366]
- [powerpc] powernv: Fix OPAL LPC access in Little Endian (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issue in opal_xscom_read (Don Zickus) [1127366]
- [powerpc] pseries: Fix endian issues in /proc/ppc64/lparcfg (Don Zickus) [1127366]
- [powerpc] Fix up the kdump base cap to 128M (Don Zickus) [1127366]
- [powerpc] Fix PTE page address mismatch in pgtable ctor/dtor (Don Zickus) [1127366]
- [powerpc] powernv: Get FSP memory errors and plumb into memory poison infrastructure (Don Zickus) [1127366]
- [powerpc] powernv: Add config option for hwpoisoning (Don Zickus) [1127366]
- [powerpc] Dynamically allocate slb_shadow from memblock (Don Zickus) [1127366]
- [powerpc] Make slb_shadow a local (Don Zickus) [1127366]
- [powerpc] Add real mode cache inhibited IO accessors (Don Zickus) [1127366]
- [powerpc] Increase EEH recovery timeout for SR-IOV (Don Zickus) [1127366]
- [powerpc] eeh: Output PHB diag-data (Don Zickus) [1127366]
- [powerpc] powernv: Move PHB-diag dump functions around (Don Zickus) [1127366]
- [powerpc] powernv: Move SG list structure to header file (Don Zickus) [1127366]
- [powerpc] powernv: Infrastructure to read opal messages in generic format (Don Zickus) [1127366]
- [powerpc] powernv: Machine check exception handling (Don Zickus) [1127366]
- [powerpc] powernv: Remove machine check handling in OPAL (Don Zickus) [1127366]
- [powerpc] book3s: Queue up and process delayed MCE events (Don Zickus) [1127366]
- [powerpc] book3s: Decode and save machine check event (Don Zickus) [1127366]
- [powerpc] book3s: Flush SLB/TLBs if we get SLB/TLB machine check errors on power8 (Don Zickus) [1127366]
- [powerpc] book3s: Flush SLB/TLBs if we get SLB/TLB machine check errors on power7 (Don Zickus) [1127366]
- [powerpc] book3s: Add flush_tlb operation in cpu_spec (Don Zickus) [1127366]
- [powerpc] book3s: Introduce a early machine check hook in cpu_spec (Don Zickus) [1127366]
- [powerpc] book3s: Return from interrupt if coming from evil context (Don Zickus) [1127366]
- [powerpc] book3s: handle machine check in Linux host (Don Zickus) [1127366]
- [powerpc] book3s: Introduce exclusive emergency stack for machine check exception (Don Zickus) [1127366]
- [powerpc] book3s: Split the common exception prolog logic into two section (Don Zickus) [1127366]
- [powerpc] powernv: Replace CONFIG_POWERNV_MSI with just CONFIG_PPC_POWERNV (Don Zickus) [1127366]
- [powerpc] pseries: CONFIG_PSERIES_MSI should depend on PPC_PSERIES (Don Zickus) [1127366]
- [powerpc] kernel/sysfs: Cleanup set up macros for PMC/non-PMC SPRs (Don Zickus) [1127366]
- [powerpc] Make irq_stat.timers_irqs counting more specific (Don Zickus) [1127366]
- [powerpc] purge all the prefetched instructions for the coherent icache flush (Don Zickus) [1127366]
- [powerpc] kernel: remove useless code which related with 'max_cpus' (Don Zickus) [1127366]
- [powerpc] boot: Ignore .dtb files (Don Zickus) [1127366]
- [powerpc] Clean up panic_timeout usage (Don Zickus) [1127366]
- [powerpc] kernel: Use 12.12s instead of 12s to avoid memory overflow (Don Zickus) [1127366]
- [powerpc] kvm: optimize "sc 1" as fast return (Don Zickus) [1127366]
- [powerpc] pseries: Fix SMP=n build of rng.c (Don Zickus) [1127366]
- [powerpc] Make cpu_to_chip_id() available when SMP=n (Don Zickus) [1127366]
- [powerpc] vio: Fix a dma_mask issue of vio (Don Zickus) [1127366]
- [powerpc] Only print PACATMSCRATCH in oops when TM is active (Don Zickus) [1127366]
- [powerpc] pseries: Duplicate dtl entries sometimes sent to userspace (Don Zickus) [1127366]
- [powerpc] Remove a few lines of oops output (Don Zickus) [1127366]
- [powerpc] Print DAR and DSISR on machine check oopses (Don Zickus) [1127366]
- [powerpc] Fix __get_user_pages_fast() irq handling (Don Zickus) [1127366]
- [powerpc] eeh: More accurate log (Don Zickus) [1127366]
- [powerpc] eeh: Enable PCI_COMMAND_MASTER for PCI bridges (Don Zickus) [1127366]
- [powerpc] Add pseries_le_defconfig (Don Zickus) [1127366]
- [kernel] uprobes/powerpc: Kill arch_uprobe->ainsn (Don Zickus) [1127366]
- [powerpc] kvm: fix rare but potential deadlock scene (Don Zickus) [1127366]
- [powerpc] add missing explicit OF includes for ppc (Don Zickus) [1127366]
- [powerpc] powernv: Add support for indirect XSCOM via debugfs (Don Zickus) [1127366]
- [powerpc] scom: Improve debugfs interface (Don Zickus) [1127366]
- [powerpc] scom: Enable 64-bit addresses (Don Zickus) [1127366]
- [powerpc] boot: Properly handle the base "of" boot wrapper (Don Zickus) [1127366]
- [powerpc] bpf: Support MOD operation (Don Zickus) [1127366]
- [powerpc] bpf: Fix DIVWU instruction opcode (Don Zickus) [1127366]
- [powerpc] tm: Remove interrupt disable in __switch_to() (Don Zickus) [1127366]
- [powerpc] nvram: Scan partitions only once (Don Zickus) [1127366]
- [powerpc] powernv: Code update interface (Don Zickus) [1127366]
- [powerpc] powernv: Create opal sysfs directory (Don Zickus) [1127366]
- [powerpc] Add VMX optimised xor for RAID5 (Don Zickus) [1127366]
- [powerpc] kexec: kexec_sequence() is in misc_64.S (Don Zickus) [1127366]
- [powerpc] Use 32 bit loads and stores when operating on condition register values (Don Zickus) [1127366]
- [powerpc] Enable multipath modules on ppc64 and pseries (Don Zickus) [1127366]
- [powerpc] pseries: Fix dedicated processor partition detection (Don Zickus) [1127366]
- [powerpc] vio: use strcpy in modalias_show (Don Zickus) [1127366]
- [powerpc] FA_DUMP depends on KEXEC (Don Zickus) [1127366]
- [powerpc] Fix a typo in comments of va to pa conversion (Don Zickus) [1127366]
- [powerpc] Move local setup.h declarations to arch includes (Don Zickus) [1127366]
- [powerpc] Fix warnings for arch/powerpc/mm/numa.c (Don Zickus) [1127366]
- [powerpc] boot: Don't change link address for OF-based platforms (Don Zickus) [1127366]
- [powerpc] Add includes to fix powernv/rng.c build (Don Zickus) [1127366]
- [powerpc] Fix PPC_EMULATED_STATS build break with sync patch (Don Zickus) [1127366]
- [powerpc] select ARCH_MIGHT_HAVE_PC_PARPORT (Don Zickus) [1127366]
- [powerpc] Don't corrupt user registers on 32-bit (Don Zickus) [1127366]
- [powerpc] kgdb: use DEFINE_PER_CPU to allocate kgdb's thread_info (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - drop is_hv_enabled (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Allow the HV and PR selection per virtual machine (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Support building HV and PR KVM as module (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - move PR related tracepoints to a separate header (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Add is_hv_enabled to kvmppc_ops (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Cleanup interrupt handling code (Don Zickus) [1127366]
- [virt] kvm/ppc: Add kvmppc_ops callback (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Add a new config variable CONFIG_KVM_BOOK3S_HV_POSSIBLE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s/pr - Rename KVM_BOOK3S_PR to KVM_BOOK3S_PR_POSSIBLE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - move book3s_64_vio_hv.c into the main kernel binary (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - remove kvmppc_handler_highmem label (Don Zickus) [1127366]
- [powerpc] export debug registers save function for KVM (Don Zickus) [1127366]
- [powerpc] move debug registers in a structure (Don Zickus) [1127366]
- [powerpc] remove unnecessary line continuations (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix vcore leak (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Better handling of exceptions that happen in real mode (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Reduce number of shadow PTEs invalidated by MMU notifiers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Mark pages accessed, and dirty if being written (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Use mmu_notifier_retry() in kvmppc_mmu_map_page() (Don Zickus) [1127366]
- [virt] kvm/ppc: Book3S PR - Better handling of host-side read-only pages (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Move skip-interrupt handlers to common code (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Allocate kvm_vcpu structs from kvm_vcpu_cache (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Make HPT accesses and updates SMP-safe (Don Zickus) [1127366]
- [virt] kvm/ppc: Book3S PR - Correct errors in H_ENTER implementation (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Handle PP0 page-protection bit in guest HPTEs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Use 64k host pages where possible (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Allow guest to use 64k pages (Don Zickus) [1127366]
- [virt] kvm/ppc: Book3S PR - Keep volatile reg values in vcpu rather than shadow_vcpu (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Don't crash host on unknown guest interrupt (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Support POWER6 compatibility mode on POWER7 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add support for guest Program Priority Register (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Store LPCR value for each virtual core (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Avoid unbalanced increments of VPA yield count (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Pull out interrupt-reading code into a subroutine (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Restructure kvmppc_hv_entry to be a subroutine (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Implement H_CONFER (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Add GET/SET_ONE_REG interface for VRSAVE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Implement timebase offset for guests (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Save/restore SIAR and SDAR along with other PMU registers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Reserve POWER8 space in get/set_one_reg (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Rework kvmppc_mmu_book3s_64_xlate() (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Make instruction fetch fallback work for system calls (Don Zickus) [1127366]
- [powerpc] pseries: Move plpar_wrapper.h to powerpc common include/asm location (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Remove dependency of pseries.h file (Don Zickus) [1127366]
- [virt] kvm/ppc: use anon_inode_getfd() with O_CLOEXEC flag (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Load up SPRG3 register with guest value on guest entry (Don Zickus) [1127366]
- [virt] kvm/ppc: Call trace_hardirqs_on before entry (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Allow negative offsets to real-mode hcall handlers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Correct tlbie usage (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Invalidate SLB entries properly (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Allow guest to use 1TB segments (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Don't keep scanning HPTEG after we find a match (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Fix invalidation of SLB entry 0 on guest entry (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Fix proto-VSID calculations (Don Zickus) [1127366]
- [powerpc] Remove the unneeded trigger of decrementer interrupt in decrementer_check_overflow (Don Zickus) [1127366]
- [virt] kvm/ppc: fix imbalance srcu_read_[un]lock() (Don Zickus) [1127366]
- [powerpc] Emulate sync instruction variants (Don Zickus) [1127366]
- [powerpc] eeh: Reorder output messages (Don Zickus) [1127366]
- [powerpc] scom: Use "devspec" rather than "path" in debugfs entries (Don Zickus) [1127366]
- [powerpc] scom: CONFIG_SCOM_DEBUGFS should depend on CONFIG_DEBUG_FS (Don Zickus) [1127366]
- [powerpc] powernv: Add scom support under OPALv3 (Don Zickus) [1127366]
- [powerpc] scom: Create debugfs files using ibm, chip-id if available (Don Zickus) [1127366]
- [powerpc] scom: Add support for "reg" property (Don Zickus) [1127366]
- [powerpc] scom: Change scom_read() and scom_write() to return errors (Don Zickus) [1127366]
- [powerpc] Enable /dev/port when isa_io_special is set (Don Zickus) [1127366]
- [powerpc] Make ftrace endian-safe (Don Zickus) [1127366]
- [powerpc] pseries: Implement arch_get_random_long() based on H_RANDOM (Don Zickus) [1127366]
- [powerpc] Implement arch_get_random_long/int() for powernv (Don Zickus) [1127366]
- [powerpc] Added __cmpdi2 for signed 64bit comparision (Don Zickus) [1127366]
- [powerpc] Fix section mismatch warning in free_lppacas (Don Zickus) [1127366]
- [powerpc] ppc64: Remove the unneeded load of ti_flags in resume_kernel (Don Zickus) [1127366]
- [powerpc] legacy_serial: Fix incorrect placement of __initdata tag (Don Zickus) [1127366]
- [serial] tty/hvc_opal: powerpc - Make OPAL HVC device tree accesses endian safe (Don Zickus) [1127366]
- [powerpc] powernv: Fix some PCI sparse errors and one LE bug (Don Zickus) [1127366]
- [powerpc] add explicit OF includes (Don Zickus) [1127366]
- [powerpc] clean-up include ordering in prom.h (Don Zickus) [1127366]
- [powerpc] Tell about irq stack coverage (Don Zickus) [1127366]
- [powerpc] Fix section mismatch warning for prom_rtas_call (Don Zickus) [1127366]
- [powerpc] Export cpu_to_chip_id() to fix build error (Don Zickus) [1127366]
- [powerpc] xmon: Fix printing of set of CPUs in xmon (Don Zickus) [1127366]
- [powerpc] pseries: Move lparcfg.c to platforms/pseries (Don Zickus) [1127366]
- [powerpc] powernv: Return secondary CPUs to firmware on kexec (Don Zickus) [1127366]
- [powerpc] Cleanup handling of the DSCR bit in the FSCR register (Don Zickus) [1127366]
- [powerpc] Skip emulating & leave interrupts off for kernel program checks (Don Zickus) [1127366]
- [powerpc] Add more exception trampolines for hypervisor exceptions (Don Zickus) [1127366]
- [powerpc] Fix location and rename exception trampolines (Don Zickus) [1127366]
- [powerpc] Add more trap names to xmon (Don Zickus) [1127366]
- [powerpc] pseries: Add a warning in the case of cross-cpu VPA registration (Don Zickus) [1127366]
- [powerpc] Update the 00-Index in Documentation/powerpc (Don Zickus) [1127366]
- [powerpc] Never handle VSX alignment exceptions from kernel (Don Zickus) [1127366]
- [powerpc] Unaligned stores and stmw are broken in emulation code (Don Zickus) [1127366]
- [powerpc] kvm: Copy the pvr value after memset (Don Zickus) [1127366]
- [powerpc] refactor of_get_cpu_node to support other architectures (Don Zickus) [1127366]
- [powerpc] Convert some mftb/mftbu into mfspr (Don Zickus) [1127366]
- [powerpc] pseries: Read and write to the 'compressed' flag of pstore (Don Zickus) [1127366]
- [powerpc] pseries: Remove (de)compression in nvram with pstore enabled (Don Zickus) [1127366]
- [powerpc] Make device tree accesses in HVC VIO console endian safe (Don Zickus) [1127366]
- [powerpc] Make chip-id information available to userspace (Don Zickus) [1127366]
- [powerpc] Use ibm, chip-id property to compute cpu_core_mask if available (Don Zickus) [1127366]
- [powerpc] Pull out cpu_core_mask updates into a separate function (Don Zickus) [1127366]
- [powerpc] Fix denormalized exception handler (Don Zickus) [1127366]
- [powerpc] Remove the redundant flush_fp_to_thread() in setup_sigcontext() (Don Zickus) [1127366]
- [powerpc] powernv: Enable detection of legacy UARTs (Don Zickus) [1127366]
- [powerpc] Check "status" property before adding legacy ISA serial ports (Don Zickus) [1127366]
- [powerpc] Cleanup udbg_16550 and add support for LPC PIO-only UARTs (Don Zickus) [1127366]
- [powerpc] powernv: Add PIO accessors for Power8 LPC bus (Don Zickus) [1127366]
- [powerpc] powernv: Add helper to get ibm, chip-id of a node (Don Zickus) [1127366]
- [powerpc] powernv: Update opal.h to add new LPC and XSCOM functions (Don Zickus) [1127366]
- [powerpc] Better split CONFIG_PPC_INDIRECT_PIO and CONFIG_PPC_INDIRECT_MMIO (Don Zickus) [1127366]
- [powerpc] ppc64: Rename SOFT_DISABLE_INTS with RECONCILE_IRQ_STATE (Don Zickus) [1127366]
- [powerpc] Implement __get_user_pages_fast() (Don Zickus) [1127366]
- [powerpc] Convert platforms to smp_generic_cpu_bootable (Don Zickus) [1127366]
- [powerpc] Add smp_generic_cpu_bootable (Don Zickus) [1127366]
- [powerpc] Remove the symbol __flush_icache_range (Don Zickus) [1127366]
- [powerpc] Move the testing of CPU_FTR_COHERENT_ICACHE into __flush_icache_range (Don Zickus) [1127366]
- [powerpc] pci: Don't use bitfield for force_32bit_msi (Don Zickus) [1127366]
- [powerpc] Remove SAVE_VSRU and REST_VSRU macros (Don Zickus) [1127366]
- [powerpc] Align p_toc (Don Zickus) [1127366]
- [powerpc] kvm/book3s_pr: Return appropriate error when allocation fails (Don Zickus) [1127366]
- [virt] kvm/ppc: Add signed type cast for comparation (Don Zickus) [1127366]
- [powerpc] eeh: Add missing procfs entry for PowerNV (Don Zickus) [1127366]
- [powerpc] pci: fix PCI-e check link issue (Don Zickus) [1127366]
- [powerpc] perf: increase the perf HW events to 6 (Don Zickus) [1127366]
- [powerpc] perf: correct typos in counter enumeration (Don Zickus) [1127366]
- [powerpc] Rename PMU interrupts from CNT to PMI (Don Zickus) [1127366]
- [powerpc] Move opcode definitions from kvm/emulate.c to asm/ppc-opcode.h (Don Zickus) [1127366]
- [powerpc] powernv: Mark pnv_pci_init_ioda2_phb() as __init (Don Zickus) [1127366]
- [powerpc] pseries: Fix a typo in pSeries_lpar_hpte_insert() (Don Zickus) [1127366]
- [powerpc] Fix the corrupt r3 error during MCE handling (Don Zickus) [1127366]
- [powerpc] Access local paca after hard irq disabled (Don Zickus) [1127366]
- [powerpc] Revert: hw_breakpoints: Fix racy access to ptrace breakpoints (Don Zickus) [1127366]
- [powerpc] kvm: Use 256K chunk to track both RMA and hash page table allocation (Don Zickus) [1127366]
- [powerpc] kvm: Contiguous memory allocator based RMA allocation (Don Zickus) [1127366]
- [powerpc] kvm: Contiguous memory allocator based hash page table allocation (Don Zickus) [1127366]
- [powerpc] Remove savemaxmem parameter setup (Don Zickus) [1127366]
- [powerpc] Handle both new style and old style reserve maps (Don Zickus) [1127366]
- [powerpc] prom: Scan reserved-ranges node for memory reservations (Don Zickus) [1127366]
- [powerpc] perf: Drop MMCRA from thread_struct (Don Zickus) [1127366]
- [powerpc] Remove unreachable relocation on exception handlers (Don Zickus) [1127366]
- [powerpc] eeh: Update MAINTAINERS (Don Zickus) [1127366]
- [powerpc] nvram64: Need return the related error code on failure occurs (Don Zickus) [1127366]
- [powerpc] Set cpu sibling mask before online cpu (Don Zickus) [1127366]
- [powerpc] idle: Convert use of typedef ctl_table to struct ctl_table (Don Zickus) [1127366]
- [powerpc] iommu: Remove unused pci_iommu_init() and pci_direct_iommu_init() (Don Zickus) [1127366]
- [powerpc] Don't flush/invalidate the d/icache for an unknown relocation type (Don Zickus) [1127366]
- [powerpc] Fix string instr. emulation for 32-bit processes on ppc64 (Don Zickus) [1127366]
- [powerpc] Fix typo in ioei_interrupt() description (Don Zickus) [1127366]
- [powerpc] proc: switch to fixed_size_llseek() (Don Zickus) [1127366]
- [powerpc] eeh: Remove eeh_mutex (Don Zickus) [1127366]
- [powerpc] pseries: Enable PSTORE in pseries_defconfig (Don Zickus) [1127366]
- [powerpc] pseries: Use 'true' instead of '1' for orderly_poweroff (Don Zickus) [1127366]
- [powerpc] smp: Use '==' instead of '<' for system_state (Don Zickus) [1127366]
- [cpufreq] Various RHEL cleanups (Prarit Bhargava) [1134369]
- [cpufreq] move policy kobj to update_policy_cpu() (Prarit Bhargava) [1134369]
- [cpufreq] propagate error returned by kobject_move() (Prarit Bhargava) [1134369]
- [cpufreq] don't restore policy->cpus on failure to move kobj (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove core_pct rounding (Prarit Bhargava) [1134369]
- [cpufreq] ondemand: Eliminate the deadband effect (Prarit Bhargava) [1134369]
- [cpufreq] Introduce new relation for freq selection (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Simplify P state adjustment logic (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Align multiple lines to open parenthesis (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Keep values in aperf/mperf in full precision (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove unnecessary intermediate variable sample_time (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add missing blank lines after declarations (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Disable interrupts during MSRs reading (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Fit code in a single line where possible (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Cleanup parentheses (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove unnecessary type casting in div_s64() call (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Make intel_pstate_kobject and debugfs_parent locals (Prarit Bhargava) [1134369]
- [cpufreq] move policy kobj to policy->cpu at resume (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Set CPU number before accessing MSRs (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: don't touch turbo bit if turbo disabled or unavailable (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Fix setting VID (Prarit Bhargava) [1134369]
- [cpufreq] unlock when failing cpufreq_update_policy() (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Correct rounding in busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Correct rounding in busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove duplicate CPU ID check (Prarit Bhargava) [1134369]
- [cpufreq] governor: remove copy_prev_load from 'struct cpu_dbs_common_info' (Prarit Bhargava) [1134369]
- [cpufreq] governor: Be friendly towards latency-sensitive bursty workloads (Prarit Bhargava) [1134369]
- [cpufreq] add support for intermediate (stable) frequencies (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Improve initial busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: add sample time scaling (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove C0 tracking (Prarit Bhargava) [1134369]
- [cpufreq] handle calls to ->target_index() in separate routine (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove unused member name of cpudata (Prarit Bhargava) [1134369]
- [cpufreq] Break out early when frequency equals target_freq (Prarit Bhargava) [1134369]
- [cpufreq] remove race while accessing cur_policy (Prarit Bhargava) [1134369]
- [cpufreq] powernow-k8: Suppress checkpatch warnings (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: remove setting P state to MAX on init (Prarit Bhargava) [1134369]
- [cpufreq] Use cpufreq_for_each_* macros for frequency table iteration (Prarit Bhargava) [1134369]
- [cpufreq] don't print value of .driver_data from core (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Set turbo VID for BayTrail (Prarit Bhargava) [1134369]
- [cpufreq] Fix build error on some platforms that use cpufreq_for_each_* (Prarit Bhargava) [1134369]
- [cpufreq] Catch double invocations of cpufreq_freq_transition_begin/end (Prarit Bhargava) [1134369]
- [cpufreq] Kconfig: Fix spelling errors (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove sample parameter in intel_pstate_calc_busy (Prarit Bhargava) [1134369]
- [cpufreq] Introduce macros for cpufreq_frequency_table iteration (Prarit Bhargava) [1134369]
- [cpufreq] use kzalloc() to allocate memory for cpufreq_frequency_table (Prarit Bhargava) [1134369]
- [cpufreq] create another field .flags in cpufreq_frequency_table (Prarit Bhargava) [1134369]
- [cpufreq] Use sizeof(*ptr) convetion for computing sizes (Prarit Bhargava) [1134369]
- [cpufreq] Convert existing drivers to use cpufreq_freq_transition_{begin|end} (Prarit Bhargava) [1134369]
- [cpufreq] Make cpufreq_notify_transition & cpufreq_notify_post_transition static (Prarit Bhargava) [1134369]
- [cpufreq] Make sure frequency transitions are serialized (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Use del_timer_sync in intel_pstate_cpu_stop (Prarit Bhargava) [1134369]
- [cpufreq] resume drivers before enabling governors (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Set core to min P state during core offline (Prarit Bhargava) [1134369]
- [cpufreq] Add stop CPU callback to cpufreq_driver interface (Prarit Bhargava) [1134369]
- [cpufreq] Remove unnecessary braces (Prarit Bhargava) [1134369]
- [cpufreq] Fix checkpatch errors and warnings (Prarit Bhargava) [1134369]
- [cpufreq] remove unused notifier CPUFREQ_{SUSPENDCHANGE|RESUMECHANGE} (Prarit Bhargava) [1134369]
- [cpufreq] Do not allow ->setpolicy drivers to provide ->target (Prarit Bhargava) [1134369]
- [cpufreq] Skip current frequency initialization for ->setpolicy drivers (Prarit Bhargava) [1134369]
- [cpufreq] Remove unnecessary variable/parameter 'frozen' (Prarit Bhargava) [1134369]
- [cpufreq] Remove cpufreq_generic_exit() (Prarit Bhargava) [1134369]
- [cpufreq] add 'freq_table' in struct cpufreq_policy (Prarit Bhargava) [1134369]
- [cpufreq] Reformat printk() statements (Prarit Bhargava) [1134369]
- [cpufreq] Implement cpufreq_generic_suspend() (Prarit Bhargava) [1134369]
- [cpufreq] suspend governors on system suspend/hibernate (Prarit Bhargava) [1134369]
- [cpufreq] move call to __find_governor() to cpufreq_init_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Initialize governor for a new policy under policy->rwsem (Prarit Bhargava) [1134369]
- [cpufreq] Initialize policy before making it available for others to use (Prarit Bhargava) [1134369]
- [cpufreq] use cpufreq_cpu_get() to avoid cpufreq_get() race conditions (Prarit Bhargava) [1134369]
- [cpufreq] stats: Remove redundant cpufreq_cpu_get() call (Prarit Bhargava) [1134369]
- [cpufreq] stats: Refactor common code into __cpufreq_stats_create_table() (Prarit Bhargava) [1134369]
- [cpufreq] stats: Fix error handling in __cpufreq_stats_create_table() (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: fix pid_reset to use fixed point values (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: remove unneeded sample buffers (Prarit Bhargava) [1134369]
- [cpufreq] Return error if ->get() failed in cpufreq_update_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Mark function as static in cpufreq.c (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Change busy calculation to use fixed point math (Prarit Bhargava) [1134369]
- [cpufreq] Refactor cpufreq_set_policy() (Prarit Bhargava) [1134369]
- [cpufreq] don't call cpufreq_update_policy() on CPU addition (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add support for Baytrail turbo P states (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Use LFM bus ratio as min ratio/P state (Prarit Bhargava) [1134369]
- [cpufreq] powernow-k8: Initialize per-cpu data-structures properly (Prarit Bhargava) [1134369]
- [cpufreq] remove sysfs link when a cpu != policy->cpu, is removed (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove energy reporting from pstate_sample tracepoint (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Take core C0 time into account for core busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: De-register CPU notifier and free struct msr on error (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Adjust the code to use the common boost attribute (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add trace point to report internal state (Prarit Bhargava) [1134369]
- [cpufreq] stats: create sysfs entries when cpufreq_stats is a module (Prarit Bhargava) [1134369]
- [cpufreq] Add boost frequency support in core (Prarit Bhargava) [1134369]
- [cpufreq] introduce cpufreq_generic_get() routine (Prarit Bhargava) [1134369]
- [cpufreq] stats: free table and remove sysfs entry in a single routine (Prarit Bhargava) [1134369]
- [cpufreq] stats: remove hotplug notifiers (Prarit Bhargava) [1134369]
- [cpufreq] stats: handle cpufreq_unregister_driver() and suspend/resume properly (Prarit Bhargava) [1134369]
- [cpufreq] Make sure CPU is running on a freq from freq-table (Prarit Bhargava) [1134369]
- [cpufreq] Introduce cpufreq_notify_post_transition() (Prarit Bhargava) [1134369]
- [cpufreq] send new set of notification for transition failures (Prarit Bhargava) [1134369]
- [cpufreq] Fix timer/workqueue corruption by protecting reading governor_enabled (Prarit Bhargava) [1134369]
- [cpufreq] preserve user_policy across suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Clean up after a failing light-weight initialization (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove periodic P state boost (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add setting voltage value for baytrail P states (Prarit Bhargava) [1134369]
- [cpufreq] remove sysfs files for CPUs which failed to come back after resume (Prarit Bhargava) [1134369]
- [cpufreq] governor: Remove fossil comment in the cpufreq_governor_dbs() (Prarit Bhargava) [1134369]
- [cpufreq] conservative: set requested_freq to policy max when it is over policy max (Prarit Bhargava) [1134369]
- [cpufreq] conservative: fix requested_freq reduction issue (Prarit Bhargava) [1134369]
- [cpufreq] move freq change notifications to cpufreq core (Prarit Bhargava) [1134369]
- [cpufreq] distinguish drivers that do asynchronous notifications (Prarit Bhargava) [1134369]
- [cpufreq] create per policy rwsem instead of per CPU cpu_policy_rwsem (Prarit Bhargava) [1134369]
- [cpufreq] Implement light weight ->target_index() routine (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Fail initialization if driver cannot be registered (Prarit Bhargava) [1134369]
- [cpufreq] Detect spurious invocations of update_policy_cpu() (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Add comment under ACPI_ADR_SPACE_SYSTEM_IO case (Prarit Bhargava) [1134369]
- [cpufreq] remove CONFIG_CPU_FREQ_TABLE (Prarit Bhargava) [1134369]
- [cpufreq] create cpufreq_generic_init() routine (Prarit Bhargava) [1134369]
- [cpufreq] powernow: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] p4: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] pcc: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] call cpufreq_driver->get() after calling ->init() (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] powernow: Use generic cpufreq routines (Prarit Bhargava) [1134369]
- [cpufreq] p4-clockmod: Use generic cpufreq routines (Prarit Bhargava) [1134369]
- [cpufreq] acpi: Use generic cpufreq routines (Prarit Bhargava) [1134369]
- [cpufreq] define generic .attr, .exit() and .verify() routines (Prarit Bhargava) [1134369]
- [cpufreq] use cpufreq_driver->flags to mark CPUFREQ_HAVE_GOVERNOR_PER_POLICY (Prarit Bhargava) [1134369]
- [cpufreq] rename __cpufreq_set_policy() as cpufreq_set_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Remove extra blank line (Prarit Bhargava) [1134369]
- [cpufreq] don't break string in print statements (Prarit Bhargava) [1134369]
- [cpufreq] remove __cpufreq_remove_dev() (Prarit Bhargava) [1134369]
- [cpufreq] remove invalid comment from __cpufreq_remove_dev() (Prarit Bhargava) [1134369]
- [cpufreq] make return type of lock_policy_rwsem_{read|write}() as void (Prarit Bhargava) [1134369]
- [cpufreq] powernow: use cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] p4-clockmod: use cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: use cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] Add new helper cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] pcc_freq: convert acpi_get_handle() to acpi_has_method() (Prarit Bhargava) [1134369]
- [cpufreq] return EEXIST instead of EBUSY for second registering (Prarit Bhargava) [1134369]
- [cpufreq] unlock correct rwsem while updating policy->cpu (Prarit Bhargava) [1134369]
- [cpufreq] Clear policy->cpus bits in __cpufreq_remove_dev_finish() (Prarit Bhargava) [1134369]
- [cpufreq] Acquire the lock in cpufreq_policy_restore() for reading (Prarit Bhargava) [1134369]
- [cpufreq] Prevent problems in update_policy_cpu() if last_cpu == new_cpu (Prarit Bhargava) [1134369]
- [cpufreq] Restructure if/else block to avoid unintended behavior (Prarit Bhargava) [1134369]
- [cpufreq] Fix crash in cpufreq-stats during suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Revert: make sure frequency transitions are serialized (Prarit Bhargava) [1134369]
- [cpufreq] Use signed type for 'ret' variable, to store negative error values (Prarit Bhargava) [1134369]
- [cpufreq] Remove temporary fix for race between CPU hotplug and sysfs-writes (Prarit Bhargava) [1134369]
- [cpufreq] Synchronize the cpufreq store_*() routines with CPU hotplug (Prarit Bhargava) [1134369]
- [cpufreq] Invoke __cpufreq_remove_dev_finish() after releasing cpu_hotplug.lock (Prarit Bhargava) [1134369]
- [cpufreq] Split __cpufreq_remove_dev() into two parts (Prarit Bhargava) [1134369]
- [cpufreq] Fix wrong time unit conversion (Prarit Bhargava) [1134369]
- [cpufreq] serialize calls to __cpufreq_governor() (Prarit Bhargava) [1134369]
- [cpufreq] don't allow governor limits to be changed when it is disabled (Prarit Bhargava) [1134369]
- [cpufreq] Don't use smp_processor_id() in preemptible context (Prarit Bhargava) [1134369]
- [cpufreq] governor: Fix typos in comments (Prarit Bhargava) [1134369]
- [cpufreq] governors: Remove duplicate check of target freq in supported range (Prarit Bhargava) [1134369]
- [cpufreq] Fix timer/workqueue corruption due to double queueing (Prarit Bhargava) [1134369]
- [cpufreq] fix bad unlock balance on !CONFIG_SMP (Prarit Bhargava) [1134369]
- [cpufreq] Fix white space in __cpufreq_remove_dev() (Prarit Bhargava) [1134369]
- [cpufreq] remove unnecessary check in __cpufreq_governor() (Prarit Bhargava) [1134369]
- [cpufreq] remove policy from cpufreq_policy_list during suspend (Prarit Bhargava) [1134369]
- [cpufreq] remove cpufreq_policy_cpu per-cpu variable (Prarit Bhargava) [1134369]
- [cpufreq] Use cpufreq_policy_list for iterating over policies (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Use cpufreq_freq_attr_rw to define the cpb attribute (Prarit Bhargava) [1134369]
- [cpufreq] ondemand: Remove redundant return statement (Prarit Bhargava) [1134369]
- [cpufreq] improve error checking on return values of __cpufreq_governor() (Prarit Bhargava) [1134369]
- [cpufreq] Fix broken usage of governor->owner's refcount (Prarit Bhargava) [1134369]
- [cpufreq] Store cpufreq policies in a list (Prarit Bhargava) [1134369]
- [cpufreq] Give consistent names to cpufreq_policy objects (Prarit Bhargava) [1134369]
- [cpufreq] Clean up header files included in the core (Prarit Bhargava) [1134369]
- [cpufreq] Pass policy to cpufreq_add_policy_cpu() (Prarit Bhargava) [1134369]
- [cpufreq] Avoid double kobject_put() for the same kobject in error code path (Prarit Bhargava) [1134369]
- [cpufreq] Preserve policy structure across suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Perform light-weight init/teardown during suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Do not hold driver module references for additional policy CPUs (Prarit Bhargava) [1134369]
- [cpufreq] Don't pass CPU to cpufreq_add_dev_{symlink|interface}() (Prarit Bhargava) [1134369]
- [cpufreq] Introduce a flag ('frozen') to separate full vs temporary init/teardown (Prarit Bhargava) [1134369]
- [cpufreq] Extract the handover of policy cpu to a helper function (Prarit Bhargava) [1134369]
- [cpufreq] Add helper to perform alloc/free of policy structure (Prarit Bhargava) [1134369]
- [cpufreq] Extract non-interface related stuff from cpufreq_add_dev_interface (Prarit Bhargava) [1134369]
- [cpufreq] Fix misplaced call to cpufreq_update_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Remove unused function __cpufreq_driver_getavg() (Prarit Bhargava) [1134369]
- [cpufreq] ondemand: Change the calculation of target frequency (Prarit Bhargava) [1134369]
- [cpufreq] Remove unused APERF/MPERF support (Prarit Bhargava) [1134369]
- [char] hwrng: Add a driver for the hwrng found in power7+ systems (Steve Best) [1123116]

* Tue Sep 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-161.el7]
- [target] iscsi: Explicily clear login response PDU in exception path (Andy Grover) [1129387]
- [target] iscsi: Avoid rejecting incorrect ITT for Data-Out (Andy Grover) [1129387]
- [target] Fix left-over se_lun->lun_sep pointer OOPs (Andy Grover) [1129387]
- [infiniband] ulp/isert: Wait for proper cleanup before unloading (Andy Grover) [1129387]
- [infiniband] ulp/isert: Improve cm events handling (Andy Grover) [1129387]
- [target] Explicitly clear ramdisk_mcp backend pages (Andy Grover) [1129387]
- [target] Report correct response length for some commands (Andy Grover) [1129387]
- [target] iscsi: Fix ABORT_TASK + connection reset iscsi_queue_req memory leak (Andy Grover) [1129387]
- [target] Use complete_all for se_cmd->t_transport_stop_comp (Andy Grover) [1129387]
- [target] lio: Set CMD_T_ACTIVE bit for Task Management Requests (Andy Grover) [1129387]
- [target] iscsi, iser: Fix hangs in connection teardown (Andy Grover) [1129387]
- [infiniband] iser: Bail from accept_np if np_thread is trying to close (Andy Grover) [1129387]
- [target] iscsi: Reject mutual authentication with reflected CHAP_C (Andy Grover) [1129387]
- [target] Fix alua_access_state attribute OOPs for un-configured devices (Andy Grover) [1129387]
- [infiniband] iser: Add missing target_put_sess_cmd for ImmedateData failure (Andy Grover) [1129387]
- [target] Don't allow setting WC emulation if device doesn't support (Andy Grover) [1129387]
- [infiniband] iser: Add missing se_cmd put for WRITE_PENDING in tx_comp_err (Andy Grover) [1129387]
- [target] iscsi: Fix ERL=2 ASYNC_EVENT connection pointer bug (Andy Grover) [1129387]
- [infiniband] ib_srpt: Use correct ib_sg_dma primitives (Andy Grover) [1129387]
- [infiniband] iser: Fix post_send_buf_count for RDMA READ/WRITE (Andy Grover) [1129387]
- [target] iscsi, iser: Fix isert_conn->state hung shutdown issues (Andy Grover) [1129387]
- [target] iscsi, iser:  Use list_del_init for ->i_conn_node (Andy Grover) [1129387]
- [target] iscsi: Fix iscsit_get_tpg_from_np tpg_state bug (Andy Grover) [1129387]
- [target] Update hw_max_sectors based on current block_size (Andy Grover) [1129387]
- [target] iscsi: Fix-up all zero data-length CDBs with R/W_BIT set (Andy Grover) [1129387]
- [target] Allow READ_CAPACITY opcode in ALUA Standby access state (Andy Grover) [1129387]
- [target] iscsi: Fix wrong buffer / buffer overrun in iscsi_change_param_value() (Andy Grover) [1129387]
- [target] iscsi: Fix multi network portal shutdown regression (Andy Grover) [1129387]
- [target] iscsi, iser: Avoid accepting transport connections during stop stage (Andy Grover) [1129387]
- [infiniband] ulp/isert: Fix iscsit_accept_np and rdma_cm racy flow (Andy Grover) [1129387]
- [infiniband] ulp/isert: Fix wrong connection requests list addition (Andy Grover) [1129387]
- [scsi] hpsa: do not require board "not ready" status after hard reset (Tomas Henzl) [1069185]
- [scsi] hpsa: make tech preview info more verbose (Tomas Henzl) [1083556]
- [scsi] hpsa: fix bad -ENOMEM return value in hpsa_big_passthru_ioctl (Tomas Henzl) [1069185]
- [scsi] hpsa: remove online devices from offline device list (Tomas Henzl) [1069185]
- [scsi] hpsa: fix non-x86 builds (Tomas Henzl) [1069185]
- [scsi] hpsa: do not unconditionally copy sense data (Tomas Henzl) [1069185]
- [scsi] hpsa: fix 6-byte READ/WRITE with 0 length data xfer (Tomas Henzl) [1069185]
- [scsi] hpsa: make hpsa_init_one return -ENOMEM if allocation of h->lockup_detected fails (Tomas Henzl) [1069185]
- [scsi] hpsa: fix handling of hpsa_volume_offline return value (Tomas Henzl) [1069185]
- [scsi] hpsa: return -ENOMEM not -1 on kzalloc failure in hpsa_get_device_id (Tomas Henzl) [1069185]
- [scsi] hpsa: remove messages about volume status VPD inquiry page not supported (Tomas Henzl) [1069185]
- [scsi] hpsa: report check condition even if no sense data present for ioaccel2 mode (Tomas Henzl) [1069185]
- [scsi] hpsa: remove bad unlikely annotation from device list updating code (Tomas Henzl) [1069185]
- [scsi] hpsa: fix event filtering to prevent excessive rescans with old firmware (Tomas Henzl) [1069185]
- [scsi] hpsa: kill annoying messages about SSD Smart Path retries (Tomas Henzl) [1069185]
- [scsi] hpsa: define extended_report_lun_entry data structure (Tomas Henzl) [1069185]
- [scsi] hpsa: Rearrange start_io to avoid one unlock/lock sequence in main io path (Tomas Henzl) [1069185]
- [scsi] hpsa: avoid unnecessary readl on every command submission (Tomas Henzl) [1069185]
- [scsi] hpsa: use per-cpu variable for lockup_detected (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unnecessary pci_set_drvdata() (Tomas Henzl) [1069185]
- [scsi] hpsa: set irq affinity hints to route MSI-X vectors across CPUs (Tomas Henzl) [1069185]
- [scsi] hpsa: allocate reply queues individually (Tomas Henzl) [1069185]
- [scsi] hpsa: choose number of reply queues more intelligently (Tomas Henzl) [1069185]
- [scsi] hpsa: remove dev_dbg() calls from hot paths (Tomas Henzl) [1069185]
- [scsi] hpsa: use gcc aligned attribute instead of manually padding structs (Tomas Henzl) [1069185]
- [scsi] hpsa: change doorbell reset delay to ten seconds (Tomas Henzl) [1069185]
- [scsi] hpsa: allow passthru ioctls to work with bidirectional commands (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unused fields from struct ctlr_info (Tomas Henzl) [1069185]
- [scsi] hpsa: fix bad comparison of signed with unsigned in hpsa_update_scsi_devices (Tomas Henzl) [1069185]
- [scsi] hpsa: do not ignore failure of sense controller parameters command (Tomas Henzl) [1069185]
- [scsi] hpsa: fix memory leak in hpsa_hba_mode_enabled (Tomas Henzl) [1069185]
- [scsi] hpsa: Checking for a NULL return from a kzalloc call (Tomas Henzl) [1069185]
- [scsi] hpsa: fix NULL dereference in hpsa_put_ctlr_into_performant_mode() (Tomas Henzl) [1069185]
- [scsi] hpsa: update driver version to 3.4.4-1 (Tomas Henzl) [1069185]
- [scsi] hpsa: fix bad endif placement in RAID 5 mapper code (Tomas Henzl) [1069185]
- [scsi] hpsa: Do not zero fields of ioaccel2 command structure twice (Tomas Henzl) [1069185]
- [scsi] hpsa: Add hba mode to the hpsa driver (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unused struct request from CommandList (Tomas Henzl) [1069185]
- [scsi] hpsa: increase the probability of a reported success after a device reset (Tomas Henzl) [1069185]
- [scsi] hpsa: bring format-in-progress drives online when ready (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unused kthread.h header (Tomas Henzl) [1069185]
- [scsi] hpsa: Add support for a few HP Storage controllers (Tomas Henzl) [1069185]
- [scsi] hpsa: add HP/3PAR vendor id to pci_ids.h (Tomas Henzl) [1069185]
- [scsi] hpsa: add sysfs debug switch for raid map debugging messages (Tomas Henzl) [1069185]
- [scsi] hpsa: improve error messages for driver initiated commands (Tomas Henzl) [1069185]
- [scsi] hpsa: only do device rescan for certain events (Tomas Henzl) [1069185]
- [scsi] hpsa: when switching out of accel mode await only accel command completions (Tomas Henzl) [1069185]
- [scsi] hpsa: add controller base data-at-rest encryption compatibility ioaccel2 (Tomas Henzl) [1069185]
- [scsi] hpsa: update source file copyrights (Tomas Henzl) [1069185]
- [scsi] hpsa: retry certain ioaccel error cases on the RAID path (Tomas Henzl) [1069185]
- [scsi] hpsa: do not inquire for unsupported ioaccel status vpd page (Tomas Henzl) [1069185]
- [scsi] hpsa: allow VPD page zero to be queried (Tomas Henzl) [1069185]
- [scsi] hpsa: rescan devices on ioaccel2 error (Tomas Henzl) [1069185]
- [scsi] hpsa: allow user to disable accelerated i/o path (Tomas Henzl) [1069185]
- [scsi] hpsa: complete the ioaccel raidmap code (Tomas Henzl) [1069185]
- [scsi] hpsa: make device update copy the raid map also (Tomas Henzl) [1069185]
- [scsi] hpsa: add task management for ioaccel mode 2 (Tomas Henzl) [1069185]
- [scsi] hpsa: teach hpsa_device_reset to do either target or lun reset (Tomas Henzl) [1069185]
- [scsi] hpsa: get ioaccel mode 2 i/o working (Tomas Henzl) [1069185]
- [scsi] hpsa: initialize controller to perform io accelerator mode 2 (Tomas Henzl) [1069185]
- [scsi] hpsa: get physical device handles for io accel mode 2 as well as mode 1 (Tomas Henzl) [1069185]
- [scsi] hpsa: do ioaccel mode 2 resource allocations (Tomas Henzl) [1069185]
- [scsi] hpsa: Acknowledge controller events in ioaccell mode 2 as well as mode 1 (Tomas Henzl) [1069185]
- [scsi] hpsa: add ioaccel mode 2 structure definitions (Tomas Henzl) [1069185]
- [scsi] hpsa: complain if physical or logical aborts are not supported (Tomas Henzl) [1069185]
- [scsi] hpsa: add hp_ssd_smart_path_enabled sysfs attribute (Tomas Henzl) [1069185]
- [scsi] hpsa: do not rescan controllers known to be locked up (Tomas Henzl) [1069185]
- [scsi] hpsa: poll controller to detect device change event (Tomas Henzl) [1069185]
- [scsi] hpsa: update raid offload status on device rescan (Tomas Henzl) [1069185]
- [scsi] hpsa: add ioaccell mode 1 RAID offload support (Tomas Henzl) [1069185]
- [scsi] hpsa: fix task management for mode-1 ioaccell path (Tomas Henzl) [1069185]
- [scsi] hpsa: only allow REQ_TYPE_FS to use fast path (Tomas Henzl) [1069185]
- [scsi] hpsa: add support for 'fastpath' i/o (Tomas Henzl) [1069185]
- [scsi] hpsa: mark last scatter gather element as the last (Tomas Henzl) [1069185]
- [scsi] hpsa: use extended report luns command for HP SSD SmartPath (Tomas Henzl) [1069185]
- [scsi] hpsa: fixup MSI-X registration (Tomas Henzl) [1069185]
- [scsi] hpsa: prevent stalled i/o (Tomas Henzl) [1069185]
- [scsi] hpsa: cap CCISS_PASSTHRU at 20 concurrent commands (Tomas Henzl) [1069185]
- [scsi] hpsa: add MSA 2040 to list of external target devices (Tomas Henzl) [1069185]
- [scsi] hpsa: fix memory leak in CCISS_BIG_PASSTHRU ioctl (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unneeded include of seq_file.h (Tomas Henzl) [1069185]
- [scsi] hpsa: add 5 second delay after doorbell reset (Tomas Henzl) [1069185]
- [scsi] hpsa: do not attempt to flush the cache on locked up controllers (Tomas Henzl) [1069185]
- [scsi] bnx2i: Make boot_nic entry visible in the sysfs session objects (Maurizio Lombardi) [1139139]
- [scsi] bnx2fc: fix incorrect DMA memory mapping in bnx2fc_unmap_sg_list() (Maurizio Lombardi) [1102526]
- [ethernet] cnic: Replace rcu_dereference() with rcu_access_pointer() (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Rebranding cnic driver (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Fix missing ISCSI_KEVENT_IF_DOWN message (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Update version to 2.5.20 and copyright year (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Use proper ulp_ops for per device operations (Maurizio Lombardi) [1089401]
- [ethernet] broadcom: Remove extern from function prototypes (Maurizio Lombardi) [1089401]
- [scsi] bnx2i: Update driver version to 2.7.10.1 (Maurizio Lombardi) [1089400]
- [scsi] bnx2i: Rebranding bnx2i driver (Maurizio Lombardi) [1089400]
- [scsi] bnx2i, be2iscsi: fix custom stats length (Maurizio Lombardi) [1089400]
- [ethernet] cnic, bnx2i, bnx2fc: Fix inconsistent use of page size (Maurizio Lombardi) [1089400 1089399 1089401]
- [scsi] bnx2fc: Rebranding bnx2fc driver (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: do not scan uninitialized lists in case of error (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: fix memory leak in bnx2fc_allocate_hash_table() (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: fix memory leak and potential NULL pointer dereference (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: remove unused variable hash_table_size (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: Updated version to 2.4.2 (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: Fixed the handling for the SCSI retry delay (Maurizio Lombardi) [1089399]
- [scsi] be2iscsi: Bump driver version (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix processing CQE before connection resources are freed (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix updating the boot enteries in sysfs (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix the copyright year (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix the sparse warning introduced in previous submission (Rob Evers) [1130072]

* Mon Sep 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-160.el7]
- [x86] module: work around kabi module breakage when 16K stacks are enabled (Kyle McMartin) [1108378]
- [kernel] redhat: bump RHEL_MINOR to 1 (Kyle McMartin) [1108378]
- [kernel] modules: export check_module_rhelversion (Kyle McMartin) [1108378]
- [kernel] modules: Add module_ext struct (Prarit Bhargava) [1110315]
- [kernel] modules: add rhelversion MODULE_INFO tag (Kyle McMartin) [1110315]
- [x86] expand 64-bit kernel stack to 16K (Johannes Weiner) [1108378]

* Mon Sep 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-159.el7]
- [ethernet] bna: Support TSO and partial checksum with non-accelerated vlans (Ivan Vecera) [1136912]
- [ethernet] bna: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1136912]
- [ethernet] bna: fix performance regression (Ivan Vecera) [1136912]
- [ethernet] bna: fill the magic in bnad_get_eeprom() instead of validating (Ivan Vecera) [1136912]
- [ethernet] bna: remove unnecessary break after return (Ivan Vecera) [1136912]
- [ethernet] bna: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Ivan Vecera) [1136912]
- [ethernet] bna: get rid of SET_ETHTOOL_OPS (Ivan Vecera) [1136912]
- [ethernet] bna: remove open-coded skb_cow_head (Ivan Vecera) [1136912]
- [ethernet] bna: Call dev_kfree_skb_any instead of dev_kfree_skb (Ivan Vecera) [1136912]
- [ethernet] bna: Convert uses of __constant_<foo> to <foo> (Ivan Vecera) [1136912]
- [ethernet] bna: Replace large udelay() with mdelay() (Ivan Vecera) [1136912]
- [ethernet] bna: Use pci_enable_msix_range() instead of pci_enable_msix() (Ivan Vecera) [1136912]
- [ethernet] bna: bnad code cleanup (Ivan Vecera) [1136912]
- [ethernet] e1000: fix possible reset_task running after adapter down (John Greene) [1091129]
- [ethernet] e1000: prevent oops when adapter is being closed and reset simultaneously (John Greene) [1091129]
- [ethernet] r8169: add missing MODULE_FIRMWARE (Ivan Vecera) [1139247]
- [ethernet] r8169: add support for RTL8168H and RTL8107E (Ivan Vecera) [1139247]
- [ethernet] r8169: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1139247]
- [ethernet] r8169: Enable RX_MULTI_EN for RTL_GIGA_MAC_VER_40 (Ivan Vecera) [1139247]
- [ethernet] r8169: support IPv6 (Ivan Vecera) [1139247]
- [ethernet] r8169: use Giant Send (Ivan Vecera) [1139247]
- [ethernet] r8169: split rtl8169_tso_csum (Ivan Vecera) [1139247]
- [ethernet] r8169: disable L23 (Ivan Vecera) [1139247]
- [ethernet] r8169: get rid of SET_ETHTOOL_OPS (Ivan Vecera) [1139247]
- [ethernet] r8169: Call dev_kfree_skby_any instead of dev_kfree_skb (Ivan Vecera) [1139247]
- [ethernet] r8169: fix the incorrect tx descriptor version (Ivan Vecera) [1139247]
- [ethernet] r8169: initialize rtl8169_stats seqlock (Ivan Vecera) [1139247]
- [ethernet] r8169: delete non-required instances of include <linux/init.h> (Ivan Vecera) [1139247]
- [ethernet] bnx2: Remove DEFINE_PCI_DEVICE_TABLE macro use (Michal Schmidt) [1092495]
- [ethernet] bnx2: Rebranding bnx2 driver (Michal Schmidt) [1092495]
- [ethernet] bnx2: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Michal Schmidt) [1092495]
- [ethernet] bnx2: Don't build unused suspend/resume functions not enabled (Michal Schmidt) [1092495]
- [ethernet] bnx2: Don't receive packets when the napi budget == 0 (Michal Schmidt) [1092495]
- [ethernet] bnx2: Call dev_kfree_skby_any instead of dev_kfree_skb (Michal Schmidt) [1092495]
- [ethernet] bnx2: Use pci_enable_msix_range() instead of pci_enable_msix() (Michal Schmidt) [1092495]
- [ethernet] bnx2: delete non-required instances of include <linux/init.h> (Michal Schmidt) [1092495]
- [ethernet] ixgbevf: Remove unused get_supported_physical_layer pointer (John Greene) [1091124]
- [ethernet] ixgbevf: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (John Greene) [1091124]
- [ethernet] ixgbevf: get rid of SET_ETHTOOL_OPS (John Greene) [1091124]
- [ethernet] ixgbevf: remove 82599 from the module description (John Greene) [1091124]
- [ethernet] ixgbevf: remove open-coded skb_cow_head (John Greene) [1091124]
- [ethernet] ixgbevf: Add bit to mark work queue initialization (John Greene) [1091124]
- [ethernet] ixgbevf: Fix rcu warnings induced by LER (John Greene) [1091124]
- [ethernet] ixgbevf: Change ixgbe_read_reg to ixgbevf_read_reg (John Greene) [1091124]
- [ethernet] ixgbevf: Additional adapter removal checks (John Greene) [1091124]
- [ethernet] ixgbevf: Check for adapter removal on register writes (John Greene) [1091124]
- [ethernet] ixgbevf: Check register reads for adapter removal (John Greene) [1091124]
- [ethernet] ixgbevf: Make the ethtool register test use accessors (John Greene) [1091124]
- [ethernet] ixgbevf: Use static inlines instead of macros (John Greene) [1091124]
- [ethernet] ixgbevf: Convert uses of __constant_<foo> to <foo> (John Greene) [1091124]
- [ethernet] ixgbevf: Protect ixgbevf_down with __IXGBEVF_DOWN bit (John Greene) [1091124]
- [ethernet] ixgbevf: Indicate removal state explicitly (John Greene) [1091124]
- [ethernet] ixgbevf: delete unneeded call to pci_set_power_state (John Greene) [1091124]
- [ethernet] ixgbevf: fix skb->pkt_type checks (John Greene) [1091124]
- [ethernet] ixgbevf: add check for CHECKSUM_PARTIAL when doing TSO (John Greene) [1091124]
- [ethernet] ixgbevf: fix handling of tx checksumming (John Greene) [1091124]
- [ethernet] ixgbevf: Use pci_enable_msix_range() instead of pci_enable_msix() (John Greene) [1091124]
- [ethernet] ixgbevf: merge ixgbevf_tx_map and ixgbevf_tx_queue into a single function (John Greene) [1091124]
- [ethernet] ixgbevf: redo dma mapping using the tx buffer info (John Greene) [1091124]
- [ethernet] ixgbevf: make the first tx_buffer a repository for most of the skb info (John Greene) [1091124]
- [ethernet] ixgbevf: add tx counters (John Greene) [1091124]
- [ethernet] ixgbevf: remove counters for Tx/Rx checksum offload (John Greene) [1091124]
- [ethernet] ixgbevf: move ring specific stats into ring specific structure (John Greene) [1091124]
- [ethernet] ixgbevf: make use of the dev pointer in the ixgbevf_ring struct (John Greene) [1091124]
- [ethernet] ixgbevf: bump version (John Greene) [1091124]
- [ethernet] ixgbevf: create function for all of ring init (John Greene) [1091124]
- [ethernet] ixgbevf: Convert ring storage form pointer to an array to array of pointers (John Greene) [1091124]
- [ethernet] ixgbevf: use pci drvdata correctly in ixgbevf_suspend() (John Greene) [1091124]
- [ethernet] ixgbevf: set the disable state when ixgbevf_qv_disable is called (John Greene) [1091124]
- [ethernet] ixgbevf: add DCB configuration into queue setup (John Greene) [1091124]
- [ethernet] ixgbe: Focus config of head, tail ntc, and ntu all into a single function (John Greene) [1091124]
- [ethernet] ixgbe: cleanup IXGBE_DESC_UNUSED (John Greene) [1091124]
- [ethernet] ixgbevf: remove redundant workaround (John Greene) [1091124]
- [ethernet] ixgbevf: Add zero_base handler to network statistics (John Greene) [1091124]
- [ethernet] ixgbevf: add BP_EXTENDED_STATS for CONFIG_NET_RX_BUSY_POLL (John Greene) [1091124]
- [ethernet] ixgbevf: implement CONFIG_NET_RX_BUSY_POLL (John Greene) [1091124]
- [ethernet] ixgbevf: have clean_rx_irq return total_rx_packets cleaned (John Greene) [1091124]
- [ethernet] ixgbevf: add ixgbevf_rx_skb (John Greene) [1091124]
- [ethernet] ixgbevf: bump driver version (John Greene) [1091124]
- [ethernet] ixgbevf: Remove extern from function prototypes (John Greene) [1091124]
- [ethernet] ixgbevf: Adds function to set PSRTYPE register (John Greene) [1091124]
- [ethernet] ixgbevf: Miscellaneous conversions to ETH_ALEN (John Greene) [1091124]
- [ethernet] ixgbevf: add wait for Rx queue disable (John Greene) [1091123]
- [ethernet] ixgbevf: fix 32-bit DMA mask handling (John Greene) [1091123]
- [ethernet] ixgbe: fix message terminations (John Greene) [1091123]
- [ethernet] ixgbe: clean up Rx time stamping code (John Greene) [1091123]
- [ethernet] ixgbe: remove open-coded skb_cow_head (John Greene) [1091123]
- [ethernet] ixgbe: Add bit to mark service task initialization (John Greene) [1091123]
- [ethernet] ixgbe: Fix rcu warnings induced by LER (John Greene) [1091123]
- [ethernet] ixgbe: Indicate removal state explicitly (John Greene) [1091123]
- [ethernet] ixgbe: fix ixgbe_check_reset_blocked() declaration (John Greene) [1091123]
- [ethernet] ixgbe: fix race conditions on queuing skb for HW time stamp (John Greene) [1091123]
- [ethernet] ixgbe: never generate both software and hardware timestamps (John Greene) [1091123]
- [ethernet] ixgbe: remove redundant if clause from PTP work (John Greene) [1091123]
- [ethernet] ixgbe: Break recursion in case of removal (John Greene) [1091123]
- [ethernet] ixgbe: Stop cacheing if the MNG FW enabled (John Greene) [1091123]
- [ethernet] ixgbe: clean up ixgbe_atr_compute_perfect_hash_82599 (John Greene) [1091123]
- [ethernet] ixgbe: use ixgbe_read_pci_cfg_word (John Greene) [1091123]
- [ethernet] ixgbe: remove unused media type (John Greene) [1091123]
- [ethernet] ixgbe: fix ixgbe_setup_mac_link_82599 autoc variables (John Greene) [1091123]
- [ethernet] ixgbe: fix ixgbe_stop_mac_link_on_d3_82599 to check mng correctly (John Greene) [1091123]
- [ethernet] ixgbe: check Core Clock Disable bit (John Greene) [1091123]
- [ethernet] ixgbe: fix errors related to protected AUTOC calls (John Greene) [1091123]
- [ethernet] ixgbe: Convert uses of __constant_<foo> to <foo> (John Greene) [1091123]
- [ethernet] ixgbe: Don't receive packets when the napi budget == 0 (John Greene) [1091123]
- [ethernet] ixgbe: add ixgbe_write_pci_cfg_word with ixgbe_removed check (John Greene) [1091123]
- [ethernet] ixgbe: fix some multiline hw_dbg prints (John Greene) [1091123]
- [ethernet] ixgbe: fixup header for ixgbe_set_rxpba_82598 (John Greene) [1091123]
- [ethernet] ixgbe: add Linux NICS mailing list to contact info (John Greene) [1091123]
- [ethernet] ixgbe: move setting rx_pb_size into get_invariants (John Greene) [1091123]
- [ethernet] ixgbe: Fix format string in ixgbe_fcoe.c (John Greene) [1091123]
- [ethernet] ixgbe: ixgbe calls skb_set_hash (John Greene) [1091123]
- [ethernet] ixgbe: implement SIOCGHWTSTAMP ioctl (John Greene) [1091123]
- [ethernet] ixgbe: Check config reads for removal (John Greene) [1091123]
- [ethernet] ixgbe: Fix up some ethtool results when adapter is removed (John Greene) [1091123]
- [ethernet] ixgbe: Restore hw_addr in LER recovery paths (John Greene) [1091123]
- [ethernet] ixgbe: Additional adapter removal checks (John Greene) [1091123]
- [ethernet] ixgbe: Check for adapter removal on register writes (John Greene) [1091123]
- [ethernet] ixgbe: Check register reads for adapter removal (John Greene) [1091123]
- [ethernet] ixgbe: Use static inlines instead of macros (John Greene) [1091123]
- [ethernet] ixgbe: Add check for FW veto bit (John Greene) [1091123]
- [ethernet] ixgbe: fix bit toggled for 82599 reset fix (John Greene) [1091123]
- [ethernet] ixgbe: collect all 82599 AUTOC code in one function (John Greene) [1091123]
- [ethernet] ixgbe: Remove extern from function prototypes (John Greene) [1091123]
- [ethernet] ixgbe: fix to use correct timeout interval for memory read completion (John Greene) [1091123]
- [ethernet] ixgbe: Add WoL support for a new device (John Greene) [1091123]
- [ethernet] ixgbe: don't use magic size number to assign ptp_caps.name (John Greene) [1091123]
- [ethernet] ixgbe: modify behavior on receiving a HW ECC error (John Greene) [1091123]
- [ethernet] ixgbe: Use pci_enable_msix_range() instead of pci_enable_msix() (John Greene) [1091123]
- [ethernet] ixgbe: bump version number (John Greene) [1091123]
- [ethernet] ixgbe: add braces around else condition in ixgbe_qv_lock_* calls (John Greene) [1091123]
- [ethernet] ixgbe: fix qv_lock_napi call in ixgbe_napi_disable_all (John Greene) [1091123]
- [ethernet] ixgbe: Reduce memory consumption with larger page sizes (John Greene) [1091123]
- [ethernet] ixgbe: Cleanup the use of tabs and spaces (John Greene) [1091124 1091123]

* Fri Sep 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-158.el7]
- [net] ipv4: implement igmp_qrv sysctl to tune igmp robustness variable (Hannes Frederic Sowa) [1110118]
- [net] ipv6: add sysctl_mld_qrv to configure query robustness variable (Hannes Frederic Sowa) [1110118]
- [net] rtnetlink: wait for unregistering devices in rtnl_link_unregister() (Florian Westphal) [1133741]
- [net] netns: Delay default_device_exit_batch until no devices are unregistering (Florian Westphal) [1133741]
- [net] netfilter: ctnetlink: fix refcnt leak in dying/unconfirmed list dumper (Florian Westphal) [1043012]
- [net] netfilter: ctnetlink: fix dumping of dying/unconfirmed conntracks (Florian Westphal) [1043012]
- [net] netfilter: nf_conntrack: initialize net.ct.generation (Florian Westphal) [1043012]
- [net] netfilter: conntrack: Fix UP builds (Florian Westphal) [1043012]
- [net] netfilter: conntrack: remove central spinlock nf_conntrack_lock (Florian Westphal) [1043012]
- [net] netfilter: conntrack: seperate expect locking from nf_conntrack_lock (Florian Westphal) [1043012]
- [net] netfilter: avoid race with exp->master ct (Florian Westphal) [1043012]
- [net] netfilter: conntrack: spinlock per cpu to protect special lists (Florian Westphal) [1043012]
- [net] netfilter: trivial code cleanup and doc changes (Florian Westphal) [1043012]
- [net] sctp: fix ABI mismatch through sctp_assoc_to_state helper (Daniel Borkmann) [1135389]
- [net] tcp: tsq: fix nonagle handling (Jiri Pirko) [1134402]
- [netdrv] veth: extend features to support tunneling (Florian Westphal) [1098138]
- [net] openvswitch: fix panic with multiple vlan headers (Jiri Benc) [1133109]
- [net] netfilter: synproxy target: restrict to INPUT/FORWARD (Jesper Brouer) [1081339]
- [net] fix rtnl notification in atomic context (Jiri Pirko) [1113925]
- [net] always advertise rx_flags changes via netlink (Jiri Pirko) [1113925]
- [net] update __dev_notify_flags() to send rtnl msg (Jiri Pirko) [1113925]

* Fri Sep 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-157.el7]
- [scsi] fusion: Remove use of DEF_SCSI_QCMD (Tomas Henzl) [1041675]
- [scsi] fusion: Add free msg frames to the head, not tail of list (Tomas Henzl) [1041675]
- [scsi] mpt2sas: Add free smids to the head, not tail of list (Tomas Henzl) [1041675]
- [scsi] mpt2sas: Remove use of DEF_SCSI_QCMD (Tomas Henzl) [1041675]
- [scsi] mpt2sas: Remove uses of serial_number (Tomas Henzl) [1041675]
- [scsi] mpt3sas: Remove use of DEF_SCSI_QCMD (Tomas Henzl) [1041675]
- [scsi] mpt3sas: Remove uses of serial_number (Tomas Henzl) [1041675]
- [scsi] qla4xxx: 5.04.00.04.07.01-k0 (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Improve loopback failure messages (Chad Dupuis) [1089349]
- [scsi] qla4xxx: from treewide: fix comments and printk msgs (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Use kmemdup instead of kmalloc + memcpy (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Fix smatch warning in func qla4xxx_conn_get_param (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Fix smatch warning in func qla4xxx_get_ep_param (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Fix memory leak for ha->saved_acb (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Export sysfs DDBs from DPC handler (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Disable INTx interrupt for ISP82XX (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Check for correct return status (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Move qla4_8xxx_ms_mem_write_128b to ql4_nx.c (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Added PEX DMA Support for ISP8022 Adapter (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Added new opcodes for 84XX Minidump template (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Add support of 0xFF capture mask for minidump (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Change default capture to firmware defined capture mask (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Add support for ISCSI_PARAM_LOCAL_IPADDR sysfs attr (Chad Dupuis) [1089349]
- [scsi] scsi_transport_iscsi: Export ISCSI_PARAM_LOCAL_IPADDR attr for iscsi_connection (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Add host statistics support (Chad Dupuis) [1089349]
- [scsi] scsi_transport_iscsi: Add host statistics support (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Added support for Diagnostics MBOX command (Chad Dupuis) [1089349]
- [scsi] qla2xxx: Update version number to 8.07.00.08.07.1-k (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove wait for online from host reset handler (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Do logins from a chip reset in DPC thread instead of the error handler thread (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove mapped vp index iterator macro dead code (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add MBC option for fast SFP data access (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix beacon blink logic for ISP26xx/83xx (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Delay driver unload if there is any pending activity going on (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Check the QLA8044_CRB_DRV_ACTIVE_INDEX register when we are not the owner of the reset (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Adjust adapter reset routine to the changes in firmware specification for ISPFx00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: IOCB data should be copied to I/O mem using memcpy_toio (Chad Dupuis) [1089346]
- [scsi] qla2xxx: ISP8044 poll ipmdio bus timeout improvement (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove unnecessary printk_ratelimited from qla_nx2.c (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Include <delay.h> file for msleep declartion in qla_nx2.c file (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use proper log message for flash lock failed error (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Decrease pci access for response queue processing for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Change copyright year to 2014 in all the source files (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Enable fw_dump_size for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Introduce fw_dump_flag to track fw dump progress (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove unnecessary delays from fw dump code path (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Track the process when the ROM_LOCK failure happens (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add ISP8044 serdes bsg interface (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Check for peg alive counter and clear any outstanding mailbox command (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Support of new firmware dump opcodes QLA8044_RDDFE(38), QLA8044_RDMDIO(39), QLA8044_POLLWR(40) (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Allow the next firmware dump if the previous dump capture fails for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Log when device state is moved to failed state (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Do not schedule reset when one is already active when receiving an invalid status handle (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Wait for reset completion without lock for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Re-sync module parameter descriptions with the code (Chad Dupuis) [1089346]
- [scsi] qla2xxx: fix error handling of qla2x00_mem_alloc() (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add IOCB Abort command asynchronous handling (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix Task Management command asynchronous handling (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correct the port no assignment for ISP82XX (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Read capture firmware dump on mailbox timeout for ISP8044 and ISP82XX (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Simplify the ISPFX00 interrupt handler code for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Avoid poisoning in the response queue for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove ISP_ABORT_NEEDED and ISP_ABORT_RETRY checks from watchdog function for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove Marker type IOCB logic for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Properly handle 32 bit mailbox register for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Enable the Flash Access Control (FAC) mailbox command (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Select correct request queue for error type IOCB for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove init control block related dead code for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use proper message for Non owner reset ACK Timeout (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Replace constant value for IOCTL IOCB abort execution status with a macro for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add handling for boot indication progress AENs for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add mutex around optrom calls to serialize accesses (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Poll during initialization for ISP25xx and ISP83xx (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix multiqueue MSI-X registration (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix warning reported by smatch (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Replace a constant with a macro definition for host->canqueue assigmnment (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Reset nic_core_reset_owner on moving from COLD to READY for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Only complete dcbx_comp and lb_portup_comp for virtual port index 0 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use scnprintf() instead of snprintf() in the sysfs handlers (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use the correct mailbox registers when acknowledging an IDC request on ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add changes to obtain ISPFX00 adapters product information in accordance with firmware update (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add logic to abort BSG commands for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Clear RISC INT reg only for an event and not always while polling (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix undefined behavior in call to snprintf() (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add BSG interface for read/write serdes register (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix issue with not displaying node name after system reboot (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Don't consider the drivers knocked out of IDC participation for future reset recovery process (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add BPM support for ISP25xx (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correctly set mailboxes for extended init control block (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Disable INTx interrupt for ISP82XX (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Honor execute firmware failures (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Print proper QLAFX00 product name at probe (Chad Dupuis) [1089346]
- [scsi] qla2xxx: print MAC via pMR (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correction to message ids (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correctly print out/in mailbox registers (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add a new interface to update versions (Chad Dupuis) [1089346]

* Fri Sep 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-156.el7]
- [tty] hvc_console: Fix wakeup of HVC thread on hvc_kick() (Steve Best) [1123045]
- [tty] hvc_opal: Kick the HVC thread on OPAL console events (Steve Best) [1123045]
- [powerpc] perf/hv-24x7: Catalog version number is be64, not be32 (Gustavo Duarte) [947159]
- [powerpc] perf/hv-24x7: Remove [static 4096], sparse chokes on it (Gustavo Duarte) [947159]
- [powerpc] perf/hv-24x7: Use (unsigned long) not (u32) values when calling plpar_hcall_norets() (Gustavo Duarte) [947159]
- [powerpc] perf/hv-gpci: Make device attr static (Gustavo Duarte) [947159]
- [powerpc] perf/hv_gpci: Probe failures use pr_debug(), and padding reduced (Gustavo Duarte) [947159]
- [powerpc] perf/hv_24x7: Probe errors changed to pr_debug(), padding fixed (Gustavo Duarte) [947159]
- [Documentation] powerpc/perf/hv_{gpci, 24x7}: Add documentation of device attributes (Gustavo Duarte) [947159]
- [powerpc] perf: Add kconfig option for hypervisor provided counters (Gustavo Duarte) [947159]
- [powerpc] perf: Add support for the hv 24x7 interface (Gustavo Duarte) [947159]
- [powerpc] perf: Add support for the hv gpci (get performance counter info) interface (Gustavo Duarte) [947159]
- [powerpc] perf: Add macros for defining event fields & formats (Gustavo Duarte) [947159]
- [powerpc] perf: Add a shared interface to get gpci version and capabilities (Gustavo Duarte) [947159]
- [powerpc] perf: Add 24x7 interface headers (Gustavo Duarte) [947159]
- [powerpc] perf: Add hv_gpci interface header (Gustavo Duarte) [947159]
- [powerpc] Add hvcalls for 24x7 and gpci (Get Performance Counter Info) (Gustavo Duarte) [947159]
- [ethernet] sfc: Remove DEFINE_PCI_DEVICE_TABLE macro use (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use __iowrite64_copy instead of a slightly different local function (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add support for busy polling (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add per-queue statistics in ethtool (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: add extra RX drop counters for nodesc_trunc and noskb_drop (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add 40G link capability decoding (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Adding PCI ID for Solarflare 7000 series 40G network adapter (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: fix calling of free_irq with already free vector (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: get rid of SET_ETHTOOL_OPS (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: On MCDI timeout, issue an FLR (and mark MCDI to fail-fast) (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Call efx_set_channels() before efx->type->dimension_resources() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Don't receive packets when the napi budget == 0 (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: check for NULL efx->ptp_data in efx_ptp_event (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use pci_enable_msix_range() instead of pci_enable_msix() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add/remove blank lines to taste (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Fail self-test with -EBUSY, not -EIO, if the device is busy (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Cosmetic changes to self-test from the out-of-tree driver (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Update product naming (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use canonical pointer type for MAC address in efx_set_mac_address() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Rename 'use_options' variable in tso_start() to clearer 'use_opt_desc' (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Preserve rx_frm_trunc counters when resizing DMA rings (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Correct comment about number of TX queues used on EF10 (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Remove unused definitions of EF10 user-mode DMA descriptors (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Replace TSOH_OFFSET with the equivalent NET_IP_ALIGN (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Rewrite adjustment of PPS event in a clearer way (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Cache skb->data in local variable in efx_ptp_rx() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Removed adhoc scheme to rate limit PTP event queue overflow message (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: fix build warning in ethernet/sfc/tx.c (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use the correct maximum TX DMA ring size for SFC9100 (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Fix transposed ptp_{under, over}size_sync_windows statistics (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Change efx_mcdi_reset_port to use ENTITY_RESET MC command (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: calls skb_set_hash (Nikolay Aleksandrov) [1110888]
- [iommu] vt-d: Use correct domain id to flush virtual machine domains (Myron Stowe) [1136539]
- [iommu] Fix IOMMU sysfs stubs (Myron Stowe) [1136539]
- [iommu] Fix compile error in iommu-sysfs.c (Myron Stowe) [1136539]
- [pci] Add bridge DMA alias quirk for Intel 82801 bridge (Myron Stowe) [1136539]
- [iommu] amd: Add sysfs support (Myron Stowe) [1136539]
- [iommu] vt-d: Make use of IOMMU sysfs support (Myron Stowe) [1136539]
- [iommu] Add sysfs support for IOMMUs (Myron Stowe) [1136539]
- [iommu] core: Make iommu_group_get_for_dev() more robust (Myron Stowe) [1136537]
- [iommu] Remove pci.h (Myron Stowe) [1136537]
- [iommu] vt-d: Update to use PCI DMA aliases (Myron Stowe) [1136537]
- [iommu] vt-d: Use iommu_group_get_for_dev() (Myron Stowe) [1136537]
- [iommu] amd: Use iommu_group_get_for_dev() (Myron Stowe) [1136537]
- [iommu] amd: Update to use PCI DMA aliases (Myron Stowe) [1136537]
- [iommu] core: Create central IOMMU group lookup/creation interface (Myron Stowe) [1136537]
- [iommu] vt-d: Suppress compiler warnings (Myron Stowe) [1136537]
- [iommu] vt-d: Fix reference count in iommu_prepare_isa (Myron Stowe) [1136537]
- [iommu] vt-d: fix bug in handling multiple RMRRs for the same PCI device (Myron Stowe) [1136537]
- [pci] Add bridge DMA alias quirk for ITE bridge (Myron Stowe) [1136537]
- [pci] Add bridge DMA alias quirk for ASMedia and Tundra bridges (Myron Stowe) [1136537]
- [pci] Add support for PCIe-to-PCI bridge DMA alias quirks (Myron Stowe) [1136537]
- [pci] Add function 1 DMA alias quirk for Marvell devices (Myron Stowe) [1136537]
- [pci] Add function 0 DMA alias quirk for Ricoh devices (Myron Stowe) [1136537]
- [pci] Add support for DMA alias quirks (Myron Stowe) [1136537]
- [pci] Convert pci_dev_flags definitions to bit shifts (Myron Stowe) [1136537]
- [pci] Add DMA alias iterator (Myron Stowe) [1136537]
- [iommu] amd: fix enabling exclusion range for an exact device (Myron Stowe) [1129880 1087643]
- [iommu] amd: Take mmap_sem when calling get_user_pages (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: fix bug in matching PCI devices with DRHD/RMRR descriptors (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix get_domain_for_dev() handling of upstream PCIe bridges (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: fix memory leakage caused by commit ea8ea46 (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix error handling in ANDD processing (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: returning free pointer in get_domain_for_dev() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Only call dmar_acpi_dev_scope_init() if DRHD units present (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Check for NULL pointer in dmar_acpi_dev_scope_init() (Myron Stowe) [1129880 1087643]
- [iommu] amd: Fix logic to determine and checking max PASID (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Include ACPI devices in iommu=pt (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Finally enable translation for non-PCI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove to_pci_dev() in intel_map_page() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove pdev from intel_iommu_attach_device() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove pdev from iommu_no_mapping() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make domain_add_dev_info() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make domain_remove_one_dev_info() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Rename 'hwdev' variables to 'dev' now that that's the norm (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove some pointless to_pci_dev() calls (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make get_valid_domain_for_dev() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make iommu_should_identity_map() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Handle RMRRs for non-PCI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make get_domain_for_dev() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make domain_context_mapp{ed, ing}() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make device_to_iommu() cope with non-PCI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make identity_mapping() take struct device not struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove segment from struct device_domain_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Store PCI segment number in struct intel_iommu (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove device_to_iommu() call from domain_remove_dev_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Simplify iommu check in domain_remove_one_dev_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Always store iommu in device_domain_info (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Use domain_remove_one_dev_info() in domain_add_dev_info() error path (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: use dmar_insert_dev_info() from dma_add_dev_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Stop dmar_insert_dev_info() freeing domains on losing race (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Pass iommu to domain_context_mapping_one() and iommu_support_dev_iotlb() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Use struct device in device_domain_info, not struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make dmar_insert_dev_info() take struct device instead of struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make iommu_dummy() take struct device instead of struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Add ACPI devices into dmaru->devices[] array (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Change scope lists to struct device, bus, devfn (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Allocate space for ACPI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Parse ANDD records (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Add ACPI namespace device reporting structures (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Be less pessimistic about domain coherency where possible (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Honour intel_iommu=sp_off for non-VMM domains (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Clean up and fix page table clear/free behaviour (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Clean up size handling for intel_iommu_unmap() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Update IOMMU state when memory hotplug happens (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Unify the way to process DMAR device scope array (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Update DRHD/RMRR/ATSR device scope caches when PCI hotplug happe (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Use RCU to protect global resources in interrupt context (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Introduce a rwsem to protect global data structures (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Introduce macro for_each_dev_scope() to walk device scope entrie (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix error in detect ATS capability (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Check for NULL pointer when freeing IOMMU data structure (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix incorrect iommu_count for si_domain (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Reduce duplicated code to handle virtual machine domains (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Free resources if failed to create domain for PCIe endpoint (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Simplify function get_domain_for_dev() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Move private structures and variables into intel-iommu.c (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Factor out dmar_alloc_dev_scope() for later reuse (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Avoid caching stale domain_device_info when hot-removing PCI dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Avoid caching stale domain_device_info and fix memory leak (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Avoid double free of g_iommus on error recovery path (Myron Stowe) [1129880 1087643]
- [iommu] amd: Fix PASID format in INVALIDATE_IOTLB_PAGES command (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix signedness bug in alloc_irte() (Myron Stowe) [1129808]
- [iommu] vt-d: free all resources if failed to initialize DMARs (Myron Stowe) [1129808]
- [iommu] vt-d: clean sparse warnings (Myron Stowe) [1129808]
- [iommu] vt-d: fix wrong return value of dmar_table_init() (Myron Stowe) [1129808]
- [iommu] vt-d: release invalidation queue when destroying IOMMU unit (Myron Stowe) [1129808]
- [iommu] vt-d: fix access after free issue in function free_dmar_iommu() (Myron Stowe) [1129808]
- [iommu] vt-d: keep shared resources when failed to initialize iommu devices (Myron Stowe) [1129808]
- [iommu] vt-d: fix invalid memory access when freeing DMAR irq (Myron Stowe) [1129808]
- [iommu] vt-d: simplify code with existing macros (Myron Stowe) [1129808]
- [iommu] vt-d: use defined macro instead of hardcoding (Myron Stowe) [1129808]
- [iommu] vt-d: mark internal functions as static (Myron Stowe) [1129808]
- [iommu] vt-d: clean up unused code (Myron Stowe) [1129808]
- [iommu] vt-d: check suitable flag in function detect_intel_iommu() (Myron Stowe) [1129808]
- [iommu] vt-d: print correct domain id of static identity domain (Myron Stowe) [1129808]
- [iommu] vt-d: refine support of 64bit guest address (Myron Stowe) [1129808]
- [iommu] vt-d: fix resource leakage on error recovery path in iommu_init_domain (Myron Stowe) [1129808]
- [iommu] vt-d: fix a race window in allocating domain ID for virtual machines (Myron Stowe) [1129808]
- [iommu] vt-d: fix PCI device reference leakage on error recovery path (Myron Stowe) [1129808]
- [iommu] vt-d: use dedicated bitmap to track remapping entry allocation status (Myron Stowe) [1129808]
- [iommu] Rename domain_has_cap to iommu_domain_has_cap (Myron Stowe) [1129808]
- [iommu] vt-d: Use dev_is_pci() to check whether it is pci device (Myron Stowe) [1129808]
- [iommu] amd: Use dev_is_pci() to check whether it is pci device (Myron Stowe) [1129808]
- [iommu] add missing include (Myron Stowe) [1129808]
- [iommu] vt-d: Mark function eoi_ioapic_pin_remapped() as static in irq_remappi (Myron Stowe) [1129808]
- [iommu] vt-d: Mark functions as static in intel_irq_remapping.c (Myron Stowe) [1129808]
- [iommu] vt-d: Mark functions as static in dmar.c (Myron Stowe) [1129808]
- [iommu] add IOMMU_EXEC flag for safely allowing XN mappings (Myron Stowe) [1129808]
- [iommu] acpica: Update DMAR table definitions (Myron Stowe) [1129808]

* Wed Sep 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-155.el7]
- [tools] perf/bench: Fix NULL pointer dereference in "perf bench all" (Jiri Olsa) [1133083]
- [tools] perf/bench/numa: Make no args mean 'run all tests' (Jiri Olsa) [1133083]
- [tools] perf/machine: Use map as success in ip__resolve_ams (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix crash in elf_section_by_name (Jiri Olsa) [1133083]
- [tools] perf/trace: Decode architecture-specific signal numbers (Jiri Olsa) [1133083]
- [tools] perf: Fix strict alias issue for find_first_bit (Jiri Olsa) [1133083]
- [tools] perf: fix BFD detection on opensuse (Jiri Olsa) [1133083]
- [tools] perf/symbols: Destroy unused symsrcs (Jiri Olsa) [1133083]
- [tools] perf/annotate: Check availability of annotate when processing samples (Jiri Olsa) [1133083]
- [tools] perf/trace: Fix ioctl 'request' beautifier build problems on !(i386 (Jiri Olsa) [1133083]
- [tools] perf/trace: Add fallback definition of EFD_SEMAPHORE (Jiri Olsa) [1133083]
- [tools] perf/list: Fix checking for supported events on older kernels (Jiri Olsa) [1133083]
- [tools] perf: Handle PERF_RECORD_HEADER_EVENT_TYPE properly (Jiri Olsa) [1133083]
- [tools] perf/probe: Do not add offset twice to uprobe address (Jiri Olsa) [1133083]
- [tools] perf/buildid-cache: Check relocation when checking for existing kcore (Jiri Olsa) [1133083]
- [tools] perf: Adjust kallsyms for relocated kernel (Jiri Olsa) [1133083]
- [tools] perf/tests: No need to set up ref_reloc_sym (Jiri Olsa) [1133083]
- [tools] perf/symbols: Prevent the use of kcore if the kernel has moved (Jiri Olsa) [1133083]
- [tools] perf/record: Get ref_reloc_sym from kernel map (Jiri Olsa) [1133083]
- [tools] perf/machine: Set up ref_reloc_sym in machine__create_kernel_maps() (Jiri Olsa) [1133083]
- [tools] perf/machine: Add machine__get_kallsyms_filename() (Jiri Olsa) [1133083]
- [tools] perf: Add kallsyms__get_function_start() (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix symbol annotation for relocated kernel (Jiri Olsa) [1133083]
- [tools] perf: Fix AAAAARGH64 memory barriers (Jiri Olsa) [1133083]
- [tools] perf: Demangle kernel and kernel module symbols too (Jiri Olsa) [1133083]
- [tools] perf/doc: Remove mention of non-existent set_perf_event_pending() from design.txt (Jiri Olsa) [1133083]
- [tools] perf/symbols: Load map before using map->map_ip() (Jiri Olsa) [1133083]
- [tools] perf: Fix traceevent plugin path definitions (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix JIT symbol resolution on heap (Jiri Olsa) [1133083]
- [tools] perf/stat: Fix memory corruption of xyarray when cpumask is used (Jiri Olsa) [1133083]
- [tools] perf/evsel: Remove duplicate member zeroing after free (Jiri Olsa) [1133083]
- [tools] perf: Ensure sscanf does not overrun the "mem" field (Jiri Olsa) [1133083]
- [tools] perf/stat: fix NULL pointer reference bug with event unit (Jiri Olsa) [1133083]
- [tools] perf: Add support for the xtensa architecture (Jiri Olsa) [1133083]
- [tools] perf/session: Free cpu_map in perf_session__cpu_bitmap (Jiri Olsa) [1133083]
- [tools] perf/timechart: Fix wrong SVG height (Jiri Olsa) [1133083]
- [tools] perf: Remove unnecessary callchain cursor state restore on unmatch (Jiri Olsa) [1133083]
- [tools] perf/callchain: Spare double comparison of callchain first entry (Jiri Olsa) [1133083]
- [tools] perf: Do proper comm override error handling (Jiri Olsa) [1133083]
- [tools] perf/symbols: Export elf_section_by_name and reuse (Jiri Olsa) [1133083]
- [tools] perf/probe: Release all dynamically allocated parameters (Jiri Olsa) [1133083]
- [tools] perf/probe: Release allocated probe_trace_event if failed (Jiri Olsa) [1133083]
- [tools] perf: Add 'build-test' make target (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when xen plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when scsi plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when jbd2 plugin is is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when cfg80211 plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when mac80211 plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when sched_switch plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when kvm plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when kmem plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when hrtimer plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when function plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add pevent_unregister_print_function() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add pevent_unregister_event_handler() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: fix pointer-integer size mismatch (Jiri Olsa) [1133083]
- [tools] perf/hists: Convert hist entry functions to use struct he_stat (Jiri Olsa) [1133083]
- [tools] perf: Factor out sample__resolve_callchain() (Jiri Olsa) [1133083]
- [tools] perf: Remove symbol_conf.use_callchain check (Jiri Olsa) [1133083]
- [tools] perf: Fix cross building (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Make plugin unload function receive pevent (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() finally!! (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in trace_seq_init() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Check return value of realloc() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add state member to struct trace_seq (Jiri Olsa) [1133083]
- [tools] perf: Fix build error due to zfree() cast (Jiri Olsa) [1133083]
- [tools] perf/record: Rename --initial-delay to --delay (Jiri Olsa) [1133083]
- [tools] perf/record: Rename --no-delay to --no-buffering (Jiri Olsa) [1133083]
- [tools] perf: Remove unused test-volatile-register-var.c (Jiri Olsa) [1133083]
- [tools] perf/probe: Fix build when DWARF support libraries not present (Jiri Olsa) [1133083]
- [tools] perf/diff: Color the Weighted Diff column (Jiri Olsa) [1133083]
- [tools] perf/diff: Color the Ratio column (Jiri Olsa) [1133083]
- [tools] perf/diff: Color the Delta column (Jiri Olsa) [1133083]
- [tools] perf: Generalize percent_color_snprintf() (Jiri Olsa) [1133083]
- [tools] include: Include <linux/compiler.h> from asm/bug.h (Jiri Olsa) [1133083]
- [tools] perf/record: Add --initial-delay option (Jiri Olsa) [1133083]
- [tools] perf: Use the DWARF unwind info only if loaded (Jiri Olsa) [1133083]
- [tools] perf: Add test for building detached source tarballs (Jiri Olsa) [1133083]
- [tools] perf: Include tools/lib/api/ in MANIFEST (Jiri Olsa) [1133083]
- [tools] include: Move perf's bug.h to a generic place (Jiri Olsa) [1133083]
- [tools] include: Define likely/unlikely in linux/compiler.h (Jiri Olsa) [1133083]
- [tools] include: Move perf's linux/compiler.h to a generic place (Jiri Olsa) [1133083]
- [tools] perf/evlist: Introduce evlist__for_each() & friends (Jiri Olsa) [1133083]
- [tools] perf/report: Move histogram entries collapsing to separate function (Jiri Olsa) [1133083]
- [tools] perf/report: Move hist browser selection code to separate function (Jiri Olsa) [1133083]
- [tools] perf/report: Move logic to warn about kptr_restrict'ed kernels to separate function (Jiri Olsa) [1133083]
- [tools] perf: Comment typo fix (Jiri Olsa) [1133083]
- [tools] perf/stat: Fix --delay option in man page (Jiri Olsa) [1133083]
- [tools] perf: Make perf_event__synthesize_mmap_events global (Jiri Olsa) [1133083]
- [tools] perf/machine: Fix id_hdr_size initialization (Jiri Olsa) [1133083]
- [tools] perf: Automate setup of FEATURE_CHECK_(C (Jiri Olsa) [1133083]
- [tools] perf/trace: Pack 'struct trace' (Jiri Olsa) [1133083]
- [tools] perf/header: Pack 'struct perf_session_env' (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Shut up plugins make message (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Replace tabs with spaces for all non-commands statements (Jiri Olsa) [1133083]
- [tools] perf/tests: Fix installation tests path setup (Jiri Olsa) [1133083]
- [tools] perf: Move arch setup into seprate Makefile (Jiri Olsa) [1133083]
- [tools] perf/stat: Remove misplaced __maybe_unused (Jiri Olsa) [1133083]
- [tools] perf/tests: Fixup leak on error path in parse events test (Jiri Olsa) [1133083]
- [tools] perf/evlist: Auto unmap on destructor (Jiri Olsa) [1133083]
- [tools] perf/evlist: Close fds on destructor (Jiri Olsa) [1133083]
- [tools] perf/evlist: Move destruction of maps to evlist destructor (Jiri Olsa) [1133083]
- [tools] perf/record: Remove old evsel_list usage (Jiri Olsa) [1133083]
- [tools] perf/evlist: Move the SIGUSR1 error reporting logic to prepare_workload (Jiri Olsa) [1133083]
- [tools] perf/evlist: Send the errno in the signal when workload fails (Jiri Olsa) [1133083]
- [tools] perf/stat: Don't show counter information when workload fails (Jiri Olsa) [1133083]
- [tools] perf: Use zfree to help detect use after free bugs (Jiri Olsa) [1133083]
- [tools] perf: Introduce zfree (Jiri Olsa) [1133083]
- [tools] perf: No need to test against NULL before calling free() (Jiri Olsa) [1133083]
- [tools] perf/ui/tui: Implement header window (Jiri Olsa) [1133083]
- [tools] perf/ui/tui: Split help message for perf top and report (Jiri Olsa) [1133083]
- [tools] perf/ui/tui: Protect windows by ui__lock (Jiri Olsa) [1133083]
- [tools] perf/probe: Support basic dwarf-based operations on uprobe events (Jiri Olsa) [1133083]
- [tools] perf/probe: Expand given path to absolute path (Jiri Olsa) [1133083]
- [tools] perf/config: Ignore generated files in feature-checks (Jiri Olsa) [1133083]
- [tools] perf: Do not synthesize the treads of default guest (Jiri Olsa) [1133083]
- [tools] perf: Use machine->pid for tgid if machine is guest (Jiri Olsa) [1133083]
- [tools] perf: Set event->header.misc to PERF_RECORD_MISC_GUEST_USER if machine is guest (Jiri Olsa) [1133083]
- [tools] perf: Find the proc info under machine->root_dir (Jiri Olsa) [1133083]
- [tools] perf: Add support for PERF_RECORD_MISC_GUEST_USER in thread__find_addr_map() (Jiri Olsa) [1133083]
- [tools] perf/report: Print session information only if --stdio is given (Jiri Olsa) [1133083]
- [tools] perf/report: Use pr_*() functions where applicable (Jiri Olsa) [1133083]
- [tools] perf/symbols: Add 'machine' member to struct addr_location (Jiri Olsa) [1133083]
- [tools] perf/mem: Remove unused parameter from dump_raw_samples() (Jiri Olsa) [1133083]
- [tools] perf/scripting/perl: Shorten function signatures (Jiri Olsa) [1133083]
- [tools] perf/scripting/python: Shorten function signatures (Jiri Olsa) [1133083]
- [tools] perf/ui/browser: Remove misplaced __maybe_unused (Jiri Olsa) [1133083]
- [tools] perf/report: Rename 'perf_report' to 'report' (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global 'O' processing code (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_CLEAN build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_INSTALL build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_LINK build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add global QUIET_CC_FPIC build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_CC build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Remove print_app_build variable (Jiri Olsa) [1133083]
- [tools] perf: Making QUIET_(CLEAN (Jiri Olsa) [1133083]
- [tools] perf/tests: Factor make install tests (Jiri Olsa) [1133083]
- [tools] perf: Rename 'perf_record_opts' to 'record_opts (Jiri Olsa) [1133083]
- [tools] perf/record: Rename 'perf_record' to plain 'record' (Jiri Olsa) [1133083]
- [tools] perf/record: Simplify perf_record__write (Jiri Olsa) [1133083]
- [tools] perf/record: Use perf_data_file__write for output file (Jiri Olsa) [1133083]
- [tools] perf/inject: Handle output file via perf_data_file object (Jiri Olsa) [1133083]
- [tools] perf: Get rid of a duplicate va_end() in error reporting routine (Jiri Olsa) [1133083]
- [tools] perf/report: Introduce helpers for processing callchains (Jiri Olsa) [1133083]
- [tools] perf/annotate: Make symbol__inc_addr_samples private (Jiri Olsa) [1133083]
- [tools] perf/annotate: Adopt methods from hists (Jiri Olsa) [1133083]
- [tools] perf/top: Use hist_entry__inc_addr_sample (Jiri Olsa) [1133083]
- [tools] perf/annotate: Add inc_samples method to addr_map_symbol (Jiri Olsa) [1133083]
- [tools] perf/hists: Leave symbol addr hist bucket auto alloc to symbol layer (Jiri Olsa) [1133083]
- [tools] perf/annotate: Auto allocate symbol per addr hist buckets (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Introduce pevent_filter_strerror() (Jiri Olsa) [1133083]
- [tools] perf/hists: Do not pass period and weight to add_hist_entry() (Jiri Olsa) [1133083]
- [tools] perf/sort: Do not compare dso again (Jiri Olsa) [1133083]
- [tools] perf/sort: Compare addresses if no symbol info (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in some string conversion functions (Jiri Olsa) [1133083]
- [tools] perf/symbols: Use consistent name for the DSO binary type member (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add --highlight option (Jiri Olsa) [1133083]
- [tools] perf/symbols: Clarify method to get DSO binary_type filename (Jiri Olsa) [1133083]
- [tools] perf/symbols: Remove needless static binary_type array (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add support for topology (Jiri Olsa) [1133083]
- [tools] perf/timechart: Get number of CPUs from perf header (Jiri Olsa) [1133083]
- [tools] perf/timechart: Print pid along the name (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add backtrace support to CPU info (Jiri Olsa) [1133083]
- [tools] Convert to new topic libraries (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Refactor pevent_filter_match() to get rid of die() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Make pevent_filter_add_filter_str() return pevent_errno (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Refactor process_filter() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Refactor create_arg_item() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in reparent_op_arg() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Make add_left() return pevent_errno (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in add_right() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in find_event() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in read_token() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() allocate_arg() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die in add_filter_type() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in show_error() (Jiri Olsa) [1133083]
- [tools] perf/completion: Complete 'perf kvm' (Jiri Olsa) [1133083]
- [tools] perf/evlist: Add perf_evlist__to_front() (Jiri Olsa) [1133083]
- [tools] perf: Fix inverted error verification bug in thread__fork (Jiri Olsa) [1133083]
- [tools] perf: Move mem_bswap32/64 to util.c (Jiri Olsa) [1133083]
- [tools] perf/evlist: Add can_select_event() method (Jiri Olsa) [1133083]
- [tools] perf/header: Allow header->data_offset to be predetermined (Jiri Olsa) [1133083]
- [tools] perf: Add perf_event_paranoid() (Jiri Olsa) [1133083]
- [tools] lib/symbol: Start carving out symbol parsing routines from perf (Jiri Olsa) [1133083]
- [tools] perf/unwinding: Use the per-feature check flags (Jiri Olsa) [1133083]
- [tools] perf: Add per-feature check flags (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix bug in usage of the basename() function (Jiri Olsa) [1133083]
- [tools] perf/symbols: Rename filename argument (Jiri Olsa) [1133083]
- [tools] perf/symbols: Constify some DSO methods parameters (Jiri Olsa) [1133083]
- [tools] perf/symbols: Set freed members to NULL in dso destructor (Jiri Olsa) [1133083]
- [tools] perf/symbols: Constify dso->long_name (Jiri Olsa) [1133083]
- [tools] perf/symbols: Remove open coded management of long_name_allocated member (Jiri Olsa) [1133083]
- [tools] perf/symbols: Set alloc flag close to setting the long_name (Jiri Olsa) [1133083]
- [tools] perf/symbols: Remove open coded management of short_name_allocated member (Jiri Olsa) [1133083]
- [tools] perf/machine: Don't open code assign dso->short_name (Jiri Olsa) [1133083]
- [tools] perf/symbols: Rename [sl]name_alloc to match the members they refer to (Jiri Olsa) [1133083]
- [tools] perf/script: Add --header/--header-only options (Jiri Olsa) [1133083]
- [tools] perf/report: Add --header/--header-only options (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in pevent_filter_clear_trivial() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in pevent_filter_add_filter_str() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in create_arg_item() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in add_event() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in pevent_filter_alloc() (Jiri Olsa) [1133083]
- [tools] perf/kvm: Make perf kvm diff support --guestmount (Jiri Olsa) [1133083]
- [tools] perf/kvm: Move code to generate filename for perf-kvm to function (Jiri Olsa) [1133083]
- [tools] perf/annotate: Fix typo (Jiri Olsa) [1133083]
- [tools] perf/archive: Remove duplicated 'runs' in man page (Jiri Olsa) [1133083]
- [tools] perf/kvm: Fix bug in 'stat report' (Jiri Olsa) [1133083]
- [tools] perf/kvm: Introduce option -v for perf kvm command (Jiri Olsa) [1133083]
- [tools] perf/evlist: Fix mmap pages rounding to power of 2 (Jiri Olsa) [1133083]
- [tools] perf/evlist: Fix max mmap_pages (Jiri Olsa) [1133083]
- [tools] perf/evlist: Remove unnecessary parentheses (Jiri Olsa) [1133083]
- [tools] perf/record: Fix display of incorrect mmap pages (Jiri Olsa) [1133083]
- [tools] perf/script: Add an option to print the source line number (Jiri Olsa) [1133083]
- [tools] perf/script: Fix symoff printing in callchains (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Report better error message on bad function args (Jiri Olsa) [1133083]
- [tools] perf/trace: Fix summary percentage when processing files (Jiri Olsa) [1133083]
- [tools] perf/trace: Add support for syscalls vs raw_syscalls (Jiri Olsa) [1133083]
- [tools] perf/build: Fix install dependency (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Update kvm plugin with is_writable_pte helper (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Remove malloc_or_die from plugin_function.c (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Several cleanups for function plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use pevent_print_func_field in hrtimer_start handler (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use static functions in jbd2 plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Remove malloc_or_die from event-plugin.c (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add cfg80211 plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add scsi plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add xen plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add function plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add sched_switch plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add mac80211 plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add kvm plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add kmem plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add hrtimer plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add jbd2 plugin (Jiri Olsa) [1133083]
- [tools] perf: Overload pr_stat traceevent print function (Jiri Olsa) [1133083]
- [tools] perf: Add trace-event global object for tracepoint interface (Jiri Olsa) [1133083]
- [tools] perf: Add trace-event object (Jiri Olsa) [1133083]
- [tools] perf: Add filename__read_str util function (Jiri Olsa) [1133083]
- [tools] perf: Add build and install plugins targets (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Harmonize the install messages in lib-traceevent (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Change pevent_parse_format to include pevent handle (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add traceevent_host_bigendian function (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add plugin build support (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add plugin support (Jiri Olsa) [1133083]
- [tools] perf/script: Do not call perf_event__preprocess_sample() twice) (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix random fd closing with no libelf (Jiri Olsa) [1133083]
- [tools] perf/kvm: Update the 'record' man page entry for new --guest/--host behavior (Jiri Olsa) [1133083]
- [tools] perf/kvm: Fix spurious '=' use in man page (Jiri Olsa) [1133083]
- [tools] perf/kvm: Add more detail about buildid-list in man page (Jiri Olsa) [1133083]
- [tools] perf/target: Move the checking of which map function to call into function (Jiri Olsa) [1133083]
- [tools] perf: Remove condition in machine__get_kernel_start_addr (Jiri Olsa) [1133083]
- [tools] perf: Remove stackprotector feature check (Jiri Olsa) [1133083]
- [tools] perf: Do not disable source line lookup just because of 1 failure (Jiri Olsa) [1133083]
- [tools] perf/symbols: Retain symbol source file name to lookup source line numbers (Jiri Olsa) [1133083]
- [tools] perf/symbols: Retain bfd reference to lookup source line numbers (Jiri Olsa) [1133083]
- [tools] perf: Use asprintf instead of malloc plus snprintf (Jiri Olsa) [1133083]
- [tools] perf/trace: Honour -m option (Jiri Olsa) [1133083]
- [tools] perf: Include test-stackprotector-all.c in test-all (Jiri Olsa) [1133083]
- [tools] perf: Correct the message in feature-libnuma checking (Jiri Olsa) [1133083]
- [tools] perf/timechart: Move wake_events list to 'struct timechart' (Jiri Olsa) [1133083]
- [tools] perf/timechart: Move power_events list to 'struct timechart' (Jiri Olsa) [1133083]
- [tools] perf/timechart: Move all_data per_pid list to 'struct timechart' (Jiri Olsa) [1133083]
- [tools] perf/timechart: Introduce tool struct (Jiri Olsa) [1133083]
- [tools] perf: Add perf_data_file__write interface (Jiri Olsa) [1133083]
- [tools] perf: Add writen function (Jiri Olsa) [1133083]
- [tools] perf: Fine tune readn function (Jiri Olsa) [1133083]
- [tools] perf: Use correct return type for readn function (Jiri Olsa) [1133083]
- [tools] perf/record: Unify data output code into perf_record__write function (Jiri Olsa) [1133083]
- [tools] perf: Fix tags/TAGS targets rebuilding (Jiri Olsa) [1133083]
- [tools] perf/timechart: Remove misplaced __maybe_unused (Jiri Olsa) [1133083]
- [tools] perf/timechart: Remove some needless struct forward declarations (Jiri Olsa) [1133083]
- [tools] perf/timechart: dynamically determine event fields offset (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix not finding kcore in buildid cache (Jiri Olsa) [1133083]
- [tools] perf/script: Print mmap[2] events also (Jiri Olsa) [1133083]
- [tools] perf/script: Print comm, fork and exit events also (Jiri Olsa) [1133083]
- [tools] perf/script: Print callchains and symbols if they exist (Jiri Olsa) [1133083]
- [tools] perf: Export setup_list (Jiri Olsa) [1133083]
- [tools] perf/thread: Move comm_list check into function (Jiri Olsa) [1133083]
- [tools] perf/symbols: Move idle syms check from top to generic function (Jiri Olsa) [1133083]
- [tools] perf/evsel: Skip ignored symbols while printing callchain (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add backtrace support (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add support for -P and -T in timechart recording (Jiri Olsa) [1133083]
- [tools] perf/timechart: Group figures and add title with details (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add support for displaying only tasks related data (Jiri Olsa) [1133083]
- [tools] perf/timechart: Use proc_num to implement --power-only (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add option to limit number of tasks (Jiri Olsa) [1133083]
- [tools] perf/timechart: Always try to print at least 15 tasks (Jiri Olsa) [1133083]
- [tools] perf/record: Default -t option to no inheritance (Jiri Olsa) [1133083]
- [tools] perf: Add option macro OPT_BOOLEAN_SET (Jiri Olsa) [1133083]
- [tools] perf: Allow '--inherit' as the negation of '--no-inherit' (Jiri Olsa) [1133083]
- [tools] perf/record: Make per-cpu mmaps the default (Jiri Olsa) [1133083]
- [tools] perf/script: Move evname print code to process_event() (Jiri Olsa) [1133083]
- [tools] perf/completion: Rename file to reflect zsh support (Jiri Olsa) [1133083]
- [tools] perf/completion: Introduce zsh support (Jiri Olsa) [1133083]
- [tools] perf/completion: Factor out call to __ltrim_colon_completions (Jiri Olsa) [1133083]
- [tools] perf/completion: Factor out compgen stuff (Jiri Olsa) [1133083]
- [tools] perf/completion: Introduce a layer of indirection (Jiri Olsa) [1133083]
- [tools] perf/top: Make -g refer to callchains (Jiri Olsa) [1133083]
- [tools] perf/trace: Remove thread summary coloring (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use helper trace-seq in print functions like kernel does (Jiri Olsa) [1133083]
- [tools] perf/stat: Add event unit and scale support (Jiri Olsa) [1133083]
- [kernel] perf: Optimize ring-buffer write by depending on control dependencies (Jiri Olsa) [1133083]
- [x86] perf: Fix leak in uncore_type_init failure paths (Jiri Olsa) [1133083]
- [kernel] perf: Fix hotplug splat (Jiri Olsa) [1133083]
- [x86] perf: Fix event scheduling (Jiri Olsa) [1133083]
- [x86] perf: Fix IVT/SNB-EP uncore CBOX NID filter table (Jiri Olsa) [1133083]
- [x86] perf: Correctly use FEATURE_PDCM (Jiri Olsa) [1133083]
- [x86] perf: Fix unknown NMI warning (Jiri Olsa) [1133083]
- [x86] perf: Fix Userspace RDPMC switch (Jiri Olsa) [1133083]
- [x86] perf: Add userspace RDPMC quirk for PPro (Jiri Olsa) [1133083]
- [kernel] uapi: convert u64 to __u64 in exported headers (Jiri Olsa) [1133083]
- [kernel] perf: Document the new transaction sample type (Jiri Olsa) [1133083]
- [kernel] perf: Introduce a flag to enable close-on-exec in perf_event_open() (Jiri Olsa) [1133083]
- [x86] perf: Add Intel RAPL PP1 energy counter support (Jiri Olsa) [1133083]
- [kernel] perf: Fix PERF_EVENT_IOC_PERIOD to force-reset the period (Jiri Olsa) [1133083]
- [x86] perf: Add RAPL hrtimer support (Jiri Olsa) [1133083]
- [x86] perf: Add Intel RAPL PMU support (Jiri Olsa) [1133083]
- [kernel] perf: Add active_entry list head to struct perf_event (Jiri Olsa) [1133083]
- [kernel] perf: Fix perf_pmu_migrate_context (Jiri Olsa) [1133083]
- [kernel] ktime: add ms_to_ktime() and ktime_add_ms() helpers (Jiri Olsa) [1133083]
- [tools] perf/traceevent: Fix conversion of pointer to integer of different size (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Fix use of multiple options in processing field (Jiri Olsa) [1131394]
- [tools] perf/header: Fix possible memory leaks in process_group_desc() (Jiri Olsa) [1131394]
- [tools] perf/header: Fix bogus group name (Jiri Olsa) [1131394]
- [tools] perf: Tag thread comm as overriden (Jiri Olsa) [1131394]
- [tools] perf/record: Add an option to force per-cpu mmaps (Jiri Olsa) [1131394]
- [tools] perf/probe: Add '--demangle'/'--no-demangle' (Jiri Olsa) [1131394]
- [tools] perf/ui/browser: Fix segfault caused by off by one handling END key (Jiri Olsa) [1131394]
- [tools] perf/symbols: Limit max callchain using max_stack on DWARF unwinding too (Jiri Olsa) [1131394]
- [tools] perf/evsel: Introduce perf_evsel__prev() method (Jiri Olsa) [1131394]
- [tools] perf: Use perf_evlist__{first, last}, perf_evsel__next (Jiri Olsa) [1131394]
- [tools] perf: Synthesize anon MMAP records again (Jiri Olsa) [1131394]
- [tools] perf/top: Add missing newline if the 'uid' is invalid (Jiri Olsa) [1131394]
- [tools] perf: Remove trivial extra semincolon (Jiri Olsa) [1131394]
- [tools] perf/trace: Tweak summary output (Jiri Olsa) [1131394]
- [tools] perf/build: Fix feature-libunwind-debug-frame handling (Jiri Olsa) [1131394]
- [tools] perf/build: Fix timerfd feature check (Jiri Olsa) [1131394]
- [tools] perf: parse the .debug_frame section in case .eh_frame is not present (Jiri Olsa) [1131394]
- [tools] perf: Check libunwind for availability of dwarf parsing feature (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add direct access to dynamic arrays (Jiri Olsa) [1131394]
- [tools] perf/target: Shorten perf_target__ to target__ (Jiri Olsa) [1131394]
- [tools] perf/tests: Handle throttle events in 'object code reading' test (Jiri Olsa) [1131394]
- [tools] perf/evlist: Refactor mmap_pages parsing (Jiri Olsa) [1131394]
- [tools] perf/evlist: Round mmap pages to power 2 - v2 (Jiri Olsa) [1131394]
- [tools] perf/record: Fix segfault with --no-mmap-pages (Jiri Olsa) [1131394]
- [tools] perf/trace: Add summary only option (Jiri Olsa) [1131394]
- [tools] perf/trace: Simplify '--summary' output (Jiri Olsa) [1131394]
- [tools] perf/trace: Change syscall summary duration order (Jiri Olsa) [1131394]
- [tools] perf/tests: Compensate lower sample freq with longer test loop (Jiri Olsa) [1131394]
- [tools] perf/trace: Fix segfault on perf trace -i perf.data (Jiri Olsa) [1131394]
- [tools] perf/trace: Separate tp syscall field caching into init routine to be reused (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify fifth argument of mmap() as fd (Jiri Olsa) [1131394]
- [tools] perf/tests: Use lower sample_freq in sw clock event period test (Jiri Olsa) [1131394]
- [tools] perf/tests: Check return of perf_evlist__open sw clock event period test (Jiri Olsa) [1131394]
- [tools] perf/record: Move existing write_output into helper function (Jiri Olsa) [1131394]
- [tools] perf/record: Use correct return type for write() (Jiri Olsa) [1131394]
- [tools] perf: Prevent condition that all sort keys are elided (Jiri Olsa) [1131394]
- [tools] perf/machine: Simplify synthesize_threads method (Jiri Olsa) [1131394]
- [tools] perf/machine: Introduce synthesize_threads method out of open coded equivalent (Jiri Olsa) [1131394]
- [tools] perf/record: Synthesize non-exec MMAP records when --data used (Jiri Olsa) [1131394]
- [tools] perf/evsel: Remove idx parm from constructor (Jiri Olsa) [1131394]
- [tools] perf/ui/tui/progress: Don't force a refresh during progress update (Jiri Olsa) [1131394]
- [tools] perf: Remove unneeded include (Jiri Olsa) [1131394]
- [tools] perf/record: Remove post_processing_offset variable (Jiri Olsa) [1131394]
- [tools] perf/record: Remove advance_output function (Jiri Olsa) [1131394]
- [tools] perf/record: Refactor feature handling into a separate function (Jiri Olsa) [1131394]
- [tools] perf/trace: Don't relookup fields by name in each sample (Jiri Olsa) [1131394]
- [tools] perf: Fix version when building out of tree (Jiri Olsa) [1131394]
- [tools] perf/evsel: Ditch evsel->handler.data field (Jiri Olsa) [1131394]
- [tools] perf: Add required memory barriers (Jiri Olsa) [1131394]
- [tools] perf: Finish the removal of 'self' arguments (Jiri Olsa) [1131394]
- [tools] perf: Check maximum frequency rate for record/top (Jiri Olsa) [1131394]
- [tools] perf/fs: Add procfs support (Jiri Olsa) [1131394]
- [tools] perf/fs: Rename NAME_find_mountpoint() to NAME__mountpoint() (Jiri Olsa) [1131394]
- [tools] perf: Factor sysfs code into generic fs object (Jiri Olsa) [1131394]
- [tools] perf/list: Add usage (Jiri Olsa) [1131394]
- [tools] perf/list: Remove a level of indentation (Jiri Olsa) [1131394]
- [tools] perf/build: Fix detection of non-core features (Jiri Olsa) [1131394]
- [tools] perf/kvm: Disable live command if timerfd is not supported (Jiri Olsa) [1131394]
- [tools] perf/hists: Consolidate __hists__add_*entry() (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add pevent_print_func_field() helper function (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add flags NOHANDLE and PRINTRAW to individual events (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Check for spaces in character array (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Have bprintk output the same as the kernel does (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Handle __print_hex(__get_dynamic_array(fieldname), len) (Jiri Olsa) [1131394]
- [tools] perf/traceevent: If s is a pointer, check printk formats (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Update printk formats when entered (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add support for extracting trace_clock in report (Jiri Olsa) [1131394]
- [tools] perf/stat: Enhance option parse error message (Jiri Olsa) [1131394]
- [tools] perf/top: Use parse_options_usage() for -s option failure (Jiri Olsa) [1131394]
- [tools] perf/report: Use parse_options_usage() for -s option failure (Jiri Olsa) [1131394]
- [tools] perf/report: Postpone setting up browser after parsing options (Jiri Olsa) [1131394]
- [tools] perf: Show single option when failed to parse (Jiri Olsa) [1131394]
- [tools] perf/evsel: Synthesize PERF_SAMPLE_TRANSACTION (Jiri Olsa) [1131394]
- [tools] perf/test: Update "sample parsing" test for PERF_SAMPLE_TRANSACTION (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add missing overflow check for TRANSACTION (Jiri Olsa) [1131394]
- [tools] perf/evsel: Always use perf_evsel__set_sample_bit() (Jiri Olsa) [1131394]
- [tools] perf/evlist: Add a debug print if event buffer mmap fails (Jiri Olsa) [1131394]
- [tools] perf: Fix libunwind build and feature detection for 32-bit build (Jiri Olsa) [1131394]
- [tools] perf: Fix 32-bit cross build (Jiri Olsa) [1131394]
- [tools] perf/script: Set up output options for in-stream attributes (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add a debug print if perf_event_open fails (Jiri Olsa) [1131394]
- [tools] perf: Get current comm instead of last one (Jiri Olsa) [1131394]
- [tools] perf: Compare hists comm by addresses (Jiri Olsa) [1131394]
- [tools] perf: Add new COMM infrastructure (Jiri Olsa) [1131394]
- [tools] perf: Add time argument on COMM setting (Jiri Olsa) [1131394]
- [tools] perf: Use an accessor to read thread comm (Jiri Olsa) [1131394]
- [tools] perf: Add missing data.h into LIB_H headers (Jiri Olsa) [1131394]
- [tools] perf/probe: Fix typo (Jiri Olsa) [1131394]
- [tools] perf/bench: Fix two warnings (Jiri Olsa) [1131394]
- [tools] perf: Show progress on histogram collapsing (Jiri Olsa) [1131394]
- [tools] perf/ui/progress: Per progress bar state (Jiri Olsa) [1131394]
- [tools] perf/ui: Rename ui_progress to ui_progress_ops (Jiri Olsa) [1131394]
- [tools] perf: Fix non-debug build (Jiri Olsa) [1131394]
- [tools] perf/evlist: Validate that mmap_pages is not too big (Jiri Olsa) [1131394]
- [tools] perf: Do not accept parse_tag_value() overflow (Jiri Olsa) [1131394]
- [tools] perf/inject: Do not repipe attributes to a perf.data file (Jiri Olsa) [1131394]
- [tools] perf/script: Make perf_script a local variable (Jiri Olsa) [1131394]
- [tools] perf/sched: Optimize build time (Jiri Olsa) [1131394]
- [tools] perf/sched: Make struct perf_sched sched a local variable (Jiri Olsa) [1131394]
- [tools] perf/bench: Change the procps visible command-name of invididual benchmark tests plus cleanups (Jiri Olsa) [1131394]
- [tools] perf/probe: Find fentry mcount fuzzed parameter location (Jiri Olsa) [1131394]
- [tools] perf/probe: Support "$vars" meta argument syntax for local variables (Jiri Olsa) [1131394]
- [tools] perf: Stop using 'self' in some more places (Jiri Olsa) [1131394]
- [tools] perf/test: Consider PERF_SAMPLE_TRANSACTION in the "sample parsing" test (Jiri Olsa) [1131394]
- [tools] perf/test: Clarify the "sample parsing" test entry (Jiri Olsa) [1131394]
- [tools] perf/top: Add --max-stack option to limit callchain stack scan (Jiri Olsa) [1131394]
- [tools] perf/report: Add --max-stack option to limit callchain stack scan (Jiri Olsa) [1131394]
- [tools] perf/session: Separating data file properties from session (Jiri Olsa) [1131394]
- [tools] perf: Add perf_data_file__open interface to data object (Jiri Olsa) [1131394]
- [tools] perf: Add data object to handle perf data file (Jiri Olsa) [1131394]
- [tools] perf: Compare dso's also when comparing symbols (Jiri Olsa) [1131394]
- [tools] perf/callchain: Convert children list to rbtree (Jiri Olsa) [1131394]
- [tools] perf/list: Show error if tracepoints not available (Jiri Olsa) [1131394]
- [tools] perf/script: Print addr by default for BTS (Jiri Olsa) [1131394]
- [tools] perf/evlist: Factor out duplicated mmap code (Jiri Olsa) [1131394]
- [tools] perf/evlist: Fix perf_evlist__mmap comments (Jiri Olsa) [1131394]
- [tools] perf: Fix bench/numa.c for 32-bit build (Jiri Olsa) [1131394]
- [tools] perf: Fix test_on_exit for 32-bit build (Jiri Olsa) [1131394]
- [tools] perf/evlist: Fix 32-bit build error (Jiri Olsa) [1131394]
- [tools] perf/session: Add missing members to perf_event__attr_swap() (Jiri Olsa) [1131394]
- [tools] perf/session: Add missing sample flush for piped events (Jiri Olsa) [1131394]
- [tools] perf/record: Improve write_output error message (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add missing decrement in id sample parsing (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add missing 'mmap2' from debug print (Jiri Olsa) [1131394]
- [tools] perf/trace: Improve messages related to /proc/sys/kernel/perf_event_paranoid (Jiri Olsa) [1131394]
- [tools] perf: Introduce filename__read_int helper (Jiri Olsa) [1131394]
- [tools] perf/evlist: Introduce perf_evlist__strerror_tp method (Jiri Olsa) [1131394]
- [tools] perf/trace: Improve event processing exit (Jiri Olsa) [1131394]
- [tools] perf/trace: Use vfs_getname hook if available (Jiri Olsa) [1131394]
- [tools] perf/trace: Split fd -> pathname array handling (Jiri Olsa) [1131394]
- [tools] perf/symbols: Fix a mmap and munmap mismatched bug (Jiri Olsa) [1131394]
- [tools] perf/symbols: Fix a memory leak due to symbol__delete not being used (Jiri Olsa) [1131394]
- [tools] perf/annotate: Another fix for annotate_browser__callq() (Jiri Olsa) [1131394]
- [tools] perf/buildid-cache: Add ability to add kcore to the cache (Jiri Olsa) [1131394]
- [tools] perf/annotate: Fix annotate_browser__callq() (Jiri Olsa) [1131394]
- [tools] perf/symbols: Add ability to find kcore in build-id cache (Jiri Olsa) [1131394]
- [tools] perf: Add copyfile_mode() (Jiri Olsa) [1131394]
- [tools] perf/annotate: Find kcore symbols on other maps (Jiri Olsa) [1131394]
- [tools] perf/build: Simplify the autodep inclusion rule (Jiri Olsa) [1131394]
- [tools] perf/build: Improve the 'stackprotector' feature test (Jiri Olsa) [1131394]
- [tools] perf/build: Remove the volatile-register-var feature check (Jiri Olsa) [1131394]
- [tools] perf/build: Simplify the libelf logic (Jiri Olsa) [1131394]
- [tools] perf/build: Fix DPACKAGE definitions for the libbfd et al testcases (Jiri Olsa) [1131394]
- [tools] perf/build: Pass through DEBUG parameter (Jiri Olsa) [1131394]
- [tools] perf/build: Fix non-existent build directory handling (Jiri Olsa) [1131394]
- [tools] perf/symbols: Add map_groups__find_ams() (Jiri Olsa) [1131394]
- [tools] perf/symbols: Workaround objdump difficulties with kcore (Jiri Olsa) [1131394]
- [tools] perf/symbols: Validate kcore module addresses (Jiri Olsa) [1131394]
- [tools] perf: Separate lbfd check out of NO_DEMANGLE condition (Jiri Olsa) [1131394]
- [tools] perf/tests: Fix memory leak in dso-data.c (Jiri Olsa) [1131394]
- [tools] perf: Fix old GCC build error in 'get_srcline' (Jiri Olsa) [1131394]
- [tools] perf/trace: Add summary option to dump syscall statistics (Jiri Olsa) [1131394]
- [tools] perf/util: Add findnew method to intlist (Jiri Olsa) [1131394]
- [tools] perf/trace: Improve the error messages (Jiri Olsa) [1131394]
- [tools] perf/timechart: Add example in the documentation (Jiri Olsa) [1131394]
- [tools] perf: Implement summary output for 'make install' (Jiri Olsa) [1131394]
- [tools] perf: Align perf version output to other build messages (Jiri Olsa) [1131394]
- [tools] perf: Harmonize the various build messages in perf, lib-traceevent, lib-lk (Jiri Olsa) [1131394]
- [tools] perf: Implement summary output for 'make clean' (Jiri Olsa) [1131394]
- [tools] perf: Fix redirection printouts (Jiri Olsa) [1131394]
- [tools] perf/trace: Initial beautifier for ioctl's 'cmd' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Prepare the strarray scnprintf method for reuse (Jiri Olsa) [1131394]
- [tools] perf/trace: Allow specifying index offset in strarrays (Jiri Olsa) [1131394]
- [tools] perf/symbols: Make a separate function to parse /proc/modules (Jiri Olsa) [1131394]
- [tools] perf/intlist: Add priv member (Jiri Olsa) [1131394]
- [tools] perf/trace: Use new machine method to loop over threads (Jiri Olsa) [1131394]
- [tools] perf/machine: Add method to loop over threads and invoke handler (Jiri Olsa) [1131394]
- [tools] perf/trace: Add record option (Jiri Olsa) [1131394]
- [tools] perf/trace: Fix comm resolution when reading events from file (Jiri Olsa) [1131394]
- [tools] perf/stat: Add units to nanosec-based counters (Jiri Olsa) [1131394]
- [tools] perf/stat: Don't require a workload when using system wide or CPU options (Jiri Olsa) [1131394]
- [tools] perf/stat: Fix misleading message when specifying cpu list or system wide (Jiri Olsa) [1131394]
- [tools] perf/evlist: Fix perf_evlist__mmap_read event overflow (Jiri Olsa) [1131394]
- [tools] perf: Ignore 'perf timechart' output file (Jiri Olsa) [1131394]
- [tools] perf/stat: Don't print bogus data on -e instructions (Jiri Olsa) [1131394]
- [tools] perf/stat: Don't print bogus data on -e cycles (Jiri Olsa) [1131394]
- [tools] perf: Move start conditions to start of the flex file (Jiri Olsa) [1131394]
- [tools] perf: Add missing -ldl for gtk build (Jiri Olsa) [1131394]
- [tools] perf/machine: Use snprintf instead of sprintf (Jiri Olsa) [1131394]
- [tools] perf/bench sched: Add --threaded option (Jiri Olsa) [1131394]
- [tools] perf/trace: Add 'trace' alias to 'perf trace' (Jiri Olsa) [1131394]
- [tools] perf/trace: Show path associated with fd in live sessions (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify mlock & friends 'addr' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Handle MSG_WAITFORONE not defined (Jiri Olsa) [1131394]
- [tools] perf/trace: Add beautifier for clock_gettime's clk_id argument (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify pipe2 'flags' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Use socket's beautifiers in socketpair (Jiri Olsa) [1131394]
- [tools] perf/trace: Don't supress zeroed args when there is an strarray entry for it (Jiri Olsa) [1131394]
- [tools] perf/trace: Add helper for syscalls with a single strarray arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify flock 'cmd' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify epoll_ctl 'op' arg (Jiri Olsa) [1131394]
- [tools] perf: Fix srcline sort key behavior (Jiri Olsa) [1131394]
- [tools] perf: Implement addr2line directly using libbfd (Jiri Olsa) [1131394]
- [tools] perf: Save failed result of get_srcline() (Jiri Olsa) [1131394]
- [tools] perf/annotate: Pass dso instead of dso_name to get_srcline() (Jiri Olsa) [1131394]
- [tools] perf: Do not try to call addr2line on non-binary files (Jiri Olsa) [1131394]
- [tools] perf/annotate: Factor out get/free_srcline() (Jiri Olsa) [1131394]
- [tools] perf/hists: Free srcline when freeing hist_entry (Jiri Olsa) [1131394]
- [tools] perf/annotate: Reuse path from the result of addr2line (Jiri Olsa) [1131394]
- [tools] perf/sort: Fix a memory leak on srcline (Jiri Olsa) [1131394]
- [tools] perf: Separate out GTK codes to libperf-gtk.so (Jiri Olsa) [1131394]
- [tools] perf/symbols: Add new option --ignore-vmlinux for perf top (Jiri Olsa) [1131394]
- [tools] perf: Adding throttle event data struct support (Jiri Olsa) [1131394]
- [tools] perf/evlist: Introduce perf_evlist__new_default function (Jiri Olsa) [1131394]
- [tools] perf: Add possibility to specify mmap size (Jiri Olsa) [1131394]
- [tools] perf: Check mmap pages value early (Jiri Olsa) [1131394]
- [tools] perf/lock: Account for lock average wait time (Jiri Olsa) [1131394]
- [tools] perf/lock: Limit bad rate precision (Jiri Olsa) [1131394]
- [tools] perf/lock: Redo __cmd_report (Jiri Olsa) [1131394]
- [tools] perf/lock: Plug some memleaks (Jiri Olsa) [1131394]
- [tools] perf/lock: Return proper code in report_lock_*_event (Jiri Olsa) [1131394]
- [tools] perf/lock: Remove dead code (Jiri Olsa) [1131394]
- [tools] perf: Unify page_size usage (Jiri Olsa) [1131394]
- [tools] perf: Remove unused trace-event-* code (Jiri Olsa) [1131394]
- [tools] perf/symbols: Support for Openembedded/Yocto -dbg packages (Jiri Olsa) [1131394]
- [tools] perf/completion: Use more comp words (Jiri Olsa) [1131394]
- [tools] perf/completion: Strip dependency on bash-completion (Jiri Olsa) [1131394]
- [tools] perf/completion: Strip function_exists () (Jiri Olsa) [1131394]
- [tools] perf/completion: Strip dependency on _filedir (Jiri Olsa) [1131394]
- [tools] perf/completion: Update __ltrim_colon_completions (Jiri Olsa) [1131394]
- [tools] perf/completion: Don't dictate perf install location (Jiri Olsa) [1131394]
- [tools] perf/trace: Add option to show process COMM (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify eventfd2 'flags' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify send/recv syscall 'flags' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Don't print zeroed args (Jiri Olsa) [1131394]
- [tools] perf/trace: Remove duplicate mmap entry in syscall_fmts array (Jiri Olsa) [1131394]
- [tools] perf/trace: Add option to show full timestamp (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify rlmimit resources (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify access 'mode' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify socket 'type' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify socket 'family' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify signal number arg in several syscalls (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify rt_sigprocmask 'how' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify fcntl 'cmd' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Use strarray for ltrace's whence arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Allow passing parms to arg formatters (Jiri Olsa) [1131394]
- [tools] perf/trace: Put syscall formatter parms into struct (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up feature_print_code() (Jiri Olsa) [1131394]
- [tools] perf/build: Pass through LDFLAGS to feature tests (Jiri Olsa) [1131394]
- [tools] perf/build: Harmonize the style of the feature testcases (Jiri Olsa) [1131394]
- [tools] perf/build: Fix O=/some/dir perf.o type of targets (Jiri Olsa) [1131394]
- [tools] perf/build: Fix non-canonical directory names in O= (Jiri Olsa) [1131394]
- [tools] perf/build: Exclude MAKEFLAGS from nested invocation (Jiri Olsa) [1131394]
- [tools] perf/build: Make sure autodep feature binaries honor the O= setting (Jiri Olsa) [1131394]
- [tools] perf/build: Pass through all targets to Makefile.perf (Jiri Olsa) [1131394]
- [tools] perf/build: Collapse the test-all.c testcase (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up various testcases (Jiri Olsa) [1131394]
- [tools] perf/build: Remove unused config/feature-tests.mak (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature checks 'liberty', 'liberty-z', 'cplus-demangle' (Jiri Olsa) [1131394]
- [tools] perf/build: Standardize the various messages output by parallel make (Jiri Olsa) [1131394]
- [tools] perf/build: Flip Makefile.parallel and Makefile.perf (Jiri Olsa) [1131394]
- [tools] perf/build: Automatically build in parallel, based on number of CPUs in the system (Jiri Olsa) [1131394]
- [tools] perf/build: Improve printout-of auto-detected features (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up auto-detection (Jiri Olsa) [1131394]
- [tools] perf/build: Invoke feature-checks 'clean' target from the main Makefile (Jiri Olsa) [1131394]
- [tools] perf: Fix double/triple-build of the feature detection logic during 'make install' et al (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up the final link (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up git-version test on re-make (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up auto-detection of features by adding a 'test-all' target (Jiri Olsa) [1131394]
- [tools] perf: Turn strlcpy() into a __weak function (Jiri Olsa) [1131394]
- [tools] perf: Clean up util/include/linux/compiler.h (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'backtrace' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'on-exit' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'strlcpy' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libbfd' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libpython-version' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libpython' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libperl' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'gtk2-infobar' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'gtk2' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libslang' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libaudit' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libunwind' (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up the libunwind logic in config/Makefile (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libelf-getphdrnum' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libelf-mmap' (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up the mmap logic in config/Makefile (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'dwarf' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'glibc' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libelf' (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up the libelf logic in config/Makefile (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'bionic' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'fortify-source' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'volatile-register-var' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'stackprotector' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'stackprotector-all' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libnuma' (Jiri Olsa) [1131394]
- [tools] perf/build: Add 'autodep' functionality, generate feature test dependencies automatically (Jiri Olsa) [1131394]
- [tools] perf/build: Add feature check core code (Jiri Olsa) [1131394]
- [tools] perf: standardize feature support define names to HAVE_{FEATURE}_SUPPORT (Jiri Olsa) [1131394]
- [tools] perf: Add support for record transaction flags (Jiri Olsa) [1131394]
- [tools] perf/record: Add abort_tx, no_tx, in_tx branch filter options to perf record -j (Jiri Olsa) [1131394]
- [tools] perf: Support sorting by in_tx or abort branch flags (Jiri Olsa) [1131394]
- [tools] perf: Fix sorting for 64bit entries (Jiri Olsa) [1131394]
- [tools] perf: Disable all pmus on unthrottling and rescheduling (Jiri Olsa) [1131394]
- [x86] perf: Fix constraint table end marker bug (Jiri Olsa) [1131394]
- [tools] perf: Remove fragile swevent hlist optimization (Jiri Olsa) [1131394]
- [tools] perf: Factor out strncpy() in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Update a stale comment (Jiri Olsa) [1131394]
- [tools] perf: Optimize perf_output_begin() -- address calculation (Jiri Olsa) [1131394]
- [tools] perf: Optimize perf_output_begin() -- lost_event case (Jiri Olsa) [1131394]
- [tools] perf: Optimize perf_output_begin() (Jiri Olsa) [1131394]
- [tools] perf: Add unlikely() to the ring-buffer code (Jiri Olsa) [1131394]
- [tools] perf: Simplify the ring-buffer code (Jiri Olsa) [1131394]
- [tools] perf: Fix the perf context switch optimization (Jiri Olsa) [1131394]
- [tools] perf: Change zero-padding of strings in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Do not waste PAGE_SIZE bytes for ALIGN(8) in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Kill the dead !vma->vm_mm code in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Remove useless atomic_t (Jiri Olsa) [1131394]
- [x86] perf: Optimize intel_pmu_pebs_fixup_ip() (Jiri Olsa) [1131394]
- [x86] perf: Suppress duplicated abort LBR records (Jiri Olsa) [1131394]
- [x86] perf: Add Haswell specific transaction flag reporting (Jiri Olsa) [1131394]
- [tools] perf: Add generic transaction flags (Jiri Olsa) [1131394]
- [tools] perf: Enforce 1 as lower limit for perf_event_max_sample_rate (Jiri Olsa) [1131394]
- [x86] perf/intel: Fix build warning in intel_pmu_drain_pebs_nhm() (Jiri Olsa) [1131394]
- [x86] perf/intel: Remove division from the intel_pmu_drain_pebs_nhm() hot path (Jiri Olsa) [1131394]
- [x86] perf/intel: Clean up EVENT_ATTR_STR() muck (Jiri Olsa) [1131394]
- [x86] perf/intel: Clean-up/reduce PEBS code (Jiri Olsa) [1131394]
- [x86] perf/intel: Clean up checkpoint-interrupt bits (Jiri Olsa) [1131394]
- [x86] perf/intel: Add Haswell TSX event aliases (Jiri Olsa) [1131394]
- [x86] perf: Report TSX transaction abort cost as weight (Jiri Olsa) [1131394]
- [x86] perf/intel: Avoid checkpointed counters causing excessive TSX aborts (Jiri Olsa) [1131394]

* Wed Sep 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-154.el7]
- [scsi] ipr: Add new CCIN definition for Grand Canyon support (Gustavo Duarte) [1088561]
- [scsi] ipr: Format HCAM overlay ID 0x21 (Gustavo Duarte) [1088561]
- [scsi] ipr: Handle early EEH (Gustavo Duarte) [1088561]
- [scsi] ipr: Add new CCIN definition for new hardware support (Gustavo Duarte) [1088561]
- [scsi] ipr: Remove extended delay bit on GSCSI reads/writes ops (Gustavo Duarte) [1088561]
- [scsi] ipr: increase dump size in ipr driver (Gustavo Duarte) [1088561]
- [kernel] trace: Remove function_trace_stop and HAVE_FUNCTION_TRACE_MCOUNT_TEST (Josh Poimboeuf) [1113829]
- [s390] ftrace: remove check of obsolete variable function_trace_stop (Josh Poimboeuf) [1113829]
- [x86] ftrace: Remove check of obsolete variable function_trace_stop (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Remove check for HAVE_FUNCTION_TRACE_MCOUNT_TEST (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Remove function_trace_stop check from list func (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Do no disable function tracing on enabling function tracing (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Remove ftrace_start/stop() (Josh Poimboeuf) [1113829]
- [kernel] ftrace-graph: Remove usage of ftrace_stop() in ftrace_graph_stop() (Josh Poimboeuf) [1113829]
- [powerpc] kernel/ftrace: Add call to ftrace_graph_is_dead() in function graph code (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Add call to ftrace_graph_is_dead() in function graph code (Josh Poimboeuf) [1113829]
- [kernel] ftrace-graph: Remove dependency of ftrace_stop() from ftrace_graph_stop() (Josh Poimboeuf) [1113829]
- [kernel] trace: Remove ftrace_stop/start() from reading the trace file (Josh Poimboeuf) [1113829]
- [kernel] power: Remove ftrace_stop/start() from suspend and hibernate (Josh Poimboeuf) [1113829]
- [x86] power/cpu: Annotate restore_processor_state() with notrace (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Move the mcount/fentry code out of entry_64.S (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Load ftrace_ops in parameter not the variable holding it (Josh Poimboeuf) [1113829]
- [kernel] trace: Remove unused function ftrace_off_permanent() (Josh Poimboeuf) [1113829]
- [kernel] ftrace: BUG when ftrace recovery fails (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Have ftrace_write() return -EPERM and clean up callers (Josh Poimboeuf) [1113829]
- [kernel] ftrace: One more missing sync after fixup of function modification failure (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Run a sync after fixup on failure (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Use breakpoints for converting function graph caller (Josh Poimboeuf) [1113829]
- [kernel] ftrace: skip over the breakpoint for ftrace caller (Josh Poimboeuf) [1113829]
- [s390] kprobes: add support for pc-relative long displacement instructions (Hendrik Brueckner) [1123429]
- [kernel] kprobes: allow to specify custom allocator for insn caches (Hendrik Brueckner) [1123429]
- [kernel] kprobes: unify insn caches (Hendrik Brueckner) [1123429]
- [kernel] uprobes: Rename arch_uprobe->def to ->defparam, minor comment updates (Oleg Nesterov) [1073627]
- [kernel] uprobes: Fix scratch register selection for rip-relative fixups (Oleg Nesterov) [1073627]
- [kernel] uprobes: Simplify rip-relative handling (Oleg Nesterov) [1073627]
- [kernel] uprobes: Simplify riprel_{pre,post}_xol() and make them similar (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill the "autask" arg of riprel_pre_xol() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Rename *riprel* helpers to make the naming consistent (Oleg Nesterov) [1073627]
- [kernel] uprobes: Cleanup the usage of UPROBE_FIX_IP/UPROBE_FIX_CALL (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill adjust_ret_addr(), simplify UPROBE_FIX_CALL logic (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce push_ret_address() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Cleanup the usage of arch_uprobe->def.fixups, make it u8 (Oleg Nesterov) [1073627]
- [kernel] uprobes: Move default_xol_ops's data into arch_uprobe->def (Oleg Nesterov) [1073627]
- [kernel] uprobes: Move UPROBE_FIX_SETF logic from arch_uprobe_post_xol() to default_post_xol_op() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Don't use arch_uprobe_abort_xol() in arch_uprobe_post_xol() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce uprobe_xol_ops->abort() and default_abort_op() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Don't change the task's state if ->pre_xol() fails (Oleg Nesterov) [1073627]
- [kernel] uprobes: Fix is_64bit_mm() with CONFIG_X86_X32 (Oleg Nesterov) [1073627]
- [kernel] uprobes: Make good_insns_* depend on CONFIG_X86_* (Oleg Nesterov) [1073627]
- [kernel] uprobes: Shift "insn_complete" from branch_setup_xol_ops() to uprobe_init_insn() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Add is_64bit_mm(), kill validate_insn_bits() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Add uprobe_init_insn(), kill validate_insn_{32,64}bits() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Refuse to attach uprobe to "word-sized" branch insns (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate relative conditional "near" jmp's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate relative conditional "short" jmp's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate relative call's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate nop's using ops->emulate() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate unconditional relative jmp's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce sizeof_long(), cleanup adjust_ret_addr() and arch_uretprobe_hijack_return_addr() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Teach arch_uprobe_post_xol() to restart if possible (Oleg Nesterov) [1073627]
- [kernel] uprobes: Send SIGILL if arch_uprobe_post_xol() fails (Oleg Nesterov) [1073627]
- [kernel] uprobes: Conditionalize the usage of handle_riprel_insn() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce uprobe_xol_ops and arch_uprobe->ops (Oleg Nesterov) [1073627]
- [kernel] uprobes: move the UPROBE_FIX_{RIP,IP,CALL} code at the end of pre/post hooks (Oleg Nesterov) [1073627]
- [kernel] uprobes: Gather "riprel" functions together (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill the "ia32_compat" check in handle_riprel_insn(), remove "mm" arg (Oleg Nesterov) [1073627]
- [kernel] uprobes: Fold prepare_fixups() into arch_uprobe_analyze_insn() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill UPROBE_SKIP_SSTEP and can_skip_sstep() (Oleg Nesterov) [1073627]

* Fri Sep 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-153.el7]
- [ethernet] enic: Add ethtool support to show classifier filters added by the driver (Stefan Assmann) [1107934]
- [ethernet] enic: remove #ifdef CONFIG_RFS_ACCEL around filter structures (Stefan Assmann) [1107934]
- [ethernet] enic: fix return values in enic_set_coalesce (Stefan Assmann) [1107934]
- [ethernet] enic: Make dummy rfs functions inline to fix !CONFIG_RFS_ACCEL build (Stefan Assmann) [1107934]
- [ethernet] enic: do tx cleanup in napi poll (Stefan Assmann) [1107934]
- [ethernet] enic: add low latency socket busy_poll support (Stefan Assmann) [1107934]
- [ethernet] enic: fix lockdep around devcmd_lock (Stefan Assmann) [1107934]
- [ethernet] enic: Add Accelerated RFS support (Stefan Assmann) [1107934]
- [net] Add skb_get_hash_raw (Stefan Assmann) [1107934]
- [net] flow_keys: Record IP layer protocol in skb_flow_dissect() (Stefan Assmann) [1107934]
- [ethernet] enic: alloc/free rx_cpu_rmap (Stefan Assmann) [1107934]
- [ethernet] enic: devcmd for adding IP 5 tuple hardware filters (Stefan Assmann) [1107934]
- [ethernet] enic: fix return value in _vnic_dev_cmd (Stefan Assmann) [1107934]
- [ethernet] enic: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Stefan Assmann) [1107934]
- [ethernet] enic: Fix 64 bit divide on 32bit system (Stefan Assmann) [1107934]
- [ethernet] enic: Add support for adaptive interrupt coalescing (Stefan Assmann) [1107934]
- [ethernet] enic: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1107934]
- [ethernet] enic: include irq.h for irqreturn_t definitions (Stefan Assmann) [1107934]
- [ethernet] enic: Call dev_kfree_skb_any instead of dev_kfree_skb (Stefan Assmann) [1107934]
- [ethernet] enic: Don't receive packets when the napi budget == 0 (Stefan Assmann) [1107934]
- [ethernet] enic: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1107934]
- [ethernet] enic: slight optimization of addr compare (Stefan Assmann) [1107934]
- [ethernet] enic: cisco-enic calls skb_set_hash (Stefan Assmann) [1107934]
- [ethernet] enic: remove unnecessary pci_set_drvdata() (Stefan Assmann) [1107934]
- [ethernet] i40e/i40evf: Bump i40e & i40evf version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Ignore a driver perceived Tx hang if the number of desc pending < 4 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add max buf len to aq debug print helper (Stefan Assmann) [1091127]
- [ethernet] i40evf: Remove DEFINE_PCI_DEVICE_TABLE macro use (Stefan Assmann) [1091127]
- [ethernet] i40evf: Fixed guest OS panic when removing vf driver (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix memory leak on unused interfaces (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't leak queue vectors (Stefan Assmann) [1091127]
- [ethernet] i40evf: do not re-arm watchdog after remove (Stefan Assmann) [1091127]
- [ethernet] i40evf: future-proof vfr_stat state check (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix scan warning on sprintf (Stefan Assmann) [1091127]
- [ethernet] i40e: always print aqtx answer (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: ARQ copy desc data even for failed commands (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't wait so long (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix extension header csum logic (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add nvmupdate support (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Clean up code (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove unnecessary break after goto (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.21 and i40evf to 0.9.40 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add set_fc and init of FC settings (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add new HW link info variable an_enabled and function update_link_info (Stefan Assmann) [1091127]
- [ethernet] i40evf: invite vector 0 to the interrupt party (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Force a shifted '1' to be unsigned (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't violate scope (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Do not free the dummy packet buffer synchronously (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.19 and i40evf to 0.9.38 (Stefan Assmann) [1091127]
- [ethernet] i40evf: change branding string (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: initialize context descriptor (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add ASQ write back timeout variable to AQ structure (Stefan Assmann) [1091127]
- [ethernet] i40evf: set flags before sending message (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: clear aq bah-bal on shutdown (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add base address registers to aq struct (Stefan Assmann) [1091127]
- [ethernet] i40evf: resend FW request if no response (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix typo (Stefan Assmann) [1091127]
- [ethernet] i40evf: return more useful error information (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't stop watchdog if it hasn't started (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Big endian fixes for handling HMC (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.17 and i40evf to 0.9.36 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove reserved type (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.13 and i40evf to 0.9.35 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: modify debug prints to avoid seg faults (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Update RSS configuration (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix off-by-one (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Reset Head and Tail on AQ initialization (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: i40e_register.h update (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to version 0.4.10 and i40evf to 0.9.34 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add Flow director stats to PF stats (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove FTYPE (Stefan Assmann) [1091127]
- [ethernet] i40evf: check admin queue error bits (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: User ether_addr_copy instead of memcpy (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't go further down (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: AdminQ API update for new FW (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: set headwb Tx context flags and use them (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: bump version to 0.4.7 for i40e and 0.9.31 for i40evf (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add PPRS bit to error bits and fix bug in Rx checksum (Stefan Assmann) [1091127]
- [ethernet] i40evf: Fix function header (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove deprecated device IDs (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix poll weight (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix TSO accounting (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove chatty reset messages (Stefan Assmann) [1091127]
- [ethernet] i40evf: use correct format for printing MAC addresses (Stefan Assmann) [1091127]
- [ethernet] i40evf: clean up log message formatting (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove bogus comment (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove unnecessary log messages (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Clean up a few things (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Fix code to accommodate i40e_register.h changes (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix rx descriptor status (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add Tx pre queue disable function (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: check AQ register for valid data (Stefan Assmann) [1091127]
- [ethernet] i40evf: make messages less dire (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove rx_errors and rx_missed (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: VEB structure added, GTIME macro update (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix crash when changing ring sizes (Stefan Assmann) [1091127]
- [ethernet] i40evf: set descriptor multiple to 32 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove unused RX_LRO define (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't use RESETTING state during reinit (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Change type to u32 to avoid sparse error (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove storm control (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Remove reserved PCTYPE defines (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Update check for AQ aliveness (Stefan Assmann) [1091127]
- [ethernet] i40evf: Use is_multicast_ether_addr helper (Stefan Assmann) [1091127]
- [ethernet] i40e: remove usless return statements (Stefan Assmann) [1091127]
- [ethernet] i40evf: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: control auto ITR through ethtool (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: set proper default for ITR registers (Stefan Assmann) [1091127]
- [ethernet] i40evf: make ethtool_ops const (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't lie to ethtool (Stefan Assmann) [1091127]
- [ethernet] i40evf: Use macro param for ethtool stats (Stefan Assmann) [1091127]
- [ethernet] i40evf: Fix the headers and update copyright year (Stefan Assmann) [1091127]
- [ethernet] i40evf: Remove unused defines (Stefan Assmann) [1091127]
- [ethernet] i40evf: Update AdminQ interface (Stefan Assmann) [1091127]
- [ethernet] i40evf: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Retrieve and store missing link config information (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove debugging message (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix panic on PF driver fail (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add driver version string to driver version command (Stefan Assmann) [1091127]
- [ethernet] i40evf: support ethtool RSS options (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: update AdminQ API (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add tracking to NVM busy state (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: unhide and enable to one prefena field (Stefan Assmann) [1091127]
- [ethernet] i40evf: program RSS LUT correctly (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove open-coded skb_cow_head (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Remove addressof casts to same type (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix error checking path (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add an FD message level (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove double space after return (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix oops in watchdog handler (Stefan Assmann) [1091127]
- [ethernet] i40evf: clean up init error messages (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't shut down admin queue on error (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add EEE LPI stats (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: reduce context descriptors (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: enable hardware feature head write back (Stefan Assmann) [1091127]
- [ethernet] i40evf: use min_t (Stefan Assmann) [1091127]
- [ethernet] i40evf: correctly program RSS HLUT table (Stefan Assmann) [1091127]
- [ethernet] i40evf: Rename i40e_ptype_lookup i40evf_ptype_lookup (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Use dma_set_mask_and_coherent (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Use correct number of VF vectors (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Some flow director HW definition fixes (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump pf&vf build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: carefully fill tx ring (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: i40e implementation for skb_set_hash (Stefan Assmann) [1091127]
- [ethernet] i40evf: Enable the ndo_set_features netdev op (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump driver versions (Stefan Assmann) [1091127]
- [ethernet] i40e: Change MSIX to MSI-X (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove errant space (Stefan Assmann) [1091127]
- [ethernet] i40evf: update version and copyright date (Stefan Assmann) [1091127]
- [ethernet] i40evf: store ring size in ring structs (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't guess device name (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove bogus comment (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix up strings in init task (Stefan Assmann) [1091127]
- [ethernet] i40evf: get rid of pci_using_dac (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix multiple crashes on remove (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove VLAN filters on close (Stefan Assmann) [1091127]
- [ethernet] i40evf: request reset on tx hang (Stefan Assmann) [1091127]
- [ethernet] i40evf: Remove duplicate include (Stefan Assmann) [1091127]
- [ethernet] i40evf: refactor reset handling (Stefan Assmann) [1091127]
- [ethernet] i40evf: change type of flags variable (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't store unnecessary array of strings (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix bogus comment (Stefan Assmann) [1091127]
- [ethernet] i40evf: clean up adapter struct (Stefan Assmann) [1091127]
- [ethernet] i40evf: trivial fixes (Stefan Assmann) [1091127]
- [ethernet] i40e: spelling error (Stefan Assmann) [1091127]
- [ethernet] i40e: Fix device ID define names to align to standard (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e & i40evf version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Ignore a driver perceived Tx hang if the number of desc pending < 4 (Stefan Assmann) [1091126]
- [ethernet] i40e: quiet complaints when removing default MAC VLAN filter and make set_mac reversible (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add max buf len to aq debug print helper (Stefan Assmann) [1091126]
- [ethernet] i40e: Add checks and message for Qualified Module info (Stefan Assmann) [1091126]
- [ethernet] i40e: set num_queue_pairs to num configured by VF (Stefan Assmann) [1091126]
- [ethernet] i40e: Enable l2tsel bit for VLAN tag control (Stefan Assmann) [1091126]
- [ethernet] i40e: Add a FD flush counter to ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e: ATR policy change to flush the table to clean stale ATR rules (Stefan Assmann) [1091126]
- [ethernet] i40e: Some FD message fixes (Stefan Assmann) [1091126]
- [ethernet] i40e: Update flow director error messages to reduce user confusion (Stefan Assmann) [1091126]
- [ethernet] i40e: fix PTP bug (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a few potential VF dereferences (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix for recent kernel panic (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove DEFINE_PCI_DEVICE_TABLE macro use (Stefan Assmann) [1091126]
- [ethernet] i40e: Cleaning up missing null-terminate in conjunction with strncpy (Stefan Assmann) [1091126]
- [ethernet] i40e: use correct structure type name in sizeof (Stefan Assmann) [1091126]
- [ethernet] i40e: fix sparse non static symbol warning (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix missing uapi/linux/dcbnl.h include in i40e_fcoe.c (Stefan Assmann) [1091126]
- [ethernet] i40e: remove support for vf unicast promiscuous mode (Stefan Assmann) [1091126]
- [ethernet] i40e: Minor comment changes (Stefan Assmann) [1091126]
- [ethernet] i40e: disable local loopback on vmdq vsi (Stefan Assmann) [1091126]
- [ethernet] i40e: use correct vf_id offset for virtchnl message (Stefan Assmann) [1091126]
- [ethernet] i40e: expose debug_write_register request (Stefan Assmann) [1091126]
- [ethernet] i40e: adds FCoE to build and updates its documentation (Stefan Assmann) [1091126]
- [ethernet] i40e: Adds FCoE related code to i40e core driver (Stefan Assmann) [1091126]
- [ethernet] i40e: adds FCoE code to the i40e driver (Stefan Assmann) [1091126]
- [ethernet] i40e: always print aqtx answer (Stefan Assmann) [1091126]
- [ethernet] i40e: Give link more time after setting flow control (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix firmware API version errors (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: ARQ copy desc data even for failed commands (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix extension header csum logic (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add nvmupdate support (Stefan Assmann) [1091126]
- [ethernet] i40e: fix format mismatch in drivers/net/ethernet/intel/i40e/i40e_debugfs.c (Stefan Assmann) [1091126]
- [ethernet] i40e: (ptp) warn when PF_ID does not match in PRTTSYN_CTL0 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Clean up code (Stefan Assmann) [1091126]
- [ethernet] i40e: fix race conditions on queuing skb for HW time stamp (Stefan Assmann) [1091126]
- [ethernet] i40e: never generate both software and hardware timestamps (Stefan Assmann) [1091126]
- [ethernet] i40e: Add ndo_get_phys_port_id() callback support (Stefan Assmann) [1091126]
- [ethernet] i40e: remove unnecessary break after goto (Stefan Assmann) [1091126]
- [net] bridge: fdb dumping takes a filter device (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.21 and i40evf to 0.9.40 (Stefan Assmann) [1091126]
- [ethernet] i40e: Implement set_settings for ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e: Add set_pauseparam to ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add set_fc and init of FC settings (Stefan Assmann) [1091126]
- [ethernet] i40e: move nway reset (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add new HW link info variable an_enabled and function update_link_info (Stefan Assmann) [1091126]
- [ethernet] i40e: Finish implementation of ethtool get settings (Stefan Assmann) [1091126]
- [ethernet] i40e: disable TPH (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a boundary condition and turning off of ntuple (Stefan Assmann) [1091126]
- [ethernet] i40e: tolerate lost interrupts (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Force a shifted '1' to be unsigned (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Do not free the dummy packet buffer synchronously (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.19 and i40evf to 0.9.38 (Stefan Assmann) [1091126]
- [ethernet] i40e: remove linux/export.h header from i40e_ptp.c (Stefan Assmann) [1091126]
- [ethernet] i40e: limit GLLAN_TXPRE_QDIS to QINDX 0-127 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: initialize context descriptor (Stefan Assmann) [1091126]
- [ethernet] i40e: FD filter replay logic bug fix (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add ASQ write back timeout variable to AQ structure (Stefan Assmann) [1091126]
- [ethernet] i40e: Correct mask assignment value (Stefan Assmann) [1091126]
- [ethernet] i40e: clear all queues and interrupts (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: clear aq bah-bal on shutdown (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add base address registers to aq struct (Stefan Assmann) [1091126]
- [ethernet] i40e: fix fdir programming (Stefan Assmann) [1091126]
- [ethernet] i40e: Add debugfs hooks to print current total FD filter count (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix the FD sideband logic to detect a FD table full condition (Stefan Assmann) [1091126]
- [ethernet] i40e: Avoid adding the TCP-IPv4 filter twice (Stefan Assmann) [1091126]
- [ethernet] i40e: only create PTP device node once (Stefan Assmann) [1091126]
- [ethernet] i40e: don't store user requested mode until we've validated it (Stefan Assmann) [1091126]
- [ethernet] i40e: break PTP hardware control from ioctl command for timestamp mode (Stefan Assmann) [1091126]
- [ethernet] i40e: rename i40e_ptp_enable to i40e_ptp_feature_enable (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Big endian fixes for handling HMC (Stefan Assmann) [1091126]
- [ethernet] i40e: do not take NVM ownership for SR read (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.17 and i40evf to 0.9.36 (Stefan Assmann) [1091126]
- [ethernet] i40e: Bypass timeout recovery level 0 so as to not cause MDD (Stefan Assmann) [1091126]
- [ethernet] i40e: no pf reset at pci remove (Stefan Assmann) [1091126]
- [ethernet] i40e: reapply LAA after reset (Stefan Assmann) [1091126]
- [ethernet] i40e: allow user to set LAA again (Stefan Assmann) [1091126]
- [ethernet] i40e: use WoL flag when setting LAA (Stefan Assmann) [1091126]
- [ethernet] i40e: Add ablitity to enable/disable link from set_link_restart_an (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove reserved type (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix ethtool coalesce settings (Stefan Assmann) [1091126]
- [ethernet] i40e: fix a stray print message (Stefan Assmann) [1091126]
- [ethernet] i40e: warn on newer/older firmware API rev (Stefan Assmann) [1091126]
- [ethernet] i40e: Add PF reset when Malicious driver event for PF (Stefan Assmann) [1091126]
- [ethernet] i40e: make prep_for_reset void (Stefan Assmann) [1091126]
- [ethernet] i40e: Stop the VF device after setting its MAC address (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.13 and i40evf to 0.9.35 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: modify debug prints to avoid seg faults (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Update RSS configuration (Stefan Assmann) [1091126]
- [ethernet] i40e: keep service tasks out of reset process (Stefan Assmann) [1091126]
- [ethernet] i40e: clear VEB stats when pf stats are cleared (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix scheduling while atomic bug during NAPI (Stefan Assmann) [1091126]
- [ethernet] i40e: debugfs fix to dump remote LLDPDU (Stefan Assmann) [1091126]
- [ethernet] i40e: Helper routine for Rx/Tx queue enable/disable wait (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix dangling ring pointers upon driver removal (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Reset Head and Tail on AQ initialization (Stefan Assmann) [1091126]
- [ethernet] i40e: workaround NVM GLQF_HKEY (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: i40e_register.h update (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to version 0.4.10 and i40evf to 0.9.34 (Stefan Assmann) [1091126]
- [ethernet] i40e: use stored base_queue value (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a bug in ethtool for FD drop packet filter action (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add Flow director stats to PF stats (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove FTYPE (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: User ether_addr_copy instead of memcpy (Stefan Assmann) [1091126]
- [net] etherdevice: Use ether_addr_copy to copy an Ethernet address (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not accept tagged packets by default (Stefan Assmann) [1091126]
- [ethernet] i40e: Separate out DCB capability and enabled flags (Stefan Assmann) [1091126]
- [ethernet] i40e: Change the notion of src and dst for FD_SB in ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: AdminQ API update for new FW (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: set headwb Tx context flags and use them (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: bump version to 0.4.7 for i40e and 0.9.31 for i40evf (Stefan Assmann) [1091126]
- [ethernet] i40e: Allow RSS table entry range and GPS to be any number, not necessarily power of 2 (Stefan Assmann) [1091126]
- [ethernet] i40e: Delete stale MAC filters after change (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not fall back to one queue model if the only feature enabled is ATR (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add PPRS bit to error bits and fix bug in Rx checksum (Stefan Assmann) [1091126]
- [ethernet] i40e: keep SR-IOV enabled in the case that RSS, VMDQ, FD_SB and DCB are disabled (Stefan Assmann) [1091126]
- [ethernet] i40e: Changes to Interrupt distribution policy (Stefan Assmann) [1091126]
- [ethernet] i40e: implement anti-spoofing for VFs (Stefan Assmann) [1091126]
- [ethernet] i40e: don't complain about removing non-existent addresses (Stefan Assmann) [1091126]
- [ethernet] i40e: remove unused variable and memory allocation (Stefan Assmann) [1091126]
- [ethernet] i40e: allow for more VSIs (Stefan Assmann) [1091126]
- [ethernet] i40e: add checks for AQ error status bits (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove deprecated device IDs (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix poll weight (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix TSO accounting (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove chatty reset messages (Stefan Assmann) [1091126]
- [ethernet] i40e: not all VSIs have rings (Stefan Assmann) [1091126]
- [ethernet] i40e: clear pxe after adminq is rebuilt (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix incorrect feature configuration status (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Clean up a few things (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Fix code to accommodate i40e_register.h changes (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix rx descriptor status (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091126]
- [ethernet] i40e: remove irqs only when they are set up (Stefan Assmann) [1091126]
- [ethernet] i40e: don't remove HMC that doesn't exist (Stefan Assmann) [1091126]
- [ethernet] i40e: print full link message (Stefan Assmann) [1091126]
- [ethernet] i40e: add xcast stats for port (Stefan Assmann) [1091126]
- [ethernet] i40e: add vsi x-cast stats (Stefan Assmann) [1091126]
- [ethernet] i40e: increase reset wait time (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add Tx pre queue disable function (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: check AQ register for valid data (Stefan Assmann) [1091126]
- [ethernet] i40e: print message for pre-production hardware (Stefan Assmann) [1091126]
- [ethernet] i40e: add VEB stats to ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e: set lan_veb index (Stefan Assmann) [1091126]
- [ethernet] i40e: add missing VSI statistics (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove rx_errors and rx_missed (Stefan Assmann) [1091126]
- [ethernet] i40e: refactor stats collection (Stefan Assmann) [1091126]
- [ethernet] i40e: refactor send version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: VEB structure added, GTIME macro update (Stefan Assmann) [1091126]
- [ethernet] i40e: notify VF of all types of resets (Stefan Assmann) [1091126]
- [ethernet] i40e: clamp jumbo frame size (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove unused RX_LRO define (Stefan Assmann) [1091126]
- [ethernet] i40e: remove check for large buffer (Stefan Assmann) [1091126]
- [ethernet] i40e: Rework register diagnostic (Stefan Assmann) [1091126]
- [ethernet] i40e: don't use OR to check a value (Stefan Assmann) [1091126]
- [ethernet] i40e: relax the firmware API version check (Stefan Assmann) [1091126]
- [ethernet] i40e: disable FCoE for MFP modes (Stefan Assmann) [1091126]
- [ethernet] i40e: add clear_pxe AdminQ request (Stefan Assmann) [1091126]
- [ethernet] i40e: Clear recovery pending, if reset failed (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Change type to u32 to avoid sparse error (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove storm control (Stefan Assmann) [1091126]
- [ethernet] i40e: Use the new i40e_get_fd_cnt_all function in other places (Stefan Assmann) [1091126]
- [ethernet] i40e: Report cmd->data in ETHTOOL_GRXCLSRLCNT instead of ETHTOOL_GRXCLSRULE (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Remove reserved PCTYPE defines (Stefan Assmann) [1091126]
- [ethernet] i40e: Tx/Rx rings declaration (Stefan Assmann) [1091126]
- [ethernet] i40evf: tweak Tx rate params and de-magic-ify (Stefan Assmann) [1091126]
- [ethernet] i40evf: don't round Tx rate down to 0 (Stefan Assmann) [1091126]
- [ethernet] i40e: enable descriptor prefetch for VFs (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Update check for AQ aliveness (Stefan Assmann) [1091126]
- [ethernet] i40e: remove usless return statements (Stefan Assmann) [1091126]
- [ethernet] i40e: fix passing wrong error code to i40e_open() (Stefan Assmann) [1091126]
- [ethernet] i40e: Check PCI_IOV config to avoid compile error (Stefan Assmann) [1091126]
- [ethernet] i40e: remove Tx work for ptp (Stefan Assmann) [1091126]
- [ethernet] i40e: Don't disable SR-IOV when VFs are assigned (Stefan Assmann) [1091126]
- [ethernet] i40e: remove hardcode of stats struct size in ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: control auto ITR through ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: set proper default for ITR registers (Stefan Assmann) [1091126]
- [ethernet] i40e: add required include (Stefan Assmann) [1091126]
- [ethernet] i40e: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Retrieve and store missing link config information (Stefan Assmann) [1091126]
- [ethernet] i40e: Update function formal parameters (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not expose fd-sb commands from debugfs (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not enable NTUPLE feature control in MFP mode (Stefan Assmann) [1091126]
- [ethernet] i40e: Change variable type to avoid typecheck failure (Stefan Assmann) [1091126]
- [ethernet] i40e: Don't stop driver probe when querying DCB config fails (Stefan Assmann) [1091126]
- [ethernet] i40e: Redistribute queue vectors after DCB reconfiguration (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add driver version string to driver version command (Stefan Assmann) [1091126]
- [ethernet] i40e: Use port VLAN in MAC/VLAN filter configuration (Stefan Assmann) [1091126]
- [ethernet] i40e: Retain MAC filters when changing port VLAN (Stefan Assmann) [1091126]
- [ethernet] i40e: remove ptp_tx_work timestamp work item (Stefan Assmann) [1091126]
- [ethernet] i40e: fix Timesync Tx interrupt handler code (Stefan Assmann) [1091126]
- [ethernet] i40e: report VF link state correctly (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091126]
- [ethernet] i40e: Tweak for-loop in i40e_ethtool.c (Stefan Assmann) [1091126]
- [ethernet] i40e: Cleanup if/else statements (Stefan Assmann) [1091126]
- [ethernet] i40e: rework fdir setup and teardown (Stefan Assmann) [1091126]
- [ethernet] i40e: use generic vsi_open to unquiesce vsi (Stefan Assmann) [1091126]
- [ethernet] i40e: abstract the close path for better netdev vsis (Stefan Assmann) [1091126]
- [ethernet] i40e: prep vsi_open logic for non-netdev cases (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: update AdminQ API (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add tracking to NVM busy state (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix an issue with displaying IPv4 FD filters (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove a FW workaround (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091126]
- [ethernet] i40e: Enable VF Tx bandwidth setting (Stefan Assmann) [1091126]
- [ethernet] i40e: Reset the VF upon conflicting VLAN configuration (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: unhide and enable to one prefena field (Stefan Assmann) [1091126]
- [ethernet] i40e: Add bridge FDB add/del/dump ops (Stefan Assmann) [1091126]
- [ethernet] i40e: fix message terminations (Stefan Assmann) [1091126]
- [ethernet] i40e: fix TCP flag replication for hardware offload (Stefan Assmann) [1091126]
- [ethernet] i40e: remove open-coded skb_cow_head (Stefan Assmann) [1091126]
- [ethernet] i40e: Mass conversion of smp_mb__*() (Stefan Assmann) [1091126]
- [powerpc] asm: Convert smp_mb__*() (Stefan Assmann) [1091126]
- [s390] asm: Convert smp_mb__*() (Stefan Assmann) [1091126]
- [x86] asm: Convert smp_mb__*() (Stefan Assmann) [1091126]
- [kernel] sched: Prepare for smp_mb__{before, after}_atomic() (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove casts of pointer to same type (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Remove addressof casts to same type (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix error checking path (Stefan Assmann) [1091126]
- [ethernet] i40e: fix function kernel doc description (Stefan Assmann) [1091126]
- [ethernet] i40e: Use DEBUG_FD message level for an FD message (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add an FD message level (Stefan Assmann) [1091126]
- [ethernet] i40e: check for netdev before debugfs use (Stefan Assmann) [1091126]
- [ethernet] i40e: Add functionality for FD SB to drop packets (Stefan Assmann) [1091126]
- [ethernet] i40e: Cleanup in FDIR SB ethtool code (Stefan Assmann) [1091126]
- [ethernet] i40e: eeprom integrity check on load and empr (Stefan Assmann) [1091126]
- [ethernet] i40e: Make the alloc and free queue vector calls orthogonal (Stefan Assmann) [1091126]
- [ethernet] i40e: Delete ATR filter on RST (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a message string (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add EEE LPI stats (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091126]
- [ethernet] i40e: potential array underflow in i40e_vc_process_vf_msg() (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: reduce context descriptors (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: enable hardware feature head write back (Stefan Assmann) [1091126]
- [ethernet] i40e: Refactor and cleanup i40e_open(), adding i40e_vsi_open() (Stefan Assmann) [1091126]
- [ethernet] i40e: Patch to enable Ethtool/netdev feature flag for NTUPLE control (Stefan Assmann) [1091126]
- [ethernet] i40e: support VF link state ndo (Stefan Assmann) [1091126]
- [ethernet] i40e: Avoid double setting of NETIF_F_SG for the HW encapsulation feature mask (Stefan Assmann) [1091126]
- [ethernet] i40e: Don't receive packets when the napi budget == 0 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Use dma_set_mask_and_coherent (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Use correct number of VF vectors (Stefan Assmann) [1091126]
- [ethernet] i40e: Let MDD events be handled by MDD handler (Stefan Assmann) [1091126]
- [ethernet] i40e: Bug fix for FDIR replay logic (Stefan Assmann) [1091126]
- [ethernet] i40e: Add code to handle FD table full condition (Stefan Assmann) [1091126]
- [ethernet] i40e: Define a new state variable to keep track of feature auto disable (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix function comments (Stefan Assmann) [1091126]
- [ethernet] i40e: simplified init string (Stefan Assmann) [1091126]
- [ethernet] i40e: cleanup strings (Stefan Assmann) [1091126]
- [ethernet] i40e: make string references to q be queue (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Some flow director HW definition fixes (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a bug in the update logic for FDIR SB filter (Stefan Assmann) [1091126]
- [ethernet] i40e: delete netdev after deleting napi and vectors (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump pf&vf build versions (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: carefully fill tx ring (Stefan Assmann) [1091126]
- [ethernet] i40e: fix nvm version and remove firmware report (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix static checker warning (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove a redundant filter addition (Stefan Assmann) [1091126]
- [ethernet] i40e: count timeout events (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove a FW workaround for Number of MSIX vectors (Stefan Assmann) [1091126]
- [ethernet] i40e: clean up comment style (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: i40e implementation for skb_set_hash (Stefan Assmann) [1091126]
- [ethernet] i40e: Prevent overflow due to kzalloc (Stefan Assmann) [1091126]
- [ethernet] i40e: Flow Director sideband accounting (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump driver versions (Stefan Assmann) [1091126]
- [ethernet] i40e: Change MSIX to MSI-X (Stefan Assmann) [1091126]
- [ethernet] i40e: tighten up ring enable/disable flow (Stefan Assmann) [1091126]
- [ethernet] i40e: remove unnecessary delay (Stefan Assmann) [1091126]
- [ethernet] i40e: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091126]
- [ethernet] i40e: don't handle VF reset on unload (Stefan Assmann) [1091126]
- [ethernet] i40e: enable extant VFs (Stefan Assmann) [1091126]
- [ethernet] i40e: reset VFs after PF reset (Stefan Assmann) [1091126]
- [ethernet] i40e: set VF state to active when reset is complete (Stefan Assmann) [1091126]
- [ethernet] i40e: remove dead code (Stefan Assmann) [1091126]
- [ethernet] i40e: Setting i40e_down bit for tx_timeout (Stefan Assmann) [1091126]
- [ethernet] i40evf: clean up memsets (Stefan Assmann) [1091126]
- [ethernet] i40e: bump driver version (Stefan Assmann) [1091126]
- [ethernet] i40e: spelling error (Stefan Assmann) [1091126]
- [ethernet] i40e: Add missing braces to i40e_dcb_need_reconfig() (Stefan Assmann) [1091126]
- [net] sunrpc: get rid of use_gssp_lock ("J. Bruce Fields") [1117914]
- [net] sunrpc: fix potential race between setting use_gss_proxy and the upcall rpc_clnt ("J. Bruce Fields") [1117914]
- [net] sunrpc: don't wait for write before allowing reads from use-gss-proxy file ("J. Bruce Fields") [1117914]
- [net] sunrpc: trim off EC bytes in GSSAPI v2 unwrap ("J. Bruce Fields") [1117914]
- [net] svcrpc: handle some gssproxy encoding errors ("J. Bruce Fields") [1117914]
- [net] svcrpc: fix error-handling on badd gssproxy downcall ("J. Bruce Fields") [1117914]

* Thu Sep 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-152.el7]
- [scsi] scsi_lib: remove the description string in scsi_io_completion() (Maurizio Lombardi) [1045998]
- [scsi] sd: fix a bug in deriving the FLUSH_TIMEOUT from the basic I/O timeout (Ewan Milne) [1123906]
- [scsi] scsi_debug: simple short transfer injection (Ewan Milne) [1132100]
- [scsi] scsi_debug: add ability to enable clustering (Ewan Milne) [1132100]
- [scsi] scsi_debug: protect device access with atomic_rw lock (Ewan Milne) [1132100]
- [scsi] scsi_debug: prepare to enable clustering (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix resp_xdwriteread() return value when running out of memory (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix duplicate dif_errors increment (Ewan Milne) [1132100]
- [scsi] scsi_debug: make pseudo_primary static (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix false positive logical block reference tag check fail (Ewan Milne) [1132100]
- [scsi] scsi_debug: simplify creation and destruction of driver attribute files (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix sparse warnings related to data integrity field (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix invalid value check for guard module parameter (Ewan Milne) [1132100]
- [scsi] scsi_debug: avoid partial copying PI from prot_sglist to dif_storep (Ewan Milne) [1132100]
- [scsi] scsi_debug: factor out copying PI from dif_storep to prot_sglist (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix buffer overrun when DIF/DIX is enabled and virtual_gb > 0 (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix logical block provisioning support when unmap_alignment != 0 (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix do_device_access() with wrap around range (Ewan Milne) [1132100]
- [scsi] lib/scatterlist: introduce sg_pcopy_from_buffer() and sg_pcopy_to_buffer() (Ewan Milne) [1132100]
- [scsi] lib/scatterlist: factor out sg_miter_get_next_page() from sg_miter_next() (Ewan Milne) [1132100]
- [scsi] scsi_debug: reduce duplication between prot_verify_read and prot_verify_write (Ewan Milne) [1132100]
- [scsi] scsi_debug: simplify offset calculation for dif_storep (Ewan Milne) [1132100]
- [scsi] scsi_debug: invalidate protection info for unmapped region (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix NULL pointer dereference with parameters dif=0 dix=1 (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix incorrectly nested kmap_atomic() (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix invalid address passed to kunmap_atomic() (Ewan Milne) [1132100]
- [scsi] use dev_printk variants where possible (Ewan Milne) [998695]
- [scsi] use dev_printk() variants for ioctl (Ewan Milne) [998695]
- [scsi] Implement st_printk() (Ewan Milne) [998695]
- [scsi] Implement ch_printk() (Ewan Milne) [998695]
- [scsi] Implement sg_printk() (Ewan Milne) [998695]
- [scsi] Implement sr_printk() (Ewan Milne) [998695]
- [scsi] ses: Use vpd information from scsi_device (Ewan Milne) [1132092]
- [scsi] Add EVPD page 0x83 and 0x80 to sysfs (Ewan Milne) [1132092]
- [scsi] Return VPD page length in scsi_vpd_inquiry() (Ewan Milne) [1132092]
- [scsi] Workaround for disks that report bad optimal transfer length (Ewan Milne) [1132092]
- [scsi] sg: O_EXCL and other lock handling (Ewan Milne) [1132092]
- [scsi] sg: add SG_FLAG_Q_AT_TAIL flag (Ewan Milne) [1132092]
- [scsi] sg: relax 16 byte cdb restriction (Ewan Milne) [1132092]
- [scsi] scsi constants: command, sense key + additional sense strings (Ewan Milne) [1132092]
- [scsi] scsi_error: disable eh_deadline if no host_reset_handler is set (Ewan Milne) [1132092]
- [scsi] cleanup switch in scsi_adjust_queue_depth (Ewan Milne) [1132092]
- [scsi] set correct completion code in scsi_send_eh_cmnd() (Ewan Milne) [1132092]
- [scsi] Spelling hsot -> host (Ewan Milne) [1132092]
- [scsi] scsi_sysfs: Implement 'is_visible' callback (Ewan Milne) [1132092]
- [scsi] export device_busy for sdev (Ewan Milne) [1132092]
- [scsi] fc: ensure scan_work isn't active when freeing fc_rport (Ewan Milne) [1132092]
- [scsi] scsi_transport_fc: Add 32Gbps speed definition (Ewan Milne) [1132092]
- [scsi] sd: bad return code of init_sd (Ewan Milne) [1132092]
- [scsi] sd: notify block layer when using temporary change to cache_type (Ewan Milne) [1132092]
- [scsi] sd: medium access timeout counter fails to reset (Ewan Milne) [1101729]
- [scsi] sd: Quiesce mode sense error messages (Ewan Milne) [1132092]
- [scsi] sd: Do not call do_div() with a 64-bit divisor (Ewan Milne) [1132092]
- [scsi] sd: Reduce buffer size for vpd request (Ewan Milne) [1132092]
- [scsi] sd: avoid deadlocks when running under multipath (Ewan Milne) [1132092]
- [scsi] st: fix enlarge_buffer (Ewan Milne) [1132092]
- [scsi] use the scsi data buffer length to extract transfer size (Ewan Milne) [1132092]
- [scsi] scsi_cmnd: Introduce scsi_transfer_length helper (Ewan Milne) [1132092]
- [scsi] Add CDB definition for COMPARE_AND_WRITE (Ewan Milne) [1132092]

* Thu Sep 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-151.el7]
- [md] raid6: avoid data corruption during recovery of double-degraded RAID6 (Jes Sorensen) [1130905]
- [block] scsi_ioctl: verify return pointer from blk_get_request (Jeff Moyer) [1104324]
- [pnp] pnpacpi: Fix acpi_pnp_match() (Myron Stowe) [1128632]
- [pnp] pnpacpi: Do not return errors if _DIS or _SRS are not present (Myron Stowe) [1128632]
- [acpi] dock: Make 'docked' sysfs attribute work as documented (Myron Stowe) [1128632]
- [acpi] dock: Use acpi_device_enumerated() to check if dock is present (Myron Stowe) [1128632]
- [acpi] hotplug: Fix panic on eject to ejected device (Myron Stowe) [1128632]
- [acpi] scan: Clear match_driver flag in acpi_bus_trim() (Myron Stowe) [1128632]
- [acpi] scan: Use direct recurrence for device hierarchy walks (Myron Stowe) [1128632]
- [acpi] Introduce acpi_set_device_status() (Myron Stowe) [1128632]
- [acpi] hotplug: Drop unfinished global notification handling routines (Myron Stowe) [1128632]
- [acpi] hotplug: Rework generic code to handle suprise removals (Myron Stowe) [1128632]
- [acpi] hotplug: Move container-specific code out of the core (Myron Stowe) [1128632]
- [acpi] hotplug: Make ACPI PCI root hotplug use common hotplug code (Myron Stowe) [1128632]
- [acpi] hotplug: Introduce common hotplug function acpi_device_hotplug() (Myron Stowe) [1128632]
- [acpi] hotplug: Do not fail bus and device checks for disabled hotplug (Myron Stowe) [1128632]
- [acpi] scan: Add acpi_device objects for all device nodes in the namespace (Myron Stowe) [1128632]
- [acpi] scan: Define non-empty device removal handler (Myron Stowe) [1128632]
- [acpi] core: Store an ACPI device pointer in struct acpi_dev_node (Myron Stowe) [1128632]
- [acpi] pm: Drop two functions that are not used any more (Myron Stowe) [1128632]
- [acpi] power: Drop automaitc resume of power resource dependent devices (Myron Stowe) [1128632]
- [acpi] Use EXPORT_SYMBOL() for acpi_bus_get_device() (Myron Stowe) [1128632]
- [acpi] Print diagnostic messages if device links cannot be created (Myron Stowe) [1128632]
- [acpi] Drop unnecessary label from acpi_bind_one() (Myron Stowe) [1128632]
- [acpi] Clean up error code path in acpi_unbind_one() (Myron Stowe) [1128632]
- [acpi] Use list_for_each_entry() in acpi_unbind_one() (Myron Stowe) [1128632]
- [acpi] acpi_bind_one()/acpi_unbind_one() whitespace cleanups (Myron Stowe) [1128632]
- [acpi] Create symlinks in acpi_bind_one() under physical_node_lock (Myron Stowe) [1128632]
- [acpi] Reduce acpi_bind_one()/acpi_unbind_one() code duplication (Myron Stowe) [1128632]
- [acpi] Do not fail acpi_bind_one() if device is already bound correctly (Myron Stowe) [1128632]
- [acpi] Move acpi_bus_get_device() from bus.c to scan.c (Myron Stowe) [1128632]
- [acpi] pm: Use ACPI_STATE_D3_COLD instead of ACPI_STATE_D3 everywhere (Myron Stowe) [1128632]
- [usb] xhci: convert TRB_CYCLE to le32 before using it to set Link TRB's cycle bit (Steve Best) [1123119]
- [usb] xhci: fix incorrect type in assignment in handle_device_notification() (Steve Best) [1123119]
- [input] alps: Rushmore and v7 resolution support (Benjamin Tissoires) [1107819]
- [input] alps: add support for v7 devices (Benjamin Tissoires) [1107819]
- [input] alps: cache firmware version (Benjamin Tissoires) [1107819]
- [input] alps: change decode function prototype to return an int (Benjamin Tissoires) [1107819]
- [input] alps: report 2 touches when we've > 2 fingers (Benjamin Tissoires) [1107819]
- [input] alps: add an alps_report_semi_mt_data function (Benjamin Tissoires) [1107819]
- [input] alps: use single touch data when v3 mt data contains only one finger (Benjamin Tissoires) [1107819]
- [input] alps: use standard contact tracking instead of DIY (Benjamin Tissoires) [1107819]
- [input] alps: use struct input_mt_pos to track coordinates (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, round down when spreading adjescent fingers over 2 points (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, fix counting of high point bits (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, add alps_get_bitmap_points() helper function (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, don't invert the Y-axis on Rushmore (Benjamin Tissoires) [1107819]
- [input] alps: improve 2-finger reporting on v3 models (Benjamin Tissoires) [1107819]
- [input] alps: fix rushmore packet decoding (Benjamin Tissoires) [1107819]
- [input] alps: add support for "Dolphin" devices (Benjamin Tissoires) [1107819]
- [input] alps: add support for DualPoint device on Dell XT2 model (Benjamin Tissoires) [1107819]
- [input] alps: change secondary device's name (Benjamin Tissoires) [1107819]
- [tools] turbostat: tweak whitespace in output format (Prarit Bhargava) [1133893]
- [tools] cpupower: bench/parse.c, Fix several minor errors (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove redundant error check (Prarit Bhargava) [1133893]
- [tools] cpupower: mperf monitor, Correct use of ! and & (Prarit Bhargava) [1133893]
- [tools] cpupower: drop negativity check on unsigned value (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove mc and smt power aware scheduler info/settings (Prarit Bhargava) [1133893]
- [tools] cpupower: cpupower info -b should return 0 on success, not the perf bias value (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove dead link to homepage, and update the targets built (Prarit Bhargava) [1133893]
- [tools] cpupower: Rename cpufrequtils -> cpupower, and libcpufreq -> libcpupower (Prarit Bhargava) [1133893]
- [tools] cpupower: If root, try to load msr driver on x86 if /dev/cpu/0/msr is not available (Prarit Bhargava) [1133893]
- [tools] cpupower: Install recently added cpupower-idle-{set, info} manpages (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove all manpages on make uninstall (Prarit Bhargava) [1133893]
- [tools] cpupower: Introduce idle state disable-by-latency and enable-all (Prarit Bhargava) [1133893]
- [tools] turbostat: Drop temperature checks (Prarit Bhargava) [1133893]
- [tools] cpufreq: Make linux-pm@vger.kernel.org official mailing list (Prarit Bhargava) [1133893]
- [tools] turbostat: simplify output, add Avg_MHz (Prarit Bhargava) [1133893]
- [tools] turbostat: introduce -s to dump counters (Prarit Bhargava) [1133893]
- [tools] turbostat: remove unused command line option (Prarit Bhargava) [1133893]
- [tools] turbostat: Add option to report joules consumed per sample (Prarit Bhargava) [1133893]
- [tools] turbostat: Clean up error handling; disambiguate error messages; use err and errx (Prarit Bhargava) [1133893]
- [tools] turbostat: Add a .gitignore to ignore the compiled turbostat binary (Prarit Bhargava) [1133893]
- [tools] turbostat: Factor out common function to open file and exit on failure (Prarit Bhargava) [1133893]
- [tools] turbostat: Add a helper to parse a single int out of a file (Prarit Bhargava) [1133893]
- [tools] turbostat: Check return value of fscanf (Prarit Bhargava) [1133893]
- [tools] turbostat: Don't attempt to printf an off_t with zx (Prarit Bhargava) [1133893]
- [tools] turbostat: Use GCC's CPUID functions to support PIC (Prarit Bhargava) [1133893]
- [tools] turbostat: Don't put unprocessed uapi headers in the include path (Prarit Bhargava) [1133893]
- [tools] cpupower: Fix sscanf robustness in cpufreq-set (Prarit Bhargava) [1133893]
- [tools] cpupower: Fix segfault due to incorrect getopt_long arugments (Prarit Bhargava) [1133893]
- [tools] cpupower: fix wrong err msg not supported vs not available (Prarit Bhargava) [1133893]
- [tools] cpupower: Add cpupower-idle-set(1) manpage (Prarit Bhargava) [1133893]
- [virt] virtio-scsi: Skip setting affinity on uninitialized vq (Fam Zheng) [1083860]
- [mm] memcontrol: remove hierarchy restrictions for swappiness and oom_control (Johannes Weiner) [1124110]
- [mm] thp: fix copy_page_rep GPF by testing is_huge_zero_pmd once only (Rik van Riel) [1123040]
- [mm] numa: Remove BUG_ON() in __handle_mm_fault() (Rik van Riel) [1119439]
- [iommu] Add empty stub for iommu_group_get_by_id() (Steve Best) [1123122]
- [input] Revert: wacom: testing result shows get_report is unnecessary (Aristeu Rozanski) [1079541]
- [kernel] kexec: fix build error when hugetlbfs is disabled (Baoquan He) [1115240]
- [kernel] kexec: export free_huge_page to VMCOREINFO (Baoquan He) [1115240]
- [kernel] kexec: save PG_head_mask in VMCOREINFO (Baoquan He) [1115240]
- [block] nvme: Fix START_STOP_UNIT Scsi->NVMe translation (David Milburn) [1111259]
- [block] nvme: Use Log Page constants in SCSI emulation (David Milburn) [1111259]
- [block] nvme: Define Log Page constants (David Milburn) [1111259]
- [block] nvme: Fix hot cpu notification dead lock (David Milburn) [1111259]
- [block] nvme: Rename io_timeout to nvme_io_timeout (David Milburn) [1111259]
- [block] nvme: Use last bytes of f/w rev SCSI Inquiry (David Milburn) [1111259]
- [block] nvme: Adhere to request queue block accounting enable/disable (David Milburn) [1111259]
- [block] nvme: Fix nvme get/put queue semantics (David Milburn) [1111259]
- [block] nvme: Delete NVME_GET_FEAT_TEMP_THRESH (David Milburn) [1111259]
- [block] nvme: Make admin timeout a module parameter (David Milburn) [1111259]
- [block] nvme: Make iod bio timeout a parameter (David Milburn) [1111259]
- [block] nvme: Prevent possible NULL pointer dereference (David Milburn) [1111259]
- [block] nvme: Fix the buffer size passed in GetLogPage(CDW10.NUMD) (David Milburn) [1111259]
- [block] nvme: Update data structures for NVMe 1.2 (David Milburn) [1111259]
- [block] nvme: Enable BUILD_BUG_ON checks (David Milburn) [1111259]
- [block] nvme: Update namespace and controller identify structures to the 1.1a spec (David Milburn) [1111259]
- [block] nvme: Flush with data support (David Milburn) [1111259]
- [block] nvme: Configure support for block flush (David Milburn) [1111259]
- [block] nvme: Add tracepoints (David Milburn) [1111259]
- [block] nvme: Protect against badly formatted CQEs (David Milburn) [1111259]
- [block] nvme: Improve error messages (David Milburn) [1111259]
- [block] nvme: Update copyright headers (David Milburn) [1111259]
- [powerpc] 64bit sendfile is capped at 2GB (Gustavo Duarte) [1107774]
- [powerpc] sched: stop updating inside arch_update_cpu_topology() when nothing to be update (Gustavo Duarte) [1098372]
- [firewire] ohci: fix probe failure with Agere/LSI controllers (Neil Horman) [994878]
- [firewire] ohci: beautify some macro definitions (Neil Horman) [994878]
- [s390] airq: silence lockdep warning (Hendrik Brueckner) [1088554]
- [virt] virtio_scsi: don't call virtqueue_add_sgs(... GFP_NOIO) holding spinlock (Hendrik Brueckner) [1088554]
- [virt] virtio_ccw: introduce device_lost in virtio_ccw_device (Hendrik Brueckner) [1088554]
- [virt] virtio: virtio_break_device() to mark all virtqueues broken (Hendrik Brueckner) [1088554]
- [virt] s390/sclp_vt220: Fix kernel panic due to early terminal input (Hendrik Brueckner) [1088554]
- [virt] virtio: fail adding buffer on broken queues (Hendrik Brueckner) [1088554]
- [virt] virtio_net: don't crash if virtqueue is broken (Hendrik Brueckner) [1088554]
- [virt] s390/virtio_ccw: fix hang in set offline processing (Hendrik Brueckner) [1088554]
- [s390] irq: improve displayed interrupt order in /proc/interrupts (Hendrik Brueckner) [1088554]
- [virt] virtio-ccw: virtio-ccw adapter interrupt support (Hendrik Brueckner) [1088554]
- [virt] virtio_ccw: fix vcdev pointer handling issues (Hendrik Brueckner) [1088554]
- [virt] s390/airq: add support for irq ranges (Hendrik Brueckner) [1088554]
- [virt] kvm/s390/virtio-ccw: Handle command rejects (Hendrik Brueckner) [1088554]
- [virt] virtio_scsi: verify if queue is broken after virtqueue_get_buf() (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: adapt to notify() returning bool (Hendrik Brueckner) [1088554]
- [virt] virtio_net: verify if queue is broken after virtqueue_get_buf() (Hendrik Brueckner) [1088554]
- [virt] virtio_blk: verify if queue is broken after virtqueue_get_buf() (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: add new function virtqueue_is_broken() (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: let virtqueue_{kick()/notify()} return a bool (Hendrik Brueckner) [1088554]
- [virt] tools/virtio: fix missing kmemleak_ignore symbol (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: plug kmemleak false positive (Hendrik Brueckner) [1088554]
- [mm] page_alloc: do not cache reclaim distances (Larry Woodman) [1120342]
- [mm] disable zone_reclaim_mode by default (Larry Woodman) [1120342]

* Tue Sep 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-150.el7]
- [net] team: set IFF_TEAM_PORT priv_flag after rx_handler is registered (Jiri Pirko) [1132943]
- [net] ipv6: fix calculation of option len in ip6_append_data (Hannes Frederic Sowa) [1127218]
- [net] ipv6: pmtudisc setting not respected with UFO/CORK (Hannes Frederic Sowa) [1127218]
- [net] ipv4: fix DO and PROBE pmtu mode regarding local fragmentation with UFO/CORK (Hannes Frederic Sowa) [1127218]
- [net] clear local_df when passing skb between namespaces (Jiri Pirko) [1128223]
- [net] rtnetlink: fix VF info size (Jiri Benc) [1128267]
- [net] netfilter: connlimit: move lock array out of struct connlimit_data (Florian Westphal) [1052282]
- [net] netfilter: connlimit: use rbtree for per-host conntrack obj storage (Florian Westphal) [1052282]
- [net] netfilter: connlimit: make same_source_net signed (Florian Westphal) [1052282]
- [net] netfilter: connlimit: use keyed locks (Florian Westphal) [1052282]
- [net] netfilter: connlimit: use kmem_cache for conn objects (Florian Westphal) [1052282]
- [net] netfilter: connlimit: move insertion of new element out of count function (Florian Westphal) [1052282]
- [net] netfilter: connlimit: improve packet-to-closed-connection logic (Florian Westphal) [1052282]
- [net] netfilter: connlimit: factor hlist search into new function (Florian Westphal) [1052282]
- [net] ipv6: increase ip6_rt_max_size to 16384 (Hannes Frederic Sowa) [1119364]
- [net] ipv6: don't count addrconf generated routes against gc limit (Hannes Frederic Sowa) [1119364]
- [net] tcp: add tcp_syncookies mode to allow unconditionally generation of syncookies (Florian Westphal) [1084439]
- [net] tcp: syncookies: do not use getnstimeofday() (Florian Westphal) [1084439]
- [net] tcp: syncookies: reduce mss table to four values (Florian Westphal) [1084439]
- [net] tcp: syncookies: reduce cookie lifetime to 128 seconds (Florian Westphal) [1084439]
- [net] sctp: only warn in proc_sctp_do_alpha_beta if write (Daniel Borkmann) [1110290]
- [net] sctp: check proc_dointvec result in proc_sctp_do_auth (Daniel Borkmann) [1110290]
- [net] sctp: propagate sysctl errors from proc_do* properly (Daniel Borkmann) [1110290]
- [net] sctp: fix permissions for rto_alpha and rto_beta knobs (Daniel Borkmann) [1110290]
- [net] sctp: cache auth_enable per endpoint (Daniel Borkmann) [1110290]
- [net] sctp: fix a missed .data initialization (Daniel Borkmann) [1110290]
- [net] sctp: fix up a spacing (Daniel Borkmann) [1110290]
- [net] sctp: add check rto_min and rto_max in sysctl (Daniel Borkmann) [1110290]
- [net] Revert: introduce netif_skb_dev_features (Florian Westphal) [1109214]
- [net] ip: push gso skb forwarding handling down the stack (Florian Westphal) [1109214]
- [net] ipv6: send pkttoobig immediately if orig frag size > mtu (Florian Westphal) [1109214]
- [net] ipv4: ip_forward: fix inverted local_df test (Florian Westphal) [1109214]
- [net] netfilter: ipv4: defrag: set local_df flag on defragmented skb (Florian Westphal) [1109214]
- [net] don't account for udp header size when computing seglen (Florian Westphal) [1109214]

* Tue Sep 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-149.el7]
- [fs] ext4: fix type declaration of ext4_validate_block_bitmap (Lukas Czerner) [1091055]
- [fs] ext4: error out if verifying the block bitmap fails (Lukas Czerner) [1091055]
- [fs] cifs: Fix memory leaks in SMB2_open (Sachin Prabhu) [1082049]
- [fs] cifs: ensure that vol->username is not NULL before running strlen on it (Sachin Prabhu) [1082049]
- [fs] cifs: Clarify SMB2/SMB3 create context and add missing ones (Sachin Prabhu) [1082049]
- [fs] cifs: Do not send ClientGUID on SMB2.02 dialect (Sachin Prabhu) [1082049]
- [fs] cifs: Set client guid on per connection basis (Sachin Prabhu) [1082049]
- [fs] cifs/netmisc: convert printk to pr_foo() (Sachin Prabhu) [1082049]
- [fs] cifs: replace seq_printf by seq_puts (Sachin Prabhu) [1082049]
- [fs] cifs: Update cifs version number to 2.03 (Sachin Prabhu) [1082049]
- [fs] cifs: new helper file_inode(file) (Sachin Prabhu) [1082049]
- [fs] cifs: fix potential races in cifs_revalidate_mapping (Sachin Prabhu) [1082049]
- [fs] cifs: new helper function: cifs_revalidate_mapping (Sachin Prabhu) [1082049]
- [fs] cifs: convert booleans in cifsInodeInfo to a flags field (Sachin Prabhu) [1082049]
- [fs] cifs: fix cifs_uniqueid_to_ino_t not to ever return 0 (Sachin Prabhu) [1082049]
- [fs] cifs: fix actimeo=0 corner case when cifs_i->time == jiffies (Sachin Prabhu) [1082049]
- [fs] cifs: fix dead code (Sachin Prabhu) [1082049]
- [fs] cifs: fix error handling cifs_user_readv (Sachin Prabhu) [1082049]
- [fs] cifs: remove unused variable (Sachin Prabhu) [1082049]
- [fs] cifs: Return correct error on query of xattr on file with empty xattrs (Sachin Prabhu) [1082049]
- [fs] cifs: fix the race in cifs_writev() (Sachin Prabhu) [1082049]
- [fs] cifs: add __init to cifs_init_inodecache() (Sachin Prabhu) [1082049]
- [fs] cifs: ->rename() without ->lookup() makes no sense (Sachin Prabhu) [1082049]
- [fs] cifs: Fix too big maxBuf size for SMB3 mounts (Sachin Prabhu) [1082049]
- [fs] cifs: Fix cifsacl mounts over smb2 to not call cifs (Sachin Prabhu) [1082049]
- [fs] cifs: retrieving CIFS ACLs when mounted with SMB2 fails dropping session (Sachin Prabhu) [1082049]
- [fs] cifs: Add protocol specific operation for CIFS xattrs (Sachin Prabhu) [1082049]
- [fs] cifs: Fix SMB2 mounts so they don't try to set or get xattrs via cifs (Sachin Prabhu) [1082049]
- [fs] cifs: Cleanup cifs open codepath (Sachin Prabhu) [1082049]
- [fs] cifs: Remove extra indentation in cifs_sfu_type (Sachin Prabhu) [1082049]
- [fs] cifs: Cleanup cifs_mknod (Sachin Prabhu) [1082049]
- [fs] cifs: Cleanup CIFSSMBOpen (Sachin Prabhu) [1082049]
- [fs] cifs: Fix memory leak in cifs_hardlink() (Sachin Prabhu) [1082049]
- [fs] cifs: Add missing end of line termination to some cifs messages (Sachin Prabhu) [1082049]
- [fs] cifs: Do not use btrfs refcopy ioctl for SMB2 copy offload (Sachin Prabhu) [1082049]
- [fs] cifs: Check SMB3 dialects against downgrade attacks (Sachin Prabhu) [1082049]
- [fs] cifs: Removed duplicated (and unneeded) goto (Sachin Prabhu) [1082049]
- [fs] cifs: Fix SMB2/SMB3 Copy offload support (refcopy) for large files (Sachin Prabhu) [1082049]
- [fs] cifs: Warn if SMB3 encryption required by server (Sachin Prabhu) [1082049]
- [fs] cifs: Set copychunk defaults (Sachin Prabhu) [1082049]
- [fs] cifs: SMB2/SMB3 Copy offload support (refcopy) phase 1 (Sachin Prabhu) [1082049]
- [fs] cifs: Use data structures to compute NTLMv2 response offsets (Sachin Prabhu) [1082049]
- [fs] cifs: O_DIRECT opens should work on directio mounts (Sachin Prabhu) [1082049]
- [fs] cifs: don't spam the logs on unexpected lookup errors (Sachin Prabhu) [1082049]
- [fs] cifs: change ERRnomem error mapping from ENOMEM to EREMOTEIO (Sachin Prabhu) [1082049]
- [fs] cifs: Fix symbolic links usage (Sachin Prabhu) [1082049]
- [fs] cifs: Query network adapter info at mount time for debugging (Sachin Prabhu) [1082049]
- [fs] cifs: Fix unused variable warning when CIFS POSIX disabled (Sachin Prabhu) [1082049]
- [fs] cifs: Allow setting per-file compression via CIFS protocol (Sachin Prabhu) [1082049]
- [fs] cifs: Query File System Alignment (Sachin Prabhu) [1082049]
- [fs] cifs: Query device characteristics at mount time from server on SMB2/3 not just on cifs mounts (Sachin Prabhu) [1082049]
- [fs] cifs: Send a logoff request before removing a smb session (Sachin Prabhu) [1082049]
- [fs] cifs: Make big endian multiplex ID sequences monotonic on the wire (Sachin Prabhu) [1082049]
- [fs] cifs: Remove redundant multiplex identifier check from check_smb_hdr() (Sachin Prabhu) [1082049]
- [fs] cifs: Query file system attributes from server on SMB2, not just cifs, mounts (Sachin Prabhu) [1082049]
- [fs] cifs: Allow setting per-file compression via SMB2/3 (Sachin Prabhu) [1082049]
- [fs] cifs: Fix corrupt SMB2 ioctl requests (Sachin Prabhu) [1082049]
- [fs] cifs: rcu-delay unload_nls() and freeing sbi (Sachin Prabhu) [1082049]
- [fs] cifs: new helper kfree_put_link() (Sachin Prabhu) [1082049]
- [fs] cifs: ntstatus_to_dos_map[] is not terminated (Sachin Prabhu) [1082049]
- [fs] cifs: Allow LANMAN auth method for servers supporting unencapsulated authentication methods (Sachin Prabhu) [1082049]
- [fs] cifs: Fix inability to write files >2GB to SMB2/3 shares (Sachin Prabhu) [1082049]
- [fs] cifs: Avoid umount hangs with smb2 when server is unresponsive (Sachin Prabhu) [1082049]
- [fs] cifs: do not treat non-symlink reparse points as valid symlinks (Sachin Prabhu) [1082049]
- [fs] cifs: update cifs.ko version (Sachin Prabhu) [1082049]
- [fs] cifs: Provide sane values for nlink (Sachin Prabhu) [1082049]
- [fs] cifs: FS-Cache: Uncache unread pages in cifs_readpages() before freeing them (Sachin Prabhu) [1082049]
- [fs] cifs: Avoid calling unlock_page() twice in cifs_readpage() when using fscache (Sachin Prabhu) [1082049]
- [fs] cifs: Do not take a reference to the page in cifs_readpage_worker() (Sachin Prabhu) [1082049]
- [fs] cifs: Fix wrong pos argument of cifs_find_lock_conflict (Sachin Prabhu) [1082049]

* Sat Aug 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-148.el7]
- [ethernet] igbvf: Remove DEFINE_PCI_DEVICE_TABLE macro use (Stefan Assmann) [1091122]
- [ethernet] igbvf: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Stefan Assmann) [1091122]
- [ethernet] igbvf: remove usless return statements (Stefan Assmann) [1091122]
- [ethernet] igbvf: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091122]
- [ethernet] igbvf: remove open-coded skb_cow_head (Stefan Assmann) [1091122]
- [ethernet] igbvf: Convert uses of __constant_<foo> to <foo> (Stefan Assmann) [1091122]
- [ethernet] igbvf: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091122]
- [ethernet] igbvf: slight optimization of addr compare (Stefan Assmann) [1091122]
- [ethernet] igbvf: add missing iounmap() on error in igbvf_probe() (Stefan Assmann) [1091122]
- [ethernet] igbvf: integer wrapping bug setting the mtu (Stefan Assmann) [1091122]
- [ethernet] igbvf: Miscellaneous conversions to ETH_ALEN (Stefan Assmann) [1091122]
- [ethernet] igbvf: Remove extern from function prototypes (Stefan Assmann) [1091122]
- [ethernet] igbvf: fix 32-bit DMA mask handling (Stefan Assmann) [1091122]
- [ethernet] igb: bump igb version to 5.2.13 (Stefan Assmann) [1091121]
- [ethernet] igb: Add message when malformed packets detected by hw (Stefan Assmann) [1091121]
- [ethernet] igb: remove unnecessary break after return (Stefan Assmann) [1091121]
- [ethernet] igb: remove unnecessary break after goto (Stefan Assmann) [1091121]
- [ethernet] igb: do a reset on SR-IOV re-init if device is down (Stefan Assmann) [1091121]
- [ethernet] igb: workaround for i210 errata 25, Slow System Clock (Stefan Assmann) [1091121]
- [ethernet] igb: bring link up when PHY is powered up (Stefan Assmann) [1091121]
- [ethernet] igb: separate hardware setting from the set_ts_config ioctl (Stefan Assmann) [1091121]
- [ethernet] igb: Replace 1/0 return values with true/false (Stefan Assmann) [1091121]
- [ethernet] igb: unhide invariant returns (Stefan Assmann) [1091121]
- [ethernet] igb: use ethtool_cmd_speed_set helper to set ethtool speed value (Stefan Assmann) [1091121]
- [ethernet] igb: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Stefan Assmann) [1091121]
- [ethernet] igb: add defaults for i210 TX/RX PBSIZE (Stefan Assmann) [1091121]
- [ethernet] igb: use mac loopback for i354 backplane (Stefan Assmann) [1091121]
- [ethernet] igb: rename igb_ptp_enable to igb_ptp_feature_enable (Stefan Assmann) [1091121]
- [ethernet] igb: remove redundant PHY power down register write (Stefan Assmann) [1091121]
- [ethernet] igb: remove usless return statements (Stefan Assmann) [1091121]
- [ethernet] igb: remove return statements for void functions (Stefan Assmann) [1091121]
- [ethernet] igb: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091121]
- [ethernet] igb: Change memcpy to struct assignment (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to remove unneeded extern declaration (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to replace deprecated DEFINE_PCI_DEVICE_TABLE (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix static initialization (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix msleep warnings (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix line length warnings (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to remove return parentheses (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix missing break in switch statements (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix assignment in if error (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to change comment style on license headers (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix for trailing statement (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix pointer location error (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix incorrect indentation (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix braces location warnings (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups for messaging (Stefan Assmann) [1091121]
- [ethernet] igb: fix message terminations (Stefan Assmann) [1091121]
- [ethernet] igb: fix stats for i210 rx_fifo_errors (Stefan Assmann) [1091121]
- [ethernet] igb: fix last_rx_timestamp usage (Stefan Assmann) [1091121]
- [ethernet] igb: remove open-coded skb_cow_head (Stefan Assmann) [1091121]
- [ethernet] igb: Convert iounmap to pci_iounmap (Stefan Assmann) [1091121]
- [ethernet] igb: fix race conditions on queuing skb for HW time stamp (Stefan Assmann) [1091121]
- [ethernet] igb: never generate both software and hardware timestamps (Stefan Assmann) [1091121]
- [ethernet] igb: Unset IGB_FLAG_HAS_MSIX-flag when falling back to msi-only (Stefan Assmann) [1091121]
- [ethernet] igb: Fix Null-pointer dereference in igb_reset_q_vector (Stefan Assmann) [1091121]
- [ethernet] igb: specify phc_index of 82575 for get_ts_info (Stefan Assmann) [1091121]
- [ethernet] igb: Fix memory leak in igb_get_module_eeprom() (Stefan Assmann) [1091121]
- [ethernet] igb: add register rd/wr for surprise removal (Stefan Assmann) [1091121]
- [ethernet] igb: implement SIOCGHWTSTAMP ioctl (Stefan Assmann) [1091121]
- [ethernet] igb: Convert uses of __constant_<foo> to <foo> (Stefan Assmann) [1091121]
- [ethernet] igb: enable VLAN stripping for VMs with i350 (Stefan Assmann) [1091121]
- [ethernet] igb: Add register defines needed for time sync functions (Stefan Assmann) [1091121]
- [ethernet] igb: remove references to long gone command line parameters (Stefan Assmann) [1091121]
- [ethernet] igb: Don't receive packets when the napi budget == 0 (Stefan Assmann) [1091121]
- [ethernet] igb: Fix code comment (Stefan Assmann) [1091121]
- [ethernet] igb: Fix for devices using ethtool for EEE settings (Stefan Assmann) [1091121]
- [ethernet] igb: fix calls to skb_set_hash (Stefan Assmann) [1091121]
- [ethernet] igb: fix warning if !CONFIG_IGB_HWMON (Stefan Assmann) [1091121]
- [ethernet] igb: fix array size calculation (Stefan Assmann) [1091121]
- [ethernet] igb: Update license text to remove FSF address and update copyright (Stefan Assmann) [1091121]
- [ethernet] igb: make local functions static and remove dead code (Stefan Assmann) [1091121]
- [ethernet] igb: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091121]
- [ethernet] igb: Change to use statically allocated array for MSIx entries (Stefan Assmann) [1091121]
- [ethernet] igb: Fix queue allocation method to accommodate changing during runtime (Stefan Assmann) [1091121]
- [ethernet] igb: Fix for issue where values could be too high for udelay function (Stefan Assmann) [1091121]
- [ethernet] igb: Start temperature sensor attribute index with 1 (Stefan Assmann) [1091121]
- [ethernet] igb: Add new feature Media Auto Sense for 82580 devices only (Stefan Assmann) [1091121]
- [ethernet] igb: Support ports mapped in 64-bit PCI space (Stefan Assmann) [1091121]
- [ethernet] igb: Add media switching feature for i354 PHY's (Stefan Assmann) [1091121]
- [ethernet] igb: Fixed Wake On LAN support (Stefan Assmann) [1091121]
- [ethernet] igb: Update link modes display in ethtool (Stefan Assmann) [1091121]
- [ethernet] igb: Explicitly initialize u64_stats_sync structures for lockdep (Stefan Assmann) [1091121]
- [ethernet] igb: Don't let ethtool try to write to iNVM in i210/i211 (Stefan Assmann) [1091121]
- [ethernet] igb: Fix master/slave mode for all m88 i354 PHY's (Stefan Assmann) [1091121]
- [ethernet] igb: Miscellaneous conversions to ETH_ALEN (Stefan Assmann) [1091121]
- [ethernet] igb: Avoid uninitialized advertised variable in eee_set_cur (Stefan Assmann) [1091121]
- [ethernet] igb: Add ethtool support to configure number of channels (Stefan Assmann) [1091121]
- [ethernet] igb: Add ethtool offline tests for i354 (Stefan Assmann) [1091121]
- [ethernet] igb: Fix ethtool loopback test for 82580 copper (Stefan Assmann) [1091121]
- [ethernet] igb: Remove extern from function prototypes (Stefan Assmann) [1091121]
- [ethernet] igb: fix 32-bit DMA mask handling (Stefan Assmann) [1091121]
- [ethernet] igb: Read flow control for i350 from correct EEPROM section (Stefan Assmann) [1091121]
- [ethernet] igb: Add additional get_phy_id call for i354 devices (Stefan Assmann) [1091121]
- [kernel] workqueue: zero cpumask of wq_numa_possible_cpumask on init (Motohiro Kosaki) [1117184]
- [firmware] memmap: don't allocate firmware_map_entry of same memory range (Motohiro Kosaki) [1117186]
- [firmware] memmap: pass the correct argument to firmware_map_find_entry_bootmem() (Motohiro Kosaki) [1117186]
- [cpufreq] acpi-cpufreq: skip loading acpi_cpufreq after intel_pstate (Motohiro Kosaki) [1123250]
- [x86] mem-hotplug: modify PGD entry when removing memory (Motohiro Kosaki) [1116286]
- [x86] mem-hotplug: pass sync_global_pgds() a correct argument in remove_pagetable() (Motohiro Kosaki) [1116286]
- [virt] kvm: increase x86 VCPU limit to 240 (Radim Krcmar) [1061403]
- [kernel] sched/fair: Rework sched_fair time accounting (Rik van Riel) [1123731]
- [kernel] math64: Add mul_u64_u32_shr() (Rik van Riel) [1123731]

* Wed Aug 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-147.el7]
- [s390] fix restore of invalid floating-point-control (Hendrik Brueckner) [1121965]
- [s390] crypto: fix aes_s390 crypto module unload problem (Hendrik Brueckner) [1103114]
- [x86] avx-512: Enable AVX-512 States Context Switch (Rui Wang) [1085563]
- [x86] avx-512: AVX-512 Feature Detection (Rui Wang) [1085563]
- [ethernet] netxen: Remove DEFINE_PCI_DEVICE_TABLE macro use (Veaceslav Falico) [1089356]
- [ethernet] netxen: slight optimization of addr compare (Veaceslav Falico) [1089356]
- [ethernet] netxen: Update version to 4.0.82 (Veaceslav Falico) [1089356]
- [ethernet] netxen: Miscellaneous conversions to ETH_ALEN (Veaceslav Falico) [1089356]
- [ethernet] netxen: get rid of SET_ETHTOOL_OPS (Veaceslav Falico) [1089356]
- [ethernet] netxen: Correct off-by-one errors in bounds checks (Veaceslav Falico) [1089356]
- [ethernet] netxen: remove unnecessary pci_set_drvdata() (Veaceslav Falico) [1089356]
- [ethernet] netxen: Print ULA information (Veaceslav Falico) [1089356]
- [ethernet] netxen: lower NAPI weight (Veaceslav Falico) [1089356]
- [ethernet] netxen: Remove extern from function prototypes (Veaceslav Falico) [1089356]
- [x86] Mark Intel Broadwell processor as supported (Steve Best) [1089025]
- [mm] Fix NULL pointer dereference in madvise(MADV_WILLNEED) support (Jan Stancek) [1072385]
- [hid] logitech-dj: Fix USB 3.0 issue (Benjamin Tissoires) [1110523]
- [lib] percpu_counter: fix bad percpu counter state during suspend (Eric Sandeen) [1129839]
- [kernel] user_namespace: fix incorrect memory barriers (Mikulas Patocka) [1128950]
- [kernel] capabilities: remove undefined caps from all processes (Paul Moore) [1123063]
- [tty] hvc: don't free hvc_console_setup after init (Luiz Capitulino) [976490]
- [mfd] lpc_ich: Add Device IDs for Intel Wildcat Point-LP PCH (Steve Best) [1086359]
- [i2c] i801: Add Device IDs for Intel Wildcat Point-LP PCH (Steve Best) [1086359]
- [x86] perf: Add model number for Avoton Silvermont (Steve Best) [1086821]
- [x86] perf: Add Silvermont (22nm Atom) support (Steve Best) [1086821]
- [x86] perf: use INTEL_UEVENT_EXTRA_REG to define MSR_OFFCORE_RSP_X (Steve Best) [1086821]
- [virt] hyperv/storvsc: Correctly handle TEST_UNIT_READY failure (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Set srb_flags in all cases (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Implement a eh_timed_out handler (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Fix a bug in handling VMBUS protocol version (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Filter commands based on the storage protocol version (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Set cmd_per_lun to reflect value supported by the Host (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Change the limits to reflect the values on the host (Fam Zheng) [1122317]
- [powerpc] perf: Add BHRB constraint and IFM MMCRA handling for EBB (Gustavo Duarte) [1121408]
- [powerpc] perf: Reject EBB events which specify a sample_type (Gustavo Duarte) [1121408]
- [powerpc] perf: Enable BHRB access for EBB events (Gustavo Duarte) [1121408]
- [powerpc] perf: Avoid mutating event in power8_get_constraint() (Gustavo Duarte) [1121408]
- [powerpc] perf: Clean up the EBB hash defines a little (Gustavo Duarte) [1121408]
- [powerpc] mm: Check paca psize is up to date for huge mappings (Gustavo Duarte) [1107337]
- [powerpc] perf: Add lost exception workaround (Gustavo Duarte) [1121407]
- [powerpc] Add a cpu feature CPU_FTR_PMAO_BUG (Gustavo Duarte) [1121407]

* Tue Aug 26 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-146.el7]
- [edac] sb_edac: add support for Haswell based systems (Seth Jennings) [1127019]
- [edac] add DDR4 and RDDR4 (Seth Jennings) [1127019]
- [edac] sb_edac: update Kconfig description (Seth Jennings) [1127019]
- [edac] sb_edac: Fix mix tab/spaces alignments (Seth Jennings) [1127019]
- [edac] sb_edac: remove bogus assumption on mc ordering (Seth Jennings) [1127019]
- [edac] sb_edac: make minimal use of channel_mask (Seth Jennings) [1127019]
- [edac] sb_edac: fix socket detection on Ivy Bridge controllers (Seth Jennings) [1127019]
- [edac] sb_edac: search devices using product id (Seth Jennings) [1127019]
- [edac] sb_edac: Degrade log level for device registration (Seth Jennings) [1127019]
- [edac] sb_edac: make RIR limit retrieval per model (Seth Jennings) [1127019]
- [edac] sb_edac: make node id retrieval per model (Seth Jennings) [1127019]
- [edac] sb_edac: make memory type detection per memory controller (Seth Jennings) [1127019]
- [hwrng] virtio-rng: add derating factor for use by hwrng core (Amit Shah) [1129195]
- [hwrng] Pass entropy to add_hwgenerator_randomness() in bits, not bytes (Amit Shah) [1129195]
- [hwrng] hw_random: fix sparse warning (NULL vs 0 for pointer) (Amit Shah) [1129195]
- [hwrng] add per-device entropy derating (Amit Shah) [1129195]
- [hwrng] create filler thread (Amit Shah) [1129195]
- [hwrng] random: add_hwgenerator_randomness() for feeding entropy from devices (Amit Shah) [1129195]
- [char] Revert: hwrng: virtio - ensure reads happen after successful probe (Amit Shah) [1129195]
- [char] hwrng: virtio - delay hwrng_register() till driver is ready (Amit Shah) [1119299]
- [char] hwrng: virtio - re-arrange struct elements for better packing (Amit Shah) [1119299]
- [char] hwrng: virtio - remove unused struct element (Amit Shah) [1119299]
- [char] hwrng: virtio - ensure reads happen after successful probe (Amit Shah) [1119299]
- [char] hwrng: fetch randomness only after device init (Amit Shah) [1119299]
- [char] hwrng: add randomness to system from rng sources (Amit Shah) [1119299]
- [char] hwrng: cleanup in hwrng_register() (Amit Shah) [1119299]
- [virt] virtio/pm: use CONFIG_PM_SLEEP instead of CONFIG_PM (Amit Shah) [1119299]
- [virt] virtio-rng: fixes for device registration/unregistration (Amos Kong) [915335]
- [virt] virtio-rng: fix boot with virtio-rng device (Amos Kong) [915335]
- [virt] virtio-rng: support multiple virtio-rng devices (Amos Kong) [915335]
- [virt] virtio-rng: don't crash if virtqueue is broken (Amos Kong) [915335]
- [pci] Fix unaligned access in AF transaction pending test (Myron Stowe) [1110896]
- [pci] Wrong register used to check pending traffic (Myron Stowe) [1110896]
- [pci] shpchp: Check bridge's secondary (not primary) bus speed (Myron Stowe) [1110896]
- [pci] Update maintainer email address (Myron Stowe) [1110896]
- [powerpc] pci: Fix NULL dereference in sys_pciconfig_iobase() list traversal (Myron Stowe) [1110896]
- [pci] Log IDE resource quirk in dmesg (Myron Stowe) [1110896]
- [pci] Change pci_bus_alloc_resource() type_mask to unsigned long (Myron Stowe) [1110896]
- [pci] Check all IORESOURCE_TYPE_BITS in pci_bus_alloc_from_region() (Myron Stowe) [1110896]
- [kernel] resources: Set type in __request_region() (Myron Stowe) [1110896]
- [s390] pci: Use generic pci_enable_resources() (Myron Stowe) [1110896]
- [pci] Add "weak" generic pcibios_enable_device() implementation (Myron Stowe) [1110896]
- [pci] Don't enable decoding if BAR hasn't been assigned an address (Myron Stowe) [1110896]
- [pci] Mark 64-bit resource as IORESOURCE_UNSET if we only support 32-bit (Myron Stowe) [1110896]
- [pci] Don't try to claim IORESOURCE_UNSET resources (Myron Stowe) [1110896]
- [pci] Check IORESOURCE_UNSET before updating BAR (Myron Stowe) [1110896]
- [pci] Don't clear IORESOURCE_UNSET when updating BAR (Myron Stowe) [1110896]
- [pci] Mark resources as IORESOURCE_UNSET if we can't assign them (Myron Stowe) [1110896]
- [pci] Remove pci_find_parent_resource() use for allocation (Myron Stowe) [1110896]
- [lib] vsprintf: Add support for IORESOURCE_UNSET in pR (Myron Stowe) [1110896]
- [kernel] resource: Add resource_contains() (Myron Stowe) [1110896]
- [message] i2o: Use pci_bus_alloc_resource(), not allocate_resource() directly (Myron Stowe) [1110896]
- [message] i2o: Refactor i2o_iop_systab_set() PCI space allocation (Myron Stowe) [1110896]
- [message] i2o: Fix I/O space alignment requirement (Myron Stowe) [1110896]
- [message] i2o: Fix I/O space allocation copy/paste error (Myron Stowe) [1110896]
- [pci] pciehp: Cleanup whitespace (Myron Stowe) [1110896]
- [pci] pciehp: Remove a non-existent card, regardless of "surprise" capability (Myron Stowe) [1110896]
- [pci] Remove unused SR-IOV VF Migration support (Myron Stowe) [1110896]
- [iommu] amd: Add include of <linux/irqreturn.h> (Myron Stowe) [1110896]
- [misc] mei: Add include of <linux/irqreturn.h> (Myron Stowe) [1110896]
- [vfio] pci: Use pci_enable_msi_range() and pci_enable_msix_range() (Myron Stowe) [1110896]
- [ata] ahci: Use pci_enable_msi_range() instead of pci_enable_msi_block() (Myron Stowe) [1110896]
- [x86] pci: Set IORESOURCE_ROM_SHADOW only for the default VGA device (Myron Stowe) [1110896]
- [pci] Remove pci_bus_b() and use list_for_each_entry() directly (Myron Stowe) [1110896]
- [pcmcia] Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [powerpc] pci: Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [drm] Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [pci] hotplug/apci: Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [pci] pciehp: Don't turn slot off when hot-added device already exists (Myron Stowe) [1110896]
- [pci] Cleanup per-arch list of object files (Myron Stowe) [1110896]
- [pci] hotplug/cpqphp: Fix hex vs decimal typo in cpqhpc_probe() (Myron Stowe) [1110896]
- [x86] pci: Fix function definition whitespace (Myron Stowe) [1110896]
- [x86] pci: Reword comments (Myron Stowe) [1110896]
- [x86] pci: Remove unnecessary local variable initialization (Myron Stowe) [1110896]
- [pci] Don't scan random busses in pci_scan_bridge() (Myron Stowe) [1110896]
- [pci] Check for child busses which use more bus numbers than allocated (Myron Stowe) [1110896]
- [pci] Remove pci_fixup_parent_subordinate_busnr() (Myron Stowe) [1110896]
- [pci] Make sure bus number resources stay within their parents bounds (Myron Stowe) [1110896]
- [pci] Use request_resource_conflict() instead of insert_ for bus numbers (Myron Stowe) [1110896]
- [pci] Assign CardBus bus number only during the second pass (Myron Stowe) [1110896]
- [pci] Clarify the "scan anyway" comment in pci_scan_bridge() (Myron Stowe) [1110896]
- [pci] Increment max correctly in pci_scan_bridge() (Myron Stowe) [1110896]
- [pci] Remove unnecessary list_empty(&pci_pme_list) check (Myron Stowe) [1110896]
- [acpi] numa: Use __weak, not the gcc-specific version (Myron Stowe) [1110896]
- [acpi] numa: Make __acpi_map_pxm_to_node(), acpi_get_pxm() static (Myron Stowe) [1110896]
- [acpi] numa: Simplify acpi_get_node() style (Myron Stowe) [1110896]
- [acpi] numa: Fix acpi_get_node() prototype (Myron Stowe) [1110896]
- [x86] pci: Remove acpi_get_pxm() usage (Myron Stowe) [1110896]
- [x86] pci: Use NUMA_NO_NODE, not -1, for unknown node (Myron Stowe) [1110896]
- [x86] pci: Remove unnecessary list_empty(&pci_root_infos) check (Myron Stowe) [1110896]
- [x86] pci: Remove mp_bus_to_node[], set_mp_bus_to_node(), get_mp_bus_to_node() (Myron Stowe) [1110896]
- [x86] pci: Use x86_pci_root_bus_node() instead of get_mp_bus_to_node() (Myron Stowe) [1110896]
- [x86] pci: Add x86_pci_root_bus_node() to look up NUMA node from PCI bus (Myron Stowe) [1110896]
- [x86] pci: Drop return value of pcibios_scan_root() (Myron Stowe) [1110896]
- [x86] pci: Merge pci_scan_bus_on_node() into pcibios_scan_root() (Myron Stowe) [1110896]
- [x86] pci: Use pcibios_scan_root() instead of pci_scan_bus_on_node() (Myron Stowe) [1110896]
- [x86] pci: Use pcibios_scan_root() instead of pci_scan_bus_with_sysdata() (Myron Stowe) [1110896]
- [x86] pci: Drop pcibios_scan_root() check for bus already scanned (Myron Stowe) [1110896]
- [ata] ahci: convert ahci_init_interrupts to a static routine (Myron Stowe) [1110896]
- [acpi] mm: use NUMA_NO_NODE (Myron Stowe) [1110896]

* Tue Aug 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-145.el7]
- [fs] btrfs: test for valid bdev before kobj removal in btrfs_rm_device (Eric Sandeen) [1071179]
- [fs] btrfs: fix abnormal long waiting in fsync (Eric Sandeen) [1071179]
- [fs] btrfs: fix crash when starting transaction (Eric Sandeen) [1071179]
- [fs] btrfs: fix btrfs_print_leaf for skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: fix race of using total_bytes_pinned (Eric Sandeen) [1071179]
- [fs] btrfs: use E2BIG instead of EIO if compression does not help (Eric Sandeen) [1071179]
- [fs] btrfs: remove stale comment from btrfs_flush_all_pending_stuffs (Eric Sandeen) [1071179]
- [fs] btrfs: fix use-after-free when cloning a trailing file hole (Eric Sandeen) [1071179]
- [fs] btrfs: fix null pointer dereference in btrfs_show_devname when name is null (Eric Sandeen) [1071179]
- [fs] btrfs: fix null pointer dereference in clone_fs_devices when name is null (Eric Sandeen) [1071179]
- [fs] btrfs: fix nossd and ssd_spread mount option regression (Eric Sandeen) [1071179]
- [fs] btrfs: fix race between balance recovery and root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: only unlock block in verify_parent_transid if we locked it (Eric Sandeen) [1071179]
- [fs] btrfs: assert send doesn't attempt to start transactions (Eric Sandeen) [1071179]
- [fs] btrfs: compression - reuse recently used workspace (Eric Sandeen) [1071179]
- [fs] btrfs: fix crash when mounting raid5 btrfs with missing disks (Eric Sandeen) [1071179]
- [fs] btrfs: create sprout should rename fsid on the sysfs as well (Eric Sandeen) [1071179]
- [fs] btrfs: dev replace should replace the sysfs entry (Eric Sandeen) [1071179]
- [fs] btrfs: dev add should add its sysfs entry (Eric Sandeen) [1071179]
- [fs] btrfs: dev delete should remove sysfs entry (Eric Sandeen) [1071179]
- [fs] btrfs: rename add_device_membership to btrfs_kobj_add_device (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlock when mounting a degraded fs (Eric Sandeen) [1071179]
- [fs] btrfs: fix NULL pointer crash when running balance and scrub concurrently (Eric Sandeen) [1071179]
- [fs] btrfs: Skip scrubbing removed chunks to avoid -ENOENT (Eric Sandeen) [1071179]
- [fs] btrfs: fix broken free space cache after the system crashed (Eric Sandeen) [1071179]
- [fs] btrfs: make free space cache write out functions more readable (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused wait queue in struct extent_buffer (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlocks with trylock on tree nodes (Eric Sandeen) [1071179]
- [fs] btrfs: fix error handling in create_pending_snapshot (Eric Sandeen) [1071179]
- [fs] btrfs: fix use of uninit "ret" in end_extent_writepage() (Eric Sandeen) [1071179]
- [fs] btrfs: free ulist in qgroup_shared_accounting() error path (Eric Sandeen) [1071179]
- [fs] btrfs: fix qgroups sanity test crash or hang (Eric Sandeen) [1071179]
- [fs] btrfs: prevent RCU warning when dereferencing radix tree slot (Eric Sandeen) [1071179]
- [fs] btrfs: fix unfinished readahead thread for raid5/6 degraded mounting (Eric Sandeen) [1071179]
- [fs] btrfs: new ioctl TREE_SEARCH_V2 (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, search_ioctl: direct copy to userspace (Eric Sandeen) [1071179]
- [fs] btrfs: new function read_extent_buffer_to_user (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, copy_to_sk: return needed size on EOVERFLOW (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, copy_to_sk: return EOVERFLOW for too small buffer (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, search_ioctl: accept varying buffer (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search: eliminate redundant nr_items check (Eric Sandeen) [1071179]
- [fs] btrfs: fix scrub_print_warning to handle skinny metadata extents (Eric Sandeen) [1071179]
- [fs] btrfs: make fsync work after cloning into a file (Eric Sandeen) [1071179]
- [fs] btrfs: use right type to get real comparison (Eric Sandeen) [1071179]
- [fs] btrfs: don't check nodes for extent items (Eric Sandeen) [1071179]
- [fs] btrfs: don't release invalid page in btrfs_page_exists_in_range() (Eric Sandeen) [1071179]
- [fs] btrfs: make sure we retry if page is a retriable exception (Eric Sandeen) [1071179]
- [fs] btrfs: make sure we retry if we couldn't get the page (Eric Sandeen) [1071179]
- [fs] btrfs: replace EINVAL with EOPNOTSUPP for dev_replace raid56 (Eric Sandeen) [1071179]
- [fs] btrfs: ioctl - fix typo s/substract/subtract/ (Eric Sandeen) [1071179]
- [fs] btrfs: fix leaf corruption after __btrfs_drop_extents (Eric Sandeen) [1071179]
- [fs] btrfs: ensure btrfs_prev_leaf doesn't miss 1 item (Eric Sandeen) [1071179]
- [fs] btrfs: fix clone to deal with holes when NO_HOLES feature is enabled (Eric Sandeen) [1071179]
- [fs] btrfs: free delayed node outside of root->inode_lock (Eric Sandeen) [1071179]
- [fs] btrfs: replace EINVAL with ERANGE for resize when ULLONG_MAX (Eric Sandeen) [1071179]
- [fs] btrfs: fix transaction leak during fsync call (Eric Sandeen) [1071179]
- [fs] btrfs: Avoid truncating page or punching hole in a already existed hole (Eric Sandeen) [1071179]
- [fs] btrfs: update commit root on snapshot creation after orphan cleanup (Eric Sandeen) [1071179]
- [fs] btrfs: ioctl, don't re-lock extent range when not necessary (Eric Sandeen) [1071179]
- [fs] btrfs: avoid visiting all extent items when cloning a range (Eric Sandeen) [1071179]
- [fs] btrfs: set dead flag on the right root when destroying snapshot (Eric Sandeen) [1071179]
- [fs] btrfs: ensure readers see new data after a clone operation (Eric Sandeen) [1071179]
- [fs] btrfs: volumes - Fix for possible null pointer dereference (Eric Sandeen) [1071179]
- [fs] btrfs: allocate raid type kobjects dynamically (Eric Sandeen) [1071179]
- [fs] btrfs: send, use the right limits for xattr names and values (Eric Sandeen) [1071179]
- [fs] btrfs: send, don't error in the presence of subvols/snapshots (Eric Sandeen) [1071179]
- [fs] btrfs: async delayed refs (Eric Sandeen) [1071179]
- [fs] btrfs: split up __extent_writepage to lower stack usage (Eric Sandeen) [1071179]
- [fs] btrfs: Drop EXTENT_UPTODATE check in hole punching and direct locking (Eric Sandeen) [1071179]
- [fs] btrfs: cut down stack usage in btree_write_cache_pages (Eric Sandeen) [1071179]
- [fs] btrfs: break up __btrfs_write_out_cache to cut down stack usage (Eric Sandeen) [1071179]
- [fs] btrfs: free tmp ulist for qgroup rescan (Eric Sandeen) [1071179]
- [fs] btrfs: usage error should not be logged into system log (Eric Sandeen) [1071179]
- [fs] btrfs: remove newline from inode cache kthread name (Eric Sandeen) [1071179]
- [fs] btrfs: remove stale newlines from log messages (Eric Sandeen) [1071179]
- [fs] btrfs: fix double free in find_lock_delalloc_range (Eric Sandeen) [1071179]
- [fs] btrfs: replace simple_strtoull() with kstrtoull() (Eric Sandeen) [1071179]
- [fs] btrfs: set right total device count for seeding support (Eric Sandeen) [1071179]
- [fs] btrfs: remove OPT_acl parse when acl disabled (Eric Sandeen) [1071179]
- [fs] btrfs: add sanity tests for new qgroup accounting code (Eric Sandeen) [1071179]
- [fs] btrfs: rework qgroup accounting (Eric Sandeen) [1071179]
- [fs] btrfs: mark mapping with error flag to report errors to userspace (Eric Sandeen) [1071179]
- [fs] btrfs: fix NULL pointer crash of deleting a seed device (Eric Sandeen) [1071179]
- [fs] btrfs: fix joining same transaction handle more than twice (Eric Sandeen) [1071179]
- [fs] btrfs: use helpers for last_trans_log_full_commit instead of opencode (Eric Sandeen) [1071179]
- [fs] btrfs: check if items are ordered when a leaf is marked dirty (Eric Sandeen) [1071179]
- [fs] btrfs: don't access non-existent key when csum tree is empty (Eric Sandeen) [1071179]
- [fs] btrfs: make sure there are not any read requests before stopping workers (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible memory leak in btrfs_create_tree() (Eric Sandeen) [1071179]
- [fs] btrfs: remove useless ACL check (Eric Sandeen) [1071179]
- [fs] btrfs: btrfs_rm_device() should zero mirror SB as well (Eric Sandeen) [1071179]
- [fs] btrfs: use bitfield instead of integer data type for the some variants in btrfs_root (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix more issues related to directory renames (Eric Sandeen) [1071179]
- [fs] btrfs: send, remove dead code from __get_cur_name_and_parent (Eric Sandeen) [1071179]
- [fs] btrfs: send, account for orphan directories when building path strings (Eric Sandeen) [1071179]
- [fs] btrfs: send, avoid unnecessary inode item lookup in the btree (Eric Sandeen) [1071179]
- [fs] btrfs: add dev maxs limit for __btrfs_alloc_chunk in kernel space (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong max system array size check in kernel space (Eric Sandeen) [1071179]
- [fs] btrfs: Add check to avoid cleanup roots already in fs_info->dead_roots (Eric Sandeen) [1071179]
- [fs] btrfs: reclaim the reserved metadata space at background (Eric Sandeen) [1071179]
- [fs] btrfs: output warning instead of error when loading free space cache failed (Eric Sandeen) [1071179]
- [fs] btrfs: Add ctime/mtime update for btrfs device add/remove (Eric Sandeen) [1071179]
- [fs] btrfs: assert that send is not in progres before root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: protect snapshots from deleting during send (Eric Sandeen) [1071179]
- [fs] btrfs: remove redundant null check in btrfs_dentry_release() (Eric Sandeen) [1071179]
- [fs] btrfs: make FS_INFO ioctl available to anyone (Eric Sandeen) [1071179]
- [fs] btrfs: make DEV_INFO ioctl available to anyone (Eric Sandeen) [1071179]
- [fs] btrfs: export more from FS_INFO to sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: retrieve more info from FS_INFO ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: balance filter: add limit of processed chunks (Eric Sandeen) [1071179]
- [fs] btrfs: fix leaf corruption caused by ENOSPC while hole punching (Eric Sandeen) [1071179]
- [fs] btrfs: do not increment on bio_index one by one (Eric Sandeen) [1071179]
- [fs] btrfs: read inode size after acquiring the mutex when punching a hole (Eric Sandeen) [1071179]
- [fs] btrfs: Remove unnecessary check for NULL (Eric Sandeen) [1071179]
- [fs] btrfs: fix inline compressed read err corruption (Eric Sandeen) [1071179]
- [fs] btrfs: return ptr error from compression workspace (Eric Sandeen) [1071179]
- [fs] btrfs: return errno instead of -1 from compression (Eric Sandeen) [1071179]
- [fs] btrfs: check_int: propagate out-of-memory error upwards (Eric Sandeen) [1071179]
- [fs] btrfs: fix hang on error (such as ENOSPC) when writing extent pages (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix corrupted path strings for long paths (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix incorrect ref access when using extrefs (Eric Sandeen) [1071179]
- [fs] btrfs: fix EIO on reading file after ioctl clone works on it (Eric Sandeen) [1071179]
- [fs] btrfs: limit the path size in send to PATH_MAX (Eric Sandeen) [1071179]
- [fs] btrfs: correctly set profile flags on seqlock retry (Eric Sandeen) [1071179]
- [fs] btrfs: use correct key when repeating search for extent item (Eric Sandeen) [1071179]
- [fs] btrfs: fix inode caching vs tree log (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible memory leaks in open_ctree() (Eric Sandeen) [1071179]
- [fs] btrfs: avoid triggering bug_on() when we fail to start inode caching task (Eric Sandeen) [1071179]
- [fs] btrfs: move btrfs_{set, clear}_and_info() to ctree.h (Eric Sandeen) [1071179]
- [fs] btrfs: replace error code from btrfs_drop_extents (Eric Sandeen) [1071179]
- [fs] btrfs: Change the hole range to a more accurate value (Eric Sandeen) [1071179]
- [fs] btrfs: fix use-after-free in mount_subvol() (Eric Sandeen) [1071179]
- [fs] btrfs: fix compile warnings on on avr32 platform (Eric Sandeen) [1071179]
- [fs] btrfs: allow mounting btrfs subvolumes with different ro/rw options (Eric Sandeen) [1071179]
- [fs] btrfs: export global block reserve size as space_info (Eric Sandeen) [1071179]
- [fs] btrfs: fix crash in remount(thread_pool=) case (Eric Sandeen) [1071179]
- [fs] btrfs: abort the transaction when we don't find our extent ref (Eric Sandeen) [1071179]
- [fs] btrfs: fix EINVAL checks in btrfs_clone (Eric Sandeen) [1071179]
- [fs] btrfs: fix unlock in __start_delalloc_inodes() (Eric Sandeen) [1071179]
- [fs] btrfs: scrub raid56 stripes in the right way (Eric Sandeen) [1071179]
- [fs] btrfs: don't compress for a small write (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient io tree navigation on wait_extent_bit (Eric Sandeen) [1071179]
- [fs] btrfs: send, build path string only once in send_hole (Eric Sandeen) [1071179]
- [fs] btrfs: filter invalid arg for btrfs resize (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix data corruption due to incorrect hole detection (Eric Sandeen) [1071179]
- [fs] btrfs: kmalloc() doesn't return an ERR_PTR (Eric Sandeen) [1071179]
- [fs] btrfs: fix snapshot vs nocow writting (Eric Sandeen) [1071179]
- [fs] btrfs: Change the expanding write sequence to fix snapshot related bug (Eric Sandeen) [1071179]
- [fs] btrfs: make device scan less noisy (Eric Sandeen) [1071179]
- [fs] btrfs: fix lockdep warning with reclaim lock inversion (Eric Sandeen) [1071179]
- [fs] btrfs: hold the commit_root_sem when getting the commit root during send (Eric Sandeen) [1071179]
- [fs] btrfs: remove transaction from send (Eric Sandeen) [1071179]
- [fs] btrfs: don't clear uptodate if the eb is under IO (Eric Sandeen) [1071179]
- [fs] btrfs: check for an extent_op on the locked ref (Eric Sandeen) [1071179]
- [fs] btrfs: do not reset last_snapshot after relocation (Eric Sandeen) [1071179]
- [fs] btrfs: fix a crash of clone with inline extents's split (Eric Sandeen) [1071179]
- [fs] btrfs: fix uninit variable warning (Eric Sandeen) [1071179]
- [fs] btrfs: take into account total references when doing backref lookup (Eric Sandeen) [1071179]
- [fs] btrfs: part 2, fix incremental send's decision to delay a dir move/rename (Eric Sandeen) [1071179]
- [fs] btrfs: fix incremental send's decision to delay a dir move/rename (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary inode generation lookup in send (Eric Sandeen) [1071179]
- [fs] btrfs: fix race when updating existing ref head (Eric Sandeen) [1071179]
- [fs] btrfs: Add trace for btrfs_workqueue alloc/destroy (Eric Sandeen) [1071179]
- [fs] btrfs: less fs tree lock contention when using autodefrag (Eric Sandeen) [1071179]
- [fs] btrfs: return EPERM when deleting a default subvolume (Eric Sandeen) [1071179]
- [fs] btrfs: add missing kfree in btrfs_destroy_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: cache extent states in defrag code path (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlock with nested trans handles (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible empty list access when flushing the delalloc inodes (Eric Sandeen) [1071179]
- [fs] btrfs: split the global ordered extents mutex (Eric Sandeen) [1071179]
- [fs] btrfs: don't flush all delalloc inodes when we doesn't get s_umount lock (Eric Sandeen) [1071179]
- [fs] btrfs: reclaim delalloc metadata more aggressively (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary lock in may_commit_transaction() (Eric Sandeen) [1071179]
- [fs] btrfs: remove the unnecessary flush when preparing the pages (Eric Sandeen) [1071179]
- [fs] btrfs: just do dirty page flush for the inode with compression before direct IO (Eric Sandeen) [1071179]
- [fs] btrfs: wake up the tasks that wait for the io earlier (Eric Sandeen) [1071179]
- [fs] btrfs: fix early enospc due to the race of the two ordered extent wait (Eric Sandeen) [1071179]
- [fs] btrfs: introduce btrfs_{start, end}_nocow_write() for each subvolume (Eric Sandeen) [1071179]
- [fs] btrfs: Add ftrace for btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the btrfs_workqueue related function type (Eric Sandeen) [1071179]
- [fs] btrfs: add readahead for send_write (Eric Sandeen) [1071179]
- [fs] btrfs: share the same code for __record_{new, deleted}_ref (Eric Sandeen) [1071179]
- [fs] btrfs: avoid unnecessary utimes update in incremental send (Eric Sandeen) [1071179]
- [fs] btrfs: make defrag not fragment files when using prealloc extents (Eric Sandeen) [1071179]
- [fs] btrfs: correctly flush data on defrag when compression is enabled (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the "_struct" suffix in btrfs_workequeue (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the old btrfs_worker (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->scrub_* workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->qgroup_rescan_worker workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->delayed_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->fixup_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->readahead_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->cache_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->rmw_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->endio_* workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->flush_workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->submit_workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->delalloc_workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Add threshold workqueue based on kernel workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Add high priority workqueue support for btrfs_workqueue_struct (Eric Sandeen) [1071179]
- [fs] btrfs: Added btrfs_workqueue_struct implemented ordered execution based on kernel workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the unused struct async_sched (Eric Sandeen) [1071179]
- [fs] btrfs: skip search tree for REG files (Eric Sandeen) [1071179]
- [fs] btrfs: fix preallocate vs double nocow write (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong lock range and write size in check_can_nocow() (Eric Sandeen) [1071179]
- [fs] btrfs: send: simplify allocation code in fs_path_ensure_buf (Eric Sandeen) [1071179]
- [fs] btrfs: send: fix old buffer length in fs_path_ensure_buf (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient btrfs_drop_extent_cache (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient split extent state insertion (Eric Sandeen) [1071179]
- [fs] btrfs: remove unneeded field / smaller extent_map structure (Eric Sandeen) [1071179]
- [fs] btrfs: skip locking when searching commit root (Eric Sandeen) [1071179]
- [fs] btrfs: wake up @scrub_pause_wait as much as we can (Eric Sandeen) [1071179]
- [fs] btrfs: cancel scrub on transaction abortion (Eric Sandeen) [1071179]
- [fs] btrfs: device_replace: fix deadlock for nocow case (Eric Sandeen) [1071179]
- [fs] btrfs: fix a possible deadlock between scrub and transaction committing (Eric Sandeen) [1071179]
- [fs] btrfs: fix send issuing outdated paths for utimes, chown and chmod (Eric Sandeen) [1071179]
- [fs] btrfs: correctly determine if blocks are shared in btrfs_compare_trees (Eric Sandeen) [1071179]
- [fs] btrfs: fix send attempting to rmdir non-empty directories (Eric Sandeen) [1071179]
- [fs] btrfs: send, don't send rmdir for same target multiple times (Eric Sandeen) [1071179]
- [fs] btrfs: incremental send, fix invalid path after dir rename (Eric Sandeen) [1071179]
- [fs] btrfs: don't insert useless holes when punching beyond the inode's size (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup delayed-ref.c:find_ref_head() (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary ref heads rb tree search (Eric Sandeen) [1071179]
- [fs] btrfs: wake up transaction thread upon remount (Eric Sandeen) [1071179]
- [fs] btrfs: stop joining the log transaction if sync log fails (Eric Sandeen) [1071179]
- [fs] btrfs: just wait or commit our own log sub-transaction (Eric Sandeen) [1071179]
- [fs] btrfs: fix skipped error handle when log sync failed (Eric Sandeen) [1071179]
- [fs] btrfs: use signed integer instead of unsigned long integer for log transid (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary memory barrier in btrfs_sync_log() (Eric Sandeen) [1071179]
- [fs] btrfs: don't start the log transaction if the log tree init fails (Eric Sandeen) [1071179]
- [fs] btrfs: fix the skipped transaction commit during the file sync (Eric Sandeen) [1071179]
- [fs] btrfs: use ACCESS_ONCE to prevent the optimize accesses to ->last_trans_log_full_commit (Eric Sandeen) [1071179]
- [fs] btrfs: avoid warning bomb of btrfs_invalidate_inodes (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible deadlock in btrfs_cleanup_transaction (Eric Sandeen) [1071179]
- [fs] btrfs: faster/more efficient insertion of file extent items (Eric Sandeen) [1071179]
- [fs] btrfs: always choose work from prio_head first (Eric Sandeen) [1071179]
- [fs] Revert: btrfs: remove transaction from btrfs send (Eric Sandeen) [1071179]
- [fs] btrfs: skip readonly root for snapshot-aware defragment (Eric Sandeen) [1071179]
- [fs] btrfs: switch to btrfs_previous_extent_item() (Eric Sandeen) [1071179]
- [fs] btrfs: skip submitting barrier for missing device (Eric Sandeen) [1071179]
- [fs] btrfs: unlock extent and pages on error in cow_file_range (Eric Sandeen) [1071179]
- [fs] btrfs: balance delayed inode updates (Eric Sandeen) [1071179]
- [fs] btrfs: add simple debugfs interface (Eric Sandeen) [1071179]
- [fs] btrfs: send: lower memory requirements in common case (Eric Sandeen) [1071179]
- [fs] btrfs: make some tree searches in send.c more efficient (Eric Sandeen) [1071179]
- [fs] btrfs: use right extent item position in send when finding extent clones (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove BUG_ON from name_cache_delete (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove BUG from process_all_refs (Eric Sandeen) [1071179]
- [fs] btrfs: send: squeeze bitfilelds in fs_path (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove virtual_mem member from fs_path (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove prepared member from fs_path (Eric Sandeen) [1071179]
- [fs] btrfs: send: replace check with an assert in gen_unique_name (Eric Sandeen) [1071179]
- [fs] btrfs: more send support for parent/child dir relationship inversion (Eric Sandeen) [1071179]
- [fs] btrfs: fix send dealing with file renames and directory moves (Eric Sandeen) [1071179]
- [fs] btrfs: only add roots if necessary in find_parent_nodes() (Eric Sandeen) [1071179]
- [fs] btrfs: Fix 32/64-bit problem with BTRFS_SET_RECEIVED_SUBVOL ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: add missing error check in incremental send (Eric Sandeen) [1071179]
- [fs] btrfs: fix use-after-free in the finishing procedure of the device replace (Eric Sandeen) [1071179]
- [fs] btrfs: fix unprotected alloc list insertion during the finishing procedure of replace (Eric Sandeen) [1071179]
- [fs] btrfs: Return EXDEV for cross file system snapshot (Eric Sandeen) [1071179]
- [fs] btrfs: don't mix the ordered extents of all files together during logging the inodes (Eric Sandeen) [1071179]
- [fs] btrfs: use right clone root offset for compressed extents (Eric Sandeen) [1071179]
- [fs] btrfs: fix null pointer deference at btrfs_sysfs_add_one+0x105 (Eric Sandeen) [1071179]
- [fs] btrfs: unset DCACHE_DISCONNECTED when mounting default subvol (Eric Sandeen) [1071179]
- [fs] btrfs: fix max_inline mount option (Eric Sandeen) [1071179]
- [fs] btrfs: fix a lockdep warning when cleaning up aborted transaction (Eric Sandeen) [1071179]
- [fs] Revert: btrfs: add ioctl to export size of global metadata reservation (Eric Sandeen) [1071179]
- [fs] btrfs: fix data corruption when reading/updating compressed extents (Eric Sandeen) [1071179]
- [fs] btrfs: don't loop forever if we can't run because of the tree mod log (Eric Sandeen) [1071179]
- [fs] btrfs: reserve no transaction units in btrfs_ioctl_set_features (Eric Sandeen) [1071179]
- [fs] btrfs: commit transaction after setting label and features (Eric Sandeen) [1071179]
- [fs] btrfs: fix assert screwup for the pending move stuff (Eric Sandeen) [1071179]
- [fs] btrfs: use late_initcall instead of module_init (Eric Sandeen) [1071179]
- [fs] btrfs: use btrfs_crc32c everywhere instead of libcrc32c (Eric Sandeen) [1071179]
- [fs] btrfs: disable snapshot aware defrag for now (Eric Sandeen) [1071179]
- [fs] btrfs: fix spin_unlock in check_ref_cleanup (Eric Sandeen) [1071179]
- [fs] btrfs: setup inode location during btrfs_init_inode_locked (Eric Sandeen) [1071179]
- [fs] btrfs: don't use ram_bytes for uncompressed inline items (Eric Sandeen) [1071179]
- [fs] btrfs: fix btrfs_search_slot_for_read backwards iteration (Eric Sandeen) [1071179]
- [fs] btrfs: do not export ulist functions (Eric Sandeen) [1071179]
- [fs] btrfs: rework ulist with list+rb_tree (Eric Sandeen) [1071179]
- [fs] btrfs: fix memory leaks on walking backrefs failure (Eric Sandeen) [1071179]
- [fs] btrfs: fix send file hole detection leading to data corruption (Eric Sandeen) [1071179]
- [fs] btrfs: add a reschedule point in btrfs_find_all_roots() (Eric Sandeen) [1071179]
- [fs] btrfs: make send's file extent item search more efficient (Eric Sandeen) [1071179]
- [fs] btrfs: fix to catch all errors when resolving indirect ref (Eric Sandeen) [1071179]
- [fs] btrfs: fix protection between walking backrefs and root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: fix warning while merging two adjacent extents (Eric Sandeen) [1071179]
- [fs] btrfs: fix infinite path build loops in incremental send (Eric Sandeen) [1071179]
- [fs] btrfs: undo sysfs when open_ctree() fails (Eric Sandeen) [1071179]
- [fs] btrfs: fix snprintf usage by send's gen_unique_name (Eric Sandeen) [1071179]
- [fs] btrfs: fix defrag 32-bit integer overflow (Eric Sandeen) [1071179]
- [fs] btrfs: sysfs: list the NO_HOLES feature (Eric Sandeen) [1071179]
- [fs] btrfs: sysfs: don't show reserved incompat feature (Eric Sandeen) [1071179]
- [fs] btrfs: call permission checks earlier in ioctls and return EPERM (Eric Sandeen) [1071179]
- [fs] btrfs: restrict snapshotting to own subvolumes (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong block group in trace during the free space allocation (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup the code of used_block_group in find_free_extent() (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup the redundant code for the block group allocation and init (Eric Sandeen) [1071179]
- [fs] btrfs: change the members' order of btrfs_space_info structure to reduce the cache miss (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong search path initialization before searching tree root (Eric Sandeen) [1071179]
- [fs] btrfs: flush the dirty pages of the ordered extent aggressively during logging csum (Eric Sandeen) [1071179]
- [fs] btrfs: fix transaction abortion when remounting btrfs from RW to RO (Eric Sandeen) [1071179]
- [fs] btrfs: faster file extent item search in clone ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent state leak on transaction abortion (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the btrfs_parse_options for remount (Eric Sandeen) [1071179]
- [fs] btrfs: Add noinode_cache mount option (Eric Sandeen) [1071179]
- [fs] btrfs: fix to search previous metadata extent item since skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: fix missing skinny metadata check in scrub_stripe() (Eric Sandeen) [1071179]
- [fs] btrfs: fix send to not send non-aligned clone operations (Eric Sandeen) [1071179]
- [fs] btrfs: fix btrfs boot when compiled as built-in (Eric Sandeen) [1071179]
- [fs] btrfs: unlock inodes in correct order in clone ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: optimize to remove unnecessary removal with ulist reallocation (Eric Sandeen) [1071179]
- [fs] btrfs: release subvolume's block_rsv before transaction commit (Eric Sandeen) [1071179]
- [fs] btrfs: only process as many file extents as there are refs (Eric Sandeen) [1071179]
- [fs] btrfs: fix qgroup rescan to work with skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent_from_logical to deal with skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: throttle delayed refs better (Eric Sandeen) [1071179]
- [fs] btrfs: attach delayed ref updates to delayed ref heads (Eric Sandeen) [1071179]
- [fs] btrfs: make fsync latency less sucky (Eric Sandeen) [1071179]
- [fs] btrfs: add support for inode properties (Eric Sandeen) [1071179]
- [fs] btrfs: faster file extent item replace operations (Eric Sandeen) [1071179]
- [fs] btrfs: handle EAGAIN case properly in btrfs_drop_snapshot() (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary transaction commit before send (Eric Sandeen) [1071179]
- [fs] btrfs: fix protection between send and root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong send_in_progress accounting (Eric Sandeen) [1071179]
- [fs] btrfs: Add treelog mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add datasum mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add datacow mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add acl mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add noflushoncommit mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add noenospc_debug mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add nodiscard mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add noautodefrag mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add "barrier" option to support "-o remount, barrier" (Eric Sandeen) [1071179]
- [fs] btrfs: only fua the first superblock when writting supers (Eric Sandeen) [1071179]
- [fs] btrfs: return free space to global_rsv as much as possible (Eric Sandeen) [1071179]
- [fs] btrfs: fix an oops when we fail to relocate tree blocks (Eric Sandeen) [1071179]
- [fs] btrfs: fix an oops when we fail to merge reloc roots (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused argument from select_reloc_root() (Eric Sandeen) [1071179]
- [fs] btrfs: reduce btree node locking duration on item update (Eric Sandeen) [1071179]
- [fs] btrfs: Integer overflow in btrfs_ioctl_resize() (Eric Sandeen) [1071179]
- [fs] btrfs: stop caching thread if extent_commit_sem is contended (Eric Sandeen) [1071179]
- [fs] rwsem: add rwsem_is_contended (Eric Sandeen) [1071179]
- [fs] btrfs: introduce the delayed inode ref deletion for the single link inode (Eric Sandeen) [1071179]
- [fs] btrfs: use flags instead of the bool variants in delayed node (Eric Sandeen) [1071179]
- [fs] btrfs: remove btrfs_end_transaction_dmeta() (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup code of btrfs_balance_delayed_items() (Eric Sandeen) [1071179]
- [fs] btrfs: don't run delayed nodes again after all nodes flush (Eric Sandeen) [1071179]
- [fs] btrfs: remove residual code in delayed inode async helper (Eric Sandeen) [1071179]
- [fs] btrfs: convert printk to btrfs_ and fix BTRFS prefix (Eric Sandeen) [1071179]
- [fs] btrfs: fix tree mod logging (Eric Sandeen) [1071179]
- [fs] btrfs: check balance of send_in_progress (Eric Sandeen) [1071179]
- [fs] btrfs: remove transaction from btrfs send (Eric Sandeen) [1071179]
- [fs] btrfs: fix double initialization of the raid kobject (Eric Sandeen) [1071179]
- [fs] btrfs: fix a warning when iput a file (Eric Sandeen) [1071179]
- [fs] btrfs: Check read-only status of roots during send (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused mnt from send_ctx (Eric Sandeen) [1071179]
- [fs] btrfs: send: clean up dead code (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlock when iterating inode refs and running delayed inodes (Eric Sandeen) [1071179]
- [fs] btrfs: remove dead comments for read_csums() (Eric Sandeen) [1071179]
- [fs] btrfs: remove field tree_mod_seq_elem from btrfs_fs_info struct (Eric Sandeen) [1071179]
- [fs] btrfs: fix use of uninitialized err variable (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary filemap writting and waiting after block group relocation (Eric Sandeen) [1071179]
- [fs] btrfs: fix error check of btrfs_lookup_dentry() (Eric Sandeen) [1071179]
- [fs] btrfs: return immediately if tree log mod is not necessary (Eric Sandeen) [1071179]
- [fs] btrfs: move the extent buffer radix tree into the fs_info (Eric Sandeen) [1071179]
- [fs] btrfs: use a bit to track if we're in the radix tree (Eric Sandeen) [1071179]
- [fs] btrfs: deal with io_tree->mapping being NULL (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient push_leaf_right (Eric Sandeen) [1071179]
- [fs] btrfs: wrap repeated code into scrub_blocked_if_needed() (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong super generation mismatch when scrubbing supers (Eric Sandeen) [1071179]
- [fs] btrfs: fix pass of transid with wrong endianness in send.c (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent_map block_len after merging (Eric Sandeen) [1071179]
- [fs] btrfs: remove dead code (Eric Sandeen) [1071179]
- [fs] btrfs: fix max dir item size calculation (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient extent state insertions (Eric Sandeen) [1071179]
- [fs] btrfs: add missing extent state caching calls (Eric Sandeen) [1071179]
- [fs] btrfs: faster and more efficient extent map insertion (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent boundary check in bio_readpage_error (Eric Sandeen) [1071179]
- [fs] btrfs: try harder to avoid btree node splits (Eric Sandeen) [1071179]
- [fs] btrfs: avoid unnecessary ordered extent cache resets (Eric Sandeen) [1071179]
- [fs] btrfs: fix leaks during sysfs teardown (Eric Sandeen) [1071179]
- [fs] btrfs: fix static checker warnings (Eric Sandeen) [1071179]
- [fs] btrfs: fix very slow inode eviction and fs unmount (Eric Sandeen) [1071179]
- [fs] btrfs: improve forever loop when doing balance relocation (Eric Sandeen) [1071179]
- [fs] btrfs: fix ordered extent check in btrfs_punch_hole (Eric Sandeen) [1071179]
- [fs] btrfs: replace BUG in can_modify_feature (Eric Sandeen) [1071179]
- [fs] btrfs: reserve no transaction units in btrfs_feature_attr_store (Eric Sandeen) [1071179]
- [fs] btrfs: make btrfs_debug match pr_debug handling related to DEBUG (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup: removed unused 'btrfs_get_inode_ref_index' (Eric Sandeen) [1071179]
- [fs] btrfs: expand btrfs_find_item() to include find_orphan_item functionality (Eric Sandeen) [1071179]
- [fs] btrfs: expand btrfs_find_item() to include find_root_ref functionality (Eric Sandeen) [1071179]
- [fs] btrfs: bootstrap generic btrfs_find_item interface (Eric Sandeen) [1071179]
- [fs] btrfs: fix unused variables in qgroup.c (Eric Sandeen) [1071179]
- [fs] btrfs: replace path->slots[0] with otherwise unused variable 'slot' (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from scrub_fixup_nodatasum (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from setup_cluster_no_bitmap (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variables from extent_io.c (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from find_free_extent (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variables from disk-io.c (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from btrfs_new_inode (Eric Sandeen) [1071179]
- [fs] btrfs: publish fs label in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish device membership in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish allocation data in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: add ioctl to export size of global metadata reservation (Eric Sandeen) [1071179]
- [fs] btrfs: use feature attribute names to print better error messages (Eric Sandeen) [1071179]
- [fs] btrfs: add ability to change features via sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish unknown feature bits in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish per-super features in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish per-super attributes in sysfs (Eric Sandeen) [1071179]
- [fs] kobject: export kobj_sysfs_ops (Eric Sandeen) [1071179]
- [fs] btrfs: publish supported featured in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: add ioctls to query/change feature bits online (Eric Sandeen) [1071179]
- [fs] btrfs: skip merge part for delayed data refs (Eric Sandeen) [1071179]
- [fs] btrfs: introduce a head ref rbtree (Eric Sandeen) [1071179]
- [fs] btrfs: fix check-integrity to look at the referenced data properly (Eric Sandeen) [1071179]
- [fs] btrfs: incompatible format change to remove hole extents (Eric Sandeen) [1071179]
- [fs] btrfs: sanitize BTRFS_IOC_FILE_EXTENT_SAME (Eric Sandeen) [1071179]
- [fs] btrfs: fix comments and printk msgs (Eric Sandeen) [1071179]
- [fs] btrfs: Fix typos in printk (Eric Sandeen) [1071179]

* Tue Aug 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-144.el7]
- [net] ipv6: Fix MLD Query message check (Jiri Pirko) [1114650]
- [net] sctp: inherit auth_capable on INIT collisions (Daniel Borkmann) [1123763] {CVE-2014-5077}
- [net] ipv6: ipv6_find_hdr restore prev functionality (Jesper Brouer) [1074516]
- [net] ipvs: fix AF assignment in ip_vs_conn_new() (Jesper Brouer) [1074516]
- [virt] kvm: always exit on EOIs for interrupts listed in the IOAPIC redir table (Alex Williamson) [1126997]
- [iommu] amd: Fix interrupt remapping for aliased devices (Alex Williamson) [1090139]
- [pci] Add Patsburg (X79) to Intel PCH root port ACS quirk (Alex Williamson) [1081428]
- [kernel] time/alarmtimer: Fix bug where relative alarm timers were treated as absolute (Prarit Bhargava) [1124941]
- [acpi] processor: Fix STARTING/DYING action in acpi_cpu_soft_notify() (Prarit Bhargava) [1099594]
- [x86] mce_intel: Add raw_lock conversion again (Prarit Bhargava) [1127257]
- [sound] alsa/control: Don't access controls outside of protected regions (Radomir Vrbovsky) [1117331] {CVE-2014-4653}
- [kernel] tick: Clear broadcast pending bit when switching to oneshot (Alex Williamson) [1109996]
- [x86] efi: Do not export efi runtime map in case old map (Dave Young) [1080109]
- [x86] efi: Quirk out SGI UV (Dave Young) [1080109]
- [x86] efi: Split efi_enter_virtual_mode (Dave Young) [1080109]
- [x86] efi: Make efi virtual runtime map passing more robust (Dave Young) [1080109]
- [x86] mm/pageattr: Export page unmapping interface (Dave Young) [1080109]
- [x86] efi: Dump the EFI page table (Dave Young) [1080109]
- [x86] mm/ptdump: Add the functionality to dump an arbitrary pagetable (Dave Young) [1080109]
- [x86] efi: Style neatening (Dave Young) [1080109]
- [x86] efi: parse_efi_setup() build fix (Dave Young) [1080109]
- [x86] ksysfs.c build fix (Dave Young) [1080109]
- [x86] efi: Delete superfluous global variables (Dave Young) [1080109]
- [x86] setup: Reserve setup_data ranges late after parsing memmap cmdline (Dave Young) [1080109]
- [x86] Export x86 boot_params to sysfs (Dave Young) [1080109]
- [x86] boot: Add xloadflags bit for EFI runtime support on kexec (Dave Young) [1080109]
- [firmware] efi: Pass necessary EFI data for kexec via setup_data (Dave Young) [1080109]
- [firmware] efi: Export EFI runtime memory mapping to sysfs (Dave Young) [1080109]
- [firmware] efi: Export more EFI table variables to sysfs (Dave Young) [1080109]
- [firmware] efi: Cleanup efi_enter_virtual_mode() function (Dave Young) [1080109]
- [firmware] efi: Fix off-by-one bug in EFI Boot Services reservation (Dave Young) [1080109]
- [firmware] efi: Add a wrapper function efi_map_region_fixed() (Dave Young) [1080109]
- [firmware] efi: Remove unused variables in __map_region() (Dave Young) [1080109]
- [firmware] efi: Check krealloc return value (Dave Young) [1080109]
- [firmware] efi: Runtime services virtual mapping (Dave Young) [1080109]
- [x86] mm/pageattr: Map in an arbitrary pgd (Dave Young) [1080109]
- [x86] mm/pageattr: Add last levels of error path (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PUD error unwinding path (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PTE pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PMD pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PUD pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PGD pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Lookup address in an arbitrary PGD (Dave Young) [1080109]
- [firmware] efi: Convert runtime services function ptrs (Dave Young) [1080109]
- [firmware] efi: Simplify EFI_DEBUG (Dave Young) [1080109]
- [firmware] efi: Fix config_table_type array termination (Dave Young) [1080109]
- [firmware] efi: make efi_lookup_mapped_addr() a common function (Dave Young) [1080109]
- [firmware] efi: provide a generic efi_config_init() (Dave Young) [1080109]
- [iommu] vt-d: Use list_for_each_entry_safe() for dmar_domain->devices traversa (Myron Stowe) [1127467]
- [iommu] vt-d: Use for_each_drhd_unit() instead of list_for_each_entry() (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call io_page_fault trace event (Myron Stowe) [1127467]
- [iommu] Add iommu_error class event to iommu trace (Myron Stowe) [1127467]
- [iommu] No need to pass '0x' when 'pa' is used (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call unmap trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call map trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call detach_device_to_domain trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call attach_device_to_domain trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call remove_device_to_group trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call add_device_to_group trace event (Myron Stowe) [1127467]
- [iommu] Add event tracing feature to iommu (Myron Stowe) [1127467]
- [iommu] intel: correct ICS register offset (Myron Stowe) [1127467]
- [Documentation] MAINTAINERS: add overall IOMMU section (Myron Stowe) [1127467]
- [iommu] amd: Fix resource leak in iommu_init_device() (Myron Stowe) [1127467]
- [iommu] amd: Clean up unnecessary MSI/MSI-X capability find (Myron Stowe) [1127467]
- [powerpc] Add iommu domain pointer to device archdata (Myron Stowe) [1127467]
- [iommu] vt-d: DMAR reporting table needs at least one DRHD (Myron Stowe) [1127467]
- [iommu] vt-d: Downgrade the warning if enabling irq remapping fails (Myron Stowe) [1127467]
- [net] l2tp: don't fall back on UDP [get|set]sockopt (Petr  Matousek) [1119466] {CVE-2014-4943}
- [x86] ptrace: force IRET path after a ptrace_stop() (Oleg Nesterov) [1115935] {CVE-2014-4699}
- [s390] ptrace: correct insufficient sanitization when setting psw mask (Hendrik Brueckner) [1113673] {CVE-2014-3534}

* Wed Aug 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-143.el7]
- [virt] kvm/async_pf: kill the unnecessary use_mm/unuse_mm async_pf_execute() (Paolo Bonzini) [1116936]
- [virt] kvm/async_pf: change async_pf_execute() to use get_user_pages(tsk => NULL) (Paolo Bonzini) [1116936]
- [virt] kvm: support any-length wildcard ioeventfd (Paolo Bonzini) [1116936]
- [virt] kvm: return an error code in kvm_vm_ioctl_register_coalesced_mmio() (Paolo Bonzini) [1116936]
- [virt] kvm/x86: preserve the high 32-bits of the PAT register (Paolo Bonzini) [1116936]
- [virt] kvm: fix wrong address when writing Hyper-V tsc page (Paolo Bonzini) [1116936]
- [kernel] sched: Fix signedness bug in yield_to() (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Check for nested events if there is an injectable interrupt (Paolo Bonzini) [1116936]
- [virt] kvm/svm: Fix CPL export via SS.DPL (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: disable APIC virtualization in nested guests (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Check for host supported fields in shadow vmcs (Paolo Bonzini) [1116936]
- [virt] kvm/x86: MOV CR/DR emulation should ignore mod (Paolo Bonzini) [1116936]
- [virt] kvm/lapic: sync highest ISR to hardware apic on EOI (Paolo Bonzini) [1116936]
- [virt] kvm/x86: get CPL from SS.DPL (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: check CS.DPL against RPL during task switch (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: drop set_rflags callback (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: use new CS.RPL as CPL during task switch (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: fix page fault tracing when KVM guest support enabled (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: DR7 masking on task switch emulation is wrong (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix CR3 reserved bits check in long mode (Paolo Bonzini) [1116936]
- [virt] kvm/x86: emulate monitor and mwait instructions as nop (Paolo Bonzini) [1116936]
- [virt] kvm/x86: implement hv EOI assist (Paolo Bonzini) [1086663 1116936]
- [virt] kvm/x86: Mark bit 7 in long-mode PDPTE according to 1GB pages support (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: handle_dr does not handle RSP correctly (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: move vmclear and vmptrld pre-checks to nested_vmx_check_vmptr (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: fail on invalid vmclear/vmptrld pointer (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: additional checks on vmxon region (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: rearrange get_vmx_mem_address (Paolo Bonzini) [1116936]
- [virt] kvm/x86: improve the usability of the 'kvm_pio' tracepoint (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Processor mode may be determined incorrectly (Paolo Bonzini) [1116936]
- [virt] kvm/x86: IN instruction emulation should ignore REP-prefix (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix CR3 reserved bits (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix wrong/stuck PMU when guest does not use PMI (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Advertise support for interrupt acknowledgement (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Ack and write vector info to intr_info if L1 asks us to (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Don't advertise single context invalidation for invept (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Advance rip to after an ICEBP instruction (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix CR3 and LDT sel should not be saved in TSS (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: speed up wildcard MMIO EVENTFD (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix page-tables reserved bits (Paolo Bonzini) [1116936]
- [virt] kvm/x86: remove WARN_ON from get_kernel_ns() (Paolo Bonzini) [1116936]
- [virt] kvm: Rename variable smep to cr4_smep (Paolo Bonzini) [1084616 1116936]
- [virt] kvm: expose SMAP feature to guest (Paolo Bonzini) [1084616 1116936]
- [virt] kvm: Disable SMAP for guests in EPT realmode and EPT unpaging mode (Paolo Bonzini) [1074747 1084616 1116936]
- [virt] kvm: Add SMAP support when setting CR4 (Paolo Bonzini) [1084616 1116936]
- [virt] kvm: Remove SMAP bit from CR4_RESERVED_BITS (Paolo Bonzini) [1084616 1116936]
- [x86] processor-flags: Fix the datatypes and add bit number defines (Paolo Bonzini) [1116936]
- [kernel] const: Add _BITUL() and _BITULL() (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: fix MPX detection (Paolo Bonzini) [1116936]
- [virt] kvm/x86: handle missing MPX in nested virtualization (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Add nested virtualization support for MPX (Paolo Bonzini) [1116936]
- [virt] kvm/svm: Allow the guest to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/svm: set/clear all DR intercepts in one swoop (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/nvmx: Allow nested guests to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/vmx: Allow the guest to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/x86: Allow the guest to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/x86: change vcpu->arch.switch_db_regs to a bit mask (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/vmx: we do rely on loading DR7 on entry (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/x86: Remove return code from enable_irq/nmi_window (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not inject NMI vmexits when L2 has a pending interrupt (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fully emulate preemption timer (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Rework interception of IRQs and NMIs (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Break kvm_for_each_vcpu loop after finding the VP_INDEX (Paolo Bonzini) [1116936]
- [x86] cpufeature: Rename X86_FEATURE_CLFLSH to X86_FEATURE_CLFLUSH (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: drop read-only large sptes when creating lower level sptes (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Enable Intel MPX for guest (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: add MSR_IA32_BNDCFGS to msrs_to_save (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: Intel MPX vmx and msr handle (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: introduce kvm_supported_xcr0() (Paolo Bonzini) [1076194 1116936]
- [virt] kvm: kABI fixup for MPX patches (Paolo Bonzini) [1116936]
- [x86] xsave: Support eager-only xsave features, add MPX support (Paolo Bonzini) [1076194 1116936]
- [x86] cpufeature: Define the Intel MPX feature flag (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: Fix xsave cpuid exposing bug (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: expose ADX feature to guest (Paolo Bonzini) [1084614 1116936]
- [virt] kvm/x86: expose new instruction RDSEED to guest (Paolo Bonzini) [1084614 1116936]
- [virt] kvm: remove redundant registration of BSP's hv_clock area (Paolo Bonzini) [1116936]
- [virt] kvm/x86: remove unused last_kernel_ns variable (Paolo Bonzini) [1116936]
- [virt] kvm/x86: correctly access the KVM_CPUID_FEATURES leaf at 0x40000101 (Paolo Bonzini) [1116936]
- [virt] kvm/x86: cache the base of the KVM cpuid leaves (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Validate guest writes to MSR_IA32_APICBASE (Paolo Bonzini) [1110125 1116936]
- [virt] kvm/x86: mark hyper-v vapic assist page as dirty (Paolo Bonzini) [1116936]
- [virt] kvm/x86: mark hyper-v hypercall page as dirty (Paolo Bonzini) [1116936]
- [virt] kvm: make KVM_MMU_AUDIT help text more readable (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Update guest activity state field on L2 exits (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fix nested_run_pending on activity state HLT (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Clean up handling of VMX-related MSRs (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Add tracepoints for nested_vmexit and nested_vmexit_inject (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Pass vmexit parameters to nested_vmx_vmexit (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Leave VMX mode on clearing of feature control MSR (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Fix DR6 update on #DB exception (Paolo Bonzini) [1079841 1116936]
- [virt] kvm/svm: Fix reading of DR6 (Paolo Bonzini) [1079841 1116936]
- [virt] kvm/x86: Sync DR7 on KVM_SET_DEBUGREGS (Paolo Bonzini) [1079841 1116936]
- [virt] kvm: remove useless write to vcpu->hv_clock.tsc_timestamp (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix debug typo error in lapic (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: check use I/O bitmap first before unconditional I/O exit (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Unconditionally uninit the MMU on nested vmexit (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Do not skip the instruction if handle_dr injects a fault (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Support direct APIC access from L2 (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Add comment on vcpu_enter_guest()'s return value (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Add support for activity state HLT (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: shadow VM_(ENTRY (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: delay mmu audit activation (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Really fix lazy FPU on nested guest (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Fix lazy FPU on nested guest (Paolo Bonzini) [1116936]
- [virt] kvm/cpuid: Fix sparse warning (Paolo Bonzini) [1116936]
- [virt] kvm: Delete prototype for non-existent function kvm_check_iopl (Paolo Bonzini) [1116936]
- [virt] kvm: Delete prototype for non-existent function complete_pio (Paolo Bonzini) [1116936]
- [virt] kvm/x86: trace cpuid emulation when called from emulator (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: cleanup decode_register_operand() a bit (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: check rex prefix inside decode_register() (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: error message typo fix (Paolo Bonzini) [1116936]
- [virt] kvm: Emulate MOVBE (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: Add initial three-byte insns support (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: Rename VendorSpecific flag (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: Use opcode length (Paolo Bonzini) [1116936]
- [virt] kvm: Add KVM_GET_EMULATED_CPUID (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Report CPU_BASED_VIRTUAL_NMI_PENDING as supported (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Report 2MB EPT pages as supported (Paolo Bonzini) [1116936]
- [virt] kvm: Move gfn_to_index to x86 specific code (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fully support nested VMX preemption timer (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: change useless int return types to void (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: unify destroy_kvm_mmu with kvm_mmu_unload (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: remove uninteresting MMU "new_cr3" callbacks (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: remove uninteresting MMU "free" callbacks (Paolo Bonzini) [1116936]
- [virt] kvm: Convert kvm_lock back to non-raw spinlock (Paolo Bonzini) [1116936]
- [virt] kvm: protect kvm_usage_count with its own spinlock (Paolo Bonzini) [1116936]
- [virt] kvm: cleanup (physical) CPU hotplug (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not generate #DF if #PF happens during exception delivery into L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Check all exceptions for intercept during delivery to L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not put exception that caused vmexit to IDT_VECTORING_INFO (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Amend nested_run_pending logic (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Enable unrestricted guest mode support (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Implement support for EFER saving on VM-exit (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not set identity page map for L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Replace kvm_set_cr0 with vmx_set_cr0 in load_vmcs12_host_state (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: fix shadow on EPT (Paolo Bonzini) [1116936]
- [virt] kvm/nept: reset PDPTR register cache on nested vmentry emulation (Paolo Bonzini) [1116936]
- [virt] kvm: Fix NULL dereference in gfn_to_hva_prot() (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: allow page tables to be in read-only slots (Paolo Bonzini) [1116936]
- [virt] kvm/x86: emulate RETF imm (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: remove unused parameter (Paolo Bonzini) [1116936]
- [virt] kvm/x86: add comments where MMIO does not return to the emulator (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: count exits to userspace during invalid guest emulation (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Advertise IA32_PAT in VM exit control (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fix up VM_ENTRY_IA32E_MODE control feature reporting (Paolo Bonzini) [1116936]
- [virt] kvm/nept: Advertise WB type EPTP (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nvmx: Keep arch.pat in sync on L1-L2 switches (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Miscelleneous cleanups (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Some additional comments (Paolo Bonzini) [1048496 1116936]
- [virt] kvm: Advertise the support of EPT to the L1 guest, through the appropriate MSR (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Nested INVEPT (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: MMU context for nested EPT (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Add nept violation/misconfigration support (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: correctly check if remote tlb flush is needed for shadowed EPT tables (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Redefine EPT-specific link_shadow_page() (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Add EPT tables support to paging_tmpl.h (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Support shadow paging for guest paging without A/D bits (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: make guest's A/D bits depends on guest's paging mode (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Move common code to paging_tmpl.h (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Fix wrong test in kvm_set_cr3 (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Fix cr3 handling in nested exit and entry (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Support LOAD_IA32_EFER entry/exit controls for L1 (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/mmu: fix check the reserved bits on the gpte of L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: correctly set tr base on nested vmexit emulation (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: reset rflags register cache during nested vmentry (Paolo Bonzini) [1116936]
- [virt] kvm/x86: handle singlestep during emulation (Paolo Bonzini) [1116936]
- [virt] kvm/x86: handle hardware breakpoints during emulation (Paolo Bonzini) [1116936]
- [virt] kvm/x86: rename EMULATE_DO_MMIO (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Drop some unused functions from lapic (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Simplify __apic_accept_irq (Paolo Bonzini) [1116936]
- [virt] kvm/perf: Support the in_tx/in_tx_cp modifiers in KVM arch perfmon emulation v5 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Set segment infomation of L1 when L2 exits (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fix read/write to MSR_IA32_FEATURE_CONTROL (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Drop useless cast (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Use proper types to access const arrays (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Set success rflags when emulate VMXON/VMXOFF in nested virt (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Change location of 3 functions in vmx.c (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Avoid zapping mmio sptes twice for generation wraparound (Paolo Bonzini) [1116936]
- [virt] kvm: add missing cleanup_srcu_struct (Paolo Bonzini) [1116936]
- [virt] kvm/irqchip: Speed up KVM_SET_GSI_ROUTING (Paolo Bonzini) [1116936]
- [virt] kvm/async_pf: mm->mm_users can not pin apf->mm (Paolo Bonzini) [1116936]
- [virt] kvm: Specify byte order for KVM_EXIT_MMIO (Paolo Bonzini) [1116936]
- [virt] kvm/eventfd: Fix lock order inversion (Paolo Bonzini) [1116936]
- [virt] kvm: add kvm_arch_vcpu_runnable() test to kvm_vcpu_on_spin() loop (Paolo Bonzini) [1116936]
- [virt] kvm/asmlinkage: Make kvm_rebooting visible (Paolo Bonzini) [1116936]
- [virt] kvm: Provide kvm_vcpu_eligible_for_directed_yield() stub (Paolo Bonzini) [1116936]
- [virt] kvm/vfio: silence GCC warning (Paolo Bonzini) [1116936]
- [virt] kvm: remove dead code (Paolo Bonzini) [1116936]
- [virt] kvm: make local functions static (Paolo Bonzini) [1116936]
- [virt] kvm/doc: Fix typo in doc/virtual/kvm (Paolo Bonzini) [1116936]
- [virt] kvm: Use cond_resched() directly and remove useless kvm_resched() (Paolo Bonzini) [1116936]
- [virt] kvm: kvm_clear_guest_page(), fix empty_zero_page usage (Paolo Bonzini) [1116936]
- [virt] kvm: remove vm mmap method (Paolo Bonzini) [1116936]
- [virt] kvm/iommu: hva align mapping page size (Paolo Bonzini) [1116936]
- [virt] kvm_host: typo fix (Paolo Bonzini) [1116936]
- [Documentation] kvm: add a 00-INDEX file (Paolo Bonzini) [1116936]
- [virt] kvm: use a more sensible error number when debugfs directory creation fails (Paolo Bonzini) [1116936]
- [virt] kvm: Fix modprobe failure for kvm_intel/kvm_amd (Paolo Bonzini) [1116936]
- [virt] kvm: Enable pvspinlock after jump_label_init() to avoid VM hang (Paolo Bonzini) [1116936]
- [virt] kvm: Drop FOLL_GET in GUP when doing async page fault (Paolo Bonzini) [1116936]
- [virt] kvm/iommu: Add leading zeros to device's BDF notation in debug messages (Paolo Bonzini) [1116936]
- [Documentation] kvm: Update cpuid documentation for steal time and pv eoi (Paolo Bonzini) [1116936]
- [virt] kvm: remove .done from struct kvm_async_pf (Paolo Bonzini) [1116936]
- [virt] kvm: Add documentation for kvm->srcu lock (Paolo Bonzini) [1116936]
- [virt] kvm: free resources after canceling async_pf (Paolo Bonzini) [1116936]
- [virt] kvm/eventfd: switch to fdget (Paolo Bonzini) [1116936]
- [virt] kvm: Introduce kvm_arch_memslots_updated() (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Rename X86_CR4_RDWRGSFS to X86_CR4_FSGSBASE (Paolo Bonzini) [1116936]
- [virt] kvm: rename __kvm_io_bus_sort_cmp to kvm_io_bus_cmp (Paolo Bonzini) [1116936]
- [virt] kvm: optimize away THP checks in kvm_is_mmio_pfn() (Paolo Bonzini) [1116936]
- [virt] kvm: use anon_inode_getfd() with O_CLOEXEC flag (Paolo Bonzini) [1116936]
- [virt] kvm: introduce __kvm_io_bus_sort_cmp (Paolo Bonzini) [1116936]
- [Documentation] virtual/kvm/api.txt fix a typo (Paolo Bonzini) [1116936]
- [virt] kvm/ppc: reserve a capability number for multitce support (Paolo Bonzini) [1116936]
- [virt] virtio_ring: change host notification API (Paolo Bonzini) [1116936]
- [x86] quirks: Mark Cave Creek chipset device id as supported (Steve Best) [1087659]
- [mm] memcg, vmscan: Fix forced scan of anonymous pages (Jerome Marchand) [1125240]
- [drm] qxl: return IRQ_NONE if it was not our irq (Jason Wang) [1095099]
- [kernel] sched/autogroup: Fix race with task_groups list (Gustavo Duarte) [1081406]
- [lib] percpu_counter: unbreak __percpu_counter_add() (Eric Sandeen) [1123968]
- [lib] percpu_counter: fix __percpu_counter_add() (Eric Sandeen) [1123968]

* Fri Aug 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-142.el7]
- [x86] Revert: Insert GART region into resource map (Myron Stowe) [1110895]
- [pci] Don't check resource_size() in pci_bus_alloc_resource() (Myron Stowe) [1110895]
- [pci] Enable INTx in pci_reenable_device() only when MSI/MSI-X not enabled (Myron Stowe) [1110895]
- [ahci] Fix broken fallback to single MSI mode (Myron Stowe) [1110895]
- [pci] Enable INTx if BIOS left them disabled (Myron Stowe) [1110895]
- [pci] msi: Add pci_enable_msi_exact() and pci_enable_msix_exact() (Myron Stowe) [1110895]
- [pci] msi: Fix cut-and-paste errors in documentation (Myron Stowe) [1110895]
- [pci] msi: Add pci_enable_msi() documentation back (Myron Stowe) [1110895]
- [pci] msi: Fix pci_msix_vec_count() htmldocs failure (Myron Stowe) [1110895]
- [pci] msi: Fix leak of msi_attrs (Myron Stowe) [1110895]
- [pci] msi: Check kmalloc() return value, fix leak of name (Myron Stowe) [1110895]
- [eisa] Revert: Initialize device before its resources (Myron Stowe) [1110895]
- [eisa] Revert: Log device resources in dmesg (Myron Stowe) [1110895]
- [pci] Check parent kobject in pci_destroy_dev() (Myron Stowe) [1110895]
- [powerpc] eeh: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pci] Fix pci_check_and_unmask_intx() comment typos (Myron Stowe) [1110895]
- [scsi] mpt: Use pci_stop_and_remove_bus_device_locked() (Myron Stowe) [1110895]
- [platform] x86: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pci] hotplug: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pcmcia] Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pci] hotplug: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [acpi] pci: Use global PCI rescan-remove locking in PCI root hotplug (Myron Stowe) [1110895]
- [pci] Add global pci_lock_rescan_remove() (Myron Stowe) [1110895]
- [pci] Cleanup pci.h whitespace (Myron Stowe) [1110895]
- [pci] Reorder so actual code comes before stubs (Myron Stowe) [1110895]
- [pci] aer: Support ACPI HEST AER error sources for PCI domains other than 0 (Myron Stowe) [1110895]
- [acpi] acpica: Add helper macros to extract bus/segment numbers from HEST table (Myron Stowe) [1110895]
- [pci] Make local functions static (Myron Stowe) [1110895]
- [pci] Remove unused alloc_pci_dev() (Myron Stowe) [1110895]
- [pci] Remove unused pci_renumber_slot() (Myron Stowe) [1110895]
- [pci] Remove unused pcie_aspm_enabled() (Myron Stowe) [1110895]
- [pci] Remove unused pci_vpd_truncate() (Myron Stowe) [1110895]
- [pci] Remove unused ID-Based Ordering support (Myron Stowe) [1110895]
- [pci] Remove unused Optimized Buffer Flush/Fill support (Myron Stowe) [1110895]
- [pci] Remove unused Latency Tolerance Reporting support (Myron Stowe) [1110895]
- [pci] Removed unused parts of Page Request Interface support (Myron Stowe) [1110895]
- [pci] Update documentation 00-INDEX file (Myron Stowe) [1110895]
- [pci] Allocate 64-bit BARs above 4G when possible (Myron Stowe) [1110895]
- [pci] Enforce bus address limits in resource allocation (Myron Stowe) [1110895]
- [pci] Split out bridge window override of minimum allocation address (Myron Stowe) [1110895]
- [agp] ati: Use PCI_COMMAND instead of hard-coded 4 (Myron Stowe) [1110895]
- [agp] intel: Use CPU physical address, not bus address, for ioremap() (Myron Stowe) [1110895]
- [agp] intel: Use pci_bus_address() to get GTTADR bus address (Myron Stowe) [1110895]
- [agp] intel: Use pci_bus_address() to get MMADR bus address (Myron Stowe) [1110895]
- [agp] intel: Support 64-bit GMADR (Myron Stowe) [1110895]
- [agp] intel: Rename gtt_bus_addr to gtt_phys_addr (Myron Stowe) [1110895]
- [drm] i915: Rename gtt_bus_addr to gtt_phys_addr (Myron Stowe) [1110895]
- [agp] Use pci_resource_start() to get CPU physical address for BAR (Myron Stowe) [1110895]
- [agp] Support 64-bit APBASE (Myron Stowe) [1110895]
- [pci] msi: Add pci_enable_msi_range() and pci_enable_msix_range() (Myron Stowe) [1110895]
- [pci] msi: Add pci_msix_vec_count() (Myron Stowe) [1110895]
- [pci] msi: Remove pci_enable_msi_block_auto() (Myron Stowe) [1110895]
- [pci] msi: Add pci_msi_vec_count() (Myron Stowe) [1110895]
- [pci] Convert ioapic to be builtin only, not modular (Myron Stowe) [1110895]
- [pci] Add pci_bus_address() to get bus address of a BAR (Myron Stowe) [1110895]
- [pci] Convert pcibios_resource_to_bus() to take a pci_bus, not a pci_dev (Myron Stowe) [1110895]
- [pci] Change pci_bus_region addresses to dma_addr_t (Myron Stowe) [1110895]
- [pci] msi: Return -ENOSYS for unimplemented interfaces, not -1 (Myron Stowe) [1110895]
- [pci] msi: Return msix_capability_init() failure if populate_msi_sysfs() fails (Myron Stowe) [1110895]
- [s390] pci: Remove superfluous check of MSI type (Myron Stowe) [1110895]
- [s390] pci: Fix single MSI only check (Myron Stowe) [1110895]
- [pci] msi: Export MSI mode using attributes, not kobjects (Myron Stowe) [1110895]
- [pci] portdrv: Remove extra get_device()/put_device() for pcie_device (Myron Stowe) [1110895]
- [pci] portdrv: Add put_device() after device_register() failure (Myron Stowe) [1110895]
- [pci] portdrv: Cleanup error paths (Myron Stowe) [1110895]
- [pci] Remove from bus_list and release resources in pci_release_dev() (Myron Stowe) [1110895]
- [pci] Move pci_proc_attach_device() to pci_bus_add_device() (Myron Stowe) [1110895]
- [pci] Use device_release_driver() in pci_stop_root_bus() (Myron Stowe) [1110895]
- [pci] aer: Consolidate HEST error source parsers (Myron Stowe) [1110895]
- [pci] aer: Ignore non-PCIe AER error sources in aer_hest_parse() (Myron Stowe) [1110895]
- [pci] aer: Clean up error printing code a bit (Myron Stowe) [1110895]
- [pci] aer: Add a TLP header print helper (Myron Stowe) [1110895]
- [eisa] Call put_device() if device_register() fails (Myron Stowe) [1110895]
- [pci] checkpatch: Deprecate DEFINE_PCI_DEVICE_TABLE (Myron Stowe) [1110895]
- [pci] Stop clearing bridge Secondary Status when setting up I/O aperture (Myron Stowe) [1110895]
- [pci] Prevent bus conflicts while checking for bridge apertures (Myron Stowe) [1110895]
- [pci] Drop "irq" param from *_restore_msi_irqs() (Myron Stowe) [1110895]
- [pci] portdrv: Remove superfluous name cast (Myron Stowe) [1110895]
- [x86] pci: Use dev_is_pci() to identify PCI devices (Myron Stowe) [1110895]
- [pci] Use dev_is_pci() to identify PCI devices (Myron Stowe) [1110895]
- [pci] Clear NumVFs when disabling SR-IOV in sriov_init() (Myron Stowe) [1110895]
- [s390] watchdog: add support for LPAR operation (diag288) (Hendrik Brueckner) [1088540]
- [s390] watchdog: use watchdog API (Hendrik Brueckner) [1088540]
- [scripts] headers_check: special case seqbuf_dump() (Prarit Bhargava) [1090078]
- [Documentation] mei-amt-version: remove unneeded call of mei_deinit() (Prarit Bhargava) [1090078]
- [drm] tegra: Include header drm/drm.h (Prarit Bhargava) [1090078]
- [mfd] lpc_ich: iTCO_wdt patch for Intel Coleto Creek DeviceIDs (Neil Horman) [1053912]
- [i2c] i801: SMBus patch for Intel Coleto Creek DeviceIDs (Neil Horman) [1053912]
- [x86] efi: earlyprintk-efi, keep fix (Rui Wang) [1085558]
- [x86] efi: Fix earlyprintk off-by-one bug (Rui Wang) [1085558]
- [x86] efi: Add EFI framebuffer earlyprintk support (Rui Wang) [1085558]
- [s390] zcrypt: remove zcrypt kmsg documentation again (Hendrik Brueckner) [1088511]
- [s390] zcrypt: add support for EP11 coprocessor cards (Hendrik Brueckner) [1088511]
- [s390] sclp_vt220: Enable ASCII console per default (Hendrik Brueckner) [1112739]
- [block] blkcg: fix use-after-free in __blkg_release_rcu() by making blkcg_gq refcnt an atomic_t (Vivek Goyal) [1118436]
- [ethernet] bnx2x: fix crash during TSO tunneling (Michal Schmidt) [1119133]
- [ethernet] cxgb4: allow large buffer size to have page size (Gustavo Duarte) [1078977]
- [fs] vfs: Don't copy mount bind mounts of /proc/<pid>/ns/mnt between namespaces (Aristeu Rozanski) [1098632]
- [cpufreq] intel_pstate: Add CPU IDs for Broadwell processors (Steve Best) [1086874]
- [pci] pciehp: Clear Data Link Layer State Changed during init (Myron Stowe) [1101097]
- [acpi] Fix bug when ACPI reset register is implemented in system memory (Nigel Croxon) [1109971]
- [ipc] shm: increase the defaults for SHMALL, SHMMAX (Larry Woodman) [1101821]
- [tools] power/turbostat: Run on Broadwell (Steve Best) [1086455]
- [drm] i915: make i915 less chatty on resume (Rob Clark) [1086777]
- [tools] cpupower: add option to display values without round offs (Prarit Bhargava) [1090540]
- [scripts] kbuild: fix make headers_install when path is too long (Frank Ramsay) [1099575]
- [kernel] audit: fix AUDIT_FEATURE_CHANGE record number (Richard Guy Briggs) [1085928]
- [usb] xhci: Link TRB must not occur within a USB payload burst (Don Zickus) [1049077]
- [virt] xen-netfront: fix resource leak in netfront (Vitaly Kuznetsov) [1070868]
- [virt] xen-blkfront: handle backend CLOSED without CLOSING (Vitaly Kuznetsov) [1070868]

* Fri Aug 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-141.el7]
- [misc] no animals were harmed in the making of this kernel (Jarod Wilson)

* Fri Jul 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-140.el7]
- [net] ipv6: addrconf: implement address generation modes (Jiri Pirko) [1107369]
- [net] gre: add link local route when local addr is any (Jiri Pirko) [1107369]
- [net] gre6: don't try to add the same route two times (Jiri Pirko) [1107369]
- [netdrv] bonding: remove no longer relevant vlan warnings (Jiri Pirko) [1048814]
- [netdrv] bonding: allow to add vlans on top of empty bond (Jiri Pirko) [1048814]
- [net] netfilter: nf_ct_timestamp: Fix BUG_ON after netns deletion (Jiri Pirko) [1085667]
- [net] netfilter: nf_nat: fix oops on netns removal (Florian Westphal) [1089581]
- [net] unix socket code abuses csum_partial (Hannes Frederic Sowa) [1106402]
- [net] ip_tunnel: Set network header properly for IP_ECN_decapsulate() (Jiri Pirko) [1094419]

* Fri Jul 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-139.el7]
- [fs] GFS2: fix potential NULL pointer dereference (Robert S Peterson) [1095835]
- [input] synaptics: fix resolution for manually provided min/max (Benjamin Tissoires) [1093449]
- [input] synaptics: change min/max quirk table to pnp-id matching (Benjamin Tissoires) [1093449]
- [input] synaptics: add a matches_pnp_id helper function (Benjamin Tissoires) [1093449]
- [input] synaptics: T540p - unify with other LEN0034 models (Benjamin Tissoires) [1093449]
- [input] synaptics: add min/max quirk for the ThinkPad W540 (Benjamin Tissoires) [1093449]
- [input] synaptics: add min/max quirk for ThinkPad Edge E431 (Benjamin Tissoires) [1093449]
- [input] synaptics: add min/max quirk for ThinkPad T431s, L440, L540, S1 Yoga and X1 (Benjamin Tissoires) [1093449]
- [input] synaptics: report INPUT_PROP_TOPBUTTONPAD property (Benjamin Tissoires) [1093449]
- [input] Add INPUT_PROP_TOPBUTTONPAD device property (Benjamin Tissoires) [1093449]
- [input] i8042: add firmware_id support (Benjamin Tissoires) [1093449]
- [input] serio: add firmware_id sysfs attribute (Benjamin Tissoires) [1093449]
- [input] synaptics: add manual min/max quirk for ThinkPad X240 (Benjamin Tissoires) [1093449]
- [input] synaptics: add manual min/max quirk (Benjamin Tissoires) [1093449]
- [input] synaptics: fix incorrect placement of __initconst (Benjamin Tissoires) [1093449]
- [s390] sclp_early: Return correct HSA block count also for zero (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Add function to detect sclp console capabilities (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Pass sccb pointer to every *_detect() function (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Replace early_read_info_sccb with sccb_early (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Get rid of sclp_early_read_info_sccb_valid (Hendrik Brueckner) [1107730]
- [s390] sclp: replace uninitialized early_event_mask_sccb variable with sccb_early (Hendrik Brueckner) [1107730]
- [s390] sclp: Consolidate early sclp init calls to sclp_early_detect() (Hendrik Brueckner) [1107730]
- [s390] sclp: Move declarations for sclp_sdias into separate header file (Hendrik Brueckner) [1107730]
- [s390] sclp: Move early code from sclp_cmd.c to sclp_early.c (Hendrik Brueckner) [1107730]
- [s390] sclp: Determine HSA size dynamically for zfcpdump (Hendrik Brueckner) [1107730]
- [s390] sclp: properly detect line mode console (Hendrik Brueckner) [1107730]
- [s390] sclp: add parameter to specify number of buffer pages (Hendrik Brueckner) [1103744]
- [md] dm-cache: set minimum_io_size to cache's data block size (Mike Snitzer) [1117872]
- [md] dm-thin: set minimum_io_size to pool's data block size (Mike Snitzer) [1117872]
- [md] dm-crypt: use per-bio data (Mike Snitzer) [1117872]
- [block] use kmalloc alignment for bio slab (Mike Snitzer) [1117872]
- [md] dm-crypt: fix cpu hotplug crash by removing per-cpu structure (Mike Snitzer) [1117872]
- [md] dm-mpath: print more useful warnings in multipath_message() (Mike Snitzer) [1117872]
- [md] dm-mpath: do not activate failed paths (Mike Snitzer) [1117872]
- [md] dm-mpath: eliminate pg_ready() wrapper (Mike Snitzer) [1117872]
- [md] dm-mpath: remove extra nesting in map function (Mike Snitzer) [1117872]
- [md] dm-mpath: remove map_io() (Mike Snitzer) [1117872]
- [md] dm-mpath: reduce memory pressure when requeuing (Mike Snitzer) [1117872]
- [md] dm-mpath: really fix lockdep warning (Mike Snitzer) [1117872]
- [md] dm-mpath: fix lock order inconsistency in multipath_ioctl (Mike Snitzer) [1117872]
- [md] dm-mpath: remove process_queued_ios() (Mike Snitzer) [1117872]
- [md] dm-mpath: fix IO hang due to logic bug in multipath_busy (Mike Snitzer) [1117872]
- [md] dm-mpath: push back requests instead of queueing (Mike Snitzer) [1117872]
- [md] dm-table: add dm_table_run_md_queue_async (Mike Snitzer) [1117872]
- [md] dm-mpath: do not call pg_init when it is already running (Mike Snitzer) [1117872]
- [md] dm-cache: fail migrations in the do_worker error path (Mike Snitzer) [1117872]
- [md] dm-cache: simplify deferred set reference count increments (Mike Snitzer) [1117872]
- [md] dm-cache-metadata: use dm-space-map-metadata.h defined size limits (Mike Snitzer) [1117872]
- [md] dm-cache-metadata: do not allow the data block size to change (Mike Snitzer) [1117872]
- [md] dm-thin-metadata: do not allow the data block size to change (Mike Snitzer) [1117872]
- [md] dm-thin: relax external origin size constraints (Mike Snitzer) [1065474]
- [md] dm-thin: switch to an atomic_t for tracking pending new block preparations (Mike Snitzer) [1065474]
- [md] dm-thin: cleanup noflush_work to use a proper completion (Mike Snitzer) [1117872]
- [md] dm-era: check for a non-NULL metadata object before closing it (Mike Snitzer) [1117872]
- [md] dm-io: simplify dec_count and sync_io (Mike Snitzer) [1117872]
- [md] dm-io: fix a race condition in the wake up code for sync_io (Mike Snitzer) [1117872]
- [md] dm-crypt, dm-zero: update author name following legal name change (Mike Snitzer) [1117872]
- [md] dm: allocate a special workqueue for deferred device removal (Mike Snitzer) [1117872]
- [md] dm-snapshot: do not split read bios sent to snapshot-origin target (Mike Snitzer) [1117872]
- [md] dm-snapshot: allocate a per-target structure for snapshot-origin target (Mike Snitzer) [1117872]
- [md] dm: introduce dm_accept_partial_bio (Mike Snitzer) [1117872]
- [md] dm: change sector_count member in clone_info from sector_t to unsigned (Mike Snitzer) [1117872]
- [md] dm: remove symbol export for dm_set_device_limits (Mike Snitzer) [1117872]
- [md] dm: disable WRITE SAME if it fails (Mike Snitzer) [1117872]
- [md] dm: use RCU_INIT_POINTER instead of rcu_assign_pointer in __unbind (Mike Snitzer) [1117872]
- [md] dm: stop using bi_private (Mike Snitzer) [1117872]
- [md] dm: remove dm_get_mapinfo (Mike Snitzer) [1117872]
- [md] dm-table: make dm_table_supports_discards static (Mike Snitzer) [1117872]
- [md] dm: make dm_table_alloc_md_mempools static (Mike Snitzer) [1117872]
- [mm] Revert: vmscan: do not swap anon pages just because free+file is low (Johannes Weiner) [1102991]
- [crypto] fips: only panic on bad/missing crypto mod signatures (Jarod Wilson) [903562]
- [x86] hugetlb: Add missing TLB page invalidation for hugetlb_cow() (Larry Woodman) [1097919]

* Fri Jul 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-138.el7]
- [mm] hugetlb: ensure hugepage access is denied if hugepages are not supported (David Gibson) [1081671]
- [x86] Delete non-required instances of include <linux/init.h> (Prarit Bhargava) [1119074]
- [mmc] sdhci-pci-o2micro: Add SeaBird SeaEagle SD3 support (David Milburn) [968020]
- [mmc] sdhci-pci: add support of O2Micro/BayHubTech SD hosts (David Milburn) [968020]
- [mmc] sdhci-pci: break out definitions to header file (David Milburn) [968020]
- [ethernet] cnic: Don't take cnic_dev_lock in cnic_alloc_uio_rings() (Maurizio Lombardi) [1079384 1094613]
- [ethernet] cnic: Don't take rcu_read_lock in cnic_rcv_netevent() (Maurizio Lombardi) [1079384 1094613]
- [idle] intel_idle: fix IVT idle state table setting (Prarit Bhargava) [1119374]
- [idle] intel_idle: fine-tune IVT residency targets (Prarit Bhargava) [1119374]
- [idle] intel_idle: do C1E promotion disable quirk for hotplugged CPUs (Prarit Bhargava) [1119374]
- [idle] intel_idle: remove superfluous dev->state_count initialization (Prarit Bhargava) [1119374]
- [x86] acpi, idle: Restructure the mwait idle routines (Prarit Bhargava) [1119374]
- [idle] intel_idle: use CPU_TASKS_FROZEN instead of a numeric constant (Prarit Bhargava) [1119374]
- [idle] intel_idle: shrink states tables (Prarit Bhargava) [1119374]
- [md] dm-thin: update discard_granularity to reflect the thin-pool blocksize (Mike Snitzer) [1099936]
- [md] dm-bio-prison: implement per bucket locking in the dm_bio_prison hash table (Mike Snitzer) [1099936]
- [md] dm-thin: return ENOSPC instead of EIO when error_if_no_space enabled (Mike Snitzer) [1099936]
- [md] dm-cache: always split discards on cache block boundaries (Mike Snitzer) [1103836]
- [md] dm-cache: fix writethrough mode quiescing in cache_map (Mike Snitzer) [1103836]
- [md] dm-cache: fix a lock-inversion (Mike Snitzer) [1103836]
- [md] dm-thin: add 'no_space_timeout' dm-thin-pool module param (Mike Snitzer) [1095639]
- [md] dm-thin: add timeout to stop out-of-data-space mode holding IO forever (Mike Snitzer) [1095639]
- [md] dm-thin: allow metadata commit if pool is in PM_OUT_OF_DATA_SPACE mode (Mike Snitzer) [1091852]
- [md] dm-thin: use INIT_WORK_ONSTACK in noflush_work to avoid ODEBUG warning (Mike Snitzer) [1098643]
- [md] dm-thin: fix rcu_read_lock being held in code that can sleep (Mike Snitzer) [1098643]
- [md] dm-thin: irqsave must always be used with the pool->lock spinlock (Mike Snitzer) [1098643]
- [md] dm-thin: sort the per thin deferred bios using an rb_tree (Mike Snitzer) [1098643]
- [md] dm-thin: use per thin device deferred bio lists (Mike Snitzer) [1098643]
- [md] dm-thin: simplify pool_is_congested (Mike Snitzer) [1098643]

* Thu Jul 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-137.el7]
- [powercap] Add to drivers Kconfig and Makefile (Steve Best) [1085575]
- [powercap] add Documentation (Steve Best) [1085575]
- [powercap] Fix build error with option -Werror=format-security (Steve Best) [1085575]
- [powercap] Introduce Intel RAPL power capping driver (Steve Best) [1085575]
- [powercap] Add class driver (Steve Best) [1085575]
- [x86] msr: add 64bit _on_cpu access functions (Steve Best) [1085575]
- [misc] bitops: Introduce BIT_ULL (Steve Best) [1085575]
- [virt] xen/spinlock: Don't use __initdate for xen_pv_spin (Vitaly Kuznetsov) [1006977]
- [virt] Revert: xen/spinlock: Disable IRQ spinlock (PV) allocation on PVHVM (Vitaly Kuznetsov) [1006977]
- [virt] xen/spinlock: Don't setup xen spinlock IPI kicker if disabled (Vitaly Kuznetsov) [1006977]
- [virt] xen/smp: Update pv_lock_ops functions before alternative code starts under PVHVM (Vitaly Kuznetsov) [1006977]
- [virt] xen/spinlock: We don't need the old structure anymore (Vitaly Kuznetsov) [1006977]
- [virt] xen/spinlock: Fix locking path engaging too soon under PVHVM (Vitaly Kuznetsov) [1006977]
- [ata] ahci: Do not receive interrupts sent by dummy ports (David Milburn) [1067838]
- [ata] ahci: do not request irq for dummy port (David Milburn) [1067838]
- [ata] ahci: fix Null pointer dereference in achi_host_active() (David Milburn) [1067838]
- [ata] ahci: Make distinct names for ports in /proc/interrupts (David Milburn) [1067838]
- [s390] 3270: fix crash with multiple reset device requests (Hendrik Brueckner) [1088320]
- [ata] ahci: accommodate tag ordered controller (David Milburn) [1083746]
- [scsi] libsas: introduce scmd_dbg() to quiet false positive "timeout" messages (David Milburn) [1074987]
- [ethernet] be2net: enable interrupts in EEH resume (Ivan Vecera) [1076682]
- [ethernet] bnx2: Fix shutdown sequence (Neil Horman) [1074656]
- [ethernet] be2net: Fix invocation of be_close() after be_clear() (Ivan Vecera) [1066644]
- [virt] hv/balloon: Ensure pressure reports are posted regularly (Luiz Capitulino) [1102888]
- [virt] kvm/x86: expose invariant tsc cpuid bit (Marcelo Tosatti) [1095990]
- [virt] kvm/x86: disable master clock if TSC is reset during suspend (Marcelo Tosatti) [1098604]
- [virt] xen/pvhvm: Initialize xen panic handler for PVHVM guests (Vitaly Kuznetsov) [839966]
- [fs] cifs: Wait for writebacks to complete before attempting write (Sachin Prabhu) [1040329]
- [fs] xfs: xfs_readsb needs to check for magic numbers (Eric Sandeen) [1102940]
- [net] svcrdma: fix offset calculation for non-page aligned sge entries (Jeff Layton) [1088954]
- [fs] lockd: ensure we tear down any live sockets when socket creation fails during lockd_up (Jeff Layton) [1085774]
- [net] svcrpc: fix gss-proxy NULL dereference in some error cases (Jeff Layton) [1085616]
- [mm] use paravirt friendly ops for NUMA hinting ptes (Vitaly Kuznetsov) [1101274]
- [mm] swap: discard while swapping only if SWAP_FLAG_DISCARD_PAGES (Rafael Aquini) [1053189]
- [x86] hwpoison: remove unused global variable in do_machine_check() (Prarit Bhargava) [1119306]
- [x86] mce: Panic when a core has reached a timeout (Prarit Bhargava) [1119306]
- [x86] mce: Improve mcheck_init_device() error handling (Prarit Bhargava) [1119306]
- [x86] mce: Fix CMCI preemption bugs (Prarit Bhargava) [1119306]
- [x86] cmci: Add proper detection of end of CMCI storms (Prarit Bhargava) [1119306]
- [x86] acpi, apei, ghes: Do not report only correctable errors with SCI (Prarit Bhargava) [1119306]
- [x86] mce: Call put_device on device_register failure (Prarit Bhargava) [1119306]
- [acpi] apei, cper: Add UEFI 2.4 support for memory error (Prarit Bhargava) [1119306]
- [x86] mce: Fix mce regression from recent cleanup (Prarit Bhargava) [1119306]
- [x86] mce: Update MCE severity condition check (Prarit Bhargava) [1119306]
- [x86] mce: Add comments to clarify usage of the various bitfields in the MCA subsystem (Prarit Bhargava) [1119306]
- [x86] mcheck, therm_throt: Process package thresholds (Prarit Bhargava) [1119306]
- [x86] mce: Fix "braodcast" typo (Prarit Bhargava) [1119306]
- [mm] vmstat: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [mm] vmstat: set N_CPU to node_states during boot (Prarit Bhargava) [1119078]
- [kernel] trace, ring-buffer: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [kernel] profile: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [mm] zswap: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [hwmon] via-cputemp: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [hwmon] coretemp: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [oprofile] nmi-timer: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [idle] intel-idle: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [base] topology: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [scsi] fcoe: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [cpufreq] acpi-cpufreq: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [scsi] bnx2i: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [scsi] bnx2fc: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [virt] x86, kvm: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] amd, uncore: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] pci, amd-bus: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] hpet: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] intel, cacheinfo: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] therm_throt: Remove unused therm_cpu_lock (Prarit Bhargava) [1119078]
- [x86] oprofile, nmi: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] amd, ibs: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] msr: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [powerpc] sysfs: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] mce: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] therm_throt: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] cpuid: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] vsyscall: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] intel, uncore: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [s390] smp: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [s390] cacheinfo: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [kernel] cpu_hotplug, perf: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [kernel] cpu/hotplug: Add lockdep annotations to get/put_online_cpus() (Prarit Bhargava) [1119078]
- [kernel] cpu/hotplug: Provide lockless versions of callback registration functions (Prarit Bhargava) [1119078]
- [Documentation] cpu-hotplug: Specify race-free way to register CPU hotplug callbacks (Prarit Bhargava) [1119078]
- [pci] Fail new_id for vendor/device values already built into driver (Bandan Das) [1055867]
- [init] main: add initcall_blacklist kernel parameter (Prarit Bhargava) [1080995]
- [kernel] pid_namespace: pidns_get() should check task_active_pid_ns() != NULL (Jan Stancek) [1106368]
- [i2c] i2c-ismt: support I2C_SMBUS_I2C_BLOCK_DATA transaction type (Neil Horman) [1094516]
- [misc] mei: fix lockdep warning when registering mei watchdog (Prarit Bhargava) [971855]

* Wed Jul 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-136.el7]
- [block] mtip32xx: minor performance enhancements (Mike Snitzer) [1105703]
- [block] mtip32xx: let blk_mq_tag_to_rq() take blk_mq_tags as the main parameter (Mike Snitzer) [1105703]
- [block] mtip32xx: move error handling to service thread (Mike Snitzer) [1105703]
- [block] mtip32xx: stop block hardware queues before quiescing IO (Mike Snitzer) [1105703]
- [block] mtip32xx: blk_mq_init_queue() returns an ERR_PTR (Mike Snitzer) [1105703]
- [block] mtip32xx: convert to use blk-mq (Mike Snitzer) [1105703]
- [block] mtip32xx: Fix ERO and NoSnoop values in PCIe upstream on AMD systems (Mike Snitzer) [1105703]
- [block] mtip32xx: Remove dfs_parent after pci unregister (Mike Snitzer) [1105703]
- [block] mtip32xx: Increase timeout for STANDBY IMMEDIATE command (Mike Snitzer) [1105703]
- [block] mtip32xx: Set queue bounce limit (Mike Snitzer) [1105703]
- [block] mtip32xx: Use pci_enable_msi() instead of pci_enable_msi_range() (Mike Snitzer) [1105703]
- [block] mtip32xx: fix bad use of smp_processor_id() (Mike Snitzer) [1105703]
- [block] mtip32xx: Use pci_enable_msix_range() instead of pci_enable_msix() (Mike Snitzer) [1105703]
- [block] mtip32xx: Remove superfluous call to pci_disable_msi() (Mike Snitzer) [1105703]
- [block] mtip32xx: Reduce the number of unaligned writes to 2 (Mike Snitzer) [1105703]
- [block] mtip32xx: Correctly handle security locked condition (Mike Snitzer) [1105703]
- [block] mtip32xx: Make SGL container per-command to eliminate high order dma allocation (Mike Snitzer) [1105703]
- [block] mtip32xx: dynamically allocate buffer in debugfs functions (Mike Snitzer) [1105703]
- [block] blk-mq: fix RHEL kABI breakage (Mike Snitzer) [1105204]
- [block] blk-mq: blk_mq_start_hw_queue() should use blk_mq_run_hw_queue() (Mike Snitzer) [1105204]
- [block] add support for limiting gaps in SG lists (Mike Snitzer) [1105204]
- [block] blk-mq: bitmap tag, fix races in bt_get() function (Mike Snitzer) [1105204]
- [block] blk-mq: bitmap tag, fix race on blk_mq_bitmap_tags::wake_cnt (Mike Snitzer) [1105204]
- [block] blk-mq: bitmap tag, fix races on shared ::wake_index fields (Mike Snitzer) [1105204]
- [block] blk_max_size_offset() should check ->max_sectors (Mike Snitzer) [1105204]
- [block] null_blk: fix softirq completions for queue_mode == 1 (Mike Snitzer) [1105204]
- [block] blk-mq: merge blk_mq_drain_queue and __blk_mq_drain_queue (Mike Snitzer) [1105204]
- [block] blk-mq: properly drain stopped queues (Mike Snitzer) [1105204]
- [block] blk-mq: for_each_* macro correctness (Mike Snitzer) [1105204]
- [scsi] reintroduce scsi_driver.init_command (Mike Snitzer) [1105204]
- [scsi] remove scsi_end_request (Mike Snitzer) [1105204]
- [scsi] explicitly release bidi buffers (Mike Snitzer) [1105204]
- [scsi] don't reference freed command in scsi_prep_return (Mike Snitzer) [1105204]
- [scsi] don't reference freed command in scsi_init_sgtable (Mike Snitzer) [1105204]
- [scsi] add support for per-host cmd pools (Mike Snitzer) [1105204]
- [scsi] simplify command allocation and freeing a bit (Mike Snitzer) [1105204]
- [scsi] megaraid: simplify internal command handling (Mike Snitzer) [1105204]
- [scsi] remove a useless get_put_device pair in scsi_requeue_command (Mike Snitzer) [1105204]
- [scsi] remove a useless get_put_device pair in scsi_next_command (Mike Snitzer) [1105204]
- [scsi] remove a useless get_put_device pair in scsi_request_fn (Mike Snitzer) [1105204]
- [scsi] do not manipulate device reference counts in scsi_get_put_command (Mike Snitzer) [1105204]
- [scsi] avoid taking host_lock in scsi_run_queue unless nessecary (Mike Snitzer) [1105204]
- [scsi] avoid useless free_list lock roundtrips (Mike Snitzer) [1105204]
- [scsi] enable destruction of blocked devices which fail LUN scanning (Mike Snitzer) [1105204]
- [scsi] Revert: reintroduce scsi_driver.init_command (Mike Snitzer) [1105204]
- [block] implement an unprep function corresponding directly to prep (Mike Snitzer) [1105204]
- [scsi] handle command allocation failure in scsi_reset_provider (Mike Snitzer) [1105204]
- [block] properly stack underlying max_segment_size to DM device (Mike Snitzer) [1105204]
- [block] remove elv_abort_queue and blk_abort_flushes (Mike Snitzer) [1105204]
- [block] __elv_next_request() shouldn't call into the elevator if bypassing (Mike Snitzer) [1105204]
- [block] trace all devices plug operation (Mike Snitzer) [1105204]
- [block] Reserve only one queue tag for sync IO if only 3 tags are available (Mike Snitzer) [1105204]
- [block] blk-exec: Cleaning up local variable address returned (Mike Snitzer) [1105204]
- [block] use __blk_end_request_all to free bios and also call rq->end_io (Mike Snitzer) [1105204]
- [block] fix RHEL kABI breakage (Mike Snitzer) [1105204]
- [block] null_blk: fix name and description of 'queue_mode' module parameter (Mike Snitzer) [1105204]
- [block] all blk-mq requests are tagged (Mike Snitzer) [1105204]
- [block] bsg: update check for rq based driver for blk-mq (Mike Snitzer) [1105204]
- [block] blk-mq: add timer in blk_mq_start_request (Mike Snitzer) [1105204]
- [block] blk-mq: always initialize request->start_time (Mike Snitzer) [1105204]
- [block] blk-mq: ->timeout should be cleared in blk_mq_rq_ctx_init() (Mike Snitzer) [1105204]
- [block] blk-mq: don't allow queue entering for a dying queue (Mike Snitzer) [1105204]
- [block] blk-mq: bump max tag depth to 10K tags (Mike Snitzer) [1105204]
- [block] add blk_rq_set_block_pc() (Mike Snitzer) [1105204]
- [block] ensure that bio_add_page() always accepts a page for an empty bio (Mike Snitzer) [1105204]
- [block] add notion of a chunk size for request merging (Mike Snitzer) [1105204]
- [block] blk-flush: clear flush_rq's tag in flush_end_io() (Mike Snitzer) [1105204]
- [block] blk-mq: let blk_mq_tag_to_rq() take blk_mq_tags as the main parameter (Mike Snitzer) [1105204]
- [block] blk-mq: fix regression from commit 624dbe475416 (Mike Snitzer) [1105204]
- [block] blk-mq: handle NULL req return from blk_map_request in single queue mode (Mike Snitzer) [1105204]
- [block] blk-mq: fix sparse warning on missed __percpu annotation (Mike Snitzer) [1105204]
- [block] blk-mq: fix schedule from atomic context (Mike Snitzer) [1105204]
- [block] blk-mq: move blk_mq_get_ctx_blk_mq_put_ctx to mq private header (Mike Snitzer) [1105204]
- [block] blk-mq: push IPI or local end_io decision to __blk_mq_complete_request() (Mike Snitzer) [1105204]
- [block] blk-mq: remember to start timeout handler for direct queue (Mike Snitzer) [1105204]
- [block] blk-mq: blk_mq_unregister_hctx() can be static (Mike Snitzer) [1105204]
- [block] blk-mq: make the sysfs mq/ layout reflect current mappings (Mike Snitzer) [1105204]
- [block] blk-mq: blk_mq_tag_to_rq should handle flush request (Mike Snitzer) [1105204]
- [block] blk-mq: request initialization optimizations (Mike Snitzer) [1105204]
- [block] add queue flag for disabling SG merging (Mike Snitzer) [1105204]
- [block] blk-mq: remove alloc_hctx and free_hctx methods (Mike Snitzer) [1105204]
- [block] blk-mq: add file comments and update copyright notices (Mike Snitzer) [1105204]
- [block] blk-mq: remove blk_mq_alloc_request_pinned (Mike Snitzer) [1105204]
- [block] blk-mq: do not use blk_mq_alloc_request_pinned in blk_mq_map_request (Mike Snitzer) [1105204]
- [block] blk-mq: remove blk_mq_wait_for_tags (Mike Snitzer) [1105204]
- [block] blk-mq: initialize request in __blk_mq_alloc_request (Mike Snitzer) [1105204]
- [block] blk-mq: merge blk_mq_alloc_reserved_request into blk_mq_alloc_request (Mike Snitzer) [1105204]
- [block] blk-mq: add helper to insert requests from irq context (Mike Snitzer) [1105204]
- [block] blk-mq: remove stale comment for blk_mq_complete_request() (Mike Snitzer) [1105204]
- [block] blk-mq: allow non-softirq completions (Mike Snitzer) [1105204]
- [block] blk-mq: pass in suggested NUMA node to ->alloc_hctx() (Mike Snitzer) [1105204]
- [block] only allocate/free mq_usage_counter in blk-mq (Mike Snitzer) [1105204]
- [block] blk-mq: avoid code duplication (Mike Snitzer) [1105204]
- [block] blk-mq: fix leak of hctx->ctx_map (Mike Snitzer) [1105204]
- [block] blk-mq: idle all hardware contexts before freeing a queue (Mike Snitzer) [1105204]
- [block] blk-mq: allow setting of per-request timeouts (Mike Snitzer) [1105204]
- [block] blk-mq: export blk_mq_tag_busy_iter (Mike Snitzer) [1105204]
- [block] blk-mq: split make request handler for multi and single queue (Mike Snitzer) [1105204]
- [block] blk-mq: save memory by freeing requests on unused hardware queues (Mike Snitzer) [1105204]
- [block] blk-mq: allow the hctx cpu hotplug notifier to return errors (Mike Snitzer) [1105204]
- [block] blk-mq: Micro-optimize blk_queue_nomerges() check (Mike Snitzer) [1105204]
- [block] Enable sysfs nomerge control for I/O requests in the plug list (Mike Snitzer) [1105204]
- [block] blk-mq: initialize q->nr_requests after calling blk_queue_make_request() (Mike Snitzer) [1105204]
- [block] blk-mq: allow changing of queue depth through sysfs (Mike Snitzer) [1105204]
- [block] blk-mq: switch ctx pending map to the sparser blk_align_bitmap (Mike Snitzer) [1105204]
- [block] blk-mq: move the cache friendly bitmap type of out blk-mq-tag (Mike Snitzer) [1105204]
- [block] blk-mq: improve support for shared tags maps (Mike Snitzer) [1105204]
- [block] blk-mq: cleanup blk_mq_init_tags (Mike Snitzer) [1105204]
- [block] blk-mq: select random tag betweet 0 and (depth - 1) (Mike Snitzer) [1105204]
- [block] blk-mq: remove barrier in bt_clear_tag() (Mike Snitzer) [1105204]
- [block] blk-mq: use clear_bit_unlock in bt_clear_tag() (Mike Snitzer) [1105204]
- [block] blk-mq: fix race in IO start accounting (Mike Snitzer) [1105204]
- [block] blk-mq: use sparser tag layout for lower queue depth (Mike Snitzer) [1105204]
- [block] blk-mq: implement new and more efficient tagging scheme (Mike Snitzer) [1105204]
- [block] blk-mq: initialize struct request fields individually (Mike Snitzer) [1105204]
- [block] blk-mq: update a hotplug comment for grammar (Mike Snitzer) [1105204]
- [block] blk-mq: add basic round-robin of what CPU to queue workqueue work on (Mike Snitzer) [1105204]
- [block] blk-mq: remove extra requeue trace (Mike Snitzer) [1105204]
- [block] null_blk: fix use after free (Mike Snitzer) [1105204]
- [block] blk-mq: refactor request insertion_merging (Mike Snitzer) [1105204]
- [block] blk-mq: remove debug BUG_ON() when draining software queues (Mike Snitzer) [1105204]
- [block] blk-mq: fix waiting for reserved tags (Mike Snitzer) [1105204]
- [block] ensure that the timer is always added (Mike Snitzer) [1105204]
- [block] fold __blk_add_timer into blk_add_timer (Mike Snitzer) [1105204]
- [block] blk-mq: respect rq_affinity (Mike Snitzer) [1105204]
- [block] blk-mq: fix race with timeouts and requeue events (Mike Snitzer) [1105204]
- [block] Revert: blk-mq: initialize req->q in allocation (Mike Snitzer) [1105204]
- [block] blk-mq: fix leak of set->tags (Mike Snitzer) [1105204]
- [block] blk-mq: initialize req->q in allocation (Mike Snitzer) [1105204]
- [block] blk-mq: user (1 << order) to implement order_to_size() (Mike Snitzer) [1105204]
- [block] blk-mq: fix allocation of set->tags (Mike Snitzer) [1105204]
- [block] blk-mq: free hctx->ctx_map when init failed (Mike Snitzer) [1105204]
- [block] export blk_finish_request (Mike Snitzer) [1105204]
- [block] blk-mq: rename mq_flush_work struct request member (Mike Snitzer) [1105204]
- [block] blk-mq: add blk_mq_requeue_request (Mike Snitzer) [1105204]
- [block] blk-mq: add blk_mq_start_hw_queues (Mike Snitzer) [1105204]
- [block] blk-mq: add blk_mq_delay_queue (Mike Snitzer) [1105204]
- [block] blk-mq: add async parameter to blk_mq_start_stopped_hw_queues (Mike Snitzer) [1105204]
- [block] blk-mq: bidi support (Mike Snitzer) [1105204]
- [block] blk-mq: allow drivers to hook into I_O completion (Mike Snitzer) [1105204]
- [block] blk-mq: kill preempt disable_enable in blk_mq_work_fn() (Mike Snitzer) [1105204]
- [block] blk-mq: don't use preempt_count() to check for right CPU (Mike Snitzer) [1105204]
- [block] blk-mq: split out tag initialization, support shared tags (Mike Snitzer) [1105204]
- [block] blk-mq: initialize request on allocation (Mike Snitzer) [1105204]
- [block] blk-mq: add ->init_request and ->exit_request methods (Mike Snitzer) [1105204]
- [block] blk-mq: make ->flush_rq fully transparent to drivers (Mike Snitzer) [1105204]
- [block] blk-mq: do not initialize req->special (Mike Snitzer) [1105204]
- [block] blk-mq: initialize resid_len (Mike Snitzer) [1105204]
- [block] blk-mq: simplify blk_mq_hw_sysfs_cpus_show() (Mike Snitzer) [1105204]
- [block] blk-mq: ensure that hardware queues are always run on the mapped CPUs (Mike Snitzer) [1105204]
- [block] add kblockd_schedule_delayed_work_on() (Mike Snitzer) [1105204]
- [block] remove 'q' parameter from kblockd_schedule_*_work() (Mike Snitzer) [1105204]
- [block] blk-mq: fix potential stall during CPU unplug with IO pending (Mike Snitzer) [1105204]
- [block] remove dead code in scsi_ioctl:blk_verify_command (Mike Snitzer) [1105204]
- [block] only calculate part_in_flight() once (Mike Snitzer) [1105204]
- [block] relax when to modify the timeout timer (Mike Snitzer) [1105204]
- [char] random: export add_disk_randomness (Mike Snitzer) [1105204]
- [block] blk-mq: add REQ_SYNC early (Mike Snitzer) [1105204]
- [block] blk-mq: Make blk_mq_cpu_notify_lock a raw spinlock (Mike Snitzer) [1105204]
- [block] blk-mq: don't dump CPU -> hw queue map on driver load (Mike Snitzer) [1105204]
- [block] blk-mq: fix wrong usage of hctx->state vs hctx->flags (Mike Snitzer) [1105204]
- [block] blk-mq: allow blk_mq_init_commands() to return failure (Mike Snitzer) [1105204]
- [block] fix regression with block enabled tagging (Mike Snitzer) [1105204]
- [block] Stop abusing rq->csd.list in blk-softirq (Mike Snitzer) [1105204]
- [scsi] Make sure cmd_flags are 64-bit (Mike Snitzer) [1109271]
- [block] Replace __get_cpu_var uses (Mike Snitzer) [1105204]
- [block] Remove useless IPI struct initialization (Mike Snitzer) [1105204]
- [block] Stop abusing csd.list for fifo_time (Mike Snitzer) [1105204]
- [block] blktrace: fix accounting of partially completed requests (Mike Snitzer) [1105204]
- [fs] bio: don't write "bio: create slab" messages to syslog (Mike Snitzer) [1105204]
- [block] make __blkdev_issue_zeroout static (Mike Snitzer) [1105204]
- [block] Do not call sector_div() with a 64-bit divisor (Mike Snitzer) [1105204]
- [block] add cond_resched() to potentially long running ioctl discard loop (Mike Snitzer) [1105204]
- [kernel] smp: Rename __smp_call_function_single() to smp_call_function_single_async() (Prarit Bhargava) [1105192]
- [kernel] smp: Remove wait argument from __smp_call_function_single() (Prarit Bhargava) [1105192]
- [kernel] smp: Move __smp_call_function_single() below its safe version (Prarit Bhargava) [1105192]
- [kernel] smp: Consolidate the various smp_call_function_single() declensions (Prarit Bhargava) [1105192]
- [kernel] smp: Teach __smp_call_function_single() to check for offline cpus (Prarit Bhargava) [1105192]
- [kernel] smp: Iterate functions through llist_for_each_entry_safe() (Prarit Bhargava) [1105192]
- [kernel] llist: lock-less list, Add llist_for_each_entry_safe() (Prarit Bhargava) [1105192]
- [kernel] smp: remove cpumask_ipi (Prarit Bhargava) [1105192]
- [kernel] smp: use lockless list for smp_call_function_single (Prarit Bhargava) [1105192]
- [kernel] smp: fix generic_exec_single indentation (Prarit Bhargava) [1105192]
- [kernel] smp: quit unconditionally enabling irqs in on_each_cpu_mask() (Prarit Bhargava) [1105192]
- [kernel] smp: free related resources when failure occurs in hotplug_cfd() (Prarit Bhargava) [1105192]
- [kernel] smp/generic-ipi/locking: Fix misleading smp_call_function_any() description (Prarit Bhargava) [1105192]
- [kernel] smp/generic-ipi: Kill unnecessary variable - csd_flags (Prarit Bhargava) [1105192]
- [kernel] init: remove __cpuinit sections from the kernel (Prarit Bhargava) [1105893]
- [block] blk-mq: remove newly added instances of __cpuinit (Prarit Bhargava) [1105893]
- [misc] delete __cpuinit usage from all remaining drivers files (Prarit Bhargava) [1105893]
- [kernel] delete __cpuinit usage from all core kernel files (Prarit Bhargava) [1105893]
- [block] delete __cpuinit usage from all block files (Prarit Bhargava) [1105893]
- [acpi] delete __cpuinit usage from all acpi files (Prarit Bhargava) [1105893]
- [kernel] rcu: delete __cpuinit usage from all rcu files (Prarit Bhargava) [1105893]
- [net] delete __cpuinit usage from all net files (Prarit Bhargava) [1105893]
- [hwmon] delete __cpuinit usage from all hwmon files (Prarit Bhargava) [1105893]
- [clocksource] delete __cpuinit usage from all related files (Prarit Bhargava) [1105893]
- [x86] delete __cpuinit usage from all x86 files (Prarit Bhargava) [1105893]
- [s390] delete __cpuinit usage from all s390 files (Prarit Bhargava) [1105893]
- [powerpc] Delete __cpuinit usage from all users (Prarit Bhargava) [1105893]

* Wed Jul 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-135.el7]
- [pci] hotplug: Avoid warning when _ADR not present (Myron Stowe) [1114228]
- [pci] hotplug/acpi: Drop unused acpiphp_debug declaration (Myron Stowe) [1114228]
- [acpi] scan: Set flags.match_driver in acpi_bus_scan_fixed() (Myron Stowe) [1114228]
- [acpi] pci_root: Clear driver_data before failing enumeration (Myron Stowe) [1114228]
- [acpi] hotplug: Fix PCI host bridge hot removal (Myron Stowe) [1114228]
- [acpi] hotplug: Fix acpi_bus_get_device() return value check (Myron Stowe) [1114228]
- [acpi] hotplug: Consolidate deferred execution of ACPI hotplug routines (Myron Stowe) [1114228]
- [acpi] hotplug: Do not execute "insert in progress" _OST (Myron Stowe) [1114228]
- [acpi] hotplug: Carry out PCI root eject directly (Myron Stowe) [1114228]
- [acpi] hotplug: Merge device hot-removal routines (Myron Stowe) [1114228]
- [acpi] hotplug: Make acpi_bus_hot_remove_device() internal (Myron Stowe) [1114228]
- [acpi] hotplug: Simplify device ejection routines (Myron Stowe) [1114228]
- [acpi] hotplug: Fix handle_root_bridge_removal() (Myron Stowe) [1114228]
- [acpi] hotplug: Refuse to hot-remove all objects with disabled hotplug (Myron Stowe) [1114228]
- [acpi] scan: Start matching drivers after trying scan handlers (Myron Stowe) [1114228]
- [acpi] Remove acpi_pci_slot_init() headers from internal.h (Myron Stowe) [1114228]
- [pci] Revert: acpi / hotplug / pci: Avoid doing too much for spurious notifies (Myron Stowe) [1114228]
- [base] Release device_hotplug_lock when store_mem_state returns EINVAL (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop WARN_ON() from acpiphp_enumerate_slots() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Fix error code path in acpiphp_enumerate_slots() (Myron Stowe) [1114228]
- [acpi] memhotplug: Use defined marco METHOD_NAME__STA (Myron Stowe) [1114228]
- [acpi] hotplug: Use kobject_init_and_add() instead of _init() and _add() (Myron Stowe) [1114228]
- [acpi] hotplug: Don't set kobject parent pointer explicitly (Myron Stowe) [1114228]
- [acpi] hotplug: Set kobject name via kobject_add(), not kobject_set_name() (Myron Stowe) [1114228]
- [base] hotplug: Remove cpu_hotplug_driver_lock() (Myron Stowe) [1114228]
- [x86] hotplug: Disable ARCH_CPU_PROBE_RELEASE on x86 (Myron Stowe) [1114228]
- [x86] hotplug: Add hotplug lock to missing places (Myron Stowe) [1114228]
- [x86] hotplug: Fix online state in cpu0 debug interface (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Avoid parent bus rescans on spurious device checks (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Use _OST to notify firmware about notify status (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Avoid doing too much for spurious notifies (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Don't trim devices before scanning the namespace (Myron Stowe) [1114228]
- [kernel] power/hibernate/memory_hotplug: Rework mutual exclusion (Myron Stowe) [1114228]
- [kernel] power/hibernate: Create memory bitmaps after freezing user space (Myron Stowe) [1114228]
- [acpi] scan: Change ordering of locks for device hotplug (Myron Stowe) [1114228]
- [acpi] hotplug: Remove containers synchronously (Myron Stowe) [1114228]
- [base] core/acpi: Avoid device hot remove locking issues (Myron Stowe) [1114228]
- [base] introduce help macro to_memory_block (Myron Stowe) [1114228]
- [base] use standard device online/offline for state change (Myron Stowe) [1114228]
- [base] refactor add_memory_section() to add_memory_block() (Myron Stowe) [1114228]
- [base] remove improper get/put in add_memory_section() (Myron Stowe) [1114228]
- [base] reduce add_memory_section() for boot-time only (Myron Stowe) [1114228]
- [base] unshare add_memory_section() from hotplug (Myron Stowe) [1114228]
- [base] use device get/put functions (Myron Stowe) [1114228]
- [base] remove unneeded variable (Myron Stowe) [1114228]
- [base] move mutex lock out of add_memory_section() (Myron Stowe) [1114228]
- [acpi] sleep: Hold acpi_scan_lock over system PM transitions (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Fix NULL pointer dereference in cleanup_bridge() (Myron Stowe) [1114228]
- [base] cpu: Check if NUMA node is valid before bringing CPU up (Myron Stowe) [1114228]
- [pci] acpi: Use dev_dbg() instead of dev_info() in acpi_pci_set_power_state() (Myron Stowe) [1114228]
- [acpi] sleep: Introduce acpi_os_prepare_extended_sleep() for extended sleep (Myron Stowe) [1114228]
- [base] core: replace strict_strto*() with kstrto*() (Myron Stowe) [1114228]
- [acpi] dock: fix error return code in dock_add() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Get rid of check_sub_bridges() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Clean up bridge_mutex usage (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Redefine enable_device() and disable_device() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Sanitize acpiphp_get_(latch) (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Get rid of unused constants in acpiphp.h (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Check for new devices on enabled slots (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Allow slots without new devices to be rescanned (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Do not check SLOT_ENABLED in enable_device() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Do not exectute _PS0 and _PS3 directly (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Do not queue up event handling work items in vain (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Consolidate slot disabling and ejecting (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop redundant checks from check_hotplug_bridge() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Rework namespace scanning and trimming routines (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Store parent in functions and bus in slots (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop handle field from struct acpiphp_bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop handle field from struct acpiphp_func (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Embed function struct into struct acpiphp_context (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop flags field from struct acpiphp_bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop sun field from struct acpiphp_slot (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Register all devices under the given bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Refactor slot allocation code in register_slot() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop func field from struct acpiphp_bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Merge hotplug event handling functions (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Pass hotplug context objects to event handlers (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Rework acpiphp_handle_to_bridge() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Unified notify handler for hotplug events (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Hotplug context objects for bridges and functions (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Always return success after adding a function (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Consolidate acpiphp_enumerate_slots() (Myron Stowe) [1114228]
- [acpi] pci: Make bus registration and unregistration symmetric (Myron Stowe) [1114228]
- [x86] pci: prevent re-allocation of already existing bridge and ROM resource (Myron Stowe) [1114228]
- [acpi] dock: Drop unnecessary local variable from dock_add() (Myron Stowe) [1114228]
- [acpi] dock/pci: Drop ACPI dock notifier chain (Myron Stowe) [1114228]
- [acpi] dock: Do not check CONFIG_ACPI_DOCK_MODULE (Myron Stowe) [1114228]
- [acpi] dock: Do not leak memory on falilures to add a dock station (Myron Stowe) [1114228]
- [acpi] Drop ACPI bus notifier call chain (Myron Stowe) [1114228]
- [acpi] dock: Rework the handling of notifications (Myron Stowe) [1114228]
- [acpi] dock: Simplify dock_init_hotplug() and dock_release_hotplug() (Myron Stowe) [1114228]
- [acpi] dock: Walk list in reverse order during removal of devices (Myron Stowe) [1114228]
- [acpi] dock: Rework and simplify find_dock_devices() (Myron Stowe) [1114228]
- [acpi] dock: Drop the hp_lock mutex from struct dock_station (Myron Stowe) [1114228]
- [acpi] simplify acpiphp driver with new helper functions (Myron Stowe) [1114228]
- [acpi] simplify dock driver with new helper functions (Myron Stowe) [1114228]
- [acpi] Export acpi_(bay) (Myron Stowe) [1114228]
- [acpi] introduce two helper functions for _EJ0 and _LCK (Myron Stowe) [1114228]
- [acpi] introduce helper function acpi_execute_simple_method() (Myron Stowe) [1114228]
- [acpi] introduce helper function acpi_has_method() (Myron Stowe) [1114228]
- [acpi] dock: simplify dock_create_acpi_device() (Myron Stowe) [1114228]
- [acpi] dock: mark initialization functions with __init (Myron Stowe) [1114228]
- [acpi] dock: drop redundant spin lock in dock station object (Myron Stowe) [1114228]
- [acpi] dock: avoid initializing acpi_dock_notifier_list multiple times (Myron Stowe) [1114228]
- [base] Use attribute groups to create sysfs memory files (Myron Stowe) [1114228]
- [mm] hugetlb: add support for gigantic page allocation at runtime (Luiz Capitulino) [996763]
- [mm] hugetlb: move helpers up in the file (Luiz Capitulino) [996763]
- [mm] hugetlb: update_and_free_page(), don't clear PG_reserved bit (Luiz Capitulino) [996763]
- [mm] hugetlb: add hstate_is_gigantic() (Luiz Capitulino) [996763]
- [mm] hugetlb: fix and clean-up node iteration code to alloc or free (Luiz Capitulino) [996763]
- [mm] dma-contiguous: clean source code and prepare for device tree (Luiz Capitulino) [996763]
- [mm] cma: Move dma contiguous changes into a seperate config (Luiz Capitulino) [996763]
- [thermal] intel_powerclamp: Fix cstate counter detection (Steve Best) [1103376]
- [thermal] Tidy up error handling in powerclamp_init (Steve Best) [1103376]
- [thermal] intel_powerclamp: Add newer CPU models (Steve Best) [1103376]
- [security] selinux: Increase ebitmap_node size for 64-bit configuration (Paul Moore) [922752]
- [security] selinux: Reduce overhead of mls_level_isvalid() function call (Paul Moore) [922752]
- [powerpc] mm: fix ".__node_distance" undefined (David Milburn) [1081734]
- [block] nvme: Retry failed commands with non-fatal error (David Milburn) [1081734]
- [block] nvme: Fix divide-by-zero in nvme_trans_io_get_num_cmds (David Milburn) [1081734]
- [block] nvme: Add getgeo to block ops (David Milburn) [1081734]
- [block] nvme: Start-stop nvme_thread during device add-remove (David Milburn) [1081734]
- [block] nvme: Make I/O timeout a module parameter (David Milburn) [1081734]
- [block] nvme: CPU hot plug notification (David Milburn) [1081734]
- [block] nvme: per-cpu io queues (David Milburn) [1081734]
- [block] nvme: Replace DEFINE_PCI_DEVICE_TABLE (David Milburn) [1081734]
- [block] nvme: IOCTL path RCU protect queue access (David Milburn) [1081734]
- [block] nvme: RCU protected access to io queues (David Milburn) [1081734]
- [block] nvme: Initialize device reference count earlier (David Milburn) [1081734]
- [scsi] fnic: fix broken FIP discovery by initializing multicast address (Chris Leech) [1100078]
- [scsi] libfcoe: Make fcoe_sysfs optional / fix fnic NULL exception (Chris Leech) [1100078]

* Mon Jul 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-134.el7]
- [fs] nfs: populate ->net in mount data when remounting (Steve Dickson) [1113248]
- [fs] nfs: fix lockup caused by pnfs_generic_pg_test (Steve Dickson) [1113248]
- [fs] nfs: Fix typo in dprintk (Steve Dickson) [1113248]
- [fs] nfs: Comment is now wrong and redundant to code (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Disconnect on registration failure (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove BUG_ON() call sites (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Avoid deadlock when credit window is reset (Steve Dickson) [1113248]
- [net] sunrpc: Move congestion window constants to header file (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reset connection timeout after successful reconnect (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Use macros for reconnection timeout constants (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Allocate missing pagelist (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove Tavor MTU setting (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Ensure ia->ri_id->qp is not NULL when reconnecting (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reduce the number of hardway buffer allocations (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Limit work done by completion handler (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reduce calls to ib_poll_cq() in completion handlers (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reduce lock contention in completion handlers (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Split the completion queue (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Make rpcrdma_ep_destroy() return void (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Simplify rpcrdma_deregister_external() synopsis (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: mount reports "Invalid mount option" if memreg mode not supported (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Fall back to MTHCAFMR when FRMR is not supported (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove REGISTER memory registration mode (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove MEMWINDOWS registration modes (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove BOUNCEBUFFERS memory registration mode (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: RPC/RDMA must invoke xprt_wake_pending_tasks() in process context (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Fix for FMR leaks (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: mind the device's max fast register page list depth (Steve Dickson) [1113248]
- [fs] nfs: Push the file layout driver into a subdirectory (Steve Dickson) [1113248]
- [fs] nfs: Handle allocation errors correctly in objlayout_alloc_layout_hdr() (Steve Dickson) [1113248]
- [fs] nfs: Handle allocation errors correctly in filelayout_alloc_layout_hdr() (Steve Dickson) [1113248]
- [fs] nfs: Use error handler on failed GETATTR with successful OPEN (Steve Dickson) [1113248]
- [fs] nfs: Fix a potential busy wait in nfs_page_group_lock (Steve Dickson) [1113248]
- [fs] nfs: Fix error handling in __nfs_pageio_add_request (Steve Dickson) [1113248]
- [net] sunrpc: suppress allocation warning in rpc_malloc() (Steve Dickson) [1113248]
- [fs] nfs: support page groups in nfs_read_completion (Steve Dickson) [1113248]
- [fs] nfs: support non page aligned layouts (Steve Dickson) [1113248]
- [fs] nfs: allow non page aligned pnfs layout segments (Steve Dickson) [1113248]
- [fs] nfs: support multiple verfs per direct req (Steve Dickson) [1113248]
- [fs] nfs: remove data list from pgio header (Steve Dickson) [1113248]
- [fs] nfs: use > 1 request to handle bsize < PAGE_SIZE (Steve Dickson) [1113248]
- [fs] nfs: chain calls to pg_test (Steve Dickson) [1113248]
- [fs] nfs: allow coalescing of subpage requests (Steve Dickson) [1113248]
- [fs] nfs: clean up filelayout_alloc_commit_info (Steve Dickson) [1113248]
- [fs] nfs: page group support in nfs_mark_uptodate (Steve Dickson) [1113248]
- [fs] nfs: page group syncing in write path (Steve Dickson) [1113248]
- [fs] nfs: page group syncing in read path (Steve Dickson) [1113248]
- [fs] nfs: add support for multiple nfs reqs per page (Steve Dickson) [1113248]
- [fs] nfs: call nfs_can_coalesce_requests for every req (Steve Dickson) [1113248]
- [fs] nfs: modify pg_test interface to return size_t (Steve Dickson) [1113248]
- [fs] nfs: remove unused arg from nfs_create_request (Steve Dickson) [1113248]
- [fs] nfs: clean up PG_* flags (Steve Dickson) [1113248]
- [fs] nfs: fix race in filelayout commit path (Steve Dickson) [1113248]
- [fs] nfs: Create a common nfs_pageio_ops struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common generic_pg_pgios() (Steve Dickson) [1113248]
- [fs] nfs: Create a common multiple_pgios() function (Steve Dickson) [1113248]
- [fs] nfs: Create a common initiate_pgio() function (Steve Dickson) [1113248]
- [fs] nfs: Create a generic_pgio function (Steve Dickson) [1113248]
- [fs] nfs: Create a common pgio_error function (Steve Dickson) [1113248]
- [fs] nfs: Create a common rpcsetup function for reads and writes (Steve Dickson) [1113248]
- [fs] nfs: Create a common rpc_call_ops struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common nfs_pgio_result_common function (Steve Dickson) [1113248]
- [fs] nfs: Create a common pgio_rpc_prepare function (Steve Dickson) [1113248]
- [fs] nfs: Create a common rw_header_alloc and rw_header_free function (Steve Dickson) [1113248]
- [fs] nfs: Create a common pgio_alloc and pgio_release function (Steve Dickson) [1113248]
- [fs] nfs: Move the write verifier into the nfs_pgio_header (Steve Dickson) [1113248]
- [fs] nfs: Create a common read and write header struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common read and write data struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common results structure for reads and writes (Steve Dickson) [1113248]
- [fs] nfs: Create a common argument structure for reads and writes (Steve Dickson) [1113248]
- [fs] nfs: remove ->read_pageio_init from rpc ops (Steve Dickson) [1113248]
- [fs] nfs: remove ->write_pageio_init from rpc ops (Steve Dickson) [1113248]
- [fs] nfs: commit layouts in fdatasync (Steve Dickson) [1113248]
- [net] sunrpc: Fix a module reference issue in rpcsec_gss (Steve Dickson) [1113248]
- [fs] nfs: Don't ignore suid/sgid bit changes after a successful write (Steve Dickson) [1113248]
- [fs] nfs: Don't declare inode uptodate unless all attributes were checked (Steve Dickson) [1113248]
- [fs] nfs: Fix memroy leak for double mounts (Steve Dickson) [1113248]
- [fs] nfs: pass string length to pr_notice message about readdir loops (Steve Dickson) [1111170]
- [net] sunrpc: rpc_restart_call/rpc_restart_call_prepare should clear task->tk_status (Steve Dickson) [1111170]
- [net] sunrpc: Don't let rpc_delay() clobber non-timeout errors (Steve Dickson) [1111170]
- [net] sunrpc: Ensure call_status() deals correctly with SOFTCONN tasks (Steve Dickson) [1111170]
- [fs] nfs: Clear the open state flags if the new stateid does not match (Steve Dickson) [1111170]
- [fs] nfs: Use correct locking when updating nfs4_state in nfs4_close_done (Steve Dickson) [1111170]
- [fs] nfs: Ensure that we free existing layout segments if we get a new layout (Steve Dickson) [1111170]
- [fs] nfs: Minor optimisation in get_layout_by_fh_locked() (Steve Dickson) [1111170]
- [fs] nfs: Ensure that the layout recall callback matches layout stateids (Steve Dickson) [1111170]
- [fs] nfs: Don't update the open stateid unless it is newer than the old one (Steve Dickson) [1111170]
- [fs] nfs: Fix wraparound issues in pnfs_seqid_is_newer() (Steve Dickson) [1111170]
- [fs] nfs: Be more aggressive in using readdirplus for 'ls -l' situations (Steve Dickson) [1111170]
- [net] sunrpc: RPC callbacks may be split across several TCP segments (Steve Dickson) [1111170]
- [net] sunrpc: Fix oops when trace sunrpc_task events in nfs client (Steve Dickson) [1111170]
- [fs] nfs: Fail the truncate() if the lock/open stateid is invalid (Steve Dickson) [1111170]
- [fs] nfs: Fail data server I/O if stateid represents a lost lock (Steve Dickson) [1111170]
- [fs] nfs: Fix the return value of nfs4_select_rw_stateid (Steve Dickson) [1111170]
- [fs] nfs: nfs4_stateid_is_current should return 'true' for an invalid stateid (Steve Dickson) [1111170]
- [fs] nfs: Fix a delegation callback race (Steve Dickson) [1111170]
- [fs] nfs: Fix another nfs4_sequence corruptor (Steve Dickson) [1111170]
- [fs] nfsd: fix bug for readdir of pseudofs ("J. Bruce Fields") [1109733 1111719]
- [fs] nfsd: Don't hand out delegations for 30 seconds after recalling them ("J. Bruce Fields") [1111227 1111719]
- [fs] nfsd: fix FREE_STATEID lockowner leak ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't halt scanning the DRC LRU list when there's an RC_INPROG entry ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill READ64 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill READ32 ("J. Bruce Fields") [1111719]
- [fs] nfsd: simplify server xdr->next_page use ("J. Bruce Fields") [1111719]
- [fs] nfsd: hash deleg stateid only on successful nfs4_set_delegation ("J. Bruce Fields") [1111719]
- [fs] nfsd: rename recall_lock to state_lock ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove unneeded zeroing of fields in nfsd4_proc_compound ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix setting of NFS4_OO_CONFIRMED in nfsd4_open ("J. Bruce Fields") [1111719]
- [fs] nfsd: use recall_lock for delegation hashing ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix laundromat next-run-time calculation ("J. Bruce Fields") [1111719]
- [fs] nfsd: make nfsd4_encode_fattr static ("J. Bruce Fields") [1111719]
- [net] sunrpc: Remove using of dprintk with KERN_WARNING ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove unused function nfsd_read_file ("J. Bruce Fields") [1111719]
- [fs] nfsd: getattr for FATTR4_WORD0_FILES_AVAIL needs the statfs buffer ("J. Bruce Fields") [1111719]
- [fs] nfsd: Error out when getting more than one fsloc/secinfo/uuid ("J. Bruce Fields") [1111719]
- [fs] nfsd: Using type of uint32_t for ex_nflavors instead of int ("J. Bruce Fields") [1111719]
- [fs] nfsd: Add missing comment of "expiry" in expkey_parse() ("J. Bruce Fields") [1111719]
- [fs] nfsd: Remove typedef of svc_client and svc_export in export.c ("J. Bruce Fields") [1111719]
- [fs] nfsd: Cleanup unneeded including net/ipv6.h ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove unneeded linux/user_namespace.h include ("J. Bruce Fields") [1111719]
- [fs] nfsd: Adds macro EX_UUID_LEN for exports uuid's length ("J. Bruce Fields") [1111719]
- [fs] nfsd: Helper function for parsing uuid ("J. Bruce Fields") [1111719]
- [fs] nfsd:Avoid NULL reference or double free in nfsd4_fslocs_free() ("J. Bruce Fields") [1109733 1111719]
- [fs] nfsd: better reservation of head space for krb5 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill write32, write64 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill WRITEMEM ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill WRITE64 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill WRITE32 ("J. Bruce Fields") [1111719]
- [fs] nfsd: really fix nfs4err_resource in 4.1 case ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow exotic read compounds ("J. Bruce Fields") [1111719]
- [fs] nfsd: more read encoding cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: read encoding cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: separate splice and readv cases ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd_vfs_read doesn't use file handle parameter ("J. Bruce Fields") [1111719]
- [fs] nfsd: turn off zero-copy-read in exotic cases ("J. Bruce Fields") [1111719]
- [fs] nfsd: estimate sequence response size ("J. Bruce Fields") [1111719]
- [fs] nfsd: better estimate of getattr response size ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't treat readlink like a zero-copy operation ("J. Bruce Fields") [1111719]
- [fs] nfsd: enforce rd_dircount ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow large readdirs ("J. Bruce Fields") [1111719]
- [fs] nfsd: use session limits to release send buffer reservation ("J. Bruce Fields") [1111719]
- [fs] nfsd: adjust buflen to session channel limit ("J. Bruce Fields") [1111719]
- [net] sunrpc: define xdr_restrict_buflen ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix buflen calculation after read encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_check_resp_size should check against whole buffer ("J. Bruce Fields") [1111719]
- [fs] nfsd: minor encode_read cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: more precise nfsd4_max_reply ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't try to encode conflicting owner if low on space ("J. Bruce Fields") [1111719]
- [fs] nfsd: convert 4.1 replay encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow encoding across page boundaries ("J. Bruce Fields") [1023319 1111719]
- [fs] nfsd: size-checking cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove redundant encode buffer size checking ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_check_resp_size needn't recalculate length ("J. Bruce Fields") [1111719]
- [fs] nfsd: reserve space before inlining 0-copy pages ("J. Bruce Fields") [1111719]
- [fs] nfsd: teach encoders to handle reserve_space failures ("J. Bruce Fields") [1111719]
- [fs] nfsd: "backfill" using write_bytes_to_xdr_buf ("J. Bruce Fields") [1111719]
- [fs] nfsd: use xdr_truncate_encode ("J. Bruce Fields") [1111719]
- [net] sunrpc: xdr_truncate_encode ("J. Bruce Fields") [1111719]
- [fs] nfsd: keep xdr buf length updated ("J. Bruce Fields") [1111719]
- [fs] nfsd: no need for encode_compoundres to adjust lengths ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove ADJUST_ARGS ("J. Bruce Fields") [1111719]
- [fs] nfsd: use xdr_stream throughout compound encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: use xdr_reserve_space in attribute encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow space for final error return ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix encoding of out-of-space replies ("J. Bruce Fields") [1111719]
- [fs] nfsd: reserve head space for krb5 integ/priv info ("J. Bruce Fields") [1111719]
- [fs] nfsd: move proc_compound xdr encode init to helper ("J. Bruce Fields") [1111719]
- [fs] nfsd: tweak nfsd4_encode_getattr to take xdr_stream ("J. Bruce Fields") [1111719]
- [fs] nfsd: embed xdr_stream in nfsd4_compoundres ("J. Bruce Fields") [1111719]
- [fs] nfsd: decoding errors can still be cached and require space ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix write reply size estimate ("J. Bruce Fields") [1111719]
- [fs] nfsd: read size estimate should include padding ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow larger 4.1 session drc slots ("J. Bruce Fields") [1111719]
- [fs] nfsd: READ, READDIR, etc., are idempotent ("J. Bruce Fields") [1111719]
- [fs] nfsd: Only set PF_LESS_THROTTLE when really needed ("J. Bruce Fields") [1111719]
- [net] sunrpc: track whether a request is coming from a loop-back interface ("J. Bruce Fields") [1111719]
- [net] sunrpc: Fix a module reference leak in svc_handle_xprt ("J. Bruce Fields") [1111719]
- [fs] nfsd: Ignore client's source port on RDMA transports ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove nfsd4_free_slab ("J. Bruce Fields") [1111719]
- [fs] nfsd: Remove assignments inside conditions ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix delegation cleanup on error ("J. Bruce Fields") [1111719]
- [fs] nfsd: Don't clear SUID/SGID after root writing data ("J. Bruce Fields") [1111719]
- [fs] nfsd: warn on finding lockowner without stateid's ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove lockowner when removing lock stateid ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix corruption on setting an ACL ("J. Bruce Fields") [1111719]
- [fs] nfsd: Get rid of empty function nfs4_state_init ("J. Bruce Fields") [1111719]
- [fs] nfsd: Use simple_read_from_buffer for coping data to userspace ("J. Bruce Fields") [1111719]
- [fs] nfsd: clean up fh_auth usage ("J. Bruce Fields") [1111719]
- [fs] nfsd: cleanup unneeded including linux/export.h ("J. Bruce Fields") [1111719]
- [fs] nfsd: Clean up nfs4_preprocess_stateid_op ("J. Bruce Fields") [1111719]
- [fs] nfsd: Mark nfs4_free_lockowner and nfs4_free_openowner as static functions ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove <linux/nfsd/debug.h> ("J. Bruce Fields") [1111719]
- [fs] nfsd: move <linux/nfsd/stats.h> to fs/nfsd ("J. Bruce Fields") [1111719]
- [fs] nfsd: move <linux/nfsd/export.h> to fs/nfsd ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove <linux/nfsd/nfsfh.h> ("J. Bruce Fields") [1111719]
- [fs] nfsd: Remove 'inline' designation for free_client() ("J. Bruce Fields") [1111719]
- [fs] nfsd: call rpc_destroy_wait_queue() from free_client() ("J. Bruce Fields") [1111719]
- [fs] nfsd: Move default initialisers from create_client() to alloc_client() ("J. Bruce Fields") [1111719]
- [fs] nfsd: set timeparms.to_maxval in setup_callback_client ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't create unnecessary mask acl ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't return high mode bits" ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix memory leak in nfsd4_encode_fattr() ("J. Bruce Fields") [1111719]
- [fs] nfsd: check passed socket's net matches NFSd superblock's one ("J. Bruce Fields") [1111719]
- [fs] nfsd: Check rpc_xprt out of xs_setup_bc_tcp ("J. Bruce Fields") [1111719]
- [net] sunrpc: New helper for creating client with rpc_xprt ("J. Bruce Fields") [1111719]
- [fs] nfsd: Free backchannel xprt in bc_destroy ("J. Bruce Fields") [1111719]
- [net] sunrpc: fix memory leak of peer addresses in XPRT ("J. Bruce Fields") [1111719]
- [fs] nfsd: Clear wcc data between compound ops ("J. Bruce Fields") [1111719]
- [fs] nfsd: Don't return NFS4ERR_STALE_STATEID for NFSv4.1+ ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix setclientid encode size ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove redundant check from nfsd4_check_resp_size ("J. Bruce Fields") [1111719]
- [fs] nfsd: use more generous NFS4_ACL_MAX ("J. Bruce Fields") [1111719]
- [fs] nfsd: minor nfsd4_replay_cache_entry cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_replay_cache_entry should be static ("J. Bruce Fields") [1111719]
- [fs] nfsd: update comments with obsolete function name ("J. Bruce Fields") [1111719]
- [fs] nfsd: Using free_conn free connection ("J. Bruce Fields") [1111719]
- [fs] nfsd: typo in nfsd_rename comment ("J. Bruce Fields") [1111719]
- [fs] nfsd: simplify saved/current fh uses in nfsd4_proc_compound ("J. Bruce Fields") [1111719]
- [fs] nfsd: Traverse unconfirmed client through hash-table ("J. Bruce Fields") [1111719]
- [net] svcrpc: explicitly reject compounds that are not padded out to 4-byte multiple ("J. Bruce Fields") [1111719]
- [fs] nfsd: notify_change needs elevated write count ("J. Bruce Fields") [1111719 1115034]
- [fs] nfsd: fix test_stateid error reply encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: leave reply buffer space for failed setattr ("J. Bruce Fields") [1111719]
- [fs] nfsd: make set of large acl return efbig, not resource ("J. Bruce Fields") [1111719]
- [fs] nfsd: session needs room for following op to error out ("J. Bruce Fields") [1111719]
- [fs] nfsd: buffer-length check for SUPPATTR_EXCLCREAT ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix lost nfserrno() call in nfsd_setattr() ("J. Bruce Fields") [1111719]
- [net] sunrpc: Mark functions as static in net/sunrpc/svc_xprt.c ("J. Bruce Fields") [1111719]
- [fs] nfsd: decrease nfsd4_encode_fattr stack usage ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix encode_entryplus_baggage stack usage ("J. Bruce Fields") [1111719]
- [fs] nfsd: simplify xdr encoding of nfsv4 names ("J. Bruce Fields") [1111719]
- [fs] nfsd: encode_rdattr_error cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_encode_fattr cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: better VERIFY comment ("J. Bruce Fields") [1111719]
- [fs] nfsd: Fix a memory leak in nfsd4_create_session ("J. Bruce Fields") [1111719]
- [fs] nfsd: get rid of unused function definition ("J. Bruce Fields") [1111719]
- [fs] nfsd:Define op_iattr for nfsd4_open instead using macro ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix compile warning without CONFIG_NFSD_V3 ("J. Bruce Fields") [1111719]
- [fs] nfsd: Don't start lockd when only NFSv4 is running ("J. Bruce Fields") [1111719]
- [net] sunrpc: Support a new option for ignoring the result of svc_register ("J. Bruce Fields") [1103348 1111719]
- [fs] nfsd: fix bad length checking for backchannel ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix a leak which can cause CREATE_SESSION failures ("J. Bruce Fields") [1111719]
- [fs] nfsd:Add missing recording of back channel attrs in nfsd4_session ("J. Bruce Fields") [1111719]
- [fs] nfsd: get rid of unused macro definition ("J. Bruce Fields") [1111719]
- [fs] nfsd: clean up unnecessary temporary variable in nfsd4_decode_fattr ("J. Bruce Fields") [1111719]
- [fs] nfsd: using nfsd4_encode_noop for encoding destroy_session/free_stateid ("J. Bruce Fields") [1111719]
- [fs] nfsd: clean up an xdr reserved space calculation ("J. Bruce Fields") [1111719]
- [fs] nfsd: get rid of unused function definition ("J. Bruce Fields") [1111719]
- [fs] nfsd: calculate the missing length of bitmap in EXCHANGE_ID ("J. Bruce Fields") [1111719]
- [fs] nfsd: revoking of suid/sgid bits after chown() in a consistent way ("J. Bruce Fields") [1111719]
- [net] sunrpc: fix some typos ("J. Bruce Fields") [1111719]
- [fs] nfsd: start documenting some XDR handling functions ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't return high mode bits ("J. Bruce Fields") [1111719]
- [fs] nfsd: export proper maximum file size to the client ("J. Bruce Fields") [1111719]
- [fs] nfsd: improve write performance with better sendspace reservations ("J. Bruce Fields") [1111719]
- [net] svcrpc: remove an unnecessary assignment ("J. Bruce Fields") [1111719]
- [fs] nfsd: Add support for NFS v4.2 operation checking ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd_shutdown_net needs state lock ("J. Bruce Fields") [1111719]
- [fs] nfsd: Combine decode operations for v4 and v4.1 ("J. Bruce Fields") [1111719]
- [fs] nfsd: -EINVAL on invalid anonuid/gid instead of silent failure ("J. Bruce Fields") [1111719]
- [fs] nfsd: return better errors to exportfs ("J. Bruce Fields") [1111719]
- [fs] nfsd: fh_update should error out in unexpected cases ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix Kconfig syntax ("J. Bruce Fields") [1111719]
- [fs] nfsd: switch to p(dD) ("J. Bruce Fields") [1111719]
- [fs] nfsd: racy access to ->d_name in nsfd4_encode_path() ("J. Bruce Fields") [1111719]
- [net] svcrpc: remove unused rq_resused ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_create_clid_dir prints uninitialized data ("J. Bruce Fields") [1111719]
- [fs] nfsd: Fix MACH_CRED NULL dereference ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix xdr decoding of large non-write compounds ("J. Bruce Fields") [1095061 1111719]
- [fs] gfs2: When using flock() a GFS2 filesystem hangs (Robert S Peterson) [1111624]
- [fs] nfs: emit a fsnotify_nameremove call in sillyrename codepath (Jeff Layton) [919347]
- [fs] nfs: remove synchronous rename code (Jeff Layton) [919347]
- [fs] nfs: convert nfs_rename to use async_rename infrastructure (Jeff Layton) [919347]
- [fs] nfs: make nfs_async_rename non-static (Jeff Layton) [919347]
- [fs] nfs: abstract out code needed to complete a sillyrename (Jeff Layton) [919347]
- [fs] gfs2: Fix race in glock lru glock disposal (Robert S Peterson) [1095835]
- [fs] gfs2: Use lockref for glocks (Robert S Peterson) [1095835]
- [fs] cifs: Fix check for regular file in couldbe_mf_symlink() (Sachin Prabhu) [1077230]
- [fs] cifs: Re-order M-F Symlink code (Sachin Prabhu) [1077230]
- [fs] cifs: Add create MFSymlinks to protocol ops struct (Sachin Prabhu) [1077230]
- [fs] cifs: use protocol specific call for query_mf_symlink() (Sachin Prabhu) [1077230]
- [fs] cifs: Rename MF symlink function names (Sachin Prabhu) [1077230]
- [fs] cifs: Rename and cleanup open_query_close_cifs_symlink() (Sachin Prabhu) [1077230]
- [fs] cifs: We do not drop reference to tlink in CIFSCheckMFSymlink() (Sachin Prabhu) [1077230]

* Tue Jul 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-133.el7]
- [s390] af_iucv: recvmsg problem for SOCK_STREAM sockets (Hendrik Brueckner) [1109703]
- [s390] af_iucv: correct cleanup if listen backlog is full (Hendrik Brueckner) [1109033]
- [kernel] auditsc: audit_krule mask accesses need bounds checking (Denys Vlasenko) [1102710] {CVE-2014-3917}
- [fs] nfs: Don't mark the data cache as invalid if it has been flushed (Scott Mayhew) [1114054]
- [fs] nfs: Clear NFS_INO_REVAL_PAGECACHE when we update the file size (Scott Mayhew) [1114054]
- [fs] nfs: Fix cache_validity check in nfs_write_pageuptodate() (Scott Mayhew) [1114054]
- [mm] avoid kABI breakage (Jerome Marchand) [1097419]
- [mm] swap: change swap_list_head to plist, add swap_avail_head (Jerome Marchand) [1097419]
- [lib] plist: add plist_requeue (Jerome Marchand) [1097419]
- [lib] plist: add helper functions (Jerome Marchand) [1097419]
- [mm] swap: change swap_info singly-linked list to list_head (Jerome Marchand) [1097419]
- [block] mtip32xx: mtip_async_complete() bug fixes (Jeff Moyer) [1102281]
- [block] mtip32xx: Unmap the DMA segments before completing the IO request (Jeff Moyer) [1102281]
- [ethernet] tg3: Change nvram command timeout value to 50ms (Ivan Vecera) [1086397]
- [ethernet] tg3: Override clock, link aware and link idle mode during NVRAM dump (Ivan Vecera) [1086397]
- [edac] sb_edac: mark MCE messages as KERN_DEBUG (Aristeu Rozanski) [1056785]
- [edac] sb_edac: use "event" instead of "exception" when MC wasnt signaled (Aristeu Rozanski) [1056785]
- [Documentation] MAINTAINERS: Add DesignWare, i.MX6, Armada, R-Car PCI host maintainers (Myron Stowe) [1110890]
- [pci] Disable Bus Master only on kexec reboot (Myron Stowe) [1110890]
- [pci] Omit PCI ID macro strings to shorten quirk names (Myron Stowe) [1110890]
- [pci] Move device_del() from pci_stop_dev() to pci_destroy_dev() (Myron Stowe) [1110890]
- [pci] Avoid unnecessary CPU switch when calling driver .probe() method (Myron Stowe) [1110890]
- [Documentation] MAINTAINERS: Add Jingoo Han as Samsung Exynos PCIe driver maintainer (Myron Stowe) [1110890]
- [Documentation] MAINTAINERS: Add Tegra PCIe maintainer (Myron Stowe) [1110890]
- [ethernet] ixgbe: set driver_max_VFs should be done before enabling SRIOV (Alex Williamson) [1090154]
- [ethernet] ixgbe: define IXGBE_MAX_VFS_DRV_LIMIT macro and cleanup const 63 (Alex Williamson) [1090154]
- [fs] nfs: advertise only supported callback netids (Jeff Layton) [1048477]
- [fs] nfs: clean up, revert increase in READDIR RPC buffer max size (Jeff Layton) [1048477]
- [net] sunrpc: Fix large reads on NFS/RDMA (Jeff Layton) [1048477]
- [net] sunrpc: remove KERN_INFO from dprintk() call sites (Jeff Layton) [1048477]
- [kernel] ftrace: Hardcode ftrace_module_init() call into load_module() (Takahiro MUNEDA) [1061553]
- [kernel] trace: Make register/unregister_ftrace_command __init (Takahiro MUNEDA) [1061553]
- [tools] turbostat: run on HSX (Prarit Bhargava) [1081657]
- [tools] Revert: turbostat: servers do not support uncore power register (Prarit Bhargava) [1081657]

* Thu Jul 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-132.el7]
- [net] neigh: set nud_state to NUD_INCOMPLETE when probing router reachability (Hannes Frederic Sowa) [1110193]
- [net] bridge: Set vlan_features to allow offloads on vlans (Florian Westphal) [1058544]
- [net] team: fix mtu setting (Jiri Pirko) [1103083]
- [net] ptp: validate the requested frequency adjustment (Jiri Benc) [1092969]
- [net] netfilter: ctnetlink: don't add null bindings if no nat requested (Florian Westphal) [1089929]
- [net] netfilter: ctnetlink: force null nat binding on insert (Florian Westphal) [1089929]
- [net] netfilter: nf_conntrack: don't release a conntrack with non-zero refcnt (Florian Westphal) [1089929]
- [net] netfilter: nf_conntrack: fix RCU race in nf_conntrack_find_get (Florian Westphal) [1089929]
- [net] rtnetlink: Only supply IFLA_VF_PORTS information when RTEXT_FILTER_VF is set (Jiri Pirko) [1092400]
- [net] rtnetlink: Warn when interface's information won't fit in our packet (Jiri Pirko) [1092400]
- [net] fib_frontend: fix possible NULL pointer dereference (Jiri Benc) [1091142]
- [net] team: forbid incorrect fall-through in notifier (Jiri Pirko) [1090495]
- [net] gre: don't allow to add the same tunnel twice (Florian Westphal) [1086498]
- [net] sctp: confirm route during forward progress (Daniel Borkmann) [1089629]
- [net] nf_conntrack: decrement global counter after object release (Jiri Pirko) [1089191]
- [net] add busy_poll device feature (Jiri Pirko) [1080093]
- [net] ipv6: reallocate addrconf router for ipv6 address when lo device up (Jiri Benc) [1077053]
- [net] macvlan: Add support for 'always_on' offload features (Florian Westphal) [928644]
- [net] macvlan: fix netdev feature propagation from lower device (Florian Westphal) [928644]

* Wed Jul 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-131.el7]
- [scsi] pm80xx: Spinlock fix (Rich Bono) [1044636]
- [scsi] aacraid: Update unsupported card list (Rich Bono) [1080712]
- [scsi] vmw_pvscsi: Some improvements in pvscsi driver (Ewan Milne) [1075090]
- [scsi] vmw_pvscsi: Add support for I/O requests coalescing (Ewan Milne) [1075090]
- [scsi] vmw_pvscsi: Fix pvscsi_abort() function (Ewan Milne) [1075090]
- [net] sctp: Fix sk_ack_backlog wrap-around problem (Daniel Borkmann) [1112726] {CVE-2014-4667}
- [net] ipv4/tunnels: fix an oops when using ipip/sit with IPsec (Jiri Pirko) [1108857]
- [net] filter: let bpf_tell_extensions return SKF_AD_MAX (Jiri Benc) [1079524]
- [net] filter: introduce SO_BPF_EXTENSIONS (Jiri Benc) [1079524]

* Tue Jul 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-130.el7]
- [scsi] qla2xxx: Update version number to 8.06.00.08.07.0-k3 (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Reduce the time we wait for a command to complete during SCSI error handling (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Clear loop_id for ports that are marked lost during fabric scanning (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Avoid escalating the SCSI error handler if the command is not found in firmware (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Don't check for firmware hung during the reset context for ISP82XX (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Issue abort command for outstanding commands during cleanup when only firmware is alive (Chad Dupuis) [1090378]
- [scsi] set DID_TIME_OUT correctly (Ewan Milne) [1103881]
- [scsi] fix invalid setting of host byte (Ewan Milne) [1103881]
- [scsi] More USB deadlock fixes (Ewan Milne) [1103881]
- [scsi] Fix USB deadlock caused by SCSI error handling (Ewan Milne) [1103881]
- [scsi] Fix command result state propagation (Ewan Milne) [1103881]
- [scsi] Fix spurious request sense in error handling (Ewan Milne) [1103881]
- [scsi] Add timeout to avoid infinite command retry (Ewan Milne) [1061871]
- [scsi] lpfc: Update version for 10.2.8021.0 driver release (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Fix ExpressLane priority setup (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Removed obsolete PCI IDs from the driver (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Fix for initializing RRQ bitmap (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Fix for cleaning up stale ring flag and sp_queue_event entries (Rob Evers) [1088574]
- [scsi] lpfc: Add iotag memory barrier (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Update Copyright on changed files from 8.3.45 patches (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fixed locking for scsi task management commands (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Convert runtime references to old xlane cfg param to fof cfg param (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix FW dump using sysfs (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix SLI4 s abort loop to process all FCP rings and under ring_lock (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fixed kernel panic in lpfc_abort_handler (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix locking for postbufq when freeing (Rob Evers) [1088574]
- [scsi] lpfc: remove self-assignments (Rob Evers) [1088574]
- [scsi] lpfc: Using plain integer as NULL pointer (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix locking for lpfc_hba_down_post (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix dynamic transitions of FirstBurst from on to off (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fixed crash during driver unload (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fixed driver error messages after firmware download (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fixed missing initialization for task management IOCBs (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fix sysfs buffer overrun in read of lpfc_fcp_cpu_map for 128 CPUs (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Incorporate changes to use reason in change_queue_depth function (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Incorporated support of a low-latency io path (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Added dport mailbox pass through support (Rob Evers) [1088574]
- [scsi] be2iscsi: Bump the driver version (Rob Evers) [1088576]
- [scsi] be2iscsi: fix bad if expression (Rob Evers) [1088576]
- [scsi] be2iscsi: fix memory leak in error path (Rob Evers) [1088576]
- [scsi] be2iscsi: Jump to 'free_memory' is apparently missing (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix destroy MCC-CQ before MCC-EQ is destroyed (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix memory corruption in MBX path (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix TCP parameters while connection offloading (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix interrupt Coalescing mechanism (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix exposing Host in sysfs after adapter initialization is complete (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix retreving MCCQ_WRB in non-embedded Mbox path (Rob Evers) [1088576]

* Tue Jul 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-129.el7]
- [drm] nouveau/bios: fix a bit shift error introduced by recent commit (Ulrich Obergfell) [1089936]
- [ethernet] sfc: PIO:Restrict to 64bit arch and use 64-bit writes (Nikolay Aleksandrov) [1089024]
- [fs] nfs: Apply NFS_MOUNT_CMP_FLAGMASK to nfs_compare_remount_data() (Scott Mayhew) [1103805]
- [fs] gfs2: Prevent recovery before the local journal is set (Robert S Peterson) [1079433]
- [fs] gfs2: Increase the max number of ACLs (Robert S Peterson) [1078231]
- [fs] gfs2: check NULL return value in gfs2_ok_to_move (Abhijith Das) [1097042]
- [fs] gfs2: Refresh quota after setting through quotactl (Abhijith Das) [1088740]
- [kernel] hrtimer: Prevent all reprogramming if hang detected (Prarit Bhargava) [1094732]
- [tty] Set correct tty name in 'active' sysfs attribute (Denys Vlasenko) [1066403]
- [ethernet] bnx2x: Fix kernel crash and data miscompare after EEH recovery (Michal Schmidt) [1101808]
- [ethernet] bnx2x: Adapter not recovery from EEH error injection (Michal Schmidt) [1067154]
- [powerpc] tm: Disable IRQ in tm_recheckpoint (Larry Woodman) [1088224]
- [x86] thinkpad: save and restore adaptive keyboard mode for suspend and, resume (Don Zickus) [1094476]
- [x86] thinkpad: support Thinkpad X1 Carbon 2nd generation's adaptive keyboard (Don Zickus) [1094476]

* Thu Jun 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-128.el7]
- [lib] random32: minor cleanups and kdoc fix (Hannes Frederic Sowa) [1100299]
- [lib] random32: avoid attempt to late reseed if in the middle of seeding (Hannes Frederic Sowa) [1100299]
- [lib] random32: use msecs_to_jiffies for reseed timer (Hannes Frederic Sowa) [1100299]
- [lib] random32: add __init prefix to prandom_start_seed_timer (Hannes Frederic Sowa) [1100299]
- [lib] random32: add test cases for taus113 implementation (Hannes Frederic Sowa) [1100299]
- [lib] random32: upgrade taus88 generator to taus113 from errata paper (Hannes Frederic Sowa) [1100299]
- [lib] random32: move rnd_state to linux/random.h (Hannes Frederic Sowa) [1100299]
- [lib] random32: add prandom_reseed_late() and call when nonblocking pool becomes initialized (Hannes Frederic Sowa) [1100299]
- [lib] random32: add periodic reseeding (Hannes Frederic Sowa) [1100299]
- [lib] random: allow architectures to optionally define random_get_entropy() (Hannes Frederic Sowa) [1100299]
- [net] packet: use percpu mmap tx frame pending refcount (Daniel Borkmann) [1052366]
- [net] packet: use reciprocal_divide in fanout_demux_hash (Daniel Borkmann) [1052366]
- [net] packet: add randomized fanout scheduler (Daniel Borkmann) [1052366]
- [net] packet: don't unconditionally schedule() in case of MSG_DONTWAIT (Daniel Borkmann) [1052366]
- [net] packet: improve socket create/bind latency in some cases (Daniel Borkmann) [1052366]
- [net] vxlan: convert to act as a pernet subsystem (Daniel Borkmann) [1039587]
- [net] vxlan: do not use vxlan_net before checking event type (Daniel Borkmann) [1039587]
- [net] vxlan: properly cleanup devs on module unload (Daniel Borkmann) [1039587]
- [net] vxlan: when lower dev unregisters remove vxlan dev as well (Daniel Borkmann) [1039587]
- [net] netfilter: x_tables: lightweight process control group matching (Daniel Borkmann) [1005839]
- [net] sctp: fix and consolidate SCTP checksumming code (Daniel Borkmann) [1054215]
- [net] checksum: fix warning in skb_checksum (Daniel Borkmann) [1054215]
- [net] skb_checksum: allow custom update/combine for walking skb (Daniel Borkmann) [1054215]
- [lib] crc32: reduce number of cases for crc32{, c}_combine (Daniel Borkmann) [1054215]
- [lib] crc32: conditionally resched when running testcases (Daniel Borkmann) [1054215]
- [lib] crc32: add test cases for crc32{, c}_combine routines (Daniel Borkmann) [1054215]
- [lib] crc32: add functionality to combine two crc32{, c}s in GF(2) (Daniel Borkmann) [1054215]
- [lib] crc32: clean up spacing in test cases (Daniel Borkmann) [1054215]
- [lib] crc32: update the comments of crc32_{be, le}_generic() (Daniel Borkmann) [1054215]
- [net] ipvs: sctp: do not recalc sctp csum when ports didn't change (Daniel Borkmann) [1054215]
- [net] ipvs: sctp: add missing verdict assignments in sctp_conn_schedule (Daniel Borkmann) [1054215]
- [tools] bpf_exp: free duplicated labels at exit time (Daniel Borkmann) [958035]
- [tools] bpf_dbg: always close socket in bpf_runnable (Daniel Borkmann) [958035]
- [net] filter: doc: improve BPF documentation (Daniel Borkmann) [958035]
- [tools] filter: bpf_asm: add minimal bpf asm tool (Daniel Borkmann) [958035]
- [tools] filter: bpf_dbg: add minimal bpf debugger (Daniel Borkmann) [958035]
- [net] sched: cls_bpf: add BPF-based classifier (Daniel Borkmann) [958035]
- [net] Use netlink_ns_capable to verify the permisions of netlink messages (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] netlink: Add variants of capable for use on netlink messages (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] diag: Move the permission check in sock_diag_put_filterinfo to packet_diag_dump (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] netlink: Rename netlink_capable netlink_allowed (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] diag: Fix ns_capable check in sock_diag_put_filterinfo (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] netlink: Fix permission check in netlink_connect() (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] filter: prevent nla extensions to peek beyond the end of the message (Jiri Benc) [1096781] {CVE-2014-3144 CVE-2014-3145}

* Fri Jun 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-127.el7]
- [net] mac80211: fix crash due to AP powersave TX vs. wakeup race (Jacob Tanenbaum) [1083534] {CVE-2014-2706}
- [ethernet] qlcnic: Fix ethtool statistics length calculation (Michal Schmidt) [1099634]
- [kernel] futex: Make lookup_pi_state more robust (Larry Woodman) [1104520] {CVE-2014-3153}
- [kernel] futex: Always cleanup owner tid in unlock_pi (Larry Woodman) [1104520] {CVE-2014-3153}
- [kernel] futex: Validate atomic acquisition in futex_lock_pi_atomic() (Larry Woodman) [1104520] {CVE-2014-3153}
- [kernel] futex: prevent requeue pi on same futex (Larry Woodman) [1104520] {CVE-2014-3153}
- [net] gro: restore frag0 optimization (and fix crash) (Michal Schmidt) [1069741]
- [net] ipv4: current group_info should be put after using (Jiri Benc) [1087416] {CVE-2014-2851}
- [net] core, nfqueue, openvswitch: Orphan frags in skb_zerocopy and handle errors (Jiri Pirko) [1079014] {CVE-2014-2568}
- [fs] aio: fix plug memory disclosure and fix reqs_active accounting backport (Jeff Moyer) [1094605] {CVE-2014-0206}

* Tue Jun 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-126.el7]
- [fs] aio: plug memory disclosure and fix reqs_active accounting (Mateusz Guzik) [1094605] {CVE-2014-0206}
- [kernel] mutexes: Give more informative mutex warning in the !lock->owner case (Larry Woodman) [1087655 1087919 1087922]
- [kernel] mutex: replace CONFIG_HAVE_ARCH_MUTEX_CPU_RELAX with simple ifdef (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Introduce cancelable MCS lock for adaptive spinning (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Modify the way optimistic spinners are queued (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Return false if task need_resched() in mutex_can_spin_on_owner() (Larry Woodman) [1087655 1087919 1087922]
- [kernel] Restructure the MCS lock defines and locking & Move mcs_spinlock.h into kernel/locking/ (Larry Woodman) [1087655 1087919 1087922]
- [misc] arch: Introduce smp_load_acquire(), smp_store_release() (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutex: Fix debug_mutexes (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutex: Fix debug checks (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Unlock the mutex without the wait_lock (Larry Woodman) [1087655 1087919 1087922]

* Tue Jun 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-125.el7]
- [scsi] st: fix corruption of the st_modedef structures in st_set_options() (Maurizio Lombardi) [1084968]
- [net] openvswitch: fix a possible deadlock and lockdep warning (Flavio Leitner) [1094867]
- [fs] dcache: make prepend_name() work correctly when called with negative *buflen (Mikulas Patocka) [1092746]
- [fs] dcache: __dentry_path() fixes (Mikulas Patocka) [1092746]
- [fs] dcache: prepend_path() needs to reinitialize dentry/vfsmount/mnt on restarts (Mikulas Patocka) [1092746]
- [net] ip: generate unique IP identificator if local fragmentation is allowed (Jiri Pirko) [1076106]
- [target] tcm_fc: Fix use-after-free of ft_tpg (Andy Grover) [1071340]
- [wireless] ath9k: tid->sched race in ath_tx_aggr_sleep() (Jacob Tanenbaum) [1083252] {CVE-2014-2672}
- [kernel] futex: Fix pthread_cond_broadcast() to wake up all threads (Larry Woodman) [1084757]
- [watchdog] hpwdt: display informative string (Nigel Croxon) [1074038]
- [mm] page-writeback: fix divide by zero in pos_ratio_polynom (Rik van Riel) [1091784]
- [mm] page-writeback: add strictlimit feature (Rik van Riel) [1091784]
- [powerpc] tm: Fix crash when forking inside a transaction (Radomir Vrbovsky) [1083215] {CVE-2014-2673}
- [block] floppy: don't write kernel-only members to FDRAWCMD ioctl output (Denys Vlasenko) [1094318] {CVE-2014-1737 CVE-2014-1738}
- [block] floppy: ignore kernel-only members in FDRAWCMD ioctl input (Denys Vlasenko) [1094318] {CVE-2014-1737 CVE-2014-1738}
- [s390] kernel: avoid page table walk on user space access (Hendrik Brueckner) [1097687]
- [s390] af_iucv: wrong mapping of sent and confirmed skbs (Hendrik Brueckner) [1098513]
- [s390] crypto: fix aes, des ctr mode concurrency finding (Hendrik Brueckner) [1097686]
- [mm] filemap: update find_get_pages_tag() to deal with shadow entries (Johannes Weiner) [1091795]
- [fs] xfs: log vector rounding leaks log space (Brian Foster) [1091136]
- [fs] xfs: truncate_setsize should be outside transactions (Brian Foster) [1091136]

* Tue May 20 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-124.el7]
- [tty] n_tty: Fix n_tty_write crash when echoing in raw mode (Aristeu Rozanski) [1094242] {CVE-2014-0196}
- [fs] gfs2: Fix uninitialized VFS inode in gfs2_create_inode (Abhijith Das) [1087995]
- [kernel] cputime: Fix jiffies based cputime assumption on steal accounting (Frederic Weisbecker) [1047732]
- [kernel] cputime: Bring cputime -> nsecs conversion (Frederic Weisbecker) [1047732]
- [kernel] cputime: Default implementation of nsecs -> cputime conversion (Frederic Weisbecker) [1047732]
- [x86] irq, pic: Probe for legacy PIC and set legacy_pic appropriately (Vivek Goyal) [1037957]
- [virt] hyperv/vmbus: Negotiate version 3.0 when running on ws2012r2 hosts (Vivek Goyal) [1037957]

* Mon May 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-123.el7]
- [mm] rmap: try_to_unmap_cluster() should lock_page() before mlocking (Larry Woodman) [1078349] {CVE-2014-3122}
- [mm] huge_memory: Fix cpuset cgroups so all pages for a task remain on correct node (Larry Woodman) [1076613]
- [mm] mprotect: fix oops in change_pmd_range called from task_numa_work (Rik van Riel) [1085050]

* Thu May 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-122.el7]
- [security] device_cgroup: check if exception removal is allowed (Aristeu Rozanski) [1086057]
- [security] device_cgroup: rework device access check and rule checking (Aristeu Rozanski) [1086057]
- [fs] autofs: fix lockref lookup (Ian Kent) [1083815]
- [mei] me: do not load the driver if the FW doesn't support MEI interface (Prarit Bhargava) [1082789]

* Tue Apr 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-121.el7]
- [virt] vhost/net: fix total length when packets are too short ("Michael S. Tsirkin") [1064446] {CVE-2014-0077}
- [virt] vhost/net: validate vhost_get_vq_desc return value ("Michael S. Tsirkin") [1070940] {CVE-2014-0055}

* Mon Apr 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-120.el7]
- [net] netfilter: fix panic when oom during rule replacement (Florian Westphal) [985657]
- [net] netfilter: x_tables: fix ordering of jumpstack allocation and table update (Florian Westphal) [985657]
- [virt] kvm/ioapic: try to recover if pending_eoi goes out of range (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: fix assignment of ioapic->rtc_status.pending_eoi (Paolo Bonzini) [1036478 1081590] {CVE-2014-0155}
- [virt] kvm/ioapic: reinject pending interrupts on KVM_SET_IRQCHIP (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: extract body of kvm_ioapic_set_irq (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: clear IRR for edge-triggered interrupts at delivery (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: merge ioapic_deliver into ioapic_service (Paolo Bonzini) [1036478]
- [virt] kvm: ignore ioapic polarity (Paolo Bonzini) [1036478]
- [core] device: Create 'device_driver_rh' KABI shadowing structure (Myron Stowe) [1083692]
- [core] device: Create 'device_rh' KABI shadowing structure (Myron Stowe) [1083692]
- [scsi] Reserve space in structures for future XCOPY support (Ewan Milne) [1080430]
- [fs] xfs: fix bad hash ordering (Brian Foster) [1083206]
- [fs] xfs: always do log forces via the workqueue (Brian Foster) [1052004]

* Thu Apr 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-119.el7]
- [net] bonding: remove bond_resend_igmp_join_requests read_unlock leftover (Veaceslav Falico) [1080924]
- [ethernet] mlx4: Support shutdown() interface (Amir Vadai) [1046216]
- [zram] fix invalid memory access (Jerome Marchand) [1081936]
- [zram] protect zram_reset_device() call (Jerome Marchand) [1081936]
- [zram] remove zram_sysfs file (Jerome Marchand) [1081936]
- [zram] use atomic64_xxx() to replace zram_stat64_xxx() (Jerome Marchand) [1081936]
- [zram] optimize memory operations with clear_page()/copy_page() (Jerome Marchand) [1081936]
- [zram] kill unused zram_get_num_devices() (Jerome Marchand) [1081936]
- [zram] simplify and optimize dev_to_zram() (Jerome Marchand) [1081936]
- [kernel] futex: revert back to the explicit waiter counting code (Larry Woodman) [1081100]
- [kernel] audit: Allow login in non-init namespaces (Richard Guy Briggs) [1082597]

* Tue Apr 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-118.el7]
- [wireless] ath9k: Fix LNA gpio for AR9485 (John Green) [1082017]
- [infiniband] core: Don't resolve passive side RoCE L2 address in cma req handler (Amir Vadai) [1075852]
- [fs] xfs: fix buffer use after free on IO error (Eric Sandeen) [924301]
- [scsi] be2iscsi: Bump the driver version (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix DMA Out of SW-IOMMU space error (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix scsi_cmnd leakage in driver (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix the session cleanup when reboot/shutdown happens (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix doorbell format for EQ/CQ/RQ s per SLI spec (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix port speed typo in driver (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix handling timed out MBX completion from FW (Rob Evers) [1052416]
- [fs] nfs: Fix a use-after-free problem in open() (Steve Dickson) [1062809]

* Mon Mar 31 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-117.el7]
- [md] dm-thin: fix dangling bio in process_deferred_bios error path (Mike Snitzer) [1081781]
- [md] dm: take care to copy the space map roots before locking the superblock (Mike Snitzer) [1081781]
- [md] dm-transaction-manager: fix corruption due to non-atomic transaction commit (Mike Snitzer) [1081781]
- [md] dm-era: fixes for issues identified upstream (Mike Snitzer) [1081781]
- [md] dm-cache: remove remainder of distinct discard block size (Mike Snitzer) [1062679]
- [md] dm-cache: prevent corruption caused by discard_block_size > cache_block_size (Mike Snitzer) [1062679]
- [ipc] change kern_ipc_perm.deleted type to bool (Phillip Lougher) [1043807] {CVE-2013-7026}
- [ipc] introduce ipc_valid_object() helper to sort out IPC_RMID races (Phillip Lougher) [1043807] {CVE-2013-7026}
- [ipc] shm: fix shm_file deletion races (Phillip Lougher) [1043807] {CVE-2013-7026}
- [drm] udl: take reference to device struct for dma-bufs (Dave Airlie) [1077774]
- [security] keys: Allow special keys (eg. DNS results) to be invalidated by CAP_SYS_ADMIN (David Howells) [1074240]

* Fri Mar 28 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-116.el7]
- [s390] qeth: postpone freeing of qdio memory (Hendrik Brueckner) [1077650]
- [kernel] rh_taint: Remove taint and update unsupported hardware message (Prarit Bhargava) [1076974]
- [fs] proc/vmcore: continue vmcore initialization if PT_NOTE is found empty (Chao WANG) [1077535]
- [net] ipv6: ip6_append_data_mtu do not handle the mtu of the second fragment properly (Jiri Pirko) [1079873]

* Tue Mar 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-115.el7]
- [block] free q->flush_rq in blk_init_allocated_queue error paths (Mike Snitzer) [1078522]
- [x86] fpu: Clear exceptions in AMD FXSAVE workaround (Phillip Lougher) [1053596] {CVE-2014-1438}
- [mm] page_alloc: spill to remote nodes before waking kswapd (Johannes Weiner) [1076546]
- [mm] vmscan: do not swap anon pages just because free+file is low (Johannes Weiner) [1076546]
- [fs] sunrpc: Ensure call_connect_status() deals correctly with SOFTCONN tasks (Steve Dickson) [1071532]
- [fs] nfs: Ensure we respect soft mount timeouts during trunking discovery (Steve Dickson) [1071532]
- [fs] nfs: Schedule recovery if nfs40_walk_client_list() is interrupted (Steve Dickson) [1071532]
- [fs] sunrpc: Ensure that call_bind times out correctly (Steve Dickson) [1071532]
- [fs] sunrpc: Ensure that call_connect times out correctly (Steve Dickson) [1071532]

* Fri Mar 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-114.el7]
- [net] netfilter: nf_conntrack_dccp: fix skb_header_pointer API usages (Jiri Pirko) [1077351] {CVE-2014-2523}
- [net] ipv6: don't set DST_NOCOUNT for remotely added routes (Jiri Pirko) [1075060] {CVE-2014-2309}
- [net] skbuff: skb_segment: orphan frags before copying ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/fskb/list_skb/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/skb/head_skb/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/skb_frag/frag/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/frag/nskb_frag/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] use kfree_skb_list() helper ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] veth: fix veth vlan features (Flavio Leitner) [1076077]
- [net] sunrpc/xprtrdma: add separate Kconfig options for NFSoRDMA client and server support (Jeff Layton) [1077957]
- [virt] kvm/x86: emulate MOVAPD (Igor Mammedov) [1052090]
- [virt] kvm/x86: emulate MOVAPS (Igor Mammedov) [1052090]
- [mm] x86: Wrong page freed on preallocate_pmds() failure exit (Larry Woodman) [1073641]
- [mm] x86: do not leak page->ptl for pmd page tables (Larry Woodman) [1073641]
- [virt] kvm/x86: fix emulator buffer overflow (Andrew Jones) [1071836] {CVE-2014-0049}
- [virt] hyperv: Change the receive buffer size for legacy hosts (Jason Wang) [1075279]
- [x86] quirks: Update DH8900CC Unsupported Device ID (Prarit Bhargava) [1076137]

* Tue Mar 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-113.el7]
- [security] selinux: fix broken peer recv check (Paul Moore) [1043165]
- [md] dm-raid: Fix possibility of skipping device recovery (Jonathan E Brassow) [1069927]
- [fs] xfs: avoid AGI/AGF deadlock scenario for inode chunk allocation (Brian Foster) [1052789]
- [md] dm-cache: fix access beyond end of origin device (Mike Snitzer) [1074606]
- [md] dm-cache: fix truncation bug when copying a block to/from >2TB fast device (Mike Snitzer) [1075709]
- [ethernet] bna: don't disable VLAN tag stripping in promisc mode (Ivan Vecera) [1057842]
- [kernel] posix-timers: Spare workqueue if there is no full dynticks CPU to kick (Frederic Weisbecker) [1074168]

* Mon Mar 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-112.el7]
- [net] bridge: multicast: enable snooping on general queries only (Florian Westphal) [1074491]
- [net] bridge: multicast: add sanity check for general query destination (Florian Westphal) [1074491]
- [net] bridge: multicast: add sanity check for query source addresses (Florian Westphal) [1074491]
- [net] inet: frag: fix oops when unloading inetfrag modules (Florian Westphal) [1073962]
- [virt] vhost/net: fix ref cnt checking deadlock ("Michael S. Tsirkin") [1065878]
- [virt] vhost_net: correctly limit the max pending buffers ("Michael S. Tsirkin") [1065878]
- [virt] vhost/net: fix a theoretical race in device cleanup ("Michael S. Tsirkin") [1065878]
- [powerpc] pseries: Expose in kernel device tree update to drmgr (Steve Best) [1064745]
- [powerpc] pseries: Update dynamic cache nodes for suspend/resume operation (Steve Best) [1064745]
- [powerpc] pseries: Device tree should only be updated once after suspend/migrate (Steve Best) [1064745]
- [powerpc] pseries: Child nodes are not detached by dlpar_detach_node (Steve Best) [1064745]
- [powerpc] pseries: Add mising of_node_put in delete_dt_node (Steve Best) [1064745]
- [powerpc] pseries: Make dlpar_configure_connector parent node aware (Steve Best) [1064745]
- [powerpc] pseries: Do all node initialization in dlpar_parse_cc_node (Steve Best) [1064745]
- [powerpc] pseries: Fix parsing of initial node path in update_dt_node (Steve Best) [1064745]
- [powerpc] pseries: Pack update_props_workarea to map correctly to rtas buffer header (Steve Best) [1064745]
- [powerpc] pseries: Fix over writing of rtas return code in update_dt_node (Steve Best) [1064745]
- [powerpc] pseries: Fix creation of loop in device node property list (Steve Best) [1064745]
- [infiniband] mlx4: Don't allocate range of steerable UD QPs for Ethernet-only device (Doug Ledford) [1061795]
- [ethernet] e1000: fix lockdep warning in e1000_reset_task (John Green) [1056355]
- [ethernet] mlx4: mlx4_init_slave() shouldn't access comm channel before PF is ready (Amir Vadai) [1058413]
- [ethernet] mlx4: Fix memory access error in mlx4_QUERY_DEV_CAP_wrapper() (Amir Vadai) [1058413]
- [mm] numa: recheck for transhuge pages under lock during protection changes (Rik van Riel) [1073674]

* Fri Mar 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-111.el7]
- [net] inet: fix for a race condition in the inet frag code (Nikolay Aleksandrov) [1070711] {CVE-2014-0100}
- [scsi] aacraid: Print warning message if unsupported card is being used (Rich Bono) [1019091]
- [drm] ttm: don't oops if no invalidate_caches() (Rob Clark) [1073470 1075068]
- [security] selinux: bigendian problems with filename trans rules (Paul Moore) [1029837]
- [security] selinux: Fix memory leak upon loading policy (Paul Moore) [1051042]
- [x86] apic: Plug racy xAPIC access of CPU hotplug code (Igor Mammedov) [1073568]
- [kernel] sched: Remove redundant update_runtime notifier (Igor Mammedov) [1074476]
- [virt] kvm/svm: fix cr8 intercept window (Radim Krcmar) [1056982]
- [video] fb: reorder the lock sequence to fix potential dead lock (Jason Wang) [1040781]
- [virt] hv/vmbus: Don't timeout during the initial connection with host (Jason Wang) [1037957]
- [virt] hv/vmbus: Specify the target CPU that should receive notification (Jason Wang) [1037957]
- [mm] percpu scalability fixes (Alexander Viro) [1072446]
- [x86] fix compile error due to X86_TRAP_NMI use in asm files (Don Zickus) [1051428]
- [x86] Ignore NMIs that come in during early boot (Don Zickus) [1051428]
- [fs] cifs: Add support for follow_link on dfs shares under posix extensions (Sachin Prabhu) [1020715]
- [fs] cifs: move unix extension call to cifs_query_symlink() (Sachin Prabhu) [1020715]
- [kernel] audit: include subject in login records (Richard Guy Briggs) [1075155]
- [kernel] audit: remove superfluous new- prefix in AUDIT_LOGIN messages (Richard Guy Briggs) [1075155]
- [ethernet] tg3: Don't check undefined error bits in RXBD (Ivan Vecera) [1071483]
- [fs] gfs2: Move recovery variables to journal structure in memory (Robert S Peterson) [1059439]
- [security] keys: Make the keyring cycle detector ignore other keyrings of the same name (David Howells) [1071346] {CVE-2014-0102}
- [x86] fix x86 fixup_irqs() error handling (Prarit Bhargava) [1074644]
- [fs] gfs2: Re-add a call to log_flush_wait when flushing the journal (Robert S Peterson) [1074556]
- [fs] gfs2: Ensure workqueue is scheduled after noexp request (Robert S Peterson) [1074556]

* Wed Mar 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-110.el7]
- [mm] Revert: percpu scalability fixes (Jarod Wilson) [1072446]

* Tue Mar 11 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-109.el7]
- [block] change flush sequence list addition back to front add (Mike Snitzer) [1072577]
- [block] fix q->flush_rq NULL pointer crash on dm-mpath flush (Mike Snitzer) [1072577]
- [md] dm-era: mark as tech preview for RHEL7.0 (Mike Snitzer) [995644]
- [md] dm-bitset: only flush the current word if it has been dirtied (Mike Snitzer) [995644]
- [md] dm-era: support non power-of-2 blocksize (Mike Snitzer) [995644]
- [md] dm: add era target (Mike Snitzer) [995644]
- [md] dm-cache-mq: fix memory allocation failure for large cache devices (Mike Snitzer) [995644]
- [md] dm-cache: fix truncation bug when mapping I/O to >2TB fast device (Mike Snitzer) [995644]
- [md] dm-space-map-metadata: fix refcount decrement below 0 which caused corruption (Mike Snitzer) [1065051]
- [Documentation] dm-thin: fix Documentation for held metadata root feature (Mike Snitzer) [1065051]
- [md] dm-thin: fix noflush suspend IO queueing (Mike Snitzer) [1065051]
- [md] dm-thin: fix deadlock in __requeue_bio_list (Mike Snitzer) [1065051]
- [md] dm-thin: fix out of data space handling (Mike Snitzer) [1065051]
- [md] dm-thin: ensure user takes action to validate data and metadata consistency (Mike Snitzer) [1065051]
- [md] dm-thin: synchronize the pool mode during suspend (Mike Snitzer) [1065051]
- [md] dm: fix Kconfig indentation (Mike Snitzer) [1065051]
- [md] dm-thin: allow metadata space larger than supported to go unused (Mike Snitzer) [1065051]
- [md] dm-thin: fix the error path for the thin device constructor (Mike Snitzer) [1065051]
- [md] dm-thin: avoid metadata commit if a pool's thin devices haven't changed (Mike Snitzer) [1065051]
- [virt] hyperv: Add support for physically discontinuous receive buffer (Jason Wang) [988689]
- [virt] virtio-scsi: Fix hotcpu_notifier use-after-free with virtscsi_freeze (Jason Wang) [1024220]
- [fs] pnode: smarter propagate_mnt() (Alexander Viro) [1072457]
- [kernel] perf: Allow mmap2 interface (Jiri Olsa) [1071945]
- [crypto] ansi_cprng: Fix off by one error in non-block size request (Radomir Vrbovsky) [1009139]
- [fs] xfs: don't leak EFSBADCRC to userspace (Brian Foster) [1071925]
- [fs] xfs: modify verifiers to differentiate CRC from other errors (Brian Foster) [1071925]
- [fs] xfs: print useful caller information in xfs_error_report (Brian Foster) [1071925]
- [fs] xfs: add xfs_verifier_error() (Brian Foster) [1071925]
- [fs] xfs: add helper for updating checksums on xfs_bufs (Brian Foster) [1071925]
- [fs] xfs: add helper for verifying checksums on xfs_bufs (Brian Foster) [1071925]
- [fs] xfs: Use defines for CRC offsets in all cases (Brian Foster) [1071925]
- [fs] xfs: skip pointless CRC updates after verifier failures (Brian Foster) [1071925]
- [fs] xfs: limit superblock corruption errors to actual corruption (Brian Foster) [1071925]
- [fs] xfs: skip verification on initial "guess" superblock read (Brian Foster) [1071925]
- [fs] xfs: xfs_sb_read_verify() doesn't flag bad crcs on primary sb (Brian Foster) [1071925]
- [md] dm-snapshot: fix data corruption (Mikulas Patocka) [1070291]
- [ethernet] e1000e: Fix SHRA register access for 82579 (John Green) [1040315]
- [ethernet] be2net: do external loopback test only when it is requested (Ivan Vecera) [1065833]
- [drm] i915: fix potential oops in early irqs (Rob Clark) [1073136]
- [security] selinux: correctly label /proc inodes in use before the policy is loaded (Paul Moore) [1071858]
- [fs] vfs: unexport the getname() symbol (Jeff Layton) [1060739]
- [mm] percpu scalability fixes (Alexander Viro) [1072446]
- [kernel] uprobes: Fix the memory out of bound overwrite in copy_insn() (Oleg Nesterov) [984056]
- [kernel] uprobes: Fix the wrong usage of current->utask in uprobe_copy_process() (Oleg Nesterov) [984056]
- [kernel] uprobes: Teach uprobe_copy_process() to handle CLONE_VFORK (Oleg Nesterov) [984056]
- [kernel] uprobes: Change uprobe_copy_process() to dup xol_area (Oleg Nesterov) [984056]
- [kernel] uprobes: Change uprobe_copy_process() to dup return_instances (Oleg Nesterov) [984056]
- [kernel] uprobes: Teach __create_xol_area() to accept the predefined vaddr (Oleg Nesterov) [984056]
- [kernel] uprobes: Introduce __create_xol_area() (Oleg Nesterov) [984056]
- [kernel] uprobes: Change the callsite of uprobe_copy_process() (Oleg Nesterov) [984056]

* Mon Mar 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-108.el7]
- [scsi] megaraid_sas: fix a small problem when reading state value from hw (Tomas Henzl) [1070563]
- [scsi] megaraid_sas: driver bug fix (Tomas Henzl) [1064509]
- [scsi] qla2xxx: Update driver version to 8.06.00.08.07.0-k2 (Chad Dupuis) [1066003]
- [scsi] qla2xxx: Fixup looking for a space in the outstanding_cmds array in qla2x00_alloc_iocbs() (Chad Dupuis) [1066003]
- [scsi] qla2xxx: Set host can_queue value based on available resources (Chad Dupuis) [1066003]
- [scsi] qla2xxx: Fix request queue null dereference (Chad Dupuis) [1058624]
- [mm] add overcommit_kbytes sysctl variable (Jerome Marchand) [1058788]
- [mm] factor commit limit calculation (Jerome Marchand) [1058788]
- [drm] radeon/uvd: add kernel parameter to make uvd optional on evergreen (Jerome Glisse) [1056702]
- [drm] radeon: free uvd ring on unload (Jerome Glisse) [1056702]
- [s390] pci: obtain function handle in hotplug notifier (Hendrik Brueckner) [1059247]
- [s390] pci/dma: fix accounting of allocated_pages (Hendrik Brueckner) [1059247]
- [s390] pci: set error state for unavailable functions (Hendrik Brueckner) [1059247]
- [s390] pci: fix removal of nonexistent pci bus (Hendrik Brueckner) [1059247]
- [s390] pci: prevent inadvertently triggered bus scans (Hendrik Brueckner) [1059247]
- [pci] msi: Make pci_enable_msi/msix() 'nvec' argument type as int (Myron Stowe) [1070909]
- [pci] msi: Export MSI mode using attributes, not kobjects (Myron Stowe) [1070909]
- [drm] nouveau: attempt to disarm all interrupts before request_irq() (Ben Skeggs) [986654]
- [drm] nouveau: disable runtime pm by default (Ben Skeggs) [1072481]
- [s390] appldata_os: fix cpu array size calculation (Hendrik Brueckner) [1071354]
- [s390] cio: Fix missing subchannels after CHPID configure on (Hendrik Brueckner) [1071248]
- [s390] pci/dma: use correct segment boundary size (Hendrik Brueckner) [1071239]
- [scsi] isci: fix reset timeout handling (David Milburn) [1040402]
- [wireless] ath9k: Add custom parameters for CUS198 (John Green) [1044005]
- [ethernet] bnx2x: utilize FW 7.8.19 (Michal Schmidt) [1058008]
- [fs] fix the performance of reading /proc/mounts and friends (Alexander Viro) [1072461]
- [fs] namespace: mount hash table is too small (Alexander Viro) [1072451]
- [fs] xfs: inode log reservations are still too small (Brian Foster) [1071068]
- [fs] aio, memory-hotplug: Fix confliction when migrating and accessing ring pages (Motohiro Kosaki) [1060974]
- [x86] only add -Werror when using RHEL7 gcc (Stefan Assmann) [1073055]
- [mm] filemap: fix truncation crash due to exceptional entries (Johannes Weiner) [1069295 1071162]
- [mm] Add kernel and mm data structure padding before kABI freeze (Larry Woodman) [1071438]
- [pci] add pci_hw_vendor_status() (Prarit Bhargava) [1073062]
- [cpufreq] pcc: Enable autoload of pcc-cpufreq for all ACPI processors (Lenny Szubowicz) [928152]
- [idle] intel_idle: Repair large-server 50-watt idle-power regression (Lenny Szubowicz) [1054325]
- [fs] clean up page array when uncached write send fails (Sachin Prabhu) [1063780]
- [fs] cifs: use a flexarray in cifs_writedata (Sachin Prabhu) [1063780]
- [mm] oom_kill: add rcu_read_lock() into find_lock_task_mm() (Oleg Nesterov) [1000335]
- [mm] oom_kill: has_intersects_mems_allowed() needs rcu_read_lock() (Oleg Nesterov) [1000335]
- [mm] oom_kill: change oom_kill.c to use for_each_thread() (Oleg Nesterov) [1000335]
- [kernel] fork: introduce for_each_thread() to replace the buggy while_each_thread() (Oleg Nesterov) [1000335]
- [kernel] fork: copy_process(), consolidate the lockless CLONE_THREAD checks (Oleg Nesterov) [1000335]
- [kernel] fork: copy_process(), don't add the uninitialized child to thread/task/pid lists (Oleg Nesterov) [1000335]
- [kernel] fork: copy_process(), unify CLONE_THREAD-or-thread_group_leader code (Oleg Nesterov) [1000335]
- [fs] exec: de_thread(), use change_pid() rather than detach_pid/attach_pid (Oleg Nesterov) [1000335]
- [powerpc] xmon: Don't signal we've entered until we're finished printing (Steve Best) [1072790]
- [powerpc] xmon: Fix timeout loop in get_output_lock() (Steve Best) [1072790]
- [powerpc] xmon: Don't loop forever in get_output_lock() (Steve Best) [1072790]

* Fri Mar 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-107.el7]
- [net] make neigh_priv_len in struct net_device 16bit instead of 8bit (Jiri Benc) [1062308]
- [net] sctp: fix sctp_sf_do_5_1D_ce to verify if we/peer is AUTH capable (Daniel Borkmann) [1070716] {CVE-2014-0101}
- [net] sctp: fix sctp_connectx abi for ia32 emulation/compat mode (Daniel Borkmann) [1058284]
- [net] ip_tunnel: return more precise errno value when adding tunnel fails (Florian Westphal) [1070135]
- [net] ip_tunnel: Add fallback tunnels to the hash lists (Florian Westphal) [1070135]
- [net] openvswitch: Fix ovs_dp_cmd_msg_size() (Francesco Fusco) [1069577]
- [net] team: Don't allow team devices to change network namespaces (Jiri Pirko) [1069527]
- [net] team: add support for sending multicast rejoins (Jiri Pirko) [1069520]
- [net] convert resend IGMP to notifier event (Jiri Pirko) [1069520]
- [net] team: add peer notification (Jiri Pirko) [1069490]
- [net] team: remove synchronize_rcu() called during port disable (Jiri Pirko) [1069498]
- [net] team: use kfree_rcu instead of synchronize_rcu in team_port_dev (Jiri Pirko) [1069498]
- [net] team: remove synchronize_rcu() called during queue override change (Jiri Pirko) [1069498]
- [net] remove last caller of skb_tail_offset() and itself (Jiri Pirko) [1068666]
- [net] netpoll: fix position of network header (Jiri Pirko) [1068666]
- [net] neigh: fix setting of default gc_* values (Jiri Pirko) [1067274]

* Thu Mar 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-106.el7]
- [drm] nouveau/devinit: lock/unlock crtc regs for all devices, not just pre-nv50 (Ben Skeggs) [928744]
- [drm] nouveau: use correct register to determine DP display bpp (Ben Skeggs) [928744]
- [pci] Enable quirks for PCIe ACS on Intel PCH root ports (Alex Williamson) [1037684]
- [pci] Add pci_dev_flag for ACS enable quirks (Alex Williamson) [1037684]
- [pci] Add device-specific PCI ACS enable (Alex Williamson) [1037684]
- [virt] hyperv-fb: kick off efifb early (Gerd Hoffmann) [1038900]
- [virt] hyperv-fb: add support for generation 2 virtual machines (Gerd Hoffmann) [1038900]
- [virt] hv/vmbus: use resource for hyperv mmio region (Gerd Hoffmann) [1038900]
- [virt] hv/vmbus: add missing breaks (Gerd Hoffmann) [1038900]
- [virt] hv/vmbus: Extract the mmio information from DSDT (Gerd Hoffmann) [1038900]
- [s390] cio/blacklist: Perform subchannel scan only when needed (Hendrik Brueckner) [1071244]
- [s390] css: Prevent unnecessary allocation in subchannel loop (Hendrik Brueckner) [1071244]
- [s390] cio: Delay scan for newly available I/O devices (Hendrik Brueckner) [1071244]
- [s390] cio: Relax subchannel scan loop (Hendrik Brueckner) [1071244]
- [s390] cio: More efficient handling of CHPID availability events (Hendrik Brueckner) [1071244]
- [ethernet] cxgb4: Add API to correctly calculate tuple fields (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Account for stid entries properly in case of IPv6 (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Assign filter server TIDs properly (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Include TCP as protocol when creating server filters (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Reserve stid 0 for T4/T5 adapters (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Add new scheme to update T4/T5 firmware (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Much cleaner implementation of is_t4()/is_t5() (Jay Fenlason) [1060264]
- [ethernet] cgxb4: remove duplicate include in cxgb4.h (Jay Fenlason) [1060264]
- [ethernet] cxgb4: remove unnecessary pci_set_drvdata() (Jay Fenlason) [1060264]
- [ethernet] cxgb4: remove workqueue when driver registration fails (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Add CLIP support to store compressed IPv6 address (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Add routines to create and remove listening IPv6 servers (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Do not set net_device::dev_id to VI index (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Force uninitialized state if FW_ON_ADAPTER is < FW_VERSION and we're the MASTER_PF (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Use cxgb4_select_ntuple to correctly calculate ntuple fields (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Server filters are supported only for IPv4 (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Calculate the filter server TID properly (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Make _c4iw_write_mem_dma() static (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix formatting of physical address (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Issue RI.FINI before closing when entering TERM (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Advertise ~0ULL as max MR size (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Always do GTS write if cidx_inc == CIDXINC_MASK (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Set arp error handler for PASS_ACCEPT_RPL messages (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix accounting for unsignaled SQ WRs to deal with wrap (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix QP flush logic (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Handle newer firmware changes (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Use correct bit shift macros for vlan filter tuples (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Add support for active and passive open connection with IPv6 address (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix stack info leak in c4iw_create_qp() (Jay Fenlason) [1060264]
- [scsi] cxgb4i: add support for T5 adapter (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: added much cleaner implementation of is_t4() (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: use DEFINE_PCI_DEVICE_TABLE (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: remove unnecessary pci_set_drvdata() (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: Staticize local symbols (Jay Fenlason) [1060264]
- [infiniband] mlx5: Remove dependency on X86 (Doug Ledford) [1058614]
- [infiniband] mlx5: Add include of <linux/slab.h> because of kzalloc()/kfree() use (Doug Ledford) [1058614]
- [infiniband] mlx5: Don't set "block multicast loopback" capability (Doug Ledford) [1058614]
- [infiniband] mlx5: Fix binary compatibility with libmlx5 (Doug Ledford) [1058614]
- [infiniband] mlx5: Fix RC transport send queue overhead computation (Doug Ledford) [1058614]
- [infiniband] mlx5: Verify reserved fields are cleared (Doug Ledford) [1058614]
- [infiniband] mlx5: Remove old field for create mkey mailbox (Doug Ledford) [1058614]
- [infiniband] mlx5: Abort driver cleanup if teardown hca fails (Doug Ledford) [1058614]
- [infiniband] mlx5: Allow creation of QPs with zero-length work queues (Doug Ledford) [1058614]
- [ethernet] mlx5: Fix PowerPC support (Doug Ledford) [1058614]
- [ethernet] mlx5: Improve debugfs readability (Doug Ledford) [1058614]
- [infiniband] mlx5: Add support for resize CQ (Doug Ledford) [1058614]
- [infiniband] mlx5: Implement modify CQ (Doug Ledford) [1058614]
- [infiniband] mlx5: Make sure doorbell record is visible before doorbell (Doug Ledford) [1058614]
- [ethernet] mlx5: Use mlx5 core style warning (Doug Ledford) [1058614]
- [ethernet] mlx5: Clear out struct before create QP command (Doug Ledford) [1058614]
- [ethernet] mlx5: Fix out arg size in access_register command (Doug Ledford) [1058614]
- [infiniband] mlx5: Fix micro UAR allocator (Doug Ledford) [1058614]
- [ethernet] mlx5: Remove dead code (Doug Ledford) [1058614]
- [infiniband] mlx5: Remove unused code in mr.c (Doug Ledford) [1058614]
- [virt] kvm/x86: introduce periodic global clock updates (Andrew Jones) [1036457]
- [virt] kvm/x86: rate-limit global clock updates (Andrew Jones) [1036457]
- [mm] slub: fix page->_count corruption (again) (Rik van Riel) [1070918]
- [kernel] stop_machine: Fix^2 race between stop_two_cpus() and stop_cpus() (Rik van Riel) [1061778 1071454]
- [fs] proc/vmcore: prevent PT_NOTE p_memsz overflow during header update (Nigel Croxon) [1061368]
- [ioat] dma: check DMA mapping error in ioat_dma_self_test() (Kyle McMartin) [922694]
- [drm] nouveau/bios: add more checks to PRAMIN image fetching (Ben Skeggs) [1033345]
- [fs] block: Fix nr_vecs for inline integrity vectors (David Milburn) [1040893]

* Wed Mar 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-105.el7]
- [redhat] kabi: actually add symbols to the whitelists this time (Jarod Wilson) [726863]

* Tue Mar 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-104.el7]
- [redhat] kabi: add initial whitelist checksums (Jiri Olsa) [726863]

* Tue Mar 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-103.el7]
- [fs] epoll: do not take the nested ep->mtx on EPOLL_CTL_DEL (Rik van Riel) [1069371]
- [fs] epoll: do not take global 'epmutex' for simple topologies (Rik van Riel) [1069371]
- [fs] epoll: optimize EPOLL_CTL_DEL using rcu (Rik van Riel) [1069371]
- [fs] epoll: add a reschedule point in ep_free() (Rik van Riel) [1069371]
- [fs] eventpoll: switch epoll_ctl() to fdget (Rik van Riel) [1069371]
- [fs] eventpoll: do not use sigprocmask() (Rik van Riel) [1069371]
- [target] iscsi-target: Add demo-mode TPG authentication context support (Andy Grover) [1066726]
- [target] Add se_portal_group->tpg_auth_group (Andy Grover) [1066726]
- [mm] page-writeback: do not count anon pages as dirtyable memory (Johannes Weiner) [832482]
- [mm] page-writeback: fix dirty_balance_reserve subtraction from dirtyable memory (Johannes Weiner) [832482]
- [misc] stackprotector: Introduce CONFIG_CC_STACKPROTECTOR_STRONG (Jarod Wilson) [1069367]
- [misc] stackprotector: Unify the HAVE_CC_STACKPROTECTOR logic between architectures (Jarod Wilson) [1069367]
- [kernel] futexes: Fix futex_hashsize initialization (Larry Woodman) [1069800]
- [kernel] futexes: Avoid taking the hb->lock if there's nothing to wake up (Larry Woodman) [1069800]
- [kernel] futexes: Document multiprocessor ordering guarantees (Larry Woodman) [1069800]
- [kernel] futexes: Increase hash table size for better performance (Larry Woodman) [1069800]
- [kernel] futexes: Clean up various details (Larry Woodman) [1069800]
- [kernel] futex: move user address verification up to common code (Larry Woodman) [1069800]
- [kernel] futex: fix handling of read-only-mapped hugepages (Larry Woodman) [1069800]
- [powerpc] Support crashkernel auto memory reservation on a system with 2GB or more (Steve Best) [1051974]
- [powerpc] Set crashkernel 'auto' memory reservation threshold to 2GB (Steve Best) [1051974]
- [s390] cio: improve cio_commit_config (Hendrik Brueckner) [1064781]
- [s390] zfcpdump: Fix mount order for XFS and ext4 (Hendrik Brueckner) [1058307]
- [scsi] iSCSI connection errors on logout (Chris Leech) [1000356]
- [block] add padding to queue_limits structure (Mike Snitzer) [973669]
- [virt] kvm/nvmx: Fix pick-up of uninjected NMIs (Marcelo Tosatti) [1069089]
- [virt] kvm/svm: fix NMI window after iret (Radim Krcmar) [1049862]
- [mm] exclude memoryless nodes from zone_reclaim (Steve Best) [1070491]
- [x86] mm/srat: Skip NUMA_NO_NODE while parsing SLIT (Prarit Bhargava) [1063539]

* Tue Mar 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-102.el7]
- [ethernet] cxgb3: remove duplicate defines (Jay Fenlason) [1060263]
- [ethernet] cxgb3: remove unnecessary pci_set_drvdata() (Jay Fenlason) [1060263]
- [ethernet] cxgb3: Add __GFP_NOWARN to k.alloc calls with v.alloc fallbacks (Jay Fenlason) [1060263]
- [ethernet] cxgb3: Missing rtnl lock in error recovery (Jay Fenlason) [1060263]
- [infiniband] cxgb3: Fix stack info leak in iwch_create_cq() (Jay Fenlason) [1060263]
- [infiniband] cxgb3: Timeout condition is never true (Jay Fenlason) [1060263]
- [ethernet] qlcnic: Update version to 5.3.48.2 (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix tx timeout (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix diagnostic test for all adapters (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix VF reset recovery (Chad Dupuis) [1063848]
- [ethernet] qlcnic: underflow in qlcnic_validate_max_tx_rings() (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix backporting BUG while doing inbox submission upto 5.3.48 (Chad Dupuis) [1063848]
- [pci] pciehp: Add hotplug_lock to serialize hotplug events (Myron Stowe) [1061514]
- [pci] pciehp: Ensure very fast hotplug events are also processed (Myron Stowe) [1061514]
- [pci] pciehp: Disable link notification across slot reset (Myron Stowe) [1061514]
- [pci] pciehp: Don't check adapter or latch status while disabling (Myron Stowe) [1061514]
- [pci] pciehp: Don't disable the link permanently during removal (Myron Stowe) [1061514]
- [pci] pciehp: Enable link state change notifications (Myron Stowe) [1061514]
- [pci] pciehp: Use link change notifications for hot-plug and removal (Myron Stowe) [1061514]
- [pci] pciehp: Make check_link_active() non-static (Myron Stowe) [1061514]
- [pci] pciehp: Move Attention & Power Indicator support tests to accessors (Myron Stowe) [1061514]
- [pci] pciehp: Use symbolic constants for Slot Control fields (Myron Stowe) [1061514]
- [pci] pciehp: Use symbolic constants, not hard-coded bitmask (Myron Stowe) [1061514]
- [pci] pciehp: Simplify "Power Fault Detected" checking/clearing (Myron Stowe) [1061514]
- [pci] pciehp: Announce slot capabilities (slot #, button, LEDs, etc) (Myron Stowe) [1061514]
- [pci] pciehp: Make various functions void since they can't fail (Myron Stowe) [1061514]
- [pci] pciehp: Remove error checks when accessing PCIe Capability (Myron Stowe) [1061514]
- [pci] pciehp: Drop pciehp_readw()/pciehp_writew() wrappers (Myron Stowe) [1061514]
- [drm] mgag200: on cards with < 2MB VRAM default to 16-bit (Dave Airlie) [1056356]
- [drm] cirrus: correct register values for 16bpp (Dave Airlie) [1056352]
- [infiniband] mlx4: Build the port IBoE GID table properly under bonding (Doug Ledford) [1061729]
- [infiniband] mlx4: Do IBoE GID table resets in port based manner (Doug Ledford) [1061729]
- [infiniband] mlx4: Do IBoE locking earlier when initializing the GID table (Doug Ledford) [1061729]
- [infiniband] mlx4: Move rtnl locking to the right location (Doug Ledford) [1061729]
- [infiniband] mlx4: Make sure GID index 0 is always occupied (Doug Ledford) [1061729]
- [infiniband] mlx4: Report using RoCE IP based gids in port caps (Doug Ledford) [1061729]
- [mm] thp: fix infinite loop on memcg OOM (Motohiro Kosaki) [1054655]
- [mm] thp: count thp_fault_fallback anytime thp fault fails (Motohiro Kosaki) [1054655]
- [mm] thp: consolidate code between handle_mm_fault() and, do_huge_pmd_anonymous_page() (Motohiro Kosaki) [1054655]
- [mm] thp: do_huge_pmd_anonymous_page() cleanup (Motohiro Kosaki) [1054655]
- [fs] nfs: fix error return in nfs4_select_rw_stateid (Steve Dickson) [1071041]
- [fs] nfs: Use the correct net namespace in nfs4_update_server (Steve Dickson) [1071041]
- [net] sunrpc: Fix a pipe_version reference leak (Steve Dickson) [1071041]
- [net] sunrpc: Fix races in xs_nospace() (Steve Dickson) [1071041]
- [fs] nfs: Do not set NFS_INO_INVALID_LABEL unless server supports labeled NFS (Steve Dickson) [1071041]
- [target] iscsi: Fix network portal creation race (Andy Grover) [1055064]
- [ethernet] bnx2x: Add missing bit in default Tx switching (Michal Schmidt) [1070726]
- [pci] dev_num_vf needs to return an int, not a bool (Alex Williamson) [1066825]
- [kernel] cgroup: update cgroup_enable_task_cg_lists() to grab siglock (Rik van Riel) [1070919]
- [powerpc] mm: Fix mmap errno when MAP_FIXED is set and mapping exceeds the allowed address space (Jerome Marchand) [1053681]

* Mon Mar 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-101.el7]
- [fs] btrfs: fix the race between write back and nocow buffered write (Zach Brown) [1051406]
- [fs] btrfs: fix the wrong nocow range check (Zach Brown) [1051406]
- [fs] btrfs: fix the reserved space leak caused by the race between nonlock dio and buffered io (Zach Brown) [1051406]
- [fs] btrfs: cleanup unnecessary parameter and variant of prepare_pages() (Zach Brown) [1051406]
- [fs] btrfs: fix access_ok() check in btrfs_ioctl_send() (Zach Brown) [1051282]
- [fs] btrfs: make sure we cleanup all reloc roots if error happens (Zach Brown) [1051282]
- [fs] btrfs: skip building backref tree for uuid and quota tree when doing balance relocation (Zach Brown) [1051282]
- [fs] btrfs: fix an oops when doing balance relocation (Zach Brown) [1051282]
- [fs] btrfs: don't miss skinny extent items on delayed ref head contention (Zach Brown) [1051282]
- [fs] btrfs: call mnt_drop_write after interrupted subvol deletion (Zach Brown) [1051282]
- [fs] btrfs: don't clear the default compression type (Zach Brown) [1051282]
- [fs] btrfs: backport of btrfs part of "block: submit_bio_wait() conversions" (Zach Brown) [1051282]
- [Documentation] filesystems: update btrfs tools section (Zach Brown) [1051282]
- [Documentation] filesystems: add new btrfs mount options (Zach Brown) [1051282]
- [fs] btrfs: update kconfig help text (Zach Brown) [1051282]
- [fs] btrfs: fix bio_size_ok() for max_sectors > 0xffff (Zach Brown) [1051282]
- [fs] btrfs: Use trace condition for get_extent tracepoint (Zach Brown) [1051282]
- [fs] btrfs: fix typo in the log message (Zach Brown) [1051282]
- [fs] btrfs: fix list delete warning when removing ordered root from the list (Zach Brown) [1051282]
- [fs] btrfs: print bytenr instead of page pointer in check-int (Zach Brown) [1051282]
- [fs] btrfs: remove dead codes from ctree.h (Zach Brown) [1051282]
- [fs] btrfs: don't wait for ordered data outside desired range (Zach Brown) [1051282]
- [fs] btrfs: fix lockdep error in async commit (Zach Brown) [1051282]
- [fs] btrfs: avoid heavy operations in btrfs_commit_super (Zach Brown) [1051282]
- [fs] btrfs: fix __btrfs_start_workers retval (Zach Brown) [1051282]
- [fs] btrfs: disable online raid-repair on ro mounts (Zach Brown) [1051282]
- [fs] btrfs: do not inc uncorrectable_errors counter on ro scrubs (Zach Brown) [1051282]
- [fs] btrfs: only drop modified extents if we logged the whole inode (Zach Brown) [1051282]
- [fs] btrfs: make sure to copy everything if we rename (Zach Brown) [1051282]
- [fs] btrfs: don't BUG_ON() if we get an error walking backrefs (Zach Brown) [1051282]
- [fs] btrfs: get rid of fdentry() (Zach Brown) [1051282]
- [fs] btrfs: fix empty_zero_page misusage (Zach Brown) [1051282]
- [fs] btrfs: rename btrfs_start_all_delalloc_inodes (Zach Brown) [1051282]
- [fs] btrfs: don't wait for the completion of all the ordered extents (Zach Brown) [1051282]
- [fs] btrfs: don't wait for all the async delalloc when shrinking delalloc (Zach Brown) [1051282]
- [fs] btrfs: fix the confusion between delalloc bytes and metadata bytes (Zach Brown) [1051282]
- [fs] btrfs: pick up the code for the item number calculation in flush_space() (Zach Brown) [1051282]
- [fs] btrfs: wait for the ordered extent only when we want (Zach Brown) [1051282]
- [fs] btrfs: remove unnecessary initialization and memory barrier in shrink_delalloc() (Zach Brown) [1051282]
- [fs] btrfs: avoid unnecessary scrub workers allocation (Zach Brown) [1051282]
- [fs] btrfs: check file extent type before anything else (Zach Brown) [1051282]
- [fs] btrfs: Remove useless variable in write_ctree_super() (Zach Brown) [1051282]
- [fs] btrfs: Fix checkpatch.pl warning of spacing issues (Zach Brown) [1051282]
- [fs] btrfs: Replace kmalloc with kmalloc_array (Zach Brown) [1051282]
- [fs] btrfs: Enclose macros with complex values within parenthesis (Zach Brown) [1051282]
- [fs] btrfs: Use WARN_ON()'s return value in place of WARN_ON(1) (Zach Brown) [1051282]
- [fs] btrfs: Remove redundant local zero structure (Zach Brown) [1051282]
- [fs] btrfs: Pack struct btrfs_device (Zach Brown) [1051282]
- [fs] btrfs: Replace multiple atomic_inc() with atomic_add() (Zach Brown) [1051282]
- [fs] btrfs: Add helper function for free_root_pointers() (Zach Brown) [1051282]
- [fs] btrfs: fix a crash when running balance and defrag concurrently (Zach Brown) [1051282]
- [fs] btrfs: do not run snapshot-aware defragment on error (Zach Brown) [1051282]
- [fs] btrfs: log recovery, don't unlink inode always on error (Zach Brown) [1051282]
- [fs] btrfs: fix csum search offset/length calculation in log tree (Zach Brown) [1051282]
- [fs] btrfs: fix verification of dir_item (Zach Brown) [1051282]
- [fs] btrfs: remove scrub_super_lock holding in btrfs_sync_log() (Zach Brown) [1051282]
- [fs] btrfs: use 'u64' rather than 'int' to get extent's generation (Zach Brown) [1051282]
- [fs] btrfs: fix the free space write out failure when there is no data space (Zach Brown) [1051282]
- [fs] btrfs: stop committing the transaction so much during relocate (Zach Brown) [1051282]
- [fs] btrfs: make sure the delalloc workers actually flush compressed writes (Zach Brown) [1051282]
- [fs] btrfs: take ordered root lock when removing ordered operations inode (Zach Brown) [1051282]
- [fs] btrfs: don't abort transaction in run_delalloc_nocow (Zach Brown) [1051282]
- [fs] btrfs: do not bug_on if we try to cow a free space cache inode (Zach Brown) [1051282]
- [fs] btrfs: return an error from btrfs_wait_ordered_range (Zach Brown) [1051282]
- [fs] btrfs: stop using vfs_read in send (Zach Brown) [1051282]
- [fs] btrfs: check_int, remove warning for mixed-mode (Zach Brown) [1051282]
- [fs] btrfs: fix check_int 'leaf item out of bounce' regression (Zach Brown) [1051282]
- [fs] btrfs: optimize extent item search in run_delayed_extent_op (Zach Brown) [1051282]
- [fs] btrfs: add tracing for failed reservations (Zach Brown) [1051282]
- [fs] btrfs: remove fs/btrfs/compat.h (Zach Brown) [1051282]
- [fs] btrfs: remove move_pages() (Zach Brown) [1051282]
- [fs] btrfs: use get_seconds() instead of btrfs wrapper (Zach Brown) [1051282]
- [fs] btrfs: fix incorrect inode acl reset (Zach Brown) [1051282]
- [fs] btrfs: Don't allocate inode that is already in use (Zach Brown) [1051282]
- [fs] btrfs: fix btrfs_prev_leaf() previous key computation (Zach Brown) [1051282]
- [fs] btrfs: optimize tree-log.c:count_inode_refs() (Zach Brown) [1051282]
- [fs] btrfs: simplify kmalloc+copy_from_user to memdup_user (Zach Brown) [1051282]
- [fs] btrfs: btrfs_add_ordered_operation, Fix last modified transaction comparison (Zach Brown) [1051282]
- [fs] btrfs: don't leak delayed node on path allocation failure (Zach Brown) [1051282]
- [fs] btrfs: Wait for uuid-tree rebuild task on remount read-only (Zach Brown) [1051282]
- [fs] btrfs: init device stats for new devices (Zach Brown) [1051282]
- [fs] btrfs: fixup error path in __btrfs_inc_extent_ref (Zach Brown) [1051282]
- [fs] btrfs: disallow 'btrfs (balance, replace) cancel' on ro mounts (Zach Brown) [1051282]
- [fs] btrfs: don't leak ioctl args in btrfs_ioctl_dev_replace (Zach Brown) [1051282]
- [fs] btrfs: nuke a bogus rw_devices decrement in __btrfs_close_devices (Zach Brown) [1051282]
- [fs] btrfs: Fix memory leakage in the tree-log.c (Zach Brown) [1051282]
- [fs] btrfs: kill unused code in btrfs_search_forward (Zach Brown) [1051282]
- [fs] btrfs: cleanup dead code of defragment (Zach Brown) [1051282]
- [fs] btrfs: remove unnecessary key copy when logging inode (Zach Brown) [1051282]
- [fs] btrfs: Simplify the logic in alloc_extent_buffer() for existing extent buffer case (Zach Brown) [1051282]
- [fs] btrfs: fix up seek_hole/seek_data handling (Zach Brown) [1051282]
- [fs] btrfs: add an assert to btrfs_lookup_csums_range for alignment (Zach Brown) [1051282]
- [fs] btrfs: fix hole check in log_one_extent (Zach Brown) [1051282]
- [fs] btrfs: add a sanity test for a vacant extent at the front of a file (Zach Brown) [1051282]
- [fs] btrfs: handle a missing extent for the first file extent (Zach Brown) [1051282]
- [fs] btrfs: stop all workers after we free block groups (Zach Brown) [1051282]
- [fs] btrfs: add tests for btrfs_get_extent (Zach Brown) [1051282]
- [fs] btrfs: add tests for find_lock_delalloc_range (Zach Brown) [1051282]
- [fs] btrfs: free reserved space on error in a few places (Zach Brown) [1051282]
- [fs] btrfs: fixup reserved trace points (Zach Brown) [1051282]
- [fs] btrfs: free up block groups after everything (Zach Brown) [1051282]
- [fs] btrfs: cleanup reserved space when freeing tree log on error (Zach Brown) [1051282]
- [fs] btrfs: do not free the dirty bytes from the trans block rsv on cleanup (Zach Brown) [1051282]
- [fs] btrfs: fix memory leaks on transaction commit failure (Zach Brown) [1051282]
- [fs] btrfs: fix the dev-replace suspend sequence (Zach Brown) [1051282]
- [fs] btrfs: improve inode hash function/inode lookup (Zach Brown) [1051282]
- [fs] btrfs: remove unnecessary tree search when logging inode (Zach Brown) [1051282]
- [fs] btrfs: remove unused max_key arg from btrfs_search_forward (Zach Brown) [1051282]
- [fs] btrfs: fix memory leak of chunks' extent map (Zach Brown) [1051282]
- [fs] btrfs: improve jitter performance of the sequential buffered write (Zach Brown) [1051282]
- [fs] btrfs: fix BUG_ON() casued by the reserved space migration (Zach Brown) [1051282]
- [fs] btrfs: remove unused parameter from btrfs_header_fsid (Zach Brown) [1051282]
- [fs] btrfs: fix two use-after-free bugs with transaction cleanup (Zach Brown) [1051282]
- [fs] btrfs: remove all BUG_ON()'s from commit_cowonly_roots (Zach Brown) [1051282]
- [fs] btrfs: don't delete ordered roots from list during cleanup (Zach Brown) [1051282]
- [fs] btrfs: cleanup transaction on abort (Zach Brown) [1051282]
- [fs] btrfs: do not release metadata for space cache inodes (Zach Brown) [1051282]
- [fs] btrfs: reset intwrite on transaction abort (Zach Brown) [1051282]
- [fs] btrfs: don't leak block group on error (Zach Brown) [1051282]
- [fs] btrfs: fix sync fs to actually wait for all data to be persisted (Zach Brown) [1051282]
- [fs] btrfs: fix tracking of orphan inode count (Zach Brown) [1051282]
- [fs] btrfs: export btrfs space shared info to userspace (Zach Brown) [1051282]
- [fs] btrfs: remove path arg from btrfs_truncate_free_space_cache (Zach Brown) [1051282]
- [fs] btrfs: remove duplicated ino cache's inode lookup (Zach Brown) [1051282]
- [fs] btrfs: do a full search everytime in btrfs_search_old_slot (Zach Brown) [1051282]
- [fs] btrfs: add a sanity test for btrfs_split_item (Zach Brown) [1051282]
- [fs] btrfs: drop unused parameter from btrfs_item_nr (Zach Brown) [1051282]
- [fs] btrfs: don't store NULL byte in symlink extents (Zach Brown) [1051282]
- [fs] btrfs: eliminate the exceptional root_tree refs=0 (Zach Brown) [1051282]

* Mon Mar 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-100.el7]
- [scsi] report sense even for TEST UNIT READY commands (Ewan Milne) [1070982]
- [bfa] Fix for crash during sfpshow command (Chad Dupuis) [1065950]
- [mm] fix GFP_THISNODE callers and clarify (Johannes Weiner) [1069551 1069639]
- [mm] page_alloc: exempt GFP_THISNODE allocations from zone fairness (Johannes Weiner) [1069551 1069639]
- [scsi] reserve space in structures for future scsi-mq changes (Mike Snitzer) [1071014]
- [block] remove unprep_rq_fn (Mike Snitzer) [1071014]
- [scsi] reintroduce scsi_driver.init_command (Mike Snitzer) [1071014]
- [block] blk-mq: support partial I/O completions (Mike Snitzer) [1071014]
- [block] blk-mq: merge blk_mq_insert_request and blk_mq_run_request (Mike Snitzer) [1071014]
- [block] blk-mq: remove blk_mq_alloc_rq (Mike Snitzer) [1071014]
- [block] blk-mq: pair blk_mq_start_request / blk_mq_requeue_request (Mike Snitzer) [1071014]
- [block] blk-mq: dont assume rq->errors is set when returning an error from ->queue_rq (Mike Snitzer) [1071014]
- [block] Fix type mismatch in ssize_t_blk_mq_tag_sysfs_show (Mike Snitzer) [1071014]
- [block] blk-mq: rework flush sequencing logic (Mike Snitzer) [1071014]
- [block] null_blk: use blk_complete_request and blk_mq_complete_request (Mike Snitzer) [1071014]
- [block] blk-mq: rework I/O completions (Mike Snitzer) [1071014]
- [block] null_blk: Fix completion processing from LIFO to FIFO (Mike Snitzer) [1071014]
- [lib] llist: move llist_reverse_order from raid5 to llist.c (Mike Snitzer) [1071014]
- [lib] llist: llist_add() can use llist_add_batch() (Mike Snitzer) [1071014]
- [lib] llist: fix_simplify llist_add() and llist_add_batch() (Mike Snitzer) [1071014]
- [block] blk-mq: Add bio_integrity setup to blk_mq_make_request (Mike Snitzer) [1071014]
- [block] blk-mq: initialize sg_reserved_size (Mike Snitzer) [1071014]
- [block] blk-mq: handle dma_drain_size (Mike Snitzer) [1071014]
- [block] blk-mq: divert __blk_put_request for MQ ops (Mike Snitzer) [1071014]
- [block] blk-mq: support at_head inserations for blk_execute_rq (Mike Snitzer) [1071014]
- [block] null_blk: Null pointer deference problem in alloc_page_buffers (Mike Snitzer) [1071014]
- [block] null_blk: fix queue leak inside removing device (Mike Snitzer) [1071014]
- [block] null_blk: support submit_queues on use_per_node_hctx (Mike Snitzer) [1071014]
- [block] null_blk: set use_per_node_hctx param to false (Mike Snitzer) [1071014]
- [block] null_blk: warning on ignored submit_queues param (Mike Snitzer) [1071014]
- [block] null_blk: refactor init and init errors code paths (Mike Snitzer) [1071014]
- [block] null_blk: mem garbage on NUMA systems during init (Mike Snitzer) [1071014]
- [block] null_blk: corrections to documentation (Mike Snitzer) [1071014]
- [block] null_blk: documentation (Mike Snitzer) [1071014]
- [block] null_blk: fix differences between RHEL7 and upstream (Mike Snitzer) [1071014]
- [target] iscsi-target: Fix connection reset hang with percpu_ida_alloc (Mike Snitzer) [1071014]
- [lib] percpu_ida: Make percpu_ida_alloc + callers accept task state bitmask (Mike Snitzer) [1071014]
- [lib] percpu_ida: Removing unused arguement from alloc_local_tag (Mike Snitzer) [1071014]
- [block] blk-mq: use hotcpu_notifier() (Mike Snitzer) [1071014]
- [block] blk-mq: uses page->list incorrectly (Mike Snitzer) [1071014]
- [block] blk-mq: use __smp_call_function_single directly (Mike Snitzer) [1071014]
- [kernel] provide a __smp_call_function_single stub for !CONFIG_SMP (Mike Snitzer) [1071014]
- [block] blk-mq: fix initializing request's start time (Mike Snitzer) [1071014]
- [block] blk-mq: don't export blk_mq_free_queue() (Mike Snitzer) [1071014]
- [block] blk-mq: make blk_sync_queue support mq (Mike Snitzer) [1071014]
- [block] blk-mq: support draining mq queue (Mike Snitzer) [1071014]
- [virt] kvm/x86: emulator_cmpxchg_emulated should mark_page_dirty (Marcelo Tosatti) [994431]
- [x86] irq: Fix kbuild warning in smp_irq_move_cleanup_interrupt() (Prarit Bhargava) [1065735]
- [security] selinux: put the mmap() DAC controls before the MAC controls (Paul Moore) [1070827]
- [infiniband] iser: Avoid dereferncing iscsi_iser conn object when not bound to iser connection (Doug Ledford) [1061129]
- [mm] Use ptep/pmdp_set_numa() for updating _PAGE_NUMA bit (Steve Best) [1049012]
- [mm] Dirty accountable change only apply to non prot numa case (Steve Best) [1049012]
- [powerpc] mm: Add new "set" flag argument to pte/pmd update function (Steve Best) [1049012]
- [powerpc] mm: Enable _PAGE_NUMA for book3s (Steve Best) [1049012]
- [powerpc] mm: Only check for _PAGE_PRESENT in set_pte/pmd functions (Steve Best) [1049012]
- [powerpc] mm: Free up _PAGE_COHERENCE for numa fault use later (Steve Best) [1049012]
- [powerpc] mm: Use HPTE constants when updating hpte bits (Steve Best) [1049012]
- [mm] Move change_prot_numa outside CONFIG_ARCH_USES_NUMA_PROT_NONE (Steve Best) [1049012]

* Fri Feb 28 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-99.el7]
- [target] Pass through I/O topology for block backstores (Andy Grover) [873474]
- [target] iscsi-target: ST response on IN6ADDR_ANY socket (Andy Grover) [913033]
- [security] keys: Fix searching of nested keyrings (David Howells) [1033467]
- [security] keys: Fix multiple key add into associative array (David Howells) [1033467]
- [security] keys: Fix the keyring hash function (David Howells) [1033467]
- [ethernet] bnx2x: Fix generic option settings (Michal Schmidt) [1066076]
- [tools] perf/kvm: Fix kvm report without guestmount (Jiri Olsa) [1051298]
- [mm] readahead: fix readahead failure for memoryless NUMA nodes and limit readahead pages (Steve Best) [1062288]
- [ethernet] Mark Intel DH8900CC Series Gigabit Network Device Unsupported (Prarit Bhargava) [727275]
- [drm] nouveau/mxm: fix null deref on load (Ben Skeggs) [1067807]
- [ethernet] i40e: Fix device ID define names to align to standard (Stefan Assmann) [1057192]
- [ethernet] i40e: add DCB option to Kconfig (Stefan Assmann) [1057192]
- [ethernet] i40e: add DCB and DCBNL support (Stefan Assmann) [1057192]
- [ethernet] i40e: implement DCB support infastructure (Stefan Assmann) [1057192]
- [ethernet] i40e: refactor flow director (Stefan Assmann) [1057192]
- [ethernet] i40e: rename defines (Stefan Assmann) [1057192]
- [ethernet] i40e: whitespace fixes (Stefan Assmann) [1057192]
- [ethernet] i40e: Change firmware workaround (Stefan Assmann) [1057192]
- [ethernet] i40e: fix compile warning on checksum_local (Stefan Assmann) [1057192]
- [ethernet] i40e: updates to AdminQ interface (Stefan Assmann) [1057192]
- [ethernet] i40e: check desc pointer before printing (Stefan Assmann) [1057192]
- [ethernet] i40e: delete non-required instances of include <linux/init.h> (Stefan Assmann) [1057192]
- [ethernet] i40e: Retain MAC filters on port VLAN deletion (Stefan Assmann) [1057192]
- [ethernet] i40e: Warn admin to reload VF driver on port VLAN configuration (Stefan Assmann) [1057192]
- [ethernet] i40e: Bump version number (Stefan Assmann) [1057192]
- [ethernet] i40e: trivial cleanup (Stefan Assmann) [1057192]
- [ethernet] i40e: whitespace fixes (Stefan Assmann) [1057192]
- [ethernet] i40e: make message meaningful (Stefan Assmann) [1057192]
- [ethernet] i40e: associate VMDq queue with VM type (Stefan Assmann) [1057192]
- [ethernet] i40e: remove extra register write (Stefan Assmann) [1057192]
- [ethernet] i40e: Bump version (Stefan Assmann) [1057192]
- [ethernet] i40e: fix log message wording (Stefan Assmann) [1057192]
- [ethernet] i40e: enable PTP (Stefan Assmann) [1057192]
- [ethernet] i40e: call clear_pxe after adminq is initialized (Stefan Assmann) [1057192]
- [ethernet] i40e: clear qtx_head before enabling Tx queue (Stefan Assmann) [1057192]
- [ethernet] i40e: adjust ITR max and min values (Stefan Assmann) [1057192]
- [ethernet] i40e: check for possible incorrect ipv6 checksum (Stefan Assmann) [1057192]
- [ethernet] i40e: allow VF to remove any MAC filter (Stefan Assmann) [1057192]
- [ethernet] i40e: do not bail when disabling if Tx queue disable fails (Stefan Assmann) [1057192]
- [ethernet] i40e: Setting queue count to 1 using ethtool is valid (Stefan Assmann) [1057192]
- [ethernet] i40e: Cleanup Doxygen warnings (Stefan Assmann) [1057192]
- [ethernet] i40e: fix long lines (Stefan Assmann) [1057192]
- [ethernet] i40e: Bump version (Stefan Assmann) [1057192]
- [ethernet] i40e: Update the Current NVM version Low value (Stefan Assmann) [1057192]
- [ethernet] i40e: drop unused macros (Stefan Assmann) [1057192]
- [ethernet] i40e: use assignment instead of memcpy (Stefan Assmann) [1057192]
- [ethernet] i40e: Turn flow director off in MFP mode (Stefan Assmann) [1057192]
- [ethernet] i40e: Add a dummy packet template (Stefan Assmann) [1057192]
- [ethernet] i40e: fix spelling errors (Stefan Assmann) [1057192]
- [ethernet] i40e: formatting and checkpatch fixes (Stefan Assmann) [1057192]
- [ethernet] i40e: shorten wordy fields (Stefan Assmann) [1057192]
- [ethernet] i40e: accept pf to pf adminq messages (Stefan Assmann) [1057192]
- [ethernet] i40e: remove interrupt on AQ error (Stefan Assmann) [1057192]
- [ethernet] i40e: release NVM resource reservation on startup (Stefan Assmann) [1057192]
- [ethernet] i40e: Cleanup reconfig rss path (Stefan Assmann) [1057192]
- [ethernet] i40e: disable packet split (Stefan Assmann) [1057192]
- [ethernet] i40e: add a comment on barrier and fix panic on reset (Stefan Assmann) [1057192]
- [ethernet] i40e: Fix MAC format in Write MAC address AQ cmd (Stefan Assmann) [1057192]
- [ethernet] i40e: Fix GPL header (Stefan Assmann) [1057192]
- [ethernet] i40e: use kernel specific defines (Stefan Assmann) [1057192]
- [ethernet] i40e: Re-enable interrupt on ICR0 (Stefan Assmann) [1057192]

* Thu Feb 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-98.el7]
- [scsi] qla4xxx: v5.04.00.04.07.00-k0 (Chad Dupuis) [1063205]
- [scsi] qla4xxx: Initialize hardware queue for ISP40XX (Chad Dupuis) [1063205]
- [fs] cifs: mask off top byte in get_rfc1002_length() (Sachin Prabhu) [1062588] {CVE-2014-0069}
- [infiniband] mlx4: Add support for steerable IB UD QPs (Doug Ledford) [1058518]
- [infiniband] mlx4: Add mechanism to support flow steering over IB links (Doug Ledford) [1058518]
- [infiniband] mlx4: Enable device-managed steering support for IB ports too (Doug Ledford) [1058518]
- [ethernet] mlx4: Add support for steerable IB UD QPs (Doug Ledford) [1058518]
- [infiniband] core: Add support for IB L2 device-managed steering (Doug Ledford) [1058518]
- [infiniband] core: Add flow steering support for IPoIB UD traffic (Doug Ledford) [1058518]
- [scsi] isci: correct erroneous for_each_isci_host macro (David Milburn) [1054302]
- [virt] vhost/net: disable zero copy by default (Jason Wang) [1069045]
- [x86] cpu-hotplug: Fix stack frame warning in check_irq_vectors_for_cpu_disable() (Prarit Bhargava) [1061317]
- [drm] radeon/kms: add crtc_disable function for legacy crtc (Jerome Glisse) [1029570]
- [drm] radeon/kms: unpin fb in atombios crtc disable (Jerome Glisse) [1029570]
- [powerpc] Fix 32-bit frames for signals delivered when transactional (Steve Best) [1059703]
- [edac] Correct workqueue setup path (Aristeu Rozanski) [1055892]
- [edac] Poll timeout cannot be zero, p2 (Aristeu Rozanski) [1055892]
- [edac] edac_mc_sysfs: poll timeout cannot be zero (Aristeu Rozanski) [1055892]

* Tue Feb 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-97.el7]
- [fs] cifs: sanity check length of data to send before sending (Sachin Prabhu) [1062588] {CVE-2014-0069}
- [fs] cifs: ensure that uncached writes handle unmapped areas correctly (Sachin Prabhu) [1062588] {CVE-2014-0069}
- [fs] cifs: set FILE_CREATED (Sachin Prabhu) [1065982]
- [fs] ext4: Disable punch hole on non-extent mapped files (Lukas Czerner) [1033438]
- [fs] Fix mountpoint reference leakage in linkat (Jeff Layton) [1063287]
- [fs] NFSD/sunrpc: avoid deadlock on TCP connection due to memory pressure ("J. Bruce Fields") [994257]
- [fs] nfsd: consider CLAIM_FH when handing out delegation ("J. Bruce Fields") [1031097]
- [fs] nfsd4: minor nfs4_setlease cleanup ("J. Bruce Fields") [1031097]
- [fs] nfsd4: need to destroy revoked delegations in destroy_client ("J. Bruce Fields") [1031097]
- [fs] nfsd: no need to unhash_stid before free ("J. Bruce Fields") [1031097]
- [fs] nfsd: nfs4_open_delegation needs to remove_stid rather than unhash_stid ("J. Bruce Fields") [1031097]
- [fs] nfsd: nfs4_free_stid ("J. Bruce Fields") [1031097]
- [fs] nfsd4: fix leak of inode reference on delegation failure ("J. Bruce Fields") [1031097]
- [fs] nfsd4: fix setlease error return ("J. Bruce Fields") [1031097]
- [fs] nfsd4: fix delegation-unlink/rename race ("J. Bruce Fields") [1031097]
- [fs] nfsd4: delay setting current_fh in open ("J. Bruce Fields") [1031097]
- [fs] nfsd4: break only delegations when appropriate ("J. Bruce Fields") [1031097]
- [fs] nfsd: make sure to balance get/put_write_access ("J. Bruce Fields") [1031097]
- [fs] nfsd: split up nfsd_setattr ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on any attribute modification ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on link ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on rename ("J. Bruce Fields") [1031097]
- [fs] locks: helper functions for delegation breaking ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on unlink ("J. Bruce Fields") [1031097]
- [fs] namei: minor vfs_unlink cleanup ("J. Bruce Fields") [1031097]
- [fs] locks: implement delegations ("J. Bruce Fields") [1031097]
- [fs] locks: introduce new FL_DELEG lock flag ("J. Bruce Fields") [1031097]
- [fs] vfs: take i_mutex on renamed file ("J. Bruce Fields") [1031097]
- [fs] vfs: rename I_MUTEX_QUOTA now that it's not used for quotas ("J. Bruce Fields") [1031097]
- [fs] vfs: don't use PARENT/CHILD lock classes for non-directories ("J. Bruce Fields") [1031097]
- [fs] vfs: pull ext4's double-i_mutex-locking into common code ("J. Bruce Fields") [1031097]
- [fs] ext4: fix FITRIM in no journal mode (Lukas Czerner) [1044519]
- [fs] ext4: add ratelimiting to ext4 messages (Lukas Czerner) [1044513]
- [fs] ext4: rate limit printk in buffer_io_error() (Lukas Czerner) [1044513]
- [fs] ext4: translate flag bits to strings in tracepoints (Lukas Czerner) [1044505]
- [fs] ext4: Fix fsync error handling after filesystem abort (Lukas Czerner) [1044501]

* Tue Feb 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-96.el7]
- [x86] Makefile: add -Werror to compile (Prarit Bhargava) [1006333]
- [edac] sb_edac: Shut up compiler warning when EDAC_DEBUG is enabled (Prarit Bhargava) [1006333]
- [kernel] mutex: Avoid label warning when !CONFIG_MUTEX_SPIN_ON_OWNER (Prarit Bhargava) [1006333]
- [infiniband] ocrdma: Fix compiler warning (Prarit Bhargava) [1006333]
- [isdn] hfcpci_softirq: get func return to suppress compiler warning (Prarit Bhargava) [1006333]
- [x86] Fix return value in generic_processor_info() (Prarit Bhargava) [1006333]
- [wireless] rtlwifi: initialize local array and set value (Prarit Bhargava) [1006333]
- [ethernet] mlx4: clean up srq_res_start_move_to() (Prarit Bhargava) [1006333]
- [ethernet] mlx4: clean up cq_res_start_move_to() (Prarit Bhargava) [1006333]
- [powerpc] Link VDSOs at 0x0 (Steve Best) [1066468]
- [powerpc] Use unstripped VDSO image for more accurate profiling data (Steve Best) [1066468]
- [scsi] fnic: Incremented driver version (Chris Leech) [831836]
- [scsi] fnic: Fnic Statistics Collection (Chris Leech) [831836]
- [scsi] fnic: host reset returns nonzero value(errno) on (Chris Leech) [831836]
- [scsi] fnic: Convert uses of compare_ether_addr to ether_addr_equal (Chris Leech) [831836]
- [scsi] fnic: remove unnecessary pci_set_drvdata() (Chris Leech) [831836]
- [scsi] fnic: fnic Driver Tuneables Exposed through CLI (Chris Leech) [831836]
- [scsi] fnic: Kernel panic while running sh/nosh with max lun (Chris Leech) [831836]
- [scsi] fnic: Hitting BUG_ON(io_req->abts_done) in (Chris Leech) [831836]
- [scsi] fnic: Remove QUEUE_FULL handling code (Chris Leech) [831836]
- [scsi] fnic: On system with >1.1TB RAM, VIC fails multipath (Chris Leech) [831836]
- [scsi] fnic: FC stat param seconds_since_last_reset not (Chris Leech) [831836]
- [scsi] fnic: BUG, sleeping function called from invalid (Chris Leech) [831836]
- [scsi] fnic: switch to fixed_size_llseek() (Chris Leech) [831836]
- [scsi] fnic: potential dead lock in fnic_is_abts_pending() (Chris Leech) [831836]
- [powerpc] mm: Fix compile error of pgtable-ppc64.h (Steve Best) [1047636]
- [powerpc] thp: Fix crash on mremap (Steve Best) [1047636]
- [ethernet] bnx2x: Allow VF rss on higher PFs (Michal Schmidt) [1062634]
- [ethernet] bnx2x: Fix VF flr flow (Michal Schmidt) [1062634]
- [ethernet] bnx2x: Correct default Tx switching behaviour (Michal Schmidt) [1058592]
- [block] sg_io: allow WRITE SAME without CAP_SYS_RAWIO (Paolo Bonzini) [966883]
- [block] sg_io: introduce unpriv_sgio queue flag (Paolo Bonzini) [966883]
- [block] sg_io: pass request_queue to blk_verify_command (Paolo Bonzini) [966883]
- [scsi] aacraid: prevent invalid pointer dereference (Frantisek Hrbata) [1034301] {CVE-2013-6380}
- [ethernet] be2net: Fix be_vlan_add/rem_vid() routines (Ivan Vecera) [1065829]
- [wireless] libertas: potential oops in debugfs (Denys Vlasenko) [1034178] {CVE-2013-6378}
- [mm] remove bogus warning in copy_huge_pmd() (Rik van Riel) [1067326]
- [wireless] ath9k: properly set MAC address and BSSID mask (Denys Vlasenko) [1033071] {CVE-2013-4579}
- [video] matroxfb: Default to 1024x768 @ 60 (Adam Jackson) [1055533]
- [powerpc] pseries: Add Gen3 definitions for PCIE link speed (Jerome Glisse) [1056701]
- [powerpc] pseries: Fix regression on PCI link speed (Jerome Glisse) [1056701]

* Sat Feb 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-95.el7]
- [fs] nfs: nfs4_destroy_session must call rpc_destroy_waitqueue (Steve Dickson) [1061707]
- [fs] nfs: Fix memory corruption in nfs4_proc_open_confirm (Steve Dickson) [1061707]
- [fs] nfs: initialize the ACL support bits to zero (Steve Dickson) [1059241 919382]
- [fs] nfs: Cleanup (Steve Dickson) [1059241 919382]
- [fs] nfs: Clean up nfs41_sequence_done (Steve Dickson) [1059241 919382]
- [fs] nfs: Fix a slot leak in nfs40_sequence_done (Steve Dickson) [1059241 919382]
- [fs] nfs: free slot before resending I/O to MDS (Steve Dickson) [1059241 919382]
- [fs] nfs: add memory barriers around NFS_INO_INVALID_DATA and NFS_INO_INVALIDATING (Steve Dickson) [1059241 919382]
- [fs] nfs: Fix races in nfs_revalidate_mapping (Steve Dickson) [1059241 919382]
- [net] sunrpc: turn warn_gssd() log message into a dprintk() (Steve Dickson) [1059241 919382]
- [fs] nfs: fix the handling of NFS_INO_INVALID_DATA flag in nfs_revalidate_mapping (Steve Dickson) [1059241 919382]
- [fs] nfs: handle servers that support only ALLOW ACE type (Steve Dickson) [1059241 919382]
- [fs] nfs: Proper delay for NFS4ERR_RECALLCONFLICT in layout_get_done (Steve Dickson) [1059622]
- [fs] nfs: fix BUG in filelayout_recover_commit_reqs (Steve Dickson) [1059622]
- [fs] nfs: fix discover_server_trunking use after free (Steve Dickson) [1059622]
- [fs] nfs: Handle errors correctly in nfs41_walk_client_list (Steve Dickson) [1059622]
- [fs] nfs: always make sure page is up-to-date before extending a write to cover the entire page (Steve Dickson) [1059622]
- [fs] nfs: page cache invalidation for dio (Steve Dickson) [1059622]
- [fs] nfs: take i_mutex during direct I/O reads (Steve Dickson) [1059622]
- [fs] nfs: merge nfs_direct_write into nfs_file_direct_write (Steve Dickson) [1059622]
- [fs] nfs: merge nfs_direct_read into nfs_file_direct_read (Steve Dickson) [1059622]
- [fs] nfs: increment i_dio_count for reads, too (Steve Dickson) [1059622]
- [fs] nfs: defer inode_dio_done call until size update is done (Steve Dickson) [1059622]
- [fs] nfs: fix size updates for aio writes (Steve Dickson) [1059622]
- [fs] nfs: properly handle ENOTSUP in SECINFO_NO_NAME (Steve Dickson) [1059622]
- [fs] nfs: Fix a race in nfs4_write_inode (Steve Dickson) [1059622]
- [fs] nfs: Don't trust attributes if a pNFS LAYOUTCOMMIT is outstanding (Steve Dickson) [1059622]
- [fs] nfs: use p(dD) point to the right include file in a comment (left over from a9004abc3) (Steve Dickson) [1059622]
- [fs] nfs: dprintk() should not print negative fileids and inode numbers (Steve Dickson) [1059622]
- [fs] nfs: use (dD) instead of open-coded (and often racy) equivalents (Steve Dickson) [1059622]
- [lib] vsprintf: document formats for dentry and struct file (Steve Dickson) [1059622]
- [lib] vsprintf: add formats for dentry/file pathnames (Steve Dickson) [1059622]
- [fs] nfs: fix dead code of ipv6_addr_scope (Steve Dickson) [1059622]
- [net] sunrpc: Fix infinite loop in RPC state machine (Steve Dickson) [1059622]
- [net] sunrpc: Add tracepoint for socket errors (Steve Dickson) [1059622]
- [net] sunrpc: Report connection error values to rpc_tasks on the pending queue (Steve Dickson) [1059622]
- [net] sunrpc: Handle connect errors ECONNABORTED and EHOSTUNREACH (Steve Dickson) [1059622]
- [net] sunrpc: Ensure xprt_connect_status handles all potential connection errors (Steve Dickson) [1059622]
- [fs] nfs: OPEN must handle the NFS4ERR_IO return code correctly (Steve Dickson) [1059622]

* Sat Feb 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-94.el7]
- [powerpc] finish off merge to put FP/VSX and VR state into structures (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in pseries EEH code (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in nvram code (Steve Best) [1051192]
- [powerpc] Fix endian issues in crash dump code (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in MSI code (Steve Best) [1051192]
- [powerpc] pseries: Fix PCIE link speed endian issue (Steve Best) [1051192]
- [powerpc] Fix topology core_id endian issue on LE builds (Steve Best) [1051192]
- [powerpc] Fix endian issue in setup-common.c (Steve Best) [1051192]
- [powerpc] allyesconfig should not select CONFIG_CPU_LITTLE_ENDIAN (Steve Best) [1051192]
- [powerpc] Fix error when cross building TAGS & cscope (Steve Best) [1051192]
- [powerpc] kvm: allow guest control "E" attribute in mas2 (Steve Best) [1051192]
- [powerpc] Wrong DWARF CFI in the kernel vdso for little-endian / ELFv2 (Steve Best) [1051192]
- [powerpc] Add CONFIG_CPU_LITTLE_ENDIAN kernel config option (Steve Best) [1051192]
- [powerpc] Don't use ELFv2 ABI to build the kernel (Steve Best) [1051192]
- [powerpc] ELF2 binaries signal handling (Steve Best) [1051192]
- [powerpc] ELF2 binaries launched directly (Steve Best) [1051192]
- [powerpc] Set eflags correctly for ELF ABIv2 core dumps (Steve Best) [1051192]
- [powerpc] Add TIF_ELF2ABI flag (Steve Best) [1051192]
- [powerpc] Remove big endianness assumption in of_find_next_cache_node (Steve Best) [1051192]
- [powerpc] word-at-a-time optimization for 64-bit Little Endian (Steve Best) [1051192]
- [powerpc] bpf: BPF JIT compiler for 64-bit Little Endian (Steve Best) [1051192]
- [powerpc] nvram: Fix endian issue when using the partition length (Steve Best) [1051192]
- [powerpc] nvram: Fix endian issue when reading the NVRAM size (Steve Best) [1051192]
- [powerpc] Use -mcpu=power7 on ppc64 little endian builds (Steve Best) [1051192]
- [powerpc] booke64: Use appropriate -mcpu (Steve Best) [1051192]
- [powerpc] Fix Unaligned LE Floating Point Loads and Stores (Steve Best) [1051192]
- [powerpc] Fix Unaligned Loads and Stores (Steve Best) [1051192]
- [powerpc] Enable Little Endian Alignment Handler for Float Pair Instructions (Steve Best) [1051192]
- [powerpc] Fix Handler of Unaligned Load/Store Strings (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in pseries iommu code (Steve Best) [1051192]
- [powerpc] Fix little endian issue in OF PCI scan (Steve Best) [1051192]
- [powerpc] Make kernel module helper endian-safe (Steve Best) [1051192]
- [powerpc] prom_init exception when updating core value (Steve Best) [1051192]
- [powerpc] kernel: Fix endian issue in rtas_pci (Steve Best) [1051192]
- [powerpc] Work around little endian gcc bug (Steve Best) [1051192]
- [powerpc] Don't set HAVE_EFFICIENT_UNALIGNED_ACCESS on little endian builds (Steve Best) [1051192]
- [powerpc] Add ability to build little endian kernels (Steve Best) [1051192]
- [powerpc] kvm: Disable KVM on little endian builds (Steve Best) [1051192]
- [powerpc] hvsi: Fix endian issues in HVSI driver (Steve Best) [1051192]
- [powerpc] powernv: More little endian issues in OPAL RTC driver (Steve Best) [1051192]
- [powerpc] powernv: Don't register exception handlers in little endian mode (Steve Best) [1051192]
- [powerpc] powernv: Fix OPAL entry and exit in little endian mode (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in OPAL console and udbg backend (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in powernv PCI code (Steve Best) [1051192]
- [powerpc] powernv: Make OPAL NVRAM device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in OPAL ICS backend (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in OPAL RTC driver (Steve Best) [1051192]
- [powerpc] Little endian sparse clean up for arch/powerpc/platforms/powernv/pci-ioda.c (Steve Best) [1051192]
- [powerpc] Little endian fix for arch/powerpc/platforms/powernv/pci-p5ioc2.c (Steve Best) [1051192]
- [powerpc] Little endian fix for arch/powerpc/platforms/powernv/pci.c (Steve Best) [1051192]
- [powerpc] Little endian fixes for platforms/powernv/opal.c (Steve Best) [1051192]
- [powerpc] uname should return ppc64le/ppcle on little endian builds (Steve Best) [1051192]
- [powerpc] Use generic memcpy code in little endian (Steve Best) [1051192]
- [powerpc] Use generic checksum code in little endian (Steve Best) [1051192]
- [powerpc] Handle VSX alignment faults in little endian mode (Steve Best) [1051192]
- [powerpc] Add little endian support to alignment handler (Steve Best) [1051192]
- [powerpc] Alignment handler shouldn't access VSX registers with TS_FPR (Steve Best) [1051192]
- [powerpc] Remove hard coded FP offsets in alignment handler (Steve Best) [1051192]
- [powerpc] Remove open coded byte swap macro in alignment handler (Steve Best) [1051192]
- [powerpc] Endian safe trampoline (Steve Best) [1051192]
- [powerpc] Include the appropriate endianness header (Steve Best) [1051192]
- [powerpc] Set MSR_LE bit on little endian builds (Steve Best) [1051192]
- [powerpc] Add little endian support for word-at-a-time functions (Steve Best) [1051192]
- [powerpc] Support endian agnostic MMIO (Steve Best) [1051192]
- [powerpc] Little endian builds double word swap VSX state during context save/restore (Steve Best) [1051192]
- [powerpc] PTRACE_PEEKUSR/PTRACE_POKEUSER of FPR registers in little endian builds (Steve Best) [1051192]
- [powerpc] Fix offset of FPRs in VSX registers in little endian builds (Steve Best) [1051192]
- [powerpc] Book 3S MMU little endian support (Steve Best) [1051192]
- [powerpc] Fix endian issues in VMX copy loops (Steve Best) [1051192]
- [powerpc] Make rwlocks endian safe (Steve Best) [1051192]
- [powerpc] Fix little endian coredumps (Steve Best) [1051192]
- [powerpc] Simplify logic in include/uapi/asm/elf.h (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in H_GET_TERM_CHAR/H_PUT_TERM_CHAR (Steve Best) [1051192]
- [powerpc] pseries: Simplify H_GET_TERM_CHAR (Steve Best) [1051192]
- [powerpc] Little endian SMP IPI demux (Steve Best) [1051192]
- [powerpc] Emulate instructions in little endian mode (Steve Best) [1051192]
- [powerpc] Fix little endian lppaca, slb_shadow and dtl_entry (Steve Best) [1051192]
- [powerpc] Add endian annotations to lppaca, slb_shadow and dtl_entry (Steve Best) [1051192]
- [powerpc] Stop using non-architected shared_proc field in lppaca (Steve Best) [1051192]
- [powerpc] Make NUMA device node code endian safe (Steve Best) [1051192]
- [powerpc] Little endian fixes for legacy_serial.c (Steve Best) [1051192]
- [powerpc] Make PCI device node device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] Make OF PCI device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] Make device tree accesses in VIO subsystem endian safe (Steve Best) [1051192]
- [powerpc] Make device tree accesses in cache info code endian safe (Steve Best) [1051192]
- [powerpc] of_parse_dma_window should take a __be32 *dma_window (Steve Best) [1051192]
- [powerpc] Fix some endian issues in xics code (Steve Best) [1051192]
- [powerpc] Add some endian annotations to time and xics code (Steve Best) [1051192]
- [powerpc] More little endian fixes for setup-common.c (Steve Best) [1051192]
- [powerpc] Make logical to real cpu mapping code endian safe (Steve Best) [1051192]
- [powerpc] Make RTAS calls endian safe (Steve Best) [1051192]
- [powerpc] Make cache info device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] Make RTAS device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] More little endian fixes for prom.c (Steve Best) [1051192]
- [powerpc] Make prom.c device tree accesses endian safe (Steve Best) [1051192]

* Fri Feb 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-93.el7]
- [net] netfilter: xt_nfqueue: fix --queue-bypass regression (Florian Westphal) [1067042]
- [net] netfilter: nft_reject_inet: fix unintended fall-through in switch-statatement (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: fix log/queue expressions for NFPROTO_INET (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: add reject module for NFPROTO_INET (Jiri Benc) [1066156]
- [net] netfilter: nft_reject: split up reject module into IPv4 and IPv6 specifc parts (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: add hook ops to struct nft_pktinfo (Jiri Benc) [1066156]
- [net] netfilter: nft_reject: fix compilation warning if NF_TABLES_IPV6 is disabled (Jiri Benc) [1066156]
- [net] netfilter: add help information to new nf_tables Kconfig options (Jiri Benc) [1066156]
- [net] netfilter: nft_reject: support for IPv6 and TCP reset (Jiri Benc) [1066156]
- [net] netfilter: reject: separate reusable code (Jiri Benc) [1066156]
- [net] netfilter: nft: add queue module (Jiri Benc) [1066156]
- [net] netfilter: xt_nfqueue: separate reusable code (Jiri Benc) [1066156]
- [net] netfilter: ip6t_reject: skip checksum verification for outgoing ipv6 packets (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: check if payload length is a power of 2 (Jiri Benc) [1034791]
- [net] netfilter: nft_meta: fix typo "CONFIG_NET_CLS_ROUTE" (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: unininline nft_trace_packet() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix loop checking with end interval elements (Jiri Benc) [1034791]
- [net] netfilter: nft_rbtree: fix data handling of end interval elements (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: do not allow NFT_SET_ELEM_INTERVAL_END flag and data (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix racy rule deletion (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix log/queue expressions for NFPROTO_INET (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add AF specific expression support (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: fix missing NFT_CT_L3PROTOCOL key in validity checks (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix potential oops when dumping sets (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix overrun in nf_tables_set_alloc_name() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix oops when deleting a chain with references (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: fix unconditional dump of 'dir' attr (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: fix compilation warning if NF_CONNTRACK_MARK is not set (Jiri Benc) [1034791]
- [net] netfilter: Add dependency on IPV6 for NF_TABLES_INET (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix missing byteorder conversion in policy (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix error path in the init functions (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: rename nft_do_chain_pktinfo() to nft_do_chain() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: prohibit deletion of a table with existing sets (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: take AF module reference when creating a table (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: perform flags validation before table allocation (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: minor nf_chain_type cleanups (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: constify chain type definitions and pointers (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: replay request after dropping locks to load chain type (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add missing module references to chain types (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix chain type module reference handling (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix check for table overflow (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: restore chain change atomicity (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: split chain policy validation from actually setting it (Jiri Benc) [1034791]
- [net] netfilter: nft_meta: fix lack of validation of the input register (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: Add support to set the connmark (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: load both IPv4 and IPv6 conntrack modules for NFPROTO_INET (Jiri Benc) [1034791]
- [net] netfilter: nft_meta: add l4proto support (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add nfproto support to meta expression (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add "inet" table for IPv4/IPv6 (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add support for multi family tables (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add hook ops to struct nft_pktinfo (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: make chain types override the default AF functions (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: dump sets in all existing families (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: remove unused variable in nf_tables_dump_set() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix type in parsing in nf_tables_set_alloc_name() (Jiri Benc) [1034791]
- [net] netfilter: add help information to new nf_tables Kconfig options (Jiri Benc) [1034791]
- [net] netfilter: select NFNETLINK when enabling NF_TABLES (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: remove nft_meta_target (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: nft_meta module get/set ops (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: Expose the table usage counter via netlink (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix issue with verdict support (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix wrong datatype in nft_validate_data_load() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix oops when updating table with user chains (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix dumping with large number of sets (Jiri Benc) [1034791]
- [net] netfilter: nft_exthdr: call ipv6_find_hdr() with explicitly initialized offset (Jiri Benc) [1034791]
- [net] netfilter: nft_reject: fix endianness in dump function (Jiri Benc) [1034791]
- [net] nf_tables*.h: Remove extern from function prototypes (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix missing rules flushing per table (Jiri Benc) [1034791]
- [net] netfilter: nft_compat: fix error path in nft_parse_compat() (Jiri Benc) [1034791]
- [net] pktgen: Fix position of ip and udp header (Jiri Pirko) [1067485]
- [net] nf: remove automatic helper assignment removal warning (Jiri Pirko) [1066453]
- [net] inet_diag: fix inet_diag_dump_icsk() to use correct state for timewait sockets (Jesper Brouer) [1059721]
- [net] netfilter: xt_socket: use sock_gen_put() (Jesper Brouer) [1059721]
- [net] inet_diag: use sock_gen_put() (Jesper Brouer) [1059721]
- [net] inet: rename ir_loc_port to ir_num (Jesper Brouer) [1059721]
- [net] inet: includes a sock_common in request_sock (Jesper Brouer) [1059721]
- [net] inet: inet_timewait_sock.h missing semi-colon when KMEMCHECK is enabled (Jesper Brouer) [1059721]
- [net] fix build errors if ipv6 is disabled (Jesper Brouer) [1059721]
- [net] sctp: fix initialization of local source address on accepted ipv6 sockets (Jesper Brouer) [1059721]
- [net] ipv6: make lookups simpler and faster (Jesper Brouer) [1059721]
- [net] tcp/dccp: remove twchain (Jesper Brouer) [1059721]
- [net] tcp: shrink tcp6_timewait_sock by one cache line (Jesper Brouer) [1059721]
- [net] inet: consolidate INET_TW_MATCH (Jesper Brouer) [1059721]
- [net] inet*.h: Remove extern from function prototypes (Jesper Brouer) [1059721]
- [net] openvswitch: datapath: fix dp check in ovs_dp_reset_user_features (Francesco Fusco) [1057099]
- [net] openvswitch: Suppress error messages on megaflow updates (Francesco Fusco) [1057099]
- [net] openvswitch: Fix ovs_flow_free() ovs-lock assert (Francesco Fusco) [1057099]
- [net] openvswitch: Fix kernel panic on ovs_flow_free (Francesco Fusco) [1057099]
- [net] openvswitch: Pad OVS_PACKET_ATTR_PACKET if linear copy was performed (Francesco Fusco) [1057099]
- [tools] perf: Fix include for non x86 architectures (Francesco Fusco) [1057099]
- [net] openvswitch: Use kmem_cache_free() instead of kfree() (Francesco Fusco) [1057099]
- [net] openvswitch: Compute checksum in skb_gso_segment() if needed (Francesco Fusco) [1057099]
- [net] openvswitch: Use skb_zerocopy() for upcall (Francesco Fusco) [1057099]
- [net] openvswitch: Pass datapath into userspace queue functions (Francesco Fusco) [1057099]
- [net] openvswitch: Drop user features if old user space attempted to create datapath (Francesco Fusco) [1057099]
- [net] openvswitch: Allow user space to announce ability to accept unaligned Netlink messages (Francesco Fusco) [1057099]
- [net] Export skb_zerocopy() to zerocopy from one skb to another (Francesco Fusco) [1057099]
- [net] nf_queue: add NFQA_SKB_CSUM_NOTVERIFIED info flag (Francesco Fusco) [1057099]
- [net] openvswitch: remove duplicated include from flow_table.c (Francesco Fusco) [1057099]
- [net] openvswitch: use kfree_rcu instead of rcu_free_{sw_flow_mask_cb, acts_callback} (Francesco Fusco) [1057099]
- [net] openvswitch: Per cpu flow stats (Francesco Fusco) [1057099]
- [net] openvswitch: Enable memory mapped Netlink i/o (Francesco Fusco) [1057099]
- [net] netlink: Avoid netlink mmap alloc if msg size exceeds frame size (Francesco Fusco) [1057099]
- [net] genl: Add genlmsg_new_unicast() for unicast message allocation (Francesco Fusco) [1057099]
- [net] openvswitch: Silence RCU lockdep checks from flow lookup (Francesco Fusco) [1057099]
- [net] openvswitch: Change ovs_flow_tbl_lookup_xx() APIs (Francesco Fusco) [1057099]
- [net] openvswitch: Shrink sw_flow_mask by 8 bytes (64-bit) or 4 bytes (32-bit) (Francesco Fusco) [1057099]
- [net] openvswitch: Correct comment (Francesco Fusco) [1057099]
- [net] Add utility functions to clear rxhash (Francesco Fusco) [1057099]
- [net] openvswitch: use CRC32 accelerated flow hash if available (Francesco Fusco) [1057099]
- [lib] hash: follow-up fixups for arch hash (Francesco Fusco) [1057099]
- [lib] hash: Add missing arch generic-y entries for asm-generic/hash.h (Francesco Fusco) [1057099]
- [lib] hash: introduce arch optimized hash library (Francesco Fusco) [1057099]
- [net] rtnl: make ifla_policy static (Jiri Pirko) [1066614]
- [net] ip, ipv6: handle gso skbs in forwarding path (Florian Westphal) [1065299]
- [net] introduce netif_skb_dev_features (Florian Westphal) [1065299]
- [net] add and use skb_gso_transport_seglen() (Florian Westphal) [1065299]
- [net] bridge: separate querier and query timer into IGMP/IPv4 and MLD/IPv6 ones (Florian Westphal) [1065257]
- [net] bridge: send query as soon as leave is received (Florian Westphal) [1065257]
- [net] gro: remove a sparse error (Thomas Graf) [1051111]
- [net] ipv4: Use proper RCU APIs for writer-side in udp_offload.c (Thomas Graf) [1051111]
- [net] vxlan: Go over all candidate streams for GRO matching (Thomas Graf) [1051111]
- [net] ipv4: Use non-atomic allocation of udp offloads structure instance (Thomas Graf) [1051111]
- [net] ipv4: udp_offload: Handle static checker complaints (Thomas Graf) [1051111]
- [net] vxlan: Share RX skb de-marking and checksum checks with ovs (Thomas Graf) [1051111]
- [net] vxlan: Add GRO support for vxlan traffic (Thomas Graf) [1051111]
- [net] vxlan: use __dev_get_by_index instead of dev_get_by_index to find interface (Thomas Graf) [1051111]
- [net] vxlan: keep original skb ownership (Thomas Graf) [1051111]
- [net] vxlan: remove vxlan_group_used in vxlan_open (Thomas Graf) [1051111]
- [net] vxlan: release rt when found circular route (Thomas Graf) [1051111]
- [net] vxlan: Use ERR_CAST inlined function instead of ERR_PTR(PTR_ERR(...)) (Thomas Graf) [1051111]
- [net] vxlan: Have the NIC drivers do less work for offloads (Thomas Graf) [1051111]
- [net] vxlan: silence one build warning (Thomas Graf) [1051111]
- [net] vxlan: Use RCU apis to access sk_user_data (Thomas Graf) [1051111]
- [net] vxlan: Avoid creating fdb entry with NULL destination (Thomas Graf) [1051111]
- [net] vxlan: Fix sparse warnings (Thomas Graf) [1051111]
- [net] vxlan: Notify drivers for listening UDP port changes (Thomas Graf) [1051111]
- [net] vxlan: Optimize vxlan rcv (Thomas Graf) [1051111]
- [net] Export gro_find_by_type helpers (Thomas Graf) [1051111]
- [net] Add GRO support for UDP encapsulating protocols (Thomas Graf) [1051111]
- [net] gro: change GRO overflow strategy (Thomas Graf) [1051111]
- [net] gre_offload: fix sparse non static symbol warning (Thomas Graf) [1051111]
- [net] gre: gro: Add GRE support to the GRO stack (Thomas Graf) [1051111]
- [net] ipv4: don't use module_init in non-modular gre_offload (Thomas Graf) [1051111]
- [net] gre_offload: statically build GRE offloading support (Thomas Graf) [1051111]
- [net] ipv6: Fix alleged compiler warning in ipv6_exthdrs_len() (Thomas Graf) [1051111]
- [net] ipv6: fix compiler warning in ipv6_exthdrs_len (Thomas Graf) [1051111]
- [net] gro: Prepare GRO stack for the upcoming tunneling support (Thomas Graf) [1051111]
- [net] gro: small napi_get_frags() optim (Thomas Graf) [1051111]
- [net] tcp: do not export tcp_gso_segment() and tcp_gro_receive() (Thomas Graf) [1051111]
- [net] gro: Clean up tcpX_gro_receive checksum verification (Thomas Graf) [1051111]
- [net] gro: Only verify TCP checksums for candidates (Thomas Graf) [1051111]
- [net] gso: handle new frag_list of frags GRO packets (Thomas Graf) [1051111]
- [net] gro: allow to build full sized skb (Thomas Graf) [1051111]
- [net] tcp: gso: fix truesize tracking (Thomas Graf) [1051111]
- [net] tcp: rename tcp_tso_segment() (Thomas Graf) [1051111]
- [net] gro: should aggregate frames without DF (Thomas Graf) [1051111]
- [net] sit: fix use after free of fb_tunnel_dev (Jiri Pirko) [1060210]
- [net] sit: allow to use rtnl ops on fb tunnel (Jiri Pirko) [1060210]
- [net] ip6tnl: fix use after free of fb_tnl_dev (Jiri Pirko) [1012835]
- [net] ip6tnl: allow to use rtnl ops on fb tunnel (Jiri Pirko) [1012835]
- [net] ip6tnl: add x-netns support (Jiri Pirko) [1012835]
- [net] Correctly sync addresses from multiple sources to single device (Vlad Yasevich) [1059394]

* Fri Feb 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-92.el7]
- [fs] xfs: ensure correct log item buffer alignment (Brian Foster) [1059843]
- [fs] xfs: ensure correct timestamp updates from truncate (Brian Foster) [1059843]
- [fs] xfs: remove XFS_TRANS_DEBUG dead code (Brian Foster) [1059843]
- [fs] xfs: return -E2BIG if hit the maximum size limits of ACLs (Brian Foster) [1059843]
- [fs] xfs: sanitize sb_inopblock in xfs_mount_validate_sb (Brian Foster) [1059843]
- [fs] xfs: convert xfs_log_commit_cil() to void (Brian Foster) [1059843]
- [fs] xfs: use tr_qm_dqalloc log reservation for dquot alloc (Brian Foster) [1059843]
- [fs] xfs: remove unused tr_swrite (Brian Foster) [1059843]
- [fs] xfs: use tr_growrtalloc for growing rt files (Brian Foster) [1059843]
- [fs] xfs: Calling destroy_work_on_stack() to pair with INIT_WORK_ONSTACK() (Brian Foster) [1059843]
- [fs] xfs: fix off-by-one error in xfs_attr3_rmt_verify (Brian Foster) [1059843]
- [fs] xfs: assert that we hold the ilock for extent map access (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_attr_map_shared in xfs_attr_list_int (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_attr_map_shared in xfs_attr_get (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_data_map_shared in xfs_qm_dqiterate (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_data_map_shared in xfs_qm_dqtobp (Brian Foster) [1059843]
- [fs] xfs: take the ilock around xfs_bmapi_read in xfs_zero_remaining_bytes (Brian Foster) [1059843]
- [fs] xfs: reinstate the ilock in xfs_readdir (Brian Foster) [1059843]
- [fs] xfs: add xfs_ilock_attr_map_shared (Brian Foster) [1059843]
- [fs] xfs: rename xfs_ilock_map_shared (Brian Foster) [1059843]
- [fs] xfs: remove xfs_iunlock_map_shared (Brian Foster) [1059843]
- [fs] xfs: no need to lock the inode in xfs_find_handle (Brian Foster) [1059843]
- [fs] xfs: abort metadata writeback on permanent errors (Brian Foster) [1059843]
- [fs] xfs: swalloc doesn't align allocations properly (Brian Foster) [1059843]
- [fs] xfs: remove xfsbdstrat error (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_imap (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_ifree_cluster (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_ialloc_inode_init (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_bulkstat (Brian Foster) [1059843]
- [fs] xfs: introduce a common helper xfs_icluster_size_fsb (Brian Foster) [1059843]
- [fs] xfs: get rid of XFS_IALLOC_BLOCKS macros (Brian Foster) [1059843]
- [fs] xfs: get rid of XFS_INODE_CLUSTER_SIZE macros (Brian Foster) [1059843]
- [fs] xfs: get rid of XFS_IALLOC_INODES macros (Brian Foster) [1059843]
- [fs] xfs: remove the quotaoff log format from the quotaoff log item (Brian Foster) [1059843]
- [fs] xfs: remove the dquot log format from the dquot log item (Brian Foster) [1059843]
- [fs] xfs: remove the inode log format from the inode log item (Brian Foster) [1059843]
- [fs] xfs: format logged extents directly into the CIL (Brian Foster) [1059843]
- [fs] xfs: format log items write directly into the linear CIL buffer (Brian Foster) [1059843]
- [fs] xfs: introduce xlog_copy_iovec (Brian Foster) [1059843]
- [fs] xfs: refactor xfs_inode_item_format (Brian Foster) [1059843]
- [fs] xfs: refactor xfs_inode_item_size (Brian Foster) [1059843]
- [fs] xfs: refactor xfs_buf_item_format_segment (Brian Foster) [1059843]
- [fs] xfs: remove duplicate code in xlog_cil_insert_format_items (Brian Foster) [1059843]
- [fs] xfs: align initial file allocations correctly (Brian Foster) [1059843]
- [fs] xfs: fix calculation of freed inode cluster blocks (Brian Foster) [1059843]
- [fs] xfs: xfs_dir2_block_to_sf temp buffer allocation fails (Brian Foster) [1059843]
- [fs] xfs: fix infinite loop by detaching the group/project hints from user dquot (Brian Foster) [1059843]
- [fs] xfs: fix assertion failure at xfs_setattr_nonsize (Brian Foster) [1059843]
- [fs] xfs: add xfs_setattr_time (Brian Foster) [1059843]
- [fs] xfs: tiny xfs_setattr_mode cleanup (Brian Foster) [1059843]
- [fs] xfs: fix false assertion at xfs_qm_vop_create_dqattach (Brian Foster) [1059843]
- [fs] xfs: integrate xfs_quota_priv header file to xfs_qm (Brian Foster) [1059843]
- [fs] xfs: make quota metadata truncation behavior consistent to user space (Brian Foster) [1059843]
- [fs] xfs: fix memory leak in xfs_dir2_node_removename (Brian Foster) [1059843]
- [fs] xfs: free the list of recovery items on error (Brian Foster) [1059843]
- [fs] xfs: growfs overruns AGFL buffer on V4 filesystems (Brian Foster) [1059843]
- [fs] xfs: don't perform discard if the given range length is less than block size (Brian Foster) [1059843]
- [fs] xfs: fix the comment explaining xfs_trans_dqlockedjoin (Brian Foster) [1059843]
- [fs] xfs: underflow bug in xfs_attrlist_by_handle() (Brian Foster) [1059843 1034667] {CVE-2013-6382}
- [fs] xfs: remove unused FI_ flags (Brian Foster) [1059843]
- [fs] xfs: open code inc_inode_iversion when logging an inode (Brian Foster) [1059843]
- [fs] xfs: increase inode cluster size for v5 filesystems (Brian Foster) [1059843]
- [fs] xfs: fix unlock in xfs_bmap_add_attrfork (Brian Foster) [1059843]
- [fs] xfs: simplify kmem_(zone_)zalloc (Brian Foster) [1059843]
- [fs] xfs: add tracepoints to AGF/AGI read operations (Brian Foster) [1059843]
- [fs] xfs: trace AIL manipulations (Brian Foster) [1059843]
- [fs] xfs: xfs_remove deadlocks due to inverted AGF vs AGI lock ordering (Brian Foster) [1059843]
- [fs] xfs: fix the extent count when allocating an new indirection array entry (Brian Foster) [1059843]
- [fs] xfs: be more forgiving of a v4 secondary sb w/ junk in v5 fields (Brian Foster) [1059843]
- [fs] xfs: fix possible NULL dereference in xlog_verify_iclog (Brian Foster) [1059843]
- [fs] xfs:xfs_dir2_node.c: pointer use before check for null (Brian Foster) [1059843]
- [fs] xfs: prevent stack overflows from page cache allocation (Brian Foster) [1059843]
- [fs] xfs: fix static and extern sparse warnings (Brian Foster) [1059843]
- [fs] xfs: validity check the directory block leaf entry count (Brian Foster) [1059843]
- [fs] xfs: make dir2 ftype offset pointers explicit (Brian Foster) [1059843]
- [fs] xfs: convert directory vector functions to constants (Brian Foster) [1059843]
- [fs] xfs: convert directory vector functions to constants (Brian Foster) [1059843]
- [fs] xfs: vectorise encoding/decoding directory headers (Brian Foster) [1059843]
- [fs] xfs: vectorise DA btree operations (Brian Foster) [1059843]
- [fs] xfs: vectorise directory leaf operations (Brian Foster) [1059843]
- [fs] xfs: vectorise directory data operations part 2 (Brian Foster) [1059843]
- [fs] xfs: vectorise directory data operations (Brian Foster) [1059843]
- [fs] xfs: vectorise remaining shortform dir2 ops (Brian Foster) [1059843]
- [fs] xfs: abstract the differences in dir2/dir3 via an ops vector (Brian Foster) [1059843]
- [fs] xfs: split xfs_rtalloc.c for userspace sanity (Brian Foster) [1059843]
- [fs] xfs: decouple inode and bmap btree header files (Brian Foster) [1059843]
- [fs] xfs: decouple log and transaction headers (Brian Foster) [1059843]
- [fs] xfs: remove unused transaction callback variables (Brian Foster) [1059843]
- [fs] xfs: split dquot buffer operations out (Brian Foster) [1059843]
- [fs] xfs: unify directory/attribute format definitions (Brian Foster) [1059843]
- [fs] xfs: create a shared header file for format-related information (Brian Foster) [1059843]
- [fs] xfs: fold xfs_change_file_space into xfs_ioc_space (Brian Foster) [1059843]
- [fs] xfs: simplify the fallocate path (Brian Foster) [1059843]
- [fs] xfs: always hold the iolock when calling xfs_change_file_space (Brian Foster) [1059843]
- [fs] xfs: remove the unused XFS_ATTR_NONBLOCK flag (Brian Foster) [1059843]
- [fs] xfs: always take the iolock around xfs_setattr_size (Brian Foster) [1059843]
- [fs] xfs: don't break from growfs ag update loop on error (Brian Foster) [1059843]
- [fs] xfs: don't emit corruption noise on fs probes (Brian Foster) [1059843]
- [fs] xfs: remove newlines from strings passed to __xfs_printk (Brian Foster) [1059843]
- [fs] xfs: prevent deadlock trying to cover an active log (Brian Foster) [1059843]
- [fs] xfs: clean up xfs_inactive() error handling, kill VN_INACTIVE_(NO)CACHE (Brian Foster) [1059843]
- [fs] xfs: push down inactive transaction mgmt for ifree (Brian Foster) [1059843]
- [fs] xfs: push down inactive transaction mgmt for truncate (Brian Foster) [1059843]
- [fs] xfs: push down inactive transaction mgmt for remote symlinks (Brian Foster) [1059843]
- [fs] xfs: add the inode directory type support to XFS_IOC_FSGEOM (Brian Foster) [1059843]
- [fs] xfs: remove usage of is_bad_inode (Brian Foster) [1059843]
- [fs] xfs: fix the wrong new_size/rnew_size at xfs_iext_realloc_direct() (Brian Foster) [1059843]
- [fs] xfs: get rid of count from xfs_iomap_write_allocate() (Brian Foster) [1059843]
- [fs] xfs: Use kmem_free() instead of free() (Brian Foster) [1059843]
- [fs] xfs: fix memory leak in xlog_recover_add_to_trans (Brian Foster) [1059843]
- [fs] xfs: dirent dtype presence is dependent on directory magic numbers (Brian Foster) [1059843]
- [fs] xfs: lockdep needs to know about 3 dquot-deep nesting (Brian Foster) [1059843]
- [fs] xfs: log recovery lsn ordering needs uuid check (Brian Foster) [1059843]
- [fs] xfs: fix XFS_IOC_FREE_EOFBLOCKS definition (Brian Foster) [1059843]
- [fs] xfs: asserting lock not held during freeing not valid (Brian Foster) [1059843]
- [fs] xfs: lock the AIL before removing the buffer item (Brian Foster) [1059843]
- [fs] ext4: yield during large unlinks (Lukas Czerner) [1044544]
- [fs] ext4: implement error handling of ext4_mb_new_preallocation() (Lukas Czerner) [1044544]
- [fs] ext4: return FIEMAP_EXTENT_UNKNOWN for delalloc extents (Lukas Czerner) [1044544]
- [fs] jbd2: fix duplicate debug label for phase 2 (Lukas Czerner) [1044544]
- [fs] jbd2: drop checkpoint mutex when waiting in __jbd2_log_wait_for_space() (Lukas Czerner) [1044544]
- [fs] jbd2: remove unused waitqueues (Lukas Czerner) [1044544]
- [fs] jbd2: fix race in t_outstanding_credits update in jbd2_journal_extend() (Lukas Czerner) [1044544]
- [fs] ext4: fix use of potentially uninitialized variables in debugging code (Lukas Czerner) [1044544]
- [fs] ext4: check error return from ext4_write_inline_data_end() (Lukas Czerner) [1044544]
- [fs] jbd2: relocate assert after state lock in journal_commit_transaction() (Lukas Czerner) [1044544]
- [fs] ext4: add cond_resched() to ext4_free_blocks() & ext4_mb_regular_allocator() (Lukas Czerner) [1044544]
- [fs] ext4: optimize test_root() (Lukas Czerner) [1044544]
- [fs] ext4: add sanity check to ext4_get_group_info() (Lukas Czerner) [1044544]
- [fs] ext4: verify group number in verify_group_input() before using it (Lukas Czerner) [1044544]
- [fs] ext4: add check to io_submit_init_bio (Lukas Czerner) [1044544]
- [fs] Fix race when checking i_size on direct i/o read (Robert S Peterson) [1052927]
- [fs] gfs2: No need to invalidate pages for a dio read (Robert S Peterson) [1052927]
- [fs] gfs2: Wait for async DIO in glock state changes (Robert S Peterson) [1052927]
- [fs] gfs2: Fix incorrect invalidation for DIO/buffered I/O (Robert S Peterson) [1052927]
- [fs] xfs: allow logical-sector sized O_DIRECT (Eric Sandeen) [999239]
- [fs] xfs: rename xfs_buftarg structure members (Eric Sandeen) [999239]
- [fs] xfs: clean up xfs_buftarg (Eric Sandeen) [999239]
- [fs] xfs: simplify xfs_setsize_buftarg callchain; remove unused arg (Eric Sandeen) [999239]
- [fs] sunrpc: Don't create a gss auth cache unless rpc.gssd is running (Steve Dickson) [1063752]
- [fs] gfs2: journal data writepages update (Robert S Peterson) [1010452]
- [fs] nfs: Fix SP4_MACH_CRED negotiation in EXCHANGE_ID (Steve Dickson) [1063509]
- [fs] gfs2: Add hints to directory leaf blocks (Robert S Peterson) [1062143]
- [fs] gfs2: Lock i_mutex and use a local gfs2_holder for fallocate (Robert S Peterson) [1062305]
- [fs] compat: fix lookup_dcookie() parameter handling (Hendrik Brueckner) [1060203]
- [fs] compat: fix parameter handling for compat readv/writev syscalls (Hendrik Brueckner) [1049599]

* Fri Feb 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-91.el7]
- [kernel] sched: Fix endless sync_sched/rcu() loop inside _cpu_down() (Rik van Riel) [1062647]
- [kernel] sched: Remove extra put_online_cpus() inside sched_setaffinity() (Rik van Riel) [1062647]
- [kernel] sched: Remove get_online_cpus() usage (Rik van Riel) [1062647]
- [mm] move mmu notifier call from change_protection to change_pmd_range (Rik van Riel) [1066655]
- [mm] numa: reorganize change_pmd_range (Rik van Riel) [1066655]
- [kernel] sched/numa: add cond_resched to task_numa_work (Rik van Riel) [1066655]
- [cpufreq] intel_pstate: Fail initialization if P-state information is missing (Marcelo Tosatti) [1061481]
- [cpufreq] intel_pstate: Add X86_FEATURE_APERFMPERF to cpu match (Marcelo Tosatti) [1061481]
- [ethernet] bnx2x: More Shutdown revisions (Michal Schmidt) [1046885]
- [ethernet] bnx2x: Don't release PCI bars on shutdown (Michal Schmidt) [1046885]
- [security] keys, shmem: implement kernel private shmem inodes (Paul Moore) [1031154 1034833]

* Wed Feb 19 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-90.el7]
- [drm] nouveau/devinit: prevent use of engines marked as disabled by hw/vbios (Rob Clark) [1054409]
- [drm] nouveau/device: provide a way for devinit to mark engines as disabled (Rob Clark) [1054409]
- [drm] nouveau/devinit: tidy up the subdev class definition (Rob Clark) [1054409]
- [drm] nouveau: populate master subdev pointer only when fully constructed (Rob Clark) [1054409]
- [drm] nouveau/i2c: use a custom bitbanging delay for the adt7473 (Rob Clark) [1054409]
- [drm] nouveau/bios: fix offset calculation for BMPv1 bioses (Rob Clark) [1054409]
- [drm] nouveau: return offset of allocated notifier (Rob Clark) [1054409]
- [drm] nouveau/bios: make jump conditional (Rob Clark) [1054409]
- [drm] nouveau: fix mthd data submission (Rob Clark) [1054409]
- [drm] nouveau/disp: min/max are reversed in nv50_crtc_gamma_set() (Rob Clark) [1054409]
- [drm] nouveau/sw: fix oops if gpu has its display block disabled (Rob Clark) [1054409]
- [drm] nouveau/kms: send timestamp data for correct head in flip completion events (Rob Clark) [1054409]
- [drm] nouveau: do not map evicted vram buffers in nouveau_bo_vma_add (Rob Clark) [1054409]
- [drm] nouveau: shift wrapping bug in nvc0_grctx_generate_r406800 (Rob Clark) [1054409]
- [drm] nouveau: allow nouveau_fence_ref() to be a noop (Rob Clark) [1054409]
- [drm] nouveau: consider CLASS_DISPLAY_3D devices while detecting dsm/optimus (Rob Clark) [1054409]
- [drm] nouveau: only runtime suspend by default in optimus configuration (Rob Clark) [1054409]
- [drm] radeon: set correct pipe config for Hawaii in DCE (Rob Clark) [1054409]
- [drm] radeon: 0x9649 is SUMO2 not SUMO (Rob Clark) [1054409]
- [drm] radeon: expose render backend mask to the userspace (Rob Clark) [1054409]
- [drm] radeon: fix render backend setup for SI and CIK (Rob Clark) [1054409]
- [drm] radeon: fix UVD 256MB check (Rob Clark) [1054409]
- [drm] i915: Use the correct GMCH_CTRL register for Sandybridge+ (Rob Clark) [1054409]
- [drm] i915: change CRTC assertion on LCPLL disable (Rob Clark) [1054409]
- [drm] i915: Fix erroneous dereference of batch_obj inside reset_status (Rob Clark) [1054409]
- [drm] radeon: fix asic gfx values for scrapper asics (Rob Clark) [1054409]
- [drm] radeon: check for 0 count in speaker allocation and SAD code (Rob Clark) [1054409]
- [drm] radeon/dpm: disable ss on Cayman (Rob Clark) [1054409]
- [drm] i915: don't update the dri1 breadcrumb with modesetting (Rob Clark) [1054409]
- [drm] i915: Fix use-after-free in do_switch (Rob Clark) [1054409]
- [drm] i915: Hold mutex across i915_gem_release (Rob Clark) [1054409]
- [drm] i915: Take modeset locks around intel_modeset_setup_hw_state() (Rob Clark) [1054409]
- [drm] radeon: add missing display tiling setup for oland (Rob Clark) [1054409]
- [drm] radeon: fix typo in cik_copy_dma (Rob Clark) [1054409]
- [drm] radeon: Fix sideport problems on certain RS690 boards (Rob Clark) [1054409]
- [drm] ttm: Fix accesses through vmas with only partial coverage (Rob Clark) [1054409]
- [drm] edid: add quirk for BPC in Samsung NP700G7A-S01PL notebook (Rob Clark) [1054409]
- [drm] i915/vlv: fix up broken precision in vlv_crtc_clock_get (Rob Clark) [1054409]
- [drm] i915/vlv: add VLV specific clock_get function v3 (Rob Clark) [1054409]
- [drm] i915/vlv: untangle integrated clock source handling v4 (Rob Clark) [1054409]
- [drm] radeon/atom: fix bus probes when hw_i2c is set (Rob Clark) [1054409]
- [drm] radeon: fixup bad vram size on SI (Rob Clark) [1054409]
- [drm] radeon: program DCE2 audio dto just like DCE3 (Rob Clark) [1054409]
- [drm] radeon: fix typo in fetching mpll params (Rob Clark) [1054409]
- [drm] i915: use the correct force_wake function at the PC8 code (Rob Clark) [1054409]
- [drm] i915: Fix pipe CSC post offset calculation (Rob Clark) [1054409]
- [drm] udl: fix issue with imported prime buffers (Rob Clark) [1054409]
- [drm] radeon: adjust TN dpm parameters for stability (Rob Clark) [1054409]
- [drm] radeon: hook up backlight functions for CI and KV family (Rob Clark) [1054409]
- [drm] radeon/i2c: do not count reg index in number of i2c byte we are writing (Rob Clark) [1054409]
- [drm] radeon: fix UVD destroy IB size (Rob Clark) [1054409]
- [drm] i915: Replicate BIOS eDP bpp clamping hack for hsw (Rob Clark) [1054409]
- [drm] i915: restore the early forcewake cleanup (Rob Clark) [1054409]
- [drm] i915/dvo: call ->mode_set callback only when the port is running (Rob Clark) [1054409]
- [drm] vmwgfx: Resource evict fixes (Rob Clark) [1054409]
- [drm] i915: fix compiler warning (Rob Clark) [1054409]
- [drm] allow DRM_IOCTL_VERSION on render-nodes (Rob Clark) [1054409]
- [drm] i915: Fix the PPT fdi lane bifurcate state handling on ivb (Rob Clark) [1054409]
- [drm] i915: No LVDS hardware on Intel D410PT and D425KT (Rob Clark) [1054409]
- [drm] i915/dp: workaround BIOS eDP bpp clamping issue (Rob Clark) [1054409]
- [drm] i915: Add HSW CRT output readout support (Rob Clark) [1054409]
- [drm] i915: Add support for pipe_bpp readout (Rob Clark) [1054409]
- [drm] radeon/dpm: fix incompatible casting on big endian (Rob Clark) [1054409]
- [drm] radeon: disable bapm on KB (Rob Clark) [1054409]
- [drm] radeon: use sw CTS/N values for audio on DCE4+ (Rob Clark) [1054409]
- [s390] crypto: Fix aes-cbc IV corruption (Hendrik Brueckner) [1063810]
- [s390] appldata: restore missing init_virt_timer() (Hendrik Brueckner) [1064246]
- [s390] mm: Fix dump memory detection (Hendrik Brueckner) [1064244]
- [s390] fix kernel crash due to linkage stack instructions (Hendrik Brueckner) [1059732]
- [s390] crypto: fix des and des3_ede ctr concurrency issue (Hendrik Brueckner) [1062269]
- [s390] crypto: fix des and des3_ede cbc concurrency issue (Hendrik Brueckner) [1062266]
- [s390] crypto: fix concurrency issue in aes-ctr mode (Hendrik Brueckner) [1062260]
- [ethernet] cxgb4: Fix referencing freed adapter (Steve Best) [1063483]
- [mm] oom: base root bonus on current usage (Johannes Weiner) [822790]
- [kernel] lockdep: increase MAX_LOCKDEP_ENTRIES (Kyle McMartin) [989385]
- [scripts] tags.sh: ignore redhat/rpm (Prarit Bhargava) [1065511]
- [security] selinux: Fix kernel BUG on empty security contexts (Paul Moore) [1064548]
- [security] selinux: add SOCK_DIAG_BY_FAMILY to the list of netlink message types (Paul Moore) [1022394]
- [powerpc] eeh: Drop taken reference to driver on eeh_rmv_device (Steve Best) [1059851]
- [scripts] tags.sh: Ignore *.mod.c (Mark Langsdorf) [1062383]
- [mm] keep page cache radix tree nodes in check (Johannes Weiner) [1062372]
- [lib] radix_tree: tree node interface (Johannes Weiner) [1062372]
- [mm] thrash detection-based file cache sizing (Johannes Weiner) [1062372]
- [mm] store shadow entries in page cache (Johannes Weiner) [1062372]
- [lib] radix-tree: radix_tree_delete_item() (Johannes Weiner) [1062372]
- [mm] shmem: save one radix tree lookup when truncating swapped pages (Johannes Weiner) [1062372]
- [mm] prepare for non-page entries in page cache radix trees (Johannes Weiner) [1062372]
- [mm] vmstat: fix UP zone state accounting (Johannes Weiner) [1062372]
- [mm] filemap: move radix tree hole searching here (Johannes Weiner) [1062372]
- [fs] cachefiles: use add_to_page_cache_lru() (Johannes Weiner) [1062372]
- [mm] page_alloc: revert NUMA aspect of fair allocation policy (Johannes Weiner) [1062372]
- [mm] page_alloc: fair zone allocator policy (Johannes Weiner) [1062372]
- [mm] memory-failure: shift page lock from head page to tail page after thp split (Naoya Horiguchi) [1051704]
- [fs] proc/page: add PageAnon check to surely detect thp (Naoya Horiguchi) [1051704]
- [mm] memory-failure: transfer page count from head page to tail page after split thp (Naoya Horiguchi) [1051704]
- [mm] memory-failure: recheck PageHuge() after hugetlb page migrate successfully (Naoya Horiguchi) [1051704]
- [mm] memory-failure: move set_migratetype_isolate() outside get_any_page() (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix false report on 2nd attempt at page recovery (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix test for a transparent huge page (Naoya Horiguchi) [1051704]
- [mm] memory-failure: fix bug triggered by unpoisoning empty zero page (Naoya Horiguchi) [1051704]
- [mm] hwpoison: don't set migration type twice to avoid holding heavily contend zone->lock (Naoya Horiguchi) [1051704]
- [mm] hwpoison: replace atomic_long_sub() with atomic_long_dec() (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix race against poison thp (Naoya Horiguchi) [1051704]
- [mm] hwpoison: don't need to hold compound lock for hugetlbfs page (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix loss of PG_dirty for errors on mlocked pages (Naoya Horiguchi) [1051704]
- [mm] hwpoison: always unset MIGRATE_ISOLATE before returning from soft_offline_page() (Naoya Horiguchi) [1051704]
- [mm] memory-failure: fix memory leak in successful soft offlining (Naoya Horiguchi) [1051704]
- [virt] kvm: move KVM_CAP_HYPERV_TIME outside #ifdef (Vadim Rozenfeld) [1057170]
- [virt] kvm: add support for Hyper-V reference time counter (Vadim Rozenfeld) [1057170]
- [input] wacom: not all multi-interface devices support touch (Aristeu Rozanski) [1022595]
- [input] wacom: add support for three new Intuos Pro devices (Aristeu Rozanski) [1022595]
- [input] wacom: LED is only supported through digitizer interface (Aristeu Rozanski) [1022595]
- [input] wacom: testing result shows get_report is unnecessary (Aristeu Rozanski) [1022595]
- [input] wacom: send proper tablet state info when pen leaves proximity (Aristeu Rozanski) [1022595]
- [input] wacom: fix error return code in wacom_probe() (Aristeu Rozanski) [1022595]
- [input] wacom: integrate resolution calculation (Aristeu Rozanski) [1022595]
- [fs] buffer: __set_page_dirty uses spin_lock_irqsave instead of spin_lock_irq (Motohiro Kosaki) [1057270]
- [mm] __set_page_dirty_nobuffers uses spin_lock_irqseve instead of spin_lock_irq (Motohiro Kosaki) [1057270]
- [virt] hv/ballon: Make pressure posting thread sleep interruptibly (Luiz Capitulino) [1065107]
- [input] hyperv-keyboard: pass through 0xE1 prefix (Jason Wang) [1044874]
- [mm] drop_caches: add some documentation and info message (Johannes Weiner) [838935]
- [scsi] megaraid_sas: Performance boost fixes (Tomas Henzl) [1064509]
- [scsi] megaraid_sas: Set 32-bit DMA mask (Tomas Henzl) [1064509]
- [scsi] megaraid_sas: Big endian code related fixes (Tomas Henzl) [1064509]
- [scsi] megaraid_sas: Don't wait forever for non-IOCTL DCMDs (Tomas Henzl) [1064509]

* Fri Feb 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-89.el7]
- [powerpc] Fix kdump hang issue on p8 with relocation on exception enabled (Steve Best) [1056321]
- [powerpc] pseries: Disable relocation on exception while going down during crash (Steve Best) [1056321]
- [kernel] sched/debug: Fix formatting of /proc/<PID>/sched (Rik van Riel) [1064583]
- [kernel] sched/fair: Remove unused variable from expire_cfs_rq_runtime() (Rik van Riel) [1064583]
- [mm] vmscan: do not scale writeback pages when deciding whether to set ZONE_WRITEBACK (Rafael Aquini) [1009508]
- [mm] vmscan: do not continue scanning if reclaim was aborted for compaction (Rafael Aquini) [1009508]
- [ethernet] bnx2{,x}: Make module parameters readable (Neil Horman) [1062836]
- [ethernet] bnx2x: namespace and dead code cleanups (Neil Horman) [1062836]
- [drm] radeon: remove generic rptr/wptr functions (Steve Best) [1048290]
- [block] nvme: Namespace use after free on surprise removal (David Milburn) [1062640]
- [block] nvme: Correct uses of INIT_WORK (David Milburn) [1062640]
- [block] nvme: Include device and queue numbers in interrupt name (David Milburn) [1062640]
- [block] nvme: Add a pci_driver shutdown method (David Milburn) [1062640]

* Thu Feb 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-88.el7]
- [mm] hugetlb: correct missing private flag clearing (Steve Best) [1062671]
- [mm] hugetlb: return a reserved page to a reserved pool if failed (Steve Best) [1062671]
- [mm] hugetlb: fix subpool accounting handling (Steve Best) [1062671]
- [mm] hugetlb: protect reserved pages when soft offlining a hugepage (Steve Best) [1062671]
- [mm] hugetlb: decrement reserve count if VM_NORESERVE alloc page cache (Steve Best) [1062671]
- [mm] hugetlb: remove decrement_hugepage_resv_vma() (Steve Best) [1062671]
- [mm] hugetlb: clean-up alloc_huge_page() (Steve Best) [1062671]
- [mm] hugetlb: add VM_NORESERVE check in vma_has_reserves() (Steve Best) [1062671]
- [mm] hugetlb: do not use a page in page cache for cow optimization (Steve Best) [1062671]
- [s390] uapi: fix struct statfs64 definition (Hendrik Brueckner) [1060191]
- [ethernet] myri10ge: Add support for ndo_busy_poll (Stanislaw Gruszka) [1059561]
- [ethernet] be2net: add dma_mapping_error() check for dma_map_page() (Ivan Vecera) [995992]
- [infiniband] srp: Avoid offlining operational SCSI devices (Doug Ledford) [1046103]
- [infiniband] srp: Remove target from list before freeing Scsi_Host structure (Doug Ledford) [1046103]
- [infiniband] srp: Add change_queue_depth and change_queue_type support (Doug Ledford) [1046103]
- [infiniband] srp: Make queue size configurable (Doug Ledford) [1046103]
- [infiniband] srp: Introduce srp_alloc_req_data() (Doug Ledford) [1046103]
- [infiniband] srp: Export sgid to sysfs (Doug Ledford) [1046103]
- [infiniband] srp: Add periodic reconnect functionality (Doug Ledford) [1046103]
- [scsi] scsi_transport_srp: Add periodic reconnect support (Doug Ledford) [1046103]
- [infiniband] srp: Start timers if a transport layer error occurs (Doug Ledford) [1046103]
- [infiniband] srp: Use SRP transport layer error recovery (Doug Ledford) [1046103]
- [scsi] scsi_transport_srp: Add transport layer error handling (Doug Ledford) [1046103]
- [infiniband] srp: Keep rport as long as the IB transport layer (Doug Ledford) [1046103]
- [infiniband] srp: Make transport layer retry count configurable (Doug Ledford) [1046103]
- [infiniband] srp: Let srp_abort() return FAST_IO_FAIL if TL offline (Doug Ledford) [1046103]
- [infiniband] srp: Bump driver version and release date (Doug Ledford) [1046103]
- [infiniband] srp: Make HCA completion vector configurable (Doug Ledford) [1046103]
- [infiniband] srp: Maintain a single connection per I_T nexus (Doug Ledford) [1046103]
- [infiniband] srp: Fail I/O fast if target offline (Doug Ledford) [1046103]
- [infiniband] srp: Skip host settle delay (Doug Ledford) [1046103]
- [infiniband] srp: Avoid skipping srp_reset_host() after a transport error (Doug Ledford) [1046103]
- [infiniband] srp: Fix remove_one crash due to resource exhaustion (Doug Ledford) [1046103]
- [infiniband] iser-target: Move INIT_WORK setup into isert_create_device_ib_res (Andy Grover) [1051179]
- [infiniband] iser-target: fix error return code in isert_create_device_ib_res() (Andy Grover) [1051179]
- [target] Fix delayed Task Aborted Status (TAS) handling bug (Andy Grover) [1051179]
- [x86] cpu: Always print SMP information in /proc/cpuinfo (Takahiro MUNEDA) [1062485]
- [x86] add rh_cpuinfo_x86 shadow struct (Prarit Bhargava) [1010325]
- [mm] thp: move preallocated PTE page table on move_huge_pmd() (Rik van Riel) [1063404]
- [mm] numa: initialise numa balancing after jump label initialisation (Rik van Riel) [1059459]
- [firmware] efivars: check for EFI_RUNTIME_SERVICES (Kyle McMartin) [1058525]

* Tue Feb 11 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-87.el7]
- [fs] nfs: fix mm page leak at nfs_symlink() (Rafael Aquini) [1060565]
- [kernel] sched/balancing: Periodically decay max cost of idle balance (Larry Woodman) [1031475]
- [kernel] sched/balancing: Consider max cost of idle balance per sched domain (Larry Woodman) [1031475]
- [kernel] sched: Reduce overestimating rq->avg_idle (Larry Woodman) [1031475]
- [fs] vfs: make sure we don't have a stale root path if unlazy_walk() fails (Rafael Aquini) [1031475]
- [fs] dcache: get/release read lock in read_seqbegin_or_lock() & friend (Rafael Aquini) [1031475]
- [fs] split read_seqretry_or_unlock(), convert d_walk() to resulting primitives (Rafael Aquini) [1031475]
- [lib] seqlock: Add a new locking reader type (Rafael Aquini) [1031475]
- [fs] dcache: Translating dentry into pathname without taking rename_lock (Rafael Aquini) [1031475]
- [fs] vfs: fix dentry RCU to refcounting possibly sleeping dput() (Rafael Aquini) [1031475]
- [fs] vfs: use lockred "dead" flag to mark unrecoverably dead dentries (Rafael Aquini) [1031475]
- [fs] vfs: reorganize dput() memory accesses (Rafael Aquini) [1031475]
- [fs] vfs: reimplement d_rcu_to_refcount() using lockref_get_or_lock() (Rafael Aquini) [1031475]
- [fs] vfs: use lockref_get_not_zero() for optimistic lockless dget_parent() (Rafael Aquini) [1031475]
- [fs] vfs: make the dentry cache use the lockref infrastructure (Rafael Aquini) [1031475]
- [fs] vfs: constify dentry parameter in d_count() (Rafael Aquini) [1031475]
- [fs] helper for reading ->d_count (Rafael Aquini) [1031475]
- [lib] lockref: use arch_mutex_cpu_relax() in CMPXCHG_LOOP() (Rafael Aquini) [1031475]
- [lib] lockref: allow relaxed cmpxchg64 variant for lockless updates (Rafael Aquini) [1031475]
- [lib] lockref: use cmpxchg64 explicitly for lockless updates (Rafael Aquini) [1031475]
- [lib] lockref: add ability to mark lockrefs "dead" (Rafael Aquini) [1031475]
- [lib] lockref: fix docbook argument names (Rafael Aquini) [1031475]
- [lib] lockref: Relax in cmpxchg loop (Rafael Aquini) [1031475]
- [lib] lockref: implement lockless reference count updates using cmpxchg() (Rafael Aquini) [1031475]
- [lib] lockref: uninline lockref helper functions (Rafael Aquini) [1031475]
- [lib] lockref: add 'lockref_get_or_lock() helper (Rafael Aquini) [1031475]
- [lib] Add new lockref infrastructure reference implementation (Rafael Aquini) [1031475]
- [s390] kdump: Increase crashkernel=auto base reservation from 128M to 160M (Baoquan He) [1052769]
- [scsi] Derive the FLUSH_TIMEOUT from the basic I/O timeout (Fam Zheng) [1047563]
- [acpi] Enhance ACPI warning for memory/IO address conflicts (Prarit Bhargava) [1047974]

* Mon Feb 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-86.el7]
- [scsi] hpsa: mark hpsa as a tech preview (Tomas Henzl) [1061210]
- [x86] mark known Intel processors as supported (Prarit Bhargava) [920766]
- [drm] mgag200: fix oops in cursor code (Dave Airlie) [1044701 1045159 1052739]
- [kernel] audit: printk USER_AVC messages when audit isn't enabled (Richard Guy Briggs) [1051539]
- [cpufreq] Do not hold driver module references for additional policy CPUs (Prarit Bhargava) [1043788]
- [cpufreq] Remove extra variables from cpufreq_add_dev_symlink() (Prarit Bhargava) [1043788]
- [net] tuntap: Fix for a race in accessing numqueues (Jason Wang) [1056399]
- [mm] numa: add a sysctl for numa_balancing (Rik van Riel) [1059782]
- [pci] Create 'pci_driver_rh' KABI shadowing structure (Myron Stowe) [1053796]
- [pci] Convert 'pci_bus' allocations and frees (Myron Stowe) [1053796]
- [pci] Create 'pci_bus_rh' KABI shadowing structure (Myron Stowe) [1053796]
- [pci] Convert specific 'pci_dev' related constructs (Myron Stowe) [1053796]
- [pci] Convert 'pci_dev' allocations and frees (Myron Stowe) [1053796]
- [pci] Create 'pci_dev_rh' KABI shadowing structure (Myron Stowe) [1053796]
- [fs] proc/meminfo: provide estimated available memory (Luiz Capitulino) [1058977]
- [x86] apic, kexec: Add disable_cpu_apicid kernel parameter (Baoquan He) [994688]
- [drm] mgag200: fix typo causing bw limits to be ignored on some chips (Dave Airlie) [1045495]
- [drm] ast, cirrus, mgag200: use drm_can_sleep (Dave Airlie) [1056989]
- [mm] prevent setting of a value less than 0 to min_free_kbytes (Steve Best) [1050899]
- [powerpc] perf: BHRB filter configuration should follow the task (Steve Best) [1061191]
- [powerpc] perf: Ignore separate BHRB privilege state filter request (Steve Best) [1061191]
- [ethernet] cxgb4: Avoid disabling PCI device twice (Steve Best) [1055438]
- [ethernet] cxgb4: Don't retrieve stats during recovery (Steve Best) [1055438]

* Fri Feb 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-85.el7]
- [kernel] errno: remove "NFS" from descriptions in comments (Eric Sandeen) [1009682]
- [md] dm-cache: do not add migration to completed list before unhooking bio (Mike Snitzer) [1057197]
- [md] dm-cache: move hook_info into common portion of per_bio_data structure (Mike Snitzer) [1057197]
- [powerpc] Add debug checks to catch invalid cpu-to-node mappings (Steve Best) [1042526]
- [powerpc] Fix the setup of CPU-to-Node mappings during CPU online (Steve Best) [1042526]
- [md] avoid deadlock when dirty buffers during md_stop (Jes Sorensen) [1060027]
- [powerpc] Fix transactional FP/VMX/VSX unavailable handlers (Steve Best) [1052083]
- [powerpc] Don't corrupt transactional state when using FP/VMX in kernel (Steve Best) [1052083]
- [powerpc] Reclaim two unused thread_info flag bits (Steve Best) [1052083]
- [powerpc] Reset MSR_LE on signal entry (Steve Best) [1052083]
- [powerpc] Wrap MSR macros with parentheses (Steve Best) [1052083]
- [powerpc] Make flush_fp_to_thread() nop when CONFIG_PPC_FPU is disabled (Steve Best) [1052083]
- [powerpc] math-emu: Move the flush FPU state function into do_mathemu (Steve Best) [1052083]
- [powerpc] math-emu: Allow math-emu to be used for HW FPU (Steve Best) [1052083]
- [powerpc] remove the unused function disable_kernel_fp() (Steve Best) [1052083]
- [powerpc] Restore dbcr0 on user space exit (Steve Best) [1052083]
- [powerpc] Provide for giveup_fpu/altivec to save state in alternate location (Steve Best) [1052083]
- [powerpc] Put FP/VSX and VR state into structures (Steve Best) [1052083]
- [powerpc] kvm: Don't corrupt guest state when kernel uses VMX (Steve Best) [1052083]
- [powerpc] Fix VRSAVE handling (Steve Best) [1052083]
- [powerpc] Fix a number of sparse warnings (Steve Best) [1052083]
- [powerpc] Align thread->fpr to 16 bytes (Steve Best) [1052083]

* Tue Feb 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-84.el7]
- [s390] Unrevert kvm support patches (Jarod Wilson) [1035261]
- [security] selinux: Fix possible NULL pointer dereference in selinux_inode_permission() (Eric Sandeen) [829715]
- [scsi] qla2xxx: Correctly set the read_optrom pointer for ISP8044 (Chad Dupuis) [1057643]
- [scsi] bnx2fc: Fixed scsi_remove_target soft lockup when rmmod bnx2x (Maurizio Lombardi) [1031770]
- [scsi] config: remove LSI Logic New Generation RAID Device Drivers (Tomas Henzl) [979031]
- [scsi] qla4xxx: v5.04.00.03.07.00-k0 (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Recreate chap data list during get chap operation (Chad Dupuis) [1049707]
- [scsi] qla4xxx: overflow in qla4xxx_set_chap_entry() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix memory leak in qla4xxx_destroy_ddb (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix sparse warnings (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Handle IPv6 AEN notifications (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Update print statements in func qla4xxx_do_dpc() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Update print statements in func qla4xxx_eh_abort() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Update print statements in qla4xxx_mailbox_command() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Updated print for device login, logout path (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Remove unused code from qla4xxx_set_ifcb() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix failure of mbox 0x31 (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Reduce rom-lock contention during reset recovery (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Driver not able to collect minidump for ISP84xx (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix pending IO completion in reset path before initiating chip reset (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix processing response queue during probe (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix failure of IDC Time Extend mailbox command (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Clear DDB index map upon connection close failure (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Return correct error status from func qla4xxx_request_irqs() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fixed AER reset sequence for ISP83xx/ISP84xx (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Correctly handle msleep_interruptible (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Rename ACB_STATE macros with IP_ADDRSTATE macros (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Use IDC_CTRL bit1 directly instead of AF_83XX_NO_FWDUMP flag (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix comments in code (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Print WARN_ONCE() if iSCSI function presence bit removed (Chad Dupuis) [1049707]
- [scsi] qla4xxx: ISP8xxx: Correct retry of adapter initialization (Chad Dupuis) [1049707]
- [scsi] hpsa: allow SCSI mid layer to handle unit attention (Tomas Henzl) [1056703]
- [scsi] hpsa: do not require board "not ready" status after hard reset (Tomas Henzl) [1056703]
- [scsi] hpsa: enable unit attention reporting (Tomas Henzl) [1056703]
- [scsi] hpsa: rename scsi prefetch field (Tomas Henzl) [1056703]
- [scsi] hpsa: use workqueue instead of kernel thread for lockup detection (Tomas Henzl) [1056703]
- [scsi] hpsa: fix pci-ids (Tomas Henzl) [1056703]

* Mon Feb 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-83.el7]
- [tools] perf/stat: Add perf stat --transaction (Prarit Bhargava) [829878]
- [kernel] perf: Add Haswell ULT model number used in Macbook Air and other systems (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Support full width counting (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Add mem-loads/stores support for Haswell (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Support Haswell/v4 LBR format (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Move NMI clearing to end of PMI handler (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Add Haswell PEBS support (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Add Haswell PEBS record support (Prarit Bhargava) [829878]
- [md] dm-log-userspace: allow mark requests to piggyback on flush requests (Mike Snitzer) [1057197]
- [md] dm-space-map-metadata: fix bug in resizing of thin metadata (Mike Snitzer) [1057197]
- [md] dm-cache: add policy name to status output (Mike Snitzer) [1057197]
- [md] dm-thin: fix pool feature parsing (Mike Snitzer) [1057197]
- [md] dm-sysfs: fix a module unload race (Mike Snitzer) [1057197]
- [md] dm-snapshot: use dm-bufio prefetch (Mike Snitzer) [1057197]
- [md] dm-snapshot: use dm-bufio (Mike Snitzer) [1057197]
- [md] dm-snapshot: prepare for switch to using dm-bufio (Mike Snitzer) [1057197]
- [md] dm-snapshot: use GFP_KERNEL when initializing exceptions (Mike Snitzer) [1057197]
- [pci] Rename PCI_VC_PORT_REG1/2 to PCI_VC_PORT_CAP1/2 (Alex Williamson) [1053168]
- [pci] Add Virtual Channel to save/restore support (Alex Williamson) [1053168]
- [pci] Add support for save/restore of extended capabilities (Alex Williamson) [1053168]
- [pci] Add pci_wait_for_pending() (refactor pci_wait_for_pending_transaction()) (Alex Williamson) [1053168]
- [s390] increase CONFIG_NR_CPUS limit (Hendrik Brueckner) [1043827]
- [s390] sclp: fix size of sclp_cpu_info structure (Hendrik Brueckner) [1043827]
- [mm] create a separate slab for page->ptl allocation (Rik van Riel) [1058896]
- [mm] properly separate the bloated ptl from the regular case (Rik van Riel) [1058896]
- [mm] dynamically allocate page->ptl if it cannot be embedded to struct page (Rik van Riel) [1058896]
- [mm] x86: handle pgtable_page_ctor() fail (Rik van Riel) [1058896]
- [mm] s390: handle pgtable_page_ctor() fail (Rik van Riel) [1058896]
- [mm] powerpc: handle pgtable_page_ctor() fail (Rik van Riel) [1058896]
- [mm] allow pgtable_page_ctor() to fail (Rik van Riel) [1058896]
- [mm] x86: add missed pgtable_pmd_page_ctor/dtor calls for preallocated pmds (Rik van Riel) [1058896]
- [mm] x86: enable split page table lock for PMD level (Rik van Riel) [1058896]
- [mm] implement split page table lock for PMD level (Rik van Riel) [1058896]
- [mm] convert the rest to new page table lock api (Rik van Riel) [1058896]
- [mm] hugetlb: convert hugetlbfs to use split pmd lock (Rik van Riel) [1058896]
- [mm] hugetlb: grab a page_table_lock after page_cache_release (Rik van Riel) [1058896]
- [mm] thp: do not access mm->pmd_huge_pte directly (Rik van Riel) [1058896]
- [mm] thp: move ptl taking inside page_check_address_pmd() (Rik van Riel) [1058896]
- [mm] thp: change pmd_trans_huge_lock() to return taken lock (Rik van Riel) [1058896]
- [mm] introduce api for split page table lock for PMD level (Rik van Riel) [1058896]
- [mm] convert mm->nr_ptes to atomic_long_t (Rik van Riel) [1058896]
- [mm] rename USE_SPLIT_PTLOCKS to USE_SPLIT_PTE_PTLOCKS (Rik van Riel) [1058896]
- [mm] avoid increase sizeof(struct page) due to split page table lock (Rik van Riel) [1058896]
- [vfio] vfio-pci: Don't use device_lock around AER interrupt setup (Alex Williamson) [1045175]
- [vfio] vfio-pci: Use pci "try" reset interface (Alex Williamson) [1045175]
- [pci] Add pci_try_reset_function(), pci_try_reset_slot(), pci_try_reset_bus() (Alex Williamson) [1045175]
- [infiniband] make sure the src net is infiniband when create new link (Jay Fenlason) [1049143]

* Fri Jan 31 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-82.el7]
- [mm] Revisit tlb_flushall_shift tuning for page flushes except on IvyBridge (Rik van Riel) [1058886]
- [mm] change tlb_flushall_shift for IvyBridge (Rik van Riel) [1058886]
- [mm] Eliminate redundant page table walk during TLB range flushing (Rik van Riel) [1058886]
- [mm] Clean up inconsistencies when flushing TLB ranges (Rik van Riel) [1058886]
- [mm] thp: avoid PageUnevictable on active/inactive lru lists (Rafael Aquini) [982739]
- [mm] swap: clear PageActive before adding pages onto unevictable list (Rafael Aquini) [982739]
- [mm] remove lru parameter from __lru_cache_add and lru_cache_add_lru (Rafael Aquini) [982739]
- [mm] remove lru parameter from __pagevec_lru_add and remove parts of pagevec API (Rafael Aquini) [982739]
- [mm] activate !PageLRU pages on mark_page_accessed if page is on local pagevec (Rafael Aquini) [982739]
- [mm] pagevec: defer deciding which LRU to add a page to until pagevec drain time (Rafael Aquini) [982739]
- [mm] add tracepoints for LRU activation and insertions (Rafael Aquini) [982739]
- [kernel] audit: fix dangling keywords in audit_log_set_loginuid() output (Richard Guy Briggs) [1045670]
- [kernel] audit: don't generate loginuid log when audit disabled (Richard Guy Briggs) [1045670]
- [kernel] audit: fix type of sessionid in audit_set_loginuid() (Richard Guy Briggs) [1045670]
- [kernel] audit: audit feature to set loginuid immutable (Richard Guy Briggs) [1045670]
- [kernel] audit: audit feature to only allow unsetting the loginuid (Richard Guy Briggs) [1045670]
- [kernel] audit: allow unsetting the loginuid (with priv) (Richard Guy Briggs) [1045670]
- [kernel] audit: remove CONFIG_AUDIT_LOGINUID_IMMUTABLE (Richard Guy Briggs) [1045670]
- [kernel] audit: loginuid functions coding style (Richard Guy Briggs) [1045670]
- [kernel] audit: change decimal constant to macro for invalid uid (Richard Guy Briggs) [1045670]
- [mm] sched/numa: Turn some magic numbers into #defines (Rik van Riel) [1049096]
- [mm] sched/numa: Rename variables in task_numa_fault() (Rik van Riel) [1049096]
- [mm] sched/numa: Do statistics calculation using local variables only (Rik van Riel) [1049096]
- [mm] sched/numa: Normalize faults_cpu stats and weigh by CPU use (Rik van Riel) [1049096]
- [mm] sched/numa: Use active_nodes nodemask to limit numa migrations (Rik van Riel) [1049096]
- [mm] sched/numa: Build per numa_group active node mask from numa_faults_cpu statistics (Rik van Riel) [1049096]
- [mm] sched/numa: Track from which nodes NUMA faults are triggered (Rik van Riel) [1049096]
- [mm] sched/numa: Rename p->numa_faults to numa_faults_memory (Rik van Riel) [1049096]
- [mm] sched/numa: Remove p->numa_migrate_deferred (Rik van Riel) [1049096]
- [mm] sched: Calculate effective load even if local weight is 0 (Rik van Riel) [1049096]
- [net] ipv4: fix tunneled VM traffic over hw VXLAN/GRE GSO NIC (Michal Schmidt) [1031869]
- [net] netfilter: nf_nat: fix access to uninitialized buffer in IRC NAT helper (Daniel Borkmann) [1058782] {CVE-2014-1690}
- [net] packet: fix send path when running with proto == 0 (Jesper Brouer) [1058729]
- [net] packet: fix use after free race in send path when dev is released (Jesper Brouer) [1058729]
- [net] Fix memory leak if TPROXY used with TCP early demux (Florian Westphal) [1054483]
- [net] ipv6: simplify detection of first operational link-local address on interface (Jiri Pirko) [1047425]

* Thu Jan 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-81.el7]
- [infiniband] core: Resolve Ethernet L2 addresses when modifying QP (Doug Ledford) [1051187]
- [infiniband] ocrdma: Populate GID table with IP based gids (Doug Ledford) [1051187]
- [infiniband] ocrdma: Handle Ethernet L2 parameters for IP based GID addressing (Doug Ledford) [1051187]
- [infiniband] mlx4: Handle Ethernet L2 parameters for IP based GID addressing (Doug Ledford) [1051187]
- [infiniband] mlx4: Use IBoE (RoCE) IP based GIDs in the port GID table (Doug Ledford) [1051187]
- [infiniband] cma: IBoE (RoCE) IP based GID addressing (Doug Ledford) [1051187]
- [infiniband] core: Ethernet L2 attributes in verbs/cm structures (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix OCRDMA_GEN2_FAMILY macro definition (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix AV_VALID bit position (Doug Ledford) [1051187]
- [infiniband] ocrdma: enable build (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove redundant check in ocrdma_build_fr() (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix a crash in rmmod (Doug Ledford) [1051187]
- [infiniband] ocrdma: Silence an integer underflow warning (Doug Ledford) [1051187]
- [infiniband] Remove unnecessary semicolons (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix compiler warning about int/pointer size mismatch (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix passing wrong opcode to modify_srq (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fill PVID in UMC case (Doug Ledford) [1051187]
- [infiniband] ocrdma: Add ABI versioning support (Doug Ledford) [1051187]
- [infiniband] ocrdma: Consider multiple SGES in case of DPP (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix for displaying proper link speed (Doug Ledford) [1051187]
- [infiniband] ocrdma: Increase STAG array size (Doug Ledford) [1051187]
- [infiniband] ocrdma: Dont use PD 0 for userpace CQ DB (Doug Ledford) [1051187]
- [infiniband] ocrdma: FRMA code cleanup (Doug Ledford) [1051187]
- [infiniband] ocrdma: For ERX2 irrespective of Qid, num_posted offset is 24 (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix to work with even a single MSI-X vector (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove the MTU check based on Ethernet MTU (Doug Ledford) [1051187]
- [infiniband] ocrdma: Add support for fast register work requests (FRWR) (Doug Ledford) [1051187]
- [infiniband] ocrdma: Create IRD queue fix (Doug Ledford) [1051187]
- [infiniband] ocrdma: Cache recv DB until QP moved to RTR (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove __packed (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove driver QP state machine (Doug Ledford) [1051187]
- [infiniband] ocrdma: Don't allow zero/invalid sgid usage (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove redundant dev reference (Doug Ledford) [1051187]
- [infiniband] ocrdma: Style and redundant code cleanup (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix several stack info leaks (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove unused include (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix error return code in ocrdma_set_create_qp_rq_cmd() (Doug Ledford) [1051187]
- [infiniband] ocrdma: Reorg structures to avoid padding (Doug Ledford) [1051187]
- [infiniband] ocrdma: Change macros to inline funtions (Doug Ledford) [1051187]
- [infiniband] ocrdma: Set bad_wr in error case (Doug Ledford) [1051187]
- [infiniband] ocrdma: Replace ocrdma_err with pr_err (Doug Ledford) [1051187]
- [infiniband] ocrdma: Use MCC_CREATE_EXT_V1 for MCC create (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove use_cnt for queues (Doug Ledford) [1051187]
- [infiniband] uverbs: Check access to userspace response buffer in extended command (Doug Ledford) [1051187]
- [infiniband] uverbs: Check input length in flow steering uverbs (Doug Ledford) [1051187]
- [infiniband] uverbs: Set error code when fail to consume all flow_spec items (Doug Ledford) [1051187]
- [infiniband] uverbs: Check reserved fields in create_flow (Doug Ledford) [1051187]
- [infiniband] uverbs: Check comp_mask in destroy_flow (Doug Ledford) [1051187]
- [infiniband] uverbs: Check reserved field in extended command header (Doug Ledford) [1051187]
- [infiniband] uverbs: New macro to set pointers to NULL if length is 0 in INIT_UDATA() (Doug Ledford) [1051187]
- [infiniband] core: const'ify inbuf in struct ib_udata (Doug Ledford) [1051187]
- [infiniband] iwcm: Don't touch cm_id after deref in rem_ref (Doug Ledford) [1051187]
- [infiniband] ucma: Convert use of typedef ctl_table to struct ctl_table (Doug Ledford) [1051187]
- [infiniband] cm: Convert to using idr_alloc_cyclic() (Doug Ledford) [1051187]
- [infiniband] core: Encorce MR access rights rules on kernel consumers (Doug Ledford) [1051187]
- [infiniband] cma: Remove unused argument and minor dead code (Doug Ledford) [1051187]
- [infiniband] ucma: Discard events for IDs not yet claimed by user space (Doug Ledford) [1051187]
- [infiniband] core: Add Cisco usNIC rdma node and transport types (Doug Ledford) [1051187]
- [infiniband] netlink: Remove superfluous RDMA_NL_GET_OP() masking (Doug Ledford) [1051187]
- [infiniband] core: Pass imm_data from ib_uverbs_send_wr to ib_send_wr correctly (Doug Ledford) [1051187]
- [infiniband] cma: Check for GID on listening device first (Doug Ledford) [1051187]
- [infiniband] cma: Use cached gids (Doug Ledford) [1051187]
- [infiniband] cma: Set IBoE SL (user-priority) by egress map when using vlans (Doug Ledford) [1051187]
- [infiniband] cma: Add IPv6 support for iWARP (Doug Ledford) [1051187]
- [infiniband] cma: Only call cma_save_ib_info() for CM REQs (Doug Ledford) [1051187]
- [infiniband] cma: Fix accessing invalid private data for UD (Doug Ledford) [1051187]
- [infiniband] cma: Fix gcc warning (Doug Ledford) [1051187]
- [infiniband] uverbs: Use get_unused_fd_flags(O_CLOEXEC) instead of get_unused_fd() (Doug Ledford) [1051187]
- [misc] drivers: avoid format string in dev_set_name (Doug Ledford) [1051187]
- [infiniband] core: Fix error return code in add_port() (Doug Ledford) [1051187]
- [infiniband] cma: Export AF_IB statistics (Doug Ledford) [1051187]
- [infiniband] ucma: Allow user space to specify AF_IB when joining multicast (Doug Ledford) [1051187]
- [infiniband] ucma: Allow user space to pass AF_IB into resolve (Doug Ledford) [1051187]
- [infiniband] ucma: Allow user space to bind to AF_IB (Doug Ledford) [1051187]
- [infiniband] ucma: Name changes to indicate only IP addresses supported (Doug Ledford) [1051187]
- [infiniband] ucma: Add ability to query GID addresses (Doug Ledford) [1051187]
- [infiniband] cma: Export cma_get_service_id() (Doug Ledford) [1051187]
- [infiniband] ucma: Support querying when IB paths are not reversible (Doug Ledford) [1051187]
- [infiniband] sa: Export function to pack a path record into wire format (Doug Ledford) [1051187]
- [infiniband] ucma: Support querying for AF_IB addresses (Doug Ledford) [1051187]
- [infiniband] cma: Only listen on IB devices when using AF_IB (Doug Ledford) [1051187]
- [infiniband] cma: Set qkey for AF_IB (Doug Ledford) [1051187]
- [infiniband] cma: Expose private data when using AF_IB (Doug Ledford) [1051187]
- [infiniband] cma: Merge cma_get/save_net_info (Doug Ledford) [1051187]
- [infiniband] cma: Remove unused SDP related code (Doug Ledford) [1051187]
- [infiniband] cma: Add support for AF_IB to cma_get_service_id() (Doug Ledford) [1051187]
- [infiniband] cma: Add support for AF_IB to rdma_resolve_route() (Doug Ledford) [1051187]
- [infiniband] cma: Add support for AF_IB to rdma_resolve_addr() (Doug Ledford) [1051187]
- [infiniband] cma: Verify that source and dest sa_family are the same (Doug Ledford) [1051187]
- [infiniband] cma: Restrict AF_IB loopback to binding to IB devices only (Doug Ledford) [1051187]
- [infiniband] cma: Add helper functions to return id address information (Doug Ledford) [1051187]
- [infiniband] cma: Do not modify sa_family when setting loopback address (Doug Ledford) [1051187]
- [infiniband] cma: Allow user to specify AF_IB when binding (Doug Ledford) [1051187]
- [infiniband] cma: Update port reservation to support AF_IB (Doug Ledford) [1051187]
- [infiniband] addr: Add AF_IB support to ip_addr_size (Doug Ledford) [1051187]
- [infiniband] cma: Include AF_IB in loopback and any address checks (Doug Ledford) [1051187]
- [infiniband] cma: Allow enabling reuseaddr in any state (Doug Ledford) [1051187]
- [infiniband] cma: Define native IB address (Doug Ledford) [1051187]
- [net] vlan: Fix header ops passthru when doing TX VLAN offload (Doug Ledford) [1051187]
- [net] vlan: Implement vlan_dev_get_egress_qos_mask as an inline (Doug Ledford) [1051187]
- [net] vlan: Provide read access to the vlan egress map (Doug Ledford) [1051187]
- [net] vlan: make vlan_dev_real_dev work over stacked vlans (Doug Ledford) [1051187]
- [net] vlan: cleanup the usage of vlan_dev_priv(dev) (Doug Ledford) [1051187]
- [ethernet] mlx4: Remove unnecessary validation for port number (Amir Vadai) [1030563]
- [ethernet] mlx4: Warn if device doesn't have enough PCI bandwidth (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: lower NAPI weight (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Start multicast join process only on active ports (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Add path query flushing in ipoib_ib_dev_cleanup (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix usage of uninitialized multicast objects (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Avoid flushing the driver workqueue on dev_down (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix deadlock between dev_change_flags() and __ipoib_dev_flush() (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Change CM skb memory allocation to be non-atomic during init (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix crash in dev_open error flow (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix race in deleting ipoib_neigh entries (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Only cycle port if HW timestamp config changes (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add PTP hardware clock (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix layout of struct mlx5_init_seg (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Flush cache workqueue before destroying it (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add netdev support for TCP/IP offloads of vxlan tunneling (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add basic support for TCP/IP offloads under tunneling (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Check port number for validity before accessing data (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add NAPI support for transmit side (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Ignore irrelevant hypervisor events (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Set CQE/EQE size to 64B by default (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Configure the XPS queue mapping on driver load (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Implement ndo_get_phys_port_id (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Expose physical port id as PF/VF capability (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Introduce nic_info new flag in QUERY_FUNC_CAP (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Rename QUERY_FUNC_CAP fields (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Remove zeroed out of explicit QUERY_FUNC_CAP fields (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Roll back round robin bitmap allocation commit for CQs, SRQs, and MPTs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: destroy workqueue when driver fails to register (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Remove selftest TX queues empty condition (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Re-enable create_flow/destroy_flow uverbs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: extended command: an improved infrastructure for uverbs commands (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Remove ib_uverbs_flow_spec structure from userspace (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Use a common header for uverbs flow_specs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Make uverbs flow structure use names like verbs ones (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Rename 'flow' structs to match other uverbs structs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: clarify overflow/underflow checks on ib_create/destroy_flow (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix page shift in create CQ for userspace (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx4: Fix device max capabilities check (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix list_del of empty list (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Remove dead code (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx4: Fix endless loop in resize CQ (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Use enum to indicate adapter page size (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Update opt param mask for RTS2RTS (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Remove "Always false" comparison (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Remove dead code in mr.c (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Change optimal_reclaimed_pages for better performance (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Clear reserved area in set_hca_cap() (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Support communicating arbitrary host page size to firmware (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Fix cleanup flow when DMA mapping fails (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix srq free in destroy qp (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Simplify mlx5_ib_destroy_srq (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix overflow check in IB_WR_FAST_REG_MR (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Multithreaded create MR (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix check of number of entries in create CQ (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Datapath structures are allocated per NUMA node (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: ICM pages are allocated on device NUMA node (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Datapath resources allocated dynamically (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add immediate activate for VGT->VST->VGT (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Initialize all mailbox buffers to zero before use (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add RFS support in UDP (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Implement resource quota enforcement (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix quota handling in the QUERY_FUNC_CAP wrapper (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Structures and init/teardown for VF resource quotas (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix checking order in MR table init (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Don't fail reg/unreg vlan for older guests (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Resource tracker for reg/unreg vlans (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Use vlan id instead of vlan index for unregistration (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix reg/unreg vlan/mac to conform to the firmware spec (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix register/unreg vlan flow (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Temporarily disable create_flow/destroy_flow uverbs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Load higher level modules according to ports type (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Unused local variable in mlx4_opreq_action (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix typo, move similar defs to same location (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Clean the code to eliminate trivial build warnings (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Ensure proper synchronization accessing memory (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix alignment of reg umr gather buffers (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix eq names to display nicely in /proc/interrupts (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Fix error code translation from firmware to driver (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix opt param mask according to firmware spec (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix opt param mask for sq err to rts transition (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Disable atomic operations (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Keep polling to reclaim pages while any returned (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Avoid async events on invalid port number (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Decrease memory consumption of mr caches (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Remove checksum on command interface commands (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix memory leak in mlx5_ib_create_srq (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix send work queue size calculation (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Rename name of mlx4_en_rx_alloc members (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Check device state when setting coalescing (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Reduce scope of local variables in mlx4_en_xmit (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [scsi] reserve extension space to prevent KABI breakages (Maurizio Lombardi) [1029903]
- [security] selinux: selinux_setprocattr()->ptrace_parent() needs rcu_read_lock() (Paul Moore) [800159]

* Mon Jan 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-80.el7]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.24 (Veaceslav Falico) [1040946]
- [acpi] memhotplug: add parameter to disable memory hotplug (Prarit Bhargava) [1046555]
- [kernel] kdump: Increase x86 crashkernel=auto base reservation from 128M to 160M (Baoquan He) [1044832]
- [mfd] lpc_ich: Add support for Intel Avoton SoC (Prarit Bhargava) [1049638]
- [net] ipv6: send Change Status Report after DAD is completed (Flavio Leitner) [1049092]
- [mm] Revert: new shrinker count/scan API (Mike Snitzer) [1056647]
- [drm] Revert: convert shrinkers to new count/scan API (Mike Snitzer) [1056647]

* Thu Jan 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-79.el7]
- [virt] virtio-net: put virtio net header inline with data ("Michael S. Tsirkin") [990993]
- [virt] virtio: VIRTIO_F_ANY_LAYOUT feature ("Michael S. Tsirkin") [990993]
- [tools] turbostat: servers do not support uncore power register (Prarit Bhargava) [1037706]
- [alsa] pcsp: Fix the order of input device unregistration (Jaroslav Kysela) [1044022]
- [alsa] ak4114: Fix wrong register array size (Jaroslav Kysela) [1044022]
- [alsa] pcsp: Fix initialization with nopcm=1 (Jaroslav Kysela) [1044022]
- [alsa] opl3: Fix possible negative array index access (Jaroslav Kysela) [1044022]
- [alsa] tea575x-tuner: move HW init to a separate function (Jaroslav Kysela) [1044022]
- [alsa] ak4xx-adda: info leak in ak4xxx_capture_source_info() (Jaroslav Kysela) [1044022]
- [alsa] vx_core: off by one in vx_read_status() (Jaroslav Kysela) [1044022]
- [alsa] Remove the rest of *_set_drvdata(NULL) calls (Jaroslav Kysela) [1044022]
- [alsa] virmidi: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] serial-u16550: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] pcsp: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] mtpav: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] mpu401: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] ml403-ac97cr: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] aloop: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] firewire-lib: use inlune function to calculate frame bytes (Jaroslav Kysela) [1044022]
- [alsa] firewire-speakers: remove not-reused member from structure (Jaroslav Kysela) [1044022]
- [alsa] snd-firewire-lib: remove unused header inclusion (Jaroslav Kysela) [1044022]
- [alsa] firewire: fix error return code in scs_probe() (Jaroslav Kysela) [1044022]
- [alsa] hda: Add Dell headset detection quirk for three laptop models (Jaroslav Kysela) [1044022]
- [alsa] hda: Add enable_msi=0 workaround for four HP machines (Jaroslav Kysela) [1044022]
- [alsa] hda: Split verb definitions into sound/hda_verbs.h (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable stereo mix as default for AD and VIA codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Ignore small negative LPIB delay correction (Jaroslav Kysela) [1044022]
- [alsa] hda: Add missing initialization of aamix paths (Jaroslav Kysela) [1044022]
- [alsa] hda: Allow capture-only configuration (Jaroslav Kysela) [1044022]
- [alsa] hda: skip depop delay before D3 for Haswell and Valleyview2 display codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Clean up async codec PM using standard async infrastructure (Jaroslav Kysela) [1044022]
- [alsa] hda: fixup ALC262 to skip depop delay before D3 on Intel BayleyBay (Jaroslav Kysela) [1044022]
- [alsa] hda: Always do delayed probes for HD-audio devices (Jaroslav Kysela) [1044022]
- [alsa] hda: allow a codec to define its own depop delay time (Jaroslav Kysela) [1044022]
- [alsa] hda: fixup ALC262 to remove depop delay on Intel BayleyBay board (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Remove depop delay for suspend and resume if applicable (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Add more codecs alias name for Dell (Jaroslav Kysela) [1044022]
- [alsa] hda: resume codecs in parallel (Jaroslav Kysela) [1044022]
- [alsa] hda: suspend codecs in parallel (Jaroslav Kysela) [1044022]
- [alsa] hda: Disable runtime PM when EPSS is unavailable (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable runtime PM on Panther Point (Jaroslav Kysela) [1044022]
- [alsa] hda: Refactor pm notification in hda_codec.c (Jaroslav Kysela) [1044022]
- [alsa] hda: Bind with HDMI codec parser automatically (Jaroslav Kysela) [1044022]
- [alsa] hda: Split the generic parser as an individual module (Jaroslav Kysela) [1044022]
- [alsa] hda: Add static DAC/pin mapping for AD1986A codec (Jaroslav Kysela) [1044022]
- [alsa] hda: One more Dell headset detection quirk (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix IEC958 ctl indexes for some simple HDMI devices (Jaroslav Kysela) [1044022]
- [alsa] hda: Mute all aamix inputs as default (Jaroslav Kysela) [1044022]
- [alsa] hda: Another Dell headset detection quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: A Dell headset detection quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove quirk for Dell Vostro 131 (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: fix uninitialized variable compile warning (Jaroslav Kysela) [1044022]
- [alsa] hda: fix mic issues on Acer Aspire E-572 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix silent output on MacBook Air 2,1 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix missing ELD info when using jackpoll_ms parameter (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: remove hp_automute_hook from alc283_fixup_chromebook (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Independent of model for HP (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix headset mic input after muted internal mic (Dell/Realtek) (Jaroslav Kysela) [1044022]
- [alsa] hda: Use always amps for auto-mute on AD1986A codec (Jaroslav Kysela) [1044022]
- [alsa] hda/analog: Handle inverted EAPD properly in vmaster hook (Jaroslav Kysela) [1044022]
- [alsa] hda: Another fixup for ASUS laptop with ALC660 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix complete_all() timing in deferred probes (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix bad EAPD setup for HP machines with AD1984A (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix silent output on ASUS W7J laptop (Jaroslav Kysela) [1044022]
- [alsa] hda: Add mono speaker quirk for Dell Inspiron 5439 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add LFE chmap to ASUS ET2700 (Jaroslav Kysela) [1044022]
- [alsa] hda: Initialize missing bass speaker pin for ASUS AIO ET2700 (Jaroslav Kysela) [1044022]
- [alsa] hda: limit mic boost on Asus UX31[A,E] (Jaroslav Kysela) [1044022]
- [alsa] hda: Check leaf nodes to find aamix amps (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix hp-mic mode without VREF bits (Jaroslav Kysela) [1044022]
- [alsa] hda: Create Headhpone Mic Jack Mode when really needed (Jaroslav Kysela) [1044022]
- [alsa] usb: use multiple packets per urb for Wireless USB inbound audio (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable mute/mic-mute LEDs for more Thinkpads with Conexant codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop bus->avoid_link_reset flag (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Set pcbeep amp for ALC668 (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Add support of ALC231 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Set current_headset_type to ALC_HEADSET_TYPE_ENUM (Jaroslav Kysela) [1044022]
- [alsa] hda: Provide missing pin configs for VAIO with ALC260 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add headset quirk for Dell Inspiron 3135 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix the headphone jack detection on Sony VAIO TX (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix missing bass speaker on ASUS N550 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix unbalanced runtime PM notification at resume (Jaroslav Kysela) [1044022]
- [alsa] hda: A casual Dell Headset quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Also enable mute/micmute LED control for "Lenovo dock" fixup (Jaroslav Kysela) [1044022]
- [alsa] hda: Select FW_LOADER from CONFIG_SND_HDA_CODEC_CA0132_DSP (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable mute/mic-mute LEDs for more Thinkpads with Realtek codec (Jaroslav Kysela) [1044022]
- [alsa] hda: load EQ params into IDT codec on HP bNB13 systems (Jaroslav Kysela) [1044022]
- [alsa] jack: Unregister input device at disconnection (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add front jack channel selector for EMU0204 (Jaroslav Kysela) [1044022]
- [alsa] hda: Don't clear the power state at snd_hda_codec_reset() (Jaroslav Kysela) [1044022]
- [alsa] hda: Control EAPD for Master volume on Lenovo N100 (Jaroslav Kysela) [1044022]
- [alsa] hda: Don't turn off EAPD for headphone on Lenovo N100 (Jaroslav Kysela) [1044022]
- [alsa] hda: Check keep_eapd_on before inv_eapd (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix Line Out automute on Realtek multifunction jacks (Jaroslav Kysela) [1044022]
- [alsa] compress_core: don't return -EBADFD from poll if paused (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix wrong baseline length in ATI/AMD generated ELD (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Skip out-of-range latency values in AMD ELD generator (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add error-checking to some codec reads (Jaroslav Kysela) [1044022]
- [alsa] usb: Fix wrong mapping of RLC and RRC channels (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Use TFx channel positions instead of FxH (Jaroslav Kysela) [1044022]
- [alsa] hda: Control SPDIF out pin on MacBookPro 11,2 (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Add new codec ALC255/ALC3234 UAJ supported (Jaroslav Kysela) [1044022]
- [alsa] hda: Apply MacBook fixups for CS4208 correctly (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Make fixup regs persist after resume (Jaroslav Kysela) [1044022]
- [alsa] hda_intel: ratelimit "spurious response" message (Jaroslav Kysela) [1044022]
- [alsa] hda: Get rid of AMD HDMI exception in hdmi_present_sense() (Jaroslav Kysela) [1044022]
- [alsa] ice1724: Fix compile warning with CONFIG_PROC_FS=n (Jaroslav Kysela) [1044022]
- [alsa] hda: block HDMI jack reports while repolling (Jaroslav Kysela) [1044022]
- [alsa] hda: Add a block_report flag to jacks (Jaroslav Kysela) [1044022]
- [alsa] hda: Delay HDMI presence reports while waiting for ELD information (Jaroslav Kysela) [1044022]
- [alsa] compress: fix drain calls blocking other compress functions (Jaroslav Kysela) [1044022]
- [alsa] hda: Another Dell headset quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Add pincfg fixup for ASUS W5A (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support for CX20952 (Jaroslav Kysela) [1044022]
- [alsa] lx6464es: Fix pointer cast compile warnings (Jaroslav Kysela) [1044022]
- [alsa] hda: Limit mic boost and add mute LED for an HP machine (Jaroslav Kysela) [1044022]
- [alsa] hda: Make sure mute LEDs stay on during runtime suspend (Realtek) (Jaroslav Kysela) [1044022]
- [alsa] ctxfi: Use WARN_ON() instead of BUG_ON() (Jaroslav Kysela) [1044022]
- [alsa] intel8x0: Fix chmap application (Jaroslav Kysela) [1044022]
- [alsa] hda: Apply GPIO setup for MacBooks with CS4208 (Jaroslav Kysela) [1044022]
- [alsa] hda: Name Haswell HDMI controllers better (Jaroslav Kysela) [1044022]
- [alsa] hda: Force buffer alignment for Haswell HDMI controllers (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable Thinkpad mute/micmute LEDs for Realtek (Jaroslav Kysela) [1044022]
- [alsa] hda: add device IDs for AMD Evergreen/Northern Islands HDMI (Jaroslav Kysela) [1044022]
- [alsa] hda: Introduce the bitmask for excluding output volume (Jaroslav Kysela) [1044022]
- [alsa] hda: Add sanity check of vmaster slave dB steps (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix possible zero-division (Jaroslav Kysela) [1044022]
- [alsa] usb: Don't trust the channel config if the channel count changed (Jaroslav Kysela) [1044022]
- [alsa] usb: For class 2 devices, use channel map from altsettings (Jaroslav Kysela) [1044022]
- [alsa] usb: supply channel maps even when wChannelConfig is unspecified (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable SPDIF for Acer TravelMate 6293 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add Device IDs for Intel Wildcat Point-LP PCH (Jaroslav Kysela) [1044022]
- [alsa] hda: rename function not_share_unassigned_cvt() (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Disallow unsupported 2ch remapping on NVIDIA codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: not choose assigned converters for unused pins of Valleyview (Jaroslav Kysela) [1044022]
- [alsa] hda: Add extra chmap for 2.1 outputs on ASUS laptops (Jaroslav Kysela) [1044022]
- [alsa] hda: Disable AA-loopback on ALC283 Chromebook (Jaroslav Kysela) [1044022]
- [alsa] lola: Fix uninitialized variable access in error message (Jaroslav Kysela) [1044022]
- [alsa] ice1724: Fix uninitialized variable access (Jaroslav Kysela) [1044022]
- [alsa] rme96: Return error code in PCM copy ops (Jaroslav Kysela) [1044022]
- [alsa] ali5451: Drop unused variable (Jaroslav Kysela) [1044022]
- [alsa] ad1889: Fix right attenuation proc output (Jaroslav Kysela) [1044022]
- [alsa] Use strlcpy() instead of strncpy() (Jaroslav Kysela) [1044022]
- [alsa] Limit the fallback card id string size (Jaroslav Kysela) [1044022]
- [alsa] memalloc: NULL-initialize in snd_malloc_dev_iram() (Jaroslav Kysela) [1044022]
- [alsa] memalloc: Make snd_{malloc|free}_dev_iram() static (Jaroslav Kysela) [1044022]
- [alsa] Optimize module name check (Jaroslav Kysela) [1044022]
- [alsa] pcm: Add fallthru comments (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove locally dead codes (Jaroslav Kysela) [1044022]
- [alsa] hda: Add a fallthru comment (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix possible NULL dereference in snd_hda_get_pin_label() (Jaroslav Kysela) [1044022]
- [alsa] 6fire: Fix probe of multiple cards (Jaroslav Kysela) [1044022]
- [alsa] memalloc: Yet another ifdef CONFIG_GENERIC_ALLOCATOR protection (Jaroslav Kysela) [1044022]
- [alsa] pcm_dmaengine: Remove hardcoded PCM formats (Jaroslav Kysela) [1044022]
- [alsa] hda: Sync EAPD with vmaster on AD1984A Thinkpads (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix silent headphone on Thinkpads with AD1984A codec (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Re-setup pin and infoframe on plug-in on all codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Disable ramp-up/down for non-PCM on AMD codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add HBR bitstreaming support for ATI/AMD HDMI codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add ELD emulation for ATI/AMD codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add ATI/AMD multi-channel audio support (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Allow HDA patches to customize more operations (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Raise the delay for alc283_shutup (Jaroslav Kysela) [1044022]
- [alsa] compress: fix drain calls blocking other compress functions (Jaroslav Kysela) [1044022]
- [alsa] Add ifdef CONFIG_GENERIC_ALLOCATOR for SNDRV_DMA_TYPE_IRAM code (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix mute LED on HP laptops in runtime suspend (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support of ALC285 / ALC293 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support of ALC255 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove OOM message after input_allocate_device (Jaroslav Kysela) [1044022]
- [alsa] Add SoC on-chip internal ram support for DMA buffer allocation (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix typos in patch_hdmi.c (Jaroslav Kysela) [1044022]
- [alsa] hda: add codec ID for Valleyview2 display codec (Jaroslav Kysela) [1044022]
- [alsa] emu10k1: code refactoring (Jaroslav Kysela) [1044022]
- [alsa] hda: Move mutex from hda_eld to per_pin in HDMI codec driver (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix possible races in HDMI driver (Jaroslav Kysela) [1044022]
- [alsa] hda: Treat zero connection as non-error (Jaroslav Kysela) [1044022]
- [alsa] hda: add connection to thinkpad_acpi to control mute/micmute LEDs (Jaroslav Kysela) [1044022]
- [alsa] hda: add HDA_FIXUP_ACT_FREE action (Jaroslav Kysela) [1044022]
- [alsa] hdsp: info leak in snd_hdsp_hwdep_ioctl() (Jaroslav Kysela) [1044022]
- [alsa] Remove unnecessary semicolons (Jaroslav Kysela) [1044022]
- [alsa] hda: Sony VAIO Pro 13 (haswell) now has a working headset jack (Jaroslav Kysela) [1044022]
- [alsa] hda: Add a headset mic model for ALC269 and friends (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable surround speakers (when line out is also present) (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: Use module_usb_driver (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: support wireless devices in snd_usb_parse_datainterval (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add support for wireless USB devices (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Tweak debug messages to be more useful (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix available channel maps missing from TLV (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix channel maps with less common speakers (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix unused slots being enabled in manual and non-PCM mappings (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix programmed active channel count (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix incorrect default channel mapping for unusual CAs (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove unused endpoint flag EP_FLAG_ACTIVATED (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: rename alt_idx to altsetting (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: clear SUBSTREAM_FLAG_SYNC_EP_STARTED on error (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: void return type of snd_usb_endpoint_deactivate() (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: don't deactivate URBs on in-use EP (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove deactivate_endpoints() (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove unused parameter from sync_ep_set_params (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix mono speakers and headset mic on Dell Vostro 5470 (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-caiaq: LED support for Maschine Controller (Jaroslav Kysela) [1044022]
- [alsa] ac97: Add ID for TI TLV320AIC27 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable internal mic on a Thinkpad machine with ALC283 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix Internal Mic boost can't control with ALC283 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add fixup for MacBook Air 6,1 and 6,2 with CS4208 codec (Jaroslav Kysela) [1044022]
- [alsa] improve buffer size computations for USB PCM audio (Jaroslav Kysela) [1044022]
- [alsa] hda: not use assigned converters for all unused pins (Jaroslav Kysela) [1044022]
- [alsa] compress: Make sure we trigger STOP before closing the stream (Jaroslav Kysela) [1044022]
- [alsa] rme9652: Remove redundant break (Jaroslav Kysela) [1044022]
- [alsa] au88x0: Remove redundant break (Jaroslav Kysela) [1044022]
- [alsa] hda/ca0132: Staticize codec_send_command (Jaroslav Kysela) [1044022]
- [alsa] ctxfi: Staticize local symbols (Jaroslav Kysela) [1044022]
- [alsa] asihpi: a couple array out of bounds issues (Jaroslav Kysela) [1044022]
- [alsa] hda: Add CS4208 codec support for MacBook 6,1 and 6,2 (Jaroslav Kysela) [1044022]
- [alsa] hda: unmute pin amplifier in infoframe setup for Haswell (Jaroslav Kysela) [1044022]
- [alsa] hda: define is_haswell() to check if a display audio codec is Haswell (Jaroslav Kysela) [1044022]
- [alsa] hda: Add dock speaker support for ASUS TX300 (Jaroslav Kysela) [1044022]
- [alsa] snd/hda: add runtime suspend/resume on optimus support (Jaroslav Kysela) [1044022]
- [alsa] hda: Simplify CONFIG_SND_HDA_I915 condition (Jaroslav Kysela) [1044022]
- [alsa] hda: add device entry and inactive flag to unsolicited response (Jaroslav Kysela) [1044022]
- [alsa] hda: Haswell codec exposes device list/select info on pins (Jaroslav Kysela) [1044022]
- [alsa] hda: add device list & select info of display pins to codec proc file (Jaroslav Kysela) [1044022]
- [alsa] hda: add flags and routines to get devices selection info for DP1.2 MST (Jaroslav Kysela) [1044022]
- [alsa] treewide: Fix printks with 0x# (Jaroslav Kysela) [1044022]
- [alsa] alsa/rme96: Add missing inclusion of linux/vmalloc.h (Jaroslav Kysela) [1044022]
- [alsa] rme96: Check the return value of pci_enable_device() in resume callback (Jaroslav Kysela) [1044022]
- [alsa] hda: Add workarounds for pop-noise on Chromebook with ALC283 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix ALC283 headphone pop-noise better (Jaroslav Kysela) [1044022]
- [alsa] rme96: Add PM support v3 (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use enums in hdspm_tco_ltc_frames() (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Fix default value in SNDRV_HDSPM_IOCTL_GET_LTC (Jaroslav Kysela) [1044022]
- [alsa] pcm: Use snd_printd_ratelimit() (Jaroslav Kysela) [1044022]
- [alsa] pcm: Add snd_printd_ratelimit() (Jaroslav Kysela) [1044022]
- [alsa] hda: Try to allow haswell HDMI audio even without powerwell (Jaroslav Kysela) [1044022]
- [alsa] hda: Limit internal mic boost for a few more Thinkpad machines (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix the order of a quirk table (janitorial) (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix internal mic boost on three Thinkpad machines (Jaroslav Kysela) [1044022]
- [alsa] rme96: Add pcm stream synchronization (Jaroslav Kysela) [1044022]
- [alsa] hda: Mute the right widget in auto_mute_via_amp mode (Jaroslav Kysela) [1044022]
- [alsa] hda: Allow auto_mute_via_amp on bind mute controls (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: fix automatic Roland/Yamaha MIDI detection (Jaroslav Kysela) [1044022]
- [alsa] don't push static constants on stack for *ph (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: WARN_ON when alts is passed as NULL (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove implicit_fb from quirk (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove is_playback from implicit feedback quirks (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: do not initialize and check implicit_fb (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: reverse condition logic in set_sync_endpoint (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: move implicit fb quirks to separate function (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: separate sync endpoint setting from set_format (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove assignment from if condition (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove disabled debug code in set_format (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix jack gating when auto_{mute,mic} is suppressed (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix invalid multi-io creation on VAIO-Z laptops (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove analog mic pin override from STAC9228 dell-bios quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: WAKEEN feature enabling for runtime pm (Jaroslav Kysela) [1044022]
- [alsa] hda: jack poll once if jackpoll_interval==0 (Jaroslav Kysela) [1044022]
- [alsa] hda: Clearing jackpoll_interval avoid pending work (Jaroslav Kysela) [1044022]
- [alsa] usx2y: remove an unneeded check (Jaroslav Kysela) [1044022]
- [alsa] hda: use azx_writew() for 16-bit length register (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix the noise after suspend on ALC283 codec (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Selectively call snd_hda_shutup_pins() (Jaroslav Kysela) [1044022]
- [alsa] hiface: return correct XRUN indication (Jaroslav Kysela) [1044022]
- [alsa] replace strict_strto*() with kstrto*() (Jaroslav Kysela) [1044022]
- [alsa] hda: Add snd_hda_jack_detect_state() helper function (Jaroslav Kysela) [1044022]
- [alsa] thinkpad-acpi: Add mute and mic-mute LED functionality (Jaroslav Kysela) [1044022]
- [alsa] hda: Headphone mic support for an Asus/Conexant device (Jaroslav Kysela) [1044022]
- [alsa] hdspm: remove unneeded semicolon (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: fix regression for fixed stream quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1986A codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop a few other static quirks for AD1986A (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop static quirk for Toshiba Satellite L40-10Q (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop static quirks for other AD1986A Samsung machines (Jaroslav Kysela) [1044022]
- [alsa] hda: Convert static quirks for AD1986A Samsung laptops (Jaroslav Kysela) [1044022]
- [alsa] hda: Convert the static quirk for Samsung Q1 Ultra (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1988 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1981 and AD1983 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1884/1984 & variants (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1882 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add fixup for HP TouchSmart with AD1984A codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Add fixup for Lenovo Thinkpad with AD1984 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Add GPIO control to AD1884 HP fixup (Jaroslav Kysela) [1044022]
- [alsa] hda: Move azx_first_init() into azx_probe_continue() (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix runtime PM check (Jaroslav Kysela) [1044022]
- [alsa] hda: Add power-welll support for haswell HDA (Jaroslav Kysela) [1044022]
- [alsa] hda: Keep halting ALC5505 DSP (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Added some comments and control register documentation (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use snd_ctl_enum_info() in snd_hdspm_info_autosync_ref (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use snd_ctl_enum_info() for texts_autosync (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use snd_ctl_enum_info for most text arrays (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Enable TCO support (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Report external sample rate to userspace (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce hdspm_external_rate_to_enum() helper function (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Include TCO and Sync-In in proc output (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Enable TCO/Sync-In in snd_hdspm_put_sync_ref() (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Enable TCO input in hdspm_external_sample_rate() (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Ignore float/int format bit (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Enable AES32 in hdspm_get_tco_sample_rate (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Enable AES32 in hdspm_get_wc_sample_rate (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add prototype declarations (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce hdspm_get_aes_sample_rate() (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Add TCO and Sync-In text entries (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aio: Drop superfluous HDSPM_AUTOSYNC_REF (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Cosmetics, no real change (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Fix TCO sync check reporting (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Create TCO readout function (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Fix S/PDIF Sync status and frequency on RME AIO (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add support for AEBs on RME AIO (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Enable AD/DA/PH gains and S/PDIF-Input select on AIO (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce generic AIO tristate control (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Refactor ENUMERATED_CTL_INFO into function (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add S/PDIF, XLR, WCK48 and ADAT-in controls for RME AIO cards (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add S/PDIF and WCK48 controls for RME RayDAT (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Drop duplicate code in hdspm_set_system_clock_mode() (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Augment HDSPM_TOGGLE_SETTING for AIO/RayDAT (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce hdspm_is_raydat_or_aio() (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add missing defines for RME AIO and RayDAT (Jaroslav Kysela) [1044022]
- [alsa] vmaster: Fix the regression of missing vmaster hook call (Jaroslav Kysela) [1044022]
- [alsa] hda: Add Dell SSID to support Headset Mic recording (Jaroslav Kysela) [1044022]
- [alsa] pcm_native: switch to fdget()/fdput() (Jaroslav Kysela) [1044022]
- [alsa] treewide: relase -> release (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: Add Audio Advantage Micro II (Jaroslav Kysela) [1044022]
- [alsa] Replace the magic number 44 with const (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support for ALC5505 DSP power-save mode (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add quirks for Roland QUAD/OCTO-CAPTURE (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: claim autodetected PCM interfaces all at once (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove superfluous Roland quirks (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add MIDI port names for some Roland devices (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add support for many Roland/Yamaha devices (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: detect implicit feedback on Roland devices (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: store protocol version in struct audioformat (Jaroslav Kysela) [1044022]
- [alsa] pci: replace numeric with standard PM state macros (Jaroslav Kysela) [1044022]
- [alsa] hda: Add missing alc_inv_dmic_sync() call in alc269_resume() (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove superfluous stac_resume() (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: poll eld at resume time (Jaroslav Kysela) [1044022]
- [alsa] hda: clean up code to reset hda link (Jaroslav Kysela) [1044022]
- [alsa] hda: Add In-driver connection info (Jaroslav Kysela) [1044022]
- [alsa] hda: Use auto_mute_via_amp=1 for VT1708 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add auto_mute_via_amp flag to generic parser (Jaroslav Kysela) [1044022]
- [alsa] vmaster: Add snd_ctl_sync_vmaster() helper function (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove unused variable (Jaroslav Kysela) [1044022]
- [alsa] hda: reset hda link during system/runtime suspend (Jaroslav Kysela) [1044022]
- [alsa] Add M2Tech hiFace USB-SPDIF driver (Jaroslav Kysela) [1044022]
- [alsa] usb: uniform style used in MODULE_SUPPORTED_DEVICE() (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-6fire: use vmalloc buffers (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-caiaq: use vmalloc buffers (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-caiaq: remove the unused snd_card_used variable (Jaroslav Kysela) [1044022]
- [alsa] hda: Make Thinkpad X220-tablet use generic parser (Jaroslav Kysela) [1044022]
- [alsa] hda: Use snd_hda_check_power_state() in patch_hdmi.c (Jaroslav Kysela) [1044022]
- [alsa] hda: Avoid choose same converter for unused pins (Jaroslav Kysela) [1044022]
- [alsa] hda: Haswell converter power state D0 verify (Jaroslav Kysela) [1044022]
- [alsa] ua101: convert __list_for_each usage to list_for_each (Jaroslav Kysela) [1044022]
- [alsa] usx2y: remove some old dead code (Jaroslav Kysela) [1044022]
- [alsa] hda: Don't take unresponsive D3 transition too serious (Jaroslav Kysela) [1044022]
- [alsa] hda: Introduce bit flags to snd_hda_codec_read/write() (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop hard dependency on CONFIG_SND_DYNAMIC_MINORS (Jaroslav Kysela) [1044022]
- [alsa] hda/via: Use standard snd_hda_shutup_pins() (Jaroslav Kysela) [1044022]
- [alsa] hda: add mic fixup for ALC269VB on Ordissimo EVE2 (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Allow SingleSpeed WordClock when in DS/QS mode (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Refactor SS/DS/QS clock multiplier into function (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add support for 128-192kHz WordClock input (Jaroslav Kysela) [1044022]
- [alsa] es1968: Add radio support for MediaForte M56VAP (Jaroslav Kysela) [1044022]
- [alsa] pci: Remove superfluous pci_set_drvdata(pci, NULL) at remove (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable mic-mute LED on more HP laptops (Jaroslav Kysela) [1044022]
- [alsa] Add kconfig to specify the max card numbers (Jaroslav Kysela) [1044022]
- [alsa] Fix the default suffix string with high card number (Jaroslav Kysela) [1044022]
- [alsa] Constify the snd_pcm_substream struct ops field (Jaroslav Kysela) [1044022]
- [alsa] hda: add PCI IDs for Intel BayTrail (Jaroslav Kysela) [1044022]
- [alsa] Fix assignment of 0/1 to bool variables (Jaroslav Kysela) [1044022]

* Tue Jan 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-78.el7]
- [scsi] hpsa: remove cancelled ID's and add a new one (Tomas Henzl) [1040644]
- [scsi] hpsa: bump driver version to 3.4.2-1 (Tomas Henzl) [1040644]
- [scsi] hpsa: add 4 new PCI ID's for HP Gen9 servers (Tomas Henzl) [1040644]

* Tue Jan 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-77.el7]
- [s390] revert kvm support patches (Jarod Wilson) [1035261 1049469]
- [block] nvme: Disable admin queue on init failure (David Milburn) [1049584]
- [block] nvme: Dynamically allocate partition numbers (David Milburn) [1049584]
- [block] nvme: Async IO queue deletion (David Milburn) [1049584]
- [block] nvme: Surprise removal handling (David Milburn) [1049584]
- [block] nvme: Abort timed out commands (David Milburn) [1049584]
- [block] nvme: Schedule reset for failed controllers (David Milburn) [1049584]
- [block] nvme: Device resume error handling (David Milburn) [1049584]
- [block] nvme: Cache dev->pci_dev in a local pointer (David Milburn) [1049584]
- [block] nvme: Fix lockdep warnings (David Milburn) [1049584]
- [block] nvme: compat SG_IO ioctl (David Milburn) [1049584]
- [block] nvme: remove deprecated IRQF_DISABLED (David Milburn) [1049584]
- [block] nvme: Avoid shift operation when writing cq head doorbell (David Milburn) [1049584]
- [block] nvme-core: replace dma_set_mask()+dma_set_coherent_mask() with new helper (David Milburn) [1049584]
- [ethernet] be2net: update driver version to 10.0.x (Ivan Vecera) [1054092]
- [ethernet] be2net: cleanup wake-on-lan code (Ivan Vecera) [1054092]
- [ethernet] be2net: use GET_MAC_LIST cmd to query mac-address from a pmac-id (Ivan Vecera) [1054092]
- [ethernet] be2net: do not use frag index in the RX-compl entry (Ivan Vecera) [1054092]
- [ethernet] be2net: Remove "10Gbps" from driver description string (Ivan Vecera) [1054092]
- [ethernet] be2net: fix incorrect setting of cmd_privileges for VFs (Ivan Vecera) [1054092]
- [ethernet] be2net: ignore mac-addr set call for an already programmed mac-addr (Ivan Vecera) [1054092]
- [ethernet] be2net: do not call be_set/get_fw_log_level() on Skyhawk-R (Ivan Vecera) [1054092]
- [ethernet] be2net: Log the profile-id used by FW during driver initialization (Ivan Vecera) [1054092]
- [ethernet] be2net: don't set "pport" field when querying "pvid" (Ivan Vecera) [1054092]
- [ethernet] be2net: Use MCC_CREATE_EXT_V1 cmd for Skyhawk-R (Ivan Vecera) [1054092]
- [infiniband] qib: Convert qib_user_sdma_pin_pages() to use get_user_pages_fast() (Jay Fenlason) [725023]
- [infiniband] qib: Improve SDMA performance (Jay Fenlason) [725023]
- [infiniband] qib: Fix txselect regression (Jay Fenlason) [725023]
- [infiniband] qib: Fix checkpatch __packed warnings (Jay Fenlason) [725023]
- [infiniband] qib: fix (some) dcache abuses (Jay Fenlason) [725023]
- [infiniband] qib: Remove GENERIC_HARDIRQ config option (Jay Fenlason) [725023]
- [infiniband] qib: Move COUNTER_MASK definition within qib_mad.h header guards (Jay Fenlason) [725023]
- [infiniband] qib: Clean up unnecessary MSI/MSI-X capability find (Jay Fenlason) [725023]
- [infiniband] qib: Make qib_driver static (Jay Fenlason) [725023]
- [infiniband] qib: Add err_decode() call for ring dump (Jay Fenlason) [725023]
- [infiniband] qib: Log all SDMA errors unconditionally (Jay Fenlason) [725023]
- [infiniband] qib: Fix module-level leak (Jay Fenlason) [725023]
- [infiniband] qib: New transmitter tunning settings for Dell 1.1 backplane (Jay Fenlason) [725023]
- [infiniband] qib: Add qp_stats debug file (Jay Fenlason) [725023]
- [infiniband] qib: Add per-context stats interface (Jay Fenlason) [725023]
- [infiniband] qib: Convert opcode counters to per-context (Jay Fenlason) [725023]
- [infiniband] qib: Optimize CQ callbacks (Jay Fenlason) [725023]
- [infiniband] qib: Add dual-rail NUMA awareness for PSM processes (Jay Fenlason) [725023]
- [infiniband] qib: Add optional NUMA affinity (Jay Fenlason) [725023]
- [infiniband] qib: Update minor version number (Jay Fenlason) [725023]
- [infiniband] qib: Remove atomic_inc_not_zero() from QP RCU (Jay Fenlason) [725023]
- [infiniband] qib: Add DCA support (Jay Fenlason) [725023]
- [infiniband] qib: avoid format string in dev_set_name (Jay Fenlason) [725023]
- [tools] power/turbostat: Support Silvermont (Lenny Szubowicz) [1048051]
- [ethernet] bnx2: Update version to 2.2.5 (Neil Horman) [1051172]
- [ethernet] bnx2: Report MDI/MDIX status to ethtool (Neil Horman) [1051172]
- [ethernet] bnx2: Enable auto-mdix when autoneg is disabled (Neil Horman) [1051172]
- [ethernet] bnx2: Advertise nothing when speed is forced (Neil Horman) [1051172]
- [ethernet] bnx2: calls skb_set_hash (Neil Horman) [1051172]
- [ethernet] bnx2: remove unnecessary pci_set_drvdata() (Neil Horman) [1051172]
- [ethernet] bnx2: Miscellaneous conversions to ETH_ALEN (Neil Horman) [1051172]
- [kernel] thermal: Disable power limit notification interrupt by default (Prarit Bhargava) [1050198]
- [kernel] thermal: Delete power-limit-notification console messages (Prarit Bhargava) [1050198]
- [x86] mce: Fix mce_start_timer semantics (Prarit Bhargava) [1045845]
- [x86] Add check for number of available vectors before CPU down (Prarit Bhargava) [1045845]
- [ethernet] i40evf: fix s390 build failure due to implicit prefetch.h (Stefan Assmann) [1053147]
- [ethernet] i40evf: A0 silicon specific (Stefan Assmann) [1053147]
- [ethernet] i40evf: add driver to kernel build system (Stefan Assmann) [1053147]
- [ethernet] i40evf: init code and hardware support (Stefan Assmann) [1053147]
- [ethernet] i40evf: driver core headers (Stefan Assmann) [1053147]
- [ethernet] i40evf: virtual channel interface (Stefan Assmann) [1053147]
- [ethernet] i40evf: core ethtool functionality (Stefan Assmann) [1053147]
- [ethernet] i40evf: transmit and receive functionality (Stefan Assmann) [1053147]
- [ethernet] i40evf: main driver core (Stefan Assmann) [1053147]
- [pci] Never treat a VF as a multifunction device (Alex Williamson) [1049716]

* Fri Jan 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-76.el7]
- [scsi] aacraid: kdump fix (Rich Bono) [1019091]
- [scsi] lpfc: update version for 8.3.7.34.3p driver release (Rob Evers) [1025854]
- [scsi] lpfc: Fixed unassigned variable in ELS timeout message (Rob Evers) [1025854]
- [scsi] lpfc: Fixed incorrect allocation of iDiags directories/files in debugfs (Rob Evers) [1025854]
- [scsi] lpfc: Fix kernel panics from corrupted ndlp list (Rob Evers) [1025854]
- [scsi] lpfc: Fix Crash in lpfc_els_timeout_handler (Rob Evers) [1025854]
- [scsi] lpfc: Fixed stopped FCF discovery on failed FCF record read (Rob Evers) [1025854]
- [scsi] lpfc: Fixed IO hang when in msi mode (Rob Evers) [1025854]
- [scsi] lpfc: Fix wrong assignment in lpfc_debugfs.c (Rob Evers) [1025854]
- [scsi] lpfc: Fix typo on NULL assignment (Rob Evers) [1025854]
- [scsi] lpfc: Update lpfc version for 8.3.7.34.1p driver release (Rob Evers) [1025854]
- [scsi] lpfc: Fixed not processing task management IOCB response status (Rob Evers) [1025854]
- [scsi] lpfc: Fixed spinlock hang (Rob Evers) [1025854]
- [scsi] lpfc: Fixed invalid Total_Data_Placed value received for els and ct command responses (Rob Evers) [1025854]
- [scsi] lpfc: Fixed invalid fcp_rsp length fir FCP_ICMND (Rob Evers) [1025854]
- [scsi] lpfc: Fixed invalid mailbox timeouts (Rob Evers) [1025854]
- [scsi] lpfc: Fixed spinlock inversion problem (Rob Evers) [1025854]
- [scsi] lpfc: Fix crash after xri limit is reached (Rob Evers) [1025854]
- [scsi] lpfc: remove unnecessary read of PCI_CAP_ID_EXP (Rob Evers) [1025854]

* Fri Jan 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-75.el7]
- [kernel] audit: log task info on feature change (Richard Guy Briggs) [1050425]
- [kernel] keys: correct alignment of system_certificate_list content in assembly file (Hendrik Brueckner) [1038139]
- [kernel] system_certificate: use real contents instead of macro GLOBAL() (Hendrik Brueckner) [1038139]
- [kernel] audit: don't generate audit feature changed log when audit disabled (Richard Guy Briggs) [1045668]
- [kernel] audit: fix incorrect order of log new and old feature (Richard Guy Briggs) [1045668]
- [kernel] selinux: apply selinux checks on new audit message types (Richard Guy Briggs) [1045668]
- [kernel] audit: implement generic feature setting and retrieving (Richard Guy Briggs) [1045668]
- [s390] smp: improve setup of possible cpu mask (Hendrik Brueckner) [1052906]
- [iommu] intel-iommu: fix off-by-one in pagetable freeing (Myron Stowe) [1048955]
- [mm] page_alloc: honor min_free_kbytes set by user (Steve Best) [1047779]
- [kernel] mutex: Do not unnecessarily deal with waiters (Larry Woodman) [1031475]
- [ethernet] tg3: Update version to 3.136 (Ivan Vecera) [1048557]
- [ethernet] tg3: Poll cpmu link state on APE + ASF enabled devices (Ivan Vecera) [1048557]
- [ethernet] tg3: Set the MAC clock to the fastest speed during boot code load (Ivan Vecera) [1048557]
- [ethernet] tg3: Add unicast filtering support (Ivan Vecera) [1048557]
- [ethernet] tg3: Refactor __tg3_set_mac_addr() (Ivan Vecera) [1048557]
- [ethernet] tg3: Expand 4g_overflow_test workaround to skb fragments of any size (Ivan Vecera) [1048557]
- [ethernet] tg3: Initialize REG_BASE_ADDR at PCI config offset 120 to 0 (Ivan Vecera) [1048557]
- [ethernet] tg3: Update version to 3.135 (Ivan Vecera) [1048557]
- [ethernet] tg3: Expand multicast drop counter miscounting fix to 5762 (Ivan Vecera) [1048557]
- [ethernet] tg3: Fix bit definition for the nvram Auto Power Down setting (Ivan Vecera) [1048557]
- [ethernet] tg3: Add flag to disable 1G Half Duplex advertisement (Ivan Vecera) [1048557]
- [ethernet] tg3: Don't add rxbds_empty to rx_over_errors (Ivan Vecera) [1048557]
- [ethernet] tg3: Give up chip reset and carrier loss handling if PCI device is not present (Ivan Vecera) [1048557]
- [ethernet] tg3: Validate hwtstamp_config completely before applying it (Ivan Vecera) [1048557]
- [ethernet] tg3: avoid double-freeing of rx data memory (Ivan Vecera) [1048557]
- [ethernet] bnx2x: fix DMA unmapping of TSO split BDs (Michal Schmidt) [1043794]
- [ethernet] bnx2x: fix VLAN configuration for VFs (Michal Schmidt) [1038666]
- [ethernet] bnx2x: fix AFEX memory overflow (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Clean before update RSS arrives (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Correct number of MSI-X vectors for VFs (Michal Schmidt) [1038666]
- [ethernet] bnx2x: limit number of interrupt vectors for 57711 (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix KR2 work-around detection of BCM8073 (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix incorrect link-up report (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix Duplex setting for 54618se (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix passive DAC cable detection (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix 578xx-KR 1G link (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix build with SRIOV disabled (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add VF Multicast filters support (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Add num of VFs to Management statistics (Michal Schmidt) [1038666]
- [ethernet] bnx2x: no error when RSS configuration fails (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add Big-Endian ethtool comment (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Add AER support (missing bits) (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Add support for Multi-Function UNDI (Michal Schmidt) [1038666]
- [ethernet] bnx2x: downgrade "valid ME register value" message level (Michal Schmidt) [1038666]
- [ethernet] bnx2x: cleanup skb_set_hash (Michal Schmidt) [1038666]
- [ethernet] bnx2x: calls skb_set_hash (Michal Schmidt) [1038666]
- [ethernet] bnx2x: avoid null pointer dereference when enabling SR-IOV (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add TSO support for SIT tunnels (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add TSO support for IPIP (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Prevent "timeout waiting for state X" (Michal Schmidt) [1038666]
- [ethernet] bnx2x: prevent CFC attention (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Prevent panic during DMAE timeout (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Clean the sp rtnl task upon unload (Michal Schmidt) [1038666]
- [ethernet] bnx2x: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Michal Schmidt) [1038666]
- [misc] list: introduce list_next_entry() and list_prev_entry() (Michal Schmidt) [1038666]
- [virt] kvm: fix apic_base enable check (Marcelo Tosatti) [1053143]
- [virt] kvm: fix x86 emulation of "movzbl bpl, eax" (Marcelo Tosatti) [1053143]
- [virt] kvm: limit PIT timer frequency (Marcelo Tosatti) [1053143]
- [virt] kvm: fix tsc catchup issue with tsc scaling (Marcelo Tosatti) [1053143]
- [virt] kvm: handle invalid root_hpa everywhere (Marcelo Tosatti) [1053143]
- [virt] kvm/mmu: handle invalid root_hpa at __direct_map (Marcelo Tosatti) [1053143]
- [virt] kvm/vmx: fix use after free of vmx->loaded_vmcs (Marcelo Tosatti) [1053143]
- [virt] kvm: Fix APIC map calculation after re-enabling (Marcelo Tosatti) [1053143]
- [virt] kvm: emulate SAHF instruction (Marcelo Tosatti) [1053143]
- [virt] flags: Rename X86_EFLAGS_BIT1 to X86_EFLAGS_FIXED (Marcelo Tosatti) [1053143]
- [virt] kvm: Mapping IOMMU pages after updating memslot (Marcelo Tosatti) [1053143]
- [fs] aio: checking for NULL instead of IS_ERR (Motohiro Kosaki) [995323]

* Fri Jan 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-74.el7]
- [net] bridge: Fix memory leak when deleting bridge with vlan filtering enabled (Vlad Yasevich) [1031068]
- [net] bridge: Call vlan_vid_del for all vids at nbp_vlan_flush (Vlad Yasevich) [1031068]
- [net] bridge: Use vlan_vid_[add/del] instead of direct ndo_vlan_rx_[add/kill]_vid calls (Vlad Yasevich) [1031068]
- [net] ipv6: add link-local, sit and loopback address with INFINITY_LIFE_TIME (Jiri Pirko) [1054095]
- [net] ipv6: don't install anycast address for /128 addresses on routers (Jiri Pirko) [1054095]
- [net] ipv6: addrconf: fix preferred lifetime state-changing behavior while valid_lft is infinity (Jiri Pirko) [1054095]
- [net] ipv4: processing ancillary IP_TOS or IP_TTL (Francesco Fusco) [1054160]
- [net] ipv4: IP_TOS and IP_TTL can be specified as ancillary data (Francesco Fusco) [1054160]
- [net] netfilter: synproxy: correct wscale option passing (Jesper Brouer) [1054076]
- [net] netfilter: synproxy: send mss option to backend (Jesper Brouer) [1054076]
- [net] ipv6: addrconf: don't cleanup prefix route for IFA_F_NOPREFIXROUTE (Jiri Pirko) [1052884]
- [net] ipv6: addrconf: add IFA_F_NOPREFIXROUTE flag to suppress creation of IP6 routes (Jiri Pirko) [1052884]
- [net] ipv6: addrconf spelling fixes (Jiri Pirko) [1052884]
- [net] ipv6: unneccessary to get address prefix in addrconf_get_prefix_route (Jiri Pirko) [1052884]
- [net] bridge: apply multicast snooping to IPv6 link-local, too (Francesco Fusco) [1051501]
- [net] bridge: prevent flooding IPv6 packets that do not have a listener (Francesco Fusco) [1051501]
- [net] ipv6: don't call fib6_run_gc() until routing is ready (Florian Westphal) [1052111]
- [net] ipv6: always set the new created dst's from in ip6_rt_copy (Neil Horman) [1050828]
- [net] vxlan: Mark vxlan_dev flags with VXLAN_F_IPV6 properly (Thomas Graf) [1049141]
- [net] netfilter: RHEL7 kABI prepare struct netns_ct (Jesper Brouer) [1030994]
- [net] reorder struct netns_ct for better cache-line usage (Jesper Brouer) [1030994]
- [net] ipv6: release dst properly in ipip6_tunnel_xmit (Michal Schmidt) [1038708]
- [net] ipv6: sit: update mtu check to take care of gso packets (Michal Schmidt) [1038708]
- [net] ipv6: sit: add GSO/TSO support (Michal Schmidt) [1038708]
- [net] ipv6: gso: make ipv6_gso_segment() stackable (Michal Schmidt) [1038708]
- [net] ipv6: wire up skb->encapsulation (Michal Schmidt) [1038708]
- [net] ipip: add GSO/TSO support (Michal Schmidt) [1038708]
- [net] inet: fix a UFO regression (Michal Schmidt) [1038708]
- [net] inet: restore gso for vxlan (Michal Schmidt) [1038708]
- [net] ipv4: gso: make inet_gso_segment() stackable (Michal Schmidt) [1038708]
- [net] ipv4: gso: send_check() & segment() cleanups (Michal Schmidt) [1038708]
- [net] generalize skb_segment() (Michal Schmidt) [1038708]
- [net] ipv4: generalize gre_handle_offloads (Michal Schmidt) [1038708]

* Thu Jan 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-73.el7]
- [kernel] audit: audit_log_start running on auditd should not stop (Richard Guy Briggs) [1019895]
- [kernel] audit: drop audit_cmd_lock in AUDIT_USER family of cases (Richard Guy Briggs) [1019895]
- [security] smack: call WARN_ONCE() instead of calling audit_log_start() (Richard Guy Briggs) [1019895]
- [security] selinux: call WARN_ONCE() instead of calling audit_log_start() (Richard Guy Briggs) [1019895]
- [virt] vfio: Convert control interface to misc driver (Alex Williamson) [1044595]
- [virt] vfio: Reserve minor for VFIO (Alex Williamson) [1044595]
- [ethernet] qlcnic: Update version to 5.3.48.1 (Chad Dupuis) [1048773]
- [ethernet] qlcnic: Fix bug in Tx completion path (Chad Dupuis) [1048773]
- [ethernet] qlcnic: Fix usage of netif_tx_{wake, stop} api during link change (Chad Dupuis) [1048773]
- [ethernet] qlcnic: Fix system hang while running traffic and bringing interface down (Chad Dupuis) [1048773]
- [virt] hyperv/netvsc: don't flush peers notifying work during setting mtu (Jason Wang) [1040785 983434]
- [virt] hyperv: Fix race between probe and open calls (Jason Wang) [983434]
- [s390] kvm: mark as Tech Preview (Hendrik Brueckner) [1049469]
- [x86] irq: Fix do_IRQ() interrupt warning for cpu hotplug retriggered irqs (Prarit Bhargava) [1052179]
- [kernel] audit: log on errors from filter user rules (Richard Guy Briggs) [1034446]
- [x86] uv: Add GRU distributed mode mappings (George Beshers) [1032365]
- [iommu] dmar: Modify warn_invalid_dmar() message to do a less loud warning (Prarit Bhargava) [968249]
- [dma] ioat: Modify ioat3_dca_init() message to do a less loud warning (Prarit Bhargava) [968235]

* Wed Jan 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-72.el7]
- [ethernet] sfc: fix sparse non static symbol warning (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fix RX drop filters for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add PTP counters to ethtool stats (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Changed the statistic name emerg_{fetch, wait} to hlb_{fetch, wait} (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: remove unused 'enum efx_rx_alloc_method' (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: remove unused 'refcnt' from efx_rx_page_state (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Implement efx_nic_type::filter_clear_rx operation for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Allow filter removal only with exactly matching priority (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Don't refer to 'stack' in filter implementation (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Change priority and flags for automatic MAC filters (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Change efx_nic_type::rx_push_indir_table to push hash key as well (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add more information to many warnings using WARN() and netdev_WARN() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove unnecessary condition for processing the TX timestamp queue (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Don't clear timestamps in efx_ptp_rx() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Enable PTP clock and timestamping for all functions on EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Associate primary and secondary functions of controller (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Store VPD serial number at probe time (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add RX packet timestamping for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Copy RX prefix into skb head area in efx_rx_mk_skb() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: split setup of hardware timestamping into NIC-type operation (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add support for SFC9100 timestamp format (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Tidy up PTP synchronization code (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: PTP - tidy up unused/useless variables (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove kernel-doc for efx_ptp_data fields not present in this version (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Initialise efx_ptp_data::phc_clock_info from a static template (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Do not use MAC address as clock name (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Store flags from MC_CMD_DRV_ATTACH for later use (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove dependency of PTP on having a dedicated channel (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Split PTP multicast filter insertion/removal out of efx_ptp_{start, stop}() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Return EBUSY for filter insertion on EF10, matching Falcon/Siena (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Expose NVRAM_PARTITION_TYPE_LICENSE on EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fold efx_flush_all() into efx_stop_port() and update comments (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Map MCDI error MC_CMD_ERR_ENOTSUP to Linux EOPNOTSUPP (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Log all unexpected MCDI errors (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add new sensor names (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Revise sensor names to be more understandable and consistent (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Report units in sensor warnings (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Correct RX dropped count for drops while interface is down (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Make initial fill of RX descriptors synchronous (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Tighten the check for RX merged completion events (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add MC BISTs to ethtool offline self test on EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Update MCDI protocol definitions (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Demote "MC Scheduler error" messages (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Poll for MCDI completion once before timeout occurs (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Refactor efx_mcdi_poll() by introducing efx_mcdi_poll_once() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: RX buffer allocation takes prefix size into account in IP header alignment (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Maintain current frequency adjustment when applying a time offset (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Stop/re-start PTP when stopping/starting the datapath (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Rate-limit log message for PTP packets without a matching timestamp event (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc/ptp: Moderate log message on event queue overflow (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add length checks to efx_xmit_with_hwtstamp() and efx_ptp_is_ptp_tx() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: remove unnecessary pci_set_drvdata() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Implement the SIOCGHWTSTAMP ioctl (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fix DMA unmapping issue with firmware assisted TSO (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Only bind to EF10 functions with the LinkCtrl and Trusted flags (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add PM and RXDP drop counters to ethtool stats (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add definitions for new stats counters and capability flag (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Refactor EF10 stat mask code to allow for more conditional stats (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fix internal indices of ethtool stats for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add rmb() between reading stats and generation count to ensure consistency (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Increase MCDI status timeout to 250ms (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Wait for MC reboot to complete before scheduling driver reset (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove extern from function prototypes (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Support ARFS for IPv6 flows (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Use TX PIO for sufficiently small packets (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Introduce inline functions to simplify TX insertion (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Separate out queue-empty check from efx_nic_may_push_tx_desc() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Allocate and link PIO buffers; map them with write-combining (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Implement firmware-assisted TSO for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fold tso_get_head_fragment() into tso_start() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add EF10 registers to register dump (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: efx_ef10_filter_update_rx_scatter() can be static (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: efx_ethtool_get_ts_info() can be static (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Reinitialise and re-validate datapath caps after MC reboot (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Clean up validation of datapath capabilities (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Reset derived rx_bad_bytes statistic when EF10 MC is rebooted (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Disable PTP on EF10 until we're ready to handle inline RX timestamps (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Minimal support for 40G link speed (Nikolay Aleksandrov) [1028038]
- [net] net_tstamp: Add SIOCGHWTSTAMP ioctl to match SIOCSHWTSTAMP (Nikolay Aleksandrov) [1028038]
- [net] socket: Merge multiple implementations of ifreq::ifr_data conversion (Nikolay Aleksandrov) [1028038]
- [net] socket: Fix minor information leak in siocdevprivate_ioctl() (Nikolay Aleksandrov) [1028038]
- [net] net_tstamp: Improve kernel-doc for struct hwtstamp_config (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Nikolay Aleksandrov) [1028038]
- [virt] virtio-net: fix refill races during restore (Jason Wang) [1040802]
- [virt] virtio: delete napi structures from netdev before releasing memory (Jason Wang) [1040802]
- [virt] virtio-net: make all RX paths handle errors consistently (Jason Wang) [1032457]
- [virt] virtio_net: fix error handling for mergeable buffers (Jason Wang) [1032457]
- [firmware] efi-pstore: Make efi-pstore return a unique id (Seiji Aguchi) [1039150]
- [firmware] efivars, efi-pstore: Hold off deletion of sysfs entry until the scan is completed (Seiji Aguchi) [1039145]
- [firmware] efi-pstore: Cocci spatch "memdup.spatch" (Seiji Aguchi) [1039145]
- [virt] kvm/svm: nested virt support off by default (Marcelo Tosatti) [1034974]
- [x86] uv: Fix NULL pointer dereference in uv_flush_tlb_others() (George Beshers) [1049559]
- [fs] kill anon_inode_getfile_private() (Motohiro Kosaki) [995323]
- [fs] rework aio migrate pages to use aio fs (Motohiro Kosaki) [995323]
- [fs] take anon inode allocation to libfs.c (Motohiro Kosaki) [995323]
- [fs] libfs: get exports to definitions of objects being exported (Motohiro Kosaki) [995323]
- [fs] aio: fix use-after-free in aio_migratepage (Motohiro Kosaki) [995323]
- [fs] aio: remove unnecessary debugging from aio_free_ring() (Motohiro Kosaki) [995323]
- [fs] aio: fix race in ring buffer page lookup introduced by page migration support (Motohiro Kosaki) [995323]
- [fs] aio: fix build when migration is disabled (Motohiro Kosaki) [995323]
- [fs] aio: Add support to aio ring pages migration (Motohiro Kosaki) [995323]
- [fs] anon_inode: Introduce a new lib function anon_inode_getfile_private() (Motohiro Kosaki) [995323]

* Tue Jan 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-71.el7]
- [md] dm-cache: add block sizes and total cache blocks to status output (Mike Snitzer) [1049591]
- [md] dm-btree: add dm_btree_find_lowest_key (Mike Snitzer) [1049591]
- [md] dm-space-map-metadata: fix extending the space map (Mike Snitzer) [1049591]
- [md] dm-space-map-common: make sure new space is used during extend (Mike Snitzer) [1049591]
- [md] dm: wait until embedded kobject is released before destroying a device (Mike Snitzer) [1049591]
- [md] dm: remove pointless kobject comparison in dm_get_from_kobject (Mike Snitzer) [1049591]
- [md] dm-snapshot: call destroy_work_on_stack() to pair with INIT_WORK_ONSTACK() (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: introduce three promotion threshold tunables (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: use list_del_init instead of list_del + INIT_LIST_HEAD (Mike Snitzer) [1049591]
- [md] dm-thin: fix set_pool_mode exposed pool operation races (Mike Snitzer) [1049591]
- [md] dm-thin: eliminate the no_free_space flag (Mike Snitzer) [1049591]
- [md] dm-thin: add error_if_no_space feature (Mike Snitzer) [1049591]
- [md] dm-thin: requeue bios to DM core if no_free_space and in read-only mode (Mike Snitzer) [1049591]
- [md] dm-thin: cleanup and improve no space handling (Mike Snitzer) [1049591]
- [md] dm-thin: log info when growing the data or metadata device (Mike Snitzer) [1049591]
- [md] dm-thin: handle metadata failures more consistently (Mike Snitzer) [1049591]
- [md] dm-thin: factor out check_low_water_mark and use bools (Mike Snitzer) [1049591]
- [md] dm-thin: add mappings to end of prepared_* lists (Mike Snitzer) [1049591]
- [md] dm-thin: return error from alloc_data_block if pool is not in write mode (Mike Snitzer) [1049591]
- [md] dm-thin: use bool rather than unsigned for flags in structures (Mike Snitzer) [1049591]
- [md] dm-persistent-data: cleanup dm-thin specific references in text (Mike Snitzer) [1049591]
- [md] dm-space-map-metadata: limit errors in sm_metadata_new_block (Mike Snitzer) [1049591]
- [md] dm-delay: use per-bio data instead of a mempool and slab cache (Mike Snitzer) [1049591]
- [md] dm-table: remove unused buggy code that extends the targets array (Mike Snitzer) [1049591]
- [md] dm-thin: fix discard support to a previously shared block (Mike Snitzer) [1049591]
- [md] dm-thin: initialize dm_thin_new_mapping returned by get_next_mapping (Mike Snitzer) [1049591]
- [md] dm-array: fix a reference counting bug in shadow_ablock (Mike Snitzer) [1049591]
- [md] dm-space-map: disallow decrementing a reference count below zero (Mike Snitzer) [1049591]
- [md] dm-stats: initialize read-only module parameter (Mike Snitzer) [1049591]
- [md] dm-bufio: initialize read-only module parameters (Mike Snitzer) [1049591]
- [md] dm-cache: actually resize cache (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: fix promotions to occur as expected (Mike Snitzer) [1049591]
- [md] dm-thin: allow pool in read-only mode to transition to read-write mode (Mike Snitzer) [1049591]
- [md] dm-thin: re-establish read-only state when switching to fail mode (Mike Snitzer) [1049591]
- [md] dm-thin: always fallback the pool mode if commit fails (Mike Snitzer) [1049591]
- [md] dm-thin: switch to read-only mode if metadata space is exhausted (Mike Snitzer) [1049591]
- [md] dm-thin: switch to read only mode if a mapping insert fails (Mike Snitzer) [1049591]
- [md] dm-space-map-metadata: return on failure in sm_metadata_new_block (Mike Snitzer) [1049591]
- [md] dm-table: fail dm_table_create on dm_round_up overflow (Mike Snitzer) [1049591]
- [md] dm-snapshot: avoid snapshot space leak on crash (Mike Snitzer) [1049591]
- [md] dm-delay: fix a possible deadlock due to shared workqueue (Mike Snitzer) [1049591]
- [md] dm-cache: resolve small nits and improve Documentation (Mike Snitzer) [1049591]
- [md] dm-cache: add cache block invalidation support (Mike Snitzer) [1049591]
- [md] dm-cache: add remove_cblock method to policy interface (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: reduce memory requirements (Mike Snitzer) [1049591]
- [md] dm-cache-metadata: check the metadata version when reading the superblock (Mike Snitzer) [1049591]
- [md] dm-cache: add passthrough mode (Mike Snitzer) [1049591]
- [md] dm-cache: cache shrinking support (Mike Snitzer) [1049591]
- [md] dm-cache: promotion optimisation for writes (Mike Snitzer) [1049591]
- [md] dm-cache: be much more aggressive about promoting writes to discarded blocks (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: implement writeback_work() and mq_{set, clear}_dirty() (Mike Snitzer) [1049591]
- [md] dm-cache: optimize commit_if_needed (Mike Snitzer) [1049591]
- [md] dm-space-map-disk: optimise sm_disk_dec_block (Mike Snitzer) [1049591]
- [md] dm: fix Kconfig menu indentation (Mike Snitzer) [1049591]
- [md] dm: allow remove to be deferred (Mike Snitzer) [1049591]
- [md] dm-table: print error on preresume failure (Mike Snitzer) [1049591]
- [md] dm-crypt: add TCW IV mode for old CBC TCRYPT containers (Mike Snitzer) [1049591]
- [md] dm-crypt: properly handle extra key string in initialization (Mike Snitzer) [1049591]
- [md] dm-cache: log error message if dm_kcopyd_copy() fails (Mike Snitzer) [1049591]
- [md] dm-cache: use cell_defer() boolean argument consistently (Mike Snitzer) [1049591]
- [md] dm-cache: return -EINVAL if the user specifies unknown cache policy (Mike Snitzer) [1049591]
- [md] dm-cache-metadata: return bool from __superblock_all_zeroes (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: a few small fixes (Mike Snitzer) [1049591]
- [md] dm-cache-policy: remove return from void policy_remove_mapping (Mike Snitzer) [1049591]
- [md] dm-cache: improve efficiency of quiescing flag management (Mike Snitzer) [1049591]
- [md] dm-cache: fix a race condition between queuing new migrations and quiescing for a shutdown (Mike Snitzer) [1049591]
- [md] dm-cache: io destined for the cache device can now serve as tick bios (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: protect residency method with existing mutex (Mike Snitzer) [1049591]
- [md] dm-array: fix bug in growing array (Mike Snitzer) [1049591]
- [md] dm-mpath: requeue I/O during pg_init (Mike Snitzer) [1049591]
- [md] dm-mpath: fix race condition between multipath_dtr and pg_init_done (Mike Snitzer) [1049591]
- [md] dm: allocate buffer for messages with small number of arguments using GFP_NOIO (Mike Snitzer) [1049591]
- [ethernet] be2net: fix max_evt_qs calculation for BE3 in SR-IOV config (Ivan Vecera) [1049512]
- [ethernet] be2net: increase the timeout value for loopback-test FW cmd (Ivan Vecera) [1049512]
- [ethernet] be2net: disable RSS when number of RXQs is reduced to 1 via set-channels (Ivan Vecera) [1049512]
- [ethernet] be2net: slight optimization of addr compare (Ivan Vecera) [1049512]
- [ethernet] be2net: calls skb_set_hash (Ivan Vecera) [1049512]
- [net] Add function to set the rxhash (Ivan Vecera) [1049512]
- [ethernet] be2net: Free/delete pmacs (in be_clear()) only if they exist (Ivan Vecera) [1049512]
- [ethernet] be2net: Fix Lancer error recovery to distinguish FW download (Ivan Vecera) [1049512]
- [ethernet] be2net: Avoid programming permenant MAC by BE3-R VFs (Ivan Vecera) [1049512]
- [ethernet] be2net: set coalesce-wm in CQ_CREATE_V2 cmd (Ivan Vecera) [1049512]
- [ethernet] be2net: Disabling and enabling interrupts in suspend and resume (Ivan Vecera) [1049512]
- [ethernet] be2net: Delete secondary unicast MAC addresses during be_close (Ivan Vecera) [1049512]
- [ethernet] be2net: Fix unconditional enabling of Rx interface options (Ivan Vecera) [1049512]
- [ethernet] be2net: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Ivan Vecera) [1049512]

* Tue Jan 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-70.el7]
- [scsi] qla4xxx: v5.04.00.02.07.00-k0 (Chad Dupuis) [948116]
- [scsi] qla4xxx: Add support for additional network parameters settings (Chad Dupuis) [1006152]
- [scsi] qla4xxx: v5.04.00.01.07.00-k0 (Chad Dupuis) [1006152]
- [scsi] qla4xxx: Add support to get CHAP details for flash target session (Chad Dupuis) [1006152]
- [scsi] qla4xxx: Add support to set CHAP entries (Chad Dupuis) [1006152]
- [scsi] qla4xxx: Use offset based on adapter type to set CHAP entry in flash (Chad Dupuis) [1006152]
- [scsi] iscsi_transport: Additional parameters for network settings (Chad Dupuis) [948116]
- [scsi] iscsi_transport: Remove net param enum values (Chad Dupuis) [948116]
- [scsi] scsi_transport_iscsi: Add support to set CHAP entries (Chad Dupuis) [1006152]
- [scsi] Update documentation for scsi eh patchset (Ewan Milne) [987784]
- [scsi] Set the minimum valid value of 'eh_deadline' as 0 (Ewan Milne) [987784]
- [scsi] Unlock accesses to eh_deadline (Ewan Milne) [987784]
- [scsi] improved eh timeout handler (Ewan Milne) [987784]
- [scsi] Fix erratic device offline during EH (Ewan Milne) [987784]
- [scsi] scsi_error: Escalate to LUN reset if abort fails (Ewan Milne) [987784]
- [scsi] Adjust eh_deadline changes to match final upstream version (Ewan Milne) [987784]
- [scsi] Disable WRITE SAME for RAID and virtual host adapter drivers (Ewan Milne) [1010379]
- [scsi] pm80xx: Removing redundant code snippets (Rich Bono) [1044113]
- [scsi] pm80xx: Tasklets synchronization fix (Rich Bono) [1044113]
- [scsi] pm8001: clean up unnecessary MSI/MSI-X capability find (Rich Bono) [1044113]
- [scsi] pm8001: use pdev->pm_cap instead of pci_find_capability(.., PCI_CAP_ID_PM) (Rich Bono) [1044113]
- [scsi] pm80xx: Module author addition (Rich Bono) [1044113]
- [scsi] pm80xx: Resetting the phy state (Rich Bono) [1044113]
- [scsi] pm80xx: Fix for direct attached device (Rich Bono) [1044113]
- [net] cnic: Add a signature to indicate valid doorbell offset (Maurizio Lombardi) [1051181]
- [scsi] bfa: Driver version upgrade to 3.2.23.0 (Vijay Guvva) [1032723]
- [scsi] bfa: Fix smatch warnings (Vijay Guvva) [1032723]
- [scsi] bfa: change FC_ELS_TOV to 20sec (Vijay Guvva) [1032723]
- [scsi] bfa: Observed auto D-port mode instead of manual (Vijay Guvva) [1032723]
- [scsi] bfa: Fix for bcu or hcm faa query hang (Vijay Guvva) [1032723]
- [scsi] bfa: LUN discovery issue in direct attach mode (Vijay Guvva) [1032723]
- [scsi] bfa: Register port with SCSI even on port init failure (Vijay Guvva) [1032723]
- [scsi] bfa: Firmware patch simplification (Vijay Guvva) [1032723]
- [ethernet] bna: Fix build due to missing use of dma_unmap_len_set() (Ivan Vecera) [1030679]
- [ethernet] bna: Update the Driver Version to 3.2.23.0 (Ivan Vecera) [1030679]
- [ethernet] bna: Firmware Patch Simplification (Ivan Vecera) [1030679]
- [ethernet] bna: Embed SKB Length in TX Vector (Ivan Vecera) [1030679]
- [ethernet] bna: Handle the TX Setup Failures (Ivan Vecera) [1030679]
- [ethernet] bna: Add NULL Check Before Dereferencing TCB (Ivan Vecera) [1030679]
- [ethernet] bna: CQ Read Fix (Ivan Vecera) [1030679]
- [ethernet] bna: RX Processing and Config Changes (Ivan Vecera) [1030679]
- [ethernet] bna: Enable Multi Buffer RX (Ivan Vecera) [1030679]
- [ethernet] bna: RX Filter Enhancements (Ivan Vecera) [1030679]
- [ethernet] bna: Fix Filter Add Del (Ivan Vecera) [1030679]
- [ethernet] bna: Set Get IOC fw State (Ivan Vecera) [1030679]
- [ethernet] bna: Add software timestamping support (Ivan Vecera) [1030679]
- [ethernet] bna: make local variable static (Ivan Vecera) [1030679]
- [ethernet] bna: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1030679]
- [ethernet] bna: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1030679]
- [ethernet] bna: Remove extern from function prototypes (Ivan Vecera) [1030679]
- [ethernet] bna: fix 32-bit DMA mask handling (Ivan Vecera) [1030679]
- [kernel] dma-api: provide a helper to set both DMA and coherent DMA masks (Ivan Vecera) [1030679]

* Mon Jan 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-69.el7]
- [firmware] efi: generalize efi_get_memory_map() (George Beshers) [973417]
- [firmware] efi: Rename __get_map() to efi_get_memory_map() (George Beshers) [973417]
- [x86] EFI stub support for large memory maps (George Beshers) [973417]
- [x86] efi: Allow efi_free() to be called with size of 0 (George Beshers) [973417]
- [x86] efi: use efi_get_memory_map() to get final map for x86 (George Beshers) [973417]
- [x86] efi: Rename memory allocation/free functions (George Beshers) [973417]
- [x86] efi: Add system table pointer argument to shared functions (George Beshers) [973417]
- [x86] efi: Move common EFI stub code from x86 arch code to common location (George Beshers) [973417]
- [x86] efi: Add proper definitions for some EFI function pointers (George Beshers) [973417]
- [x86] efi: correct call to free_pages (George Beshers) [973417]
- [ethernet] i40e: correctly setup ARQ descriptors (Stefan Assmann) [1011561]
- [ethernet] i40e: remove redundant AQ enable (Stefan Assmann) [1011561]
- [ethernet] i40e: Enable/Disable PF switch LB on SR-IOV configure changes (Stefan Assmann) [1011561]
- [ethernet] i40e: whitespace paren and comment tweaks (Stefan Assmann) [1011561]
- [ethernet] i40e: rework shadow ram read functions (Stefan Assmann) [1011561]
- [ethernet] i40e: check MAC type before any REG access (Stefan Assmann) [1011561]
- [ethernet] i40e: move PF ID init from PF reset to SC init (Stefan Assmann) [1011561]
- [ethernet] i40e: Reduce range of interrupt reg in reg test (Stefan Assmann) [1011561]
- [ethernet] i40e: update firmware api to 1.1 (Stefan Assmann) [1011561]
- [ethernet] i40e: Add code to wait for FW to complete in reset path (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: Allow VF to set already assigned MAC address (Stefan Assmann) [1011561]
- [ethernet] i40e: Stop accepting any VLAN tag on VLAN 0 filter set (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not enable broadcast promiscuous by default (Stefan Assmann) [1011561]
- [ethernet] i40e: Expose AQ debugfs hooks (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not allow AQ calls from ndo-ops (Stefan Assmann) [1011561]
- [ethernet] i40e: check asq alive before notify (Stefan Assmann) [1011561]
- [ethernet] i40e: Admin queue shutdown fixes (Stefan Assmann) [1011561]
- [ethernet] i40e: Hide the Port VLAN VLAN ID (Stefan Assmann) [1011561]
- [ethernet] i40e: use correct struct for get and update vsi params (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix VF driver MAC address configuration (Stefan Assmann) [1011561]
- [ethernet] i40e: support VFs on PFs other than 0 (Stefan Assmann) [1011561]
- [ethernet] i40e: acknowledge VFLR when disabling SR-IOV (Stefan Assmann) [1011561]
- [ethernet] i40e: don't allocate zero size (Stefan Assmann) [1011561]
- [ethernet] i40e: use struct assign instead of memcpy (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not enable default port on the VEB (Stefan Assmann) [1011561]
- [ethernet] i40e: avoid unnecessary register read (Stefan Assmann) [1011561]
- [ethernet] i40e: fix whitespace (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix SR-IOV VF port VLAN (Stefan Assmann) [1011561]
- [ethernet] i40e: Record dma buffer info for dummy packets (Stefan Assmann) [1011561]
- [ethernet] i40e: remove un-necessary io-write (Stefan Assmann) [1011561]
- [ethernet] i40e: Remove unnecessary prototypes (Stefan Assmann) [1011561]
- [ethernet] i40e: I40E_FLAG_MQ_ENABLED is not used (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix ring allocation (Stefan Assmann) [1011561]
- [ethernet] i40e: catch unset q_vector (Stefan Assmann) [1011561]
- [ethernet] i40e: keep allocated memory in structs (Stefan Assmann) [1011561]
- [ethernet] i40e: fix error handling when alloc of vsi array fails (Stefan Assmann) [1011561]
- [ethernet] i40e: reinit buffer size each time (Stefan Assmann) [1011561]
- [ethernet] i40e: use functions to enable and disable icr 0 (Stefan Assmann) [1011561]
- [ethernet] i40e: add header file flag _I40E_TXRX_H_ (Stefan Assmann) [1011561]
- [ethernet] i40e: guard against vf message races (Stefan Assmann) [1011561]
- [ethernet] i40e: fix constant cast issues (Stefan Assmann) [1011561]
- [ethernet] i40e: Change the ethtool NVM read method to use AQ (Stefan Assmann) [1011561]
- [ethernet] i40e: fix mac address checking (Stefan Assmann) [1011561]
- [ethernet] i40e: Dump the whole NVM, not half (Stefan Assmann) [1011561]
- [ethernet] i40e: report VF MAC addresses correctly (Stefan Assmann) [1011561]
- [ethernet] i40e: update led set args (Stefan Assmann) [1011561]
- [ethernet] i40e: make a define from a large constant (Stefan Assmann) [1011561]
- [ethernet] i40e: be more informative (Stefan Assmann) [1011561]
- [ethernet] i40e: fix error return (Stefan Assmann) [1011561]
- [ethernet] i40e: remove chatty log messages (Stefan Assmann) [1011561]
- [ethernet] i40e: remove redundant code (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor VF reset flow (Stefan Assmann) [1011561]
- [ethernet] i40e: move i40e_reset_vf (Stefan Assmann) [1011561]
- [ethernet] i40e: Rx checksum offload for VXLAN (Stefan Assmann) [1011561]
- [ethernet] i40e: Implementation of VXLAN ndo's (Stefan Assmann) [1011561]
- [ethernet] i40e: fix curly brace use and return type (Stefan Assmann) [1011561]
- [ethernet] i40e: add wake-on-lan support (Stefan Assmann) [1011561]
- [ethernet] i40e: Populate and check pci bus speed and width (Stefan Assmann) [1011561]
- [uapi] pci_regs: Add PCI bus link speed and width defines (Stefan Assmann) [1011561]
- [ethernet] i40e: Suppress HMC error to Interrupt message level (Stefan Assmann) [1011561]
- [ethernet] i40e: using for_each_set_bit to simplify the code (Stefan Assmann) [1011561]
- [ethernet] i40e: make functions static and remove dead code (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix off by one in i40e_dbg_command_write (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version number (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix wrong mask bits being used in misc interrupt (Stefan Assmann) [1011561]
- [ethernet] i40e: more print_hex_dump use (Stefan Assmann) [1011561]
- [ethernet] i40e: fix up scanf decoders (Stefan Assmann) [1011561]
- [ethernet] i40e: simplify error messages for dump descriptor (Stefan Assmann) [1011561]
- [ethernet] i40e: prevent null pointer exception in dump descriptor (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix dump output from debugfs calls (Stefan Assmann) [1011561]
- [ethernet] i40e: Remove FCoE in i40e_virtchnl_pf.c code (Stefan Assmann) [1011561]
- [ethernet] i40e: support for suspend and resume (Stefan Assmann) [1011561]
- [ethernet] i40e: rtnl_lock in reset path fixes (Stefan Assmann) [1011561]
- [ethernet] i40e: Add basic support for get/set channels for RSS (Stefan Assmann) [1011561]
- [ethernet] i40e: function to reconfigure RSS queues and rebuild (Stefan Assmann) [1011561]
- [ethernet] i40e: reinit flow for the main VSI (Stefan Assmann) [1011561]
- [ethernet] i40e: use same number of queues as CPUs (Stefan Assmann) [1011561]
- [ethernet] i40e: trivial fixes (Stefan Assmann) [1011561]
- [ethernet] i40e: init flow control settings to disabled (Stefan Assmann) [1011561]
- [ethernet] i40e: Tell the stack about our actual number of queues (Stefan Assmann) [1011561]
- [ethernet] i40e: fix pf reset after offline test (Stefan Assmann) [1011561]
- [ethernet] i40e: fix up some of the ethtool connection reporting (Stefan Assmann) [1011561]
- [ethernet] i40e: fix null dereference (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version number (Stefan Assmann) [1011561]
- [ethernet] i40e: remove and fix confusing define name (Stefan Assmann) [1011561]
- [ethernet] i40e: complain about out-of-range descriptor request (Stefan Assmann) [1011561]
- [ethernet] i40e: loopback info and set loopback fix (Stefan Assmann) [1011561]
- [ethernet] i40e: restrict diag test messages (Stefan Assmann) [1011561]
- [ethernet] i40e: Add a new variable to track number of pf instances (Stefan Assmann) [1011561]
- [ethernet] i40e: add num_VFs message (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor ethtool tests (Stefan Assmann) [1011561]
- [ethernet] i40e: clear test state bit after all ethtool tests (Stefan Assmann) [1011561]
- [ethernet] i40e: only set up the rings to be used (Stefan Assmann) [1011561]
- [ethernet] i40e: Enable all PCTYPEs except FCOE for RSS (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor reset code (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: whitespace (Stefan Assmann) [1011561]
- [ethernet] i40e: enable early hardware support (Stefan Assmann) [1011561]
- [ethernet] i40e: Add flag for L2 VEB filtering (Stefan Assmann) [1011561]
- [ethernet] i40e: get media type during link info (Stefan Assmann) [1011561]
- [ethernet] i40e: check multi-bit state correctly (Stefan Assmann) [1011561]
- [ethernet] i40e: separate TSYNVALID and TSYNINDX fields in Rx descriptor (Stefan Assmann) [1011561]
- [ethernet] i40e: sync header files with hardware (Stefan Assmann) [1011561]
- [ethernet] i40e: restrict diag test length (Stefan Assmann) [1011561]
- [ethernet] i40e: add support for triggering EMPR (Stefan Assmann) [1011561]
- [ethernet] i40e: add interrupt test (Stefan Assmann) [1011561]
- [ethernet] i40e: default debug mask setting (Stefan Assmann) [1011561]
- [ethernet] i40e: fix debugging messages (Stefan Assmann) [1011561]
- [ethernet] i40e: properly add VF MAC addresses (Stefan Assmann) [1011561]
- [ethernet] i40e: retry call on timeout (Stefan Assmann) [1011561]
- [ethernet] i40e: select reset counters correctly (Stefan Assmann) [1011561]
- [ethernet] i40e: allow one more vector for VFs (Stefan Assmann) [1011561]
- [ethernet] i40e: firmware version fields offsets update (Stefan Assmann) [1011561]
- [ethernet] i40e: simplify aq head-tail-len setups (Stefan Assmann) [1011561]
- [ethernet] i40e: clear AQ head and tail registers (Stefan Assmann) [1011561]
- [ethernet] i40e: register file updates (Stefan Assmann) [1011561]
- [ethernet] i40e: set pf_id based on device and function numbers (Stefan Assmann) [1011561]
- [ethernet] i40e: fix error return code in i40e_probe() (Stefan Assmann) [1011561]
- [ethernet] i40e: remove unused including <linux/version.h> (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: use pf_id for pf function id in qtx_ctl (Stefan Assmann) [1011561]
- [ethernet] i40e: check vsi ptrs before dumping them (Stefan Assmann) [1011561]
- [ethernet] i40e: reorder block declarations in debugfs (Stefan Assmann) [1011561]
- [ethernet] i40e: tweaking icr0 handling for legacy irq (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor fdir setup function (Stefan Assmann) [1011561]
- [ethernet] i40e: fix sign extension issue (Stefan Assmann) [1011561]
- [ethernet] i40e: fix use of untrusted scalar value warning (Stefan Assmann) [1011561]
- [ethernet] i40e: clamp debugfs nvm read command (Stefan Assmann) [1011561]
- [ethernet] i40e: debugfs fixups (Stefan Assmann) [1011561]
- [ethernet] i40e: fixup legacy interrupt handling (Stefan Assmann) [1011561]
- [ethernet] i40e: assign correct vector to VF (Stefan Assmann) [1011561]
- [ethernet] i40e: don't free nonexistent rings (Stefan Assmann) [1011561]
- [ethernet] i40e: do not flush after re-enabling interrupts (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: Add support for 64 bit netstats (Stefan Assmann) [1011561]
- [ethernet] i40e: Move rings from pointer to array to array of pointers (Stefan Assmann) [1011561]
- [ethernet] i40e: Replace ring container array with linked list (Stefan Assmann) [1011561]
- [ethernet] i40e: Move q_vectors from pointer to array to array of pointers (Stefan Assmann) [1011561]
- [ethernet] i40e: Split bytes and packets from Rx/Tx stats (Stefan Assmann) [1011561]
- [ethernet] i40e: Add support for Tx byte queue limits (Stefan Assmann) [1011561]
- [ethernet] i40e: Drop dead code and flags from Tx hotpath (Stefan Assmann) [1011561]
- [ethernet] i40e: clean up Tx fast path (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not directly increment Tx next_to_use (Stefan Assmann) [1011561]
- [ethernet] i40e: Cleanup Tx buffer info layout (Stefan Assmann) [1011561]
- [ethernet] i40e: Drop unused completed stat (Stefan Assmann) [1011561]
- [ethernet] i40e: Link code updates (Stefan Assmann) [1011561]
- [ethernet] i40e: clean up coccicheck reported errors (Stefan Assmann) [1011561]
- [ethernet] i40e: better return values (Stefan Assmann) [1011561]
- [ethernet] i40e: convert ret to aq_ret (Stefan Assmann) [1011561]
- [ethernet] i40e: small clean ups from review (Stefan Assmann) [1011561]
- [ethernet] i40e: use common failure flow (Stefan Assmann) [1011561]
- [net] sunrpc/rpc_pipe: fix cleanup of dummy gssd directory when notification fails (Jeff Layton) [1048105]
- [net] sunrpc: add an "info" file for the dummy gssd pipe (Jeff Layton) [1048105]
- [net] sunrpc/rpc_pipe: remove the clntXX dir if creating the pipe fails (Jeff Layton) [1048105]
- [fs] nfs: fix do_div() warning by instead using sector_div() (Steve Dickson) [769365]
- [misc] MAINTAINERS: Update contact information for Trond Myklebust (Steve Dickson) [769365]
- [fs] nfs: Prevent a 3-way deadlock between layoutreturn, open and state recovery (Steve Dickson) [769365]
- [net] sunrpc: do not fail gss proc NULL calls with EACCES (Steve Dickson) [769365]
- [fs] nfs: close needs to handle NFS4ERR_ADMIN_REVOKED (Steve Dickson) [769365]
- [fs] nfs: Update list of irrecoverable errors on DELEGRETURN (Steve Dickson) [769365]
- [fs] nfs: wait on recovery for async session errors (Steve Dickson) [769365]
- [fs] nfs: Fix a warning in nfs_setsecurity (Steve Dickson) [769365]
- [fs] nfs: Enabling v4.2 should not recompile nfsd and lockd (Steve Dickson) [769365]
- [fs] nfs: fix pnfs Kconfig defaults (Steve Dickson) [769365]
- [fs] nfs: correctly report misuse of "migration" mount option (Steve Dickson) [769365]
- [ethernet] igb: fix driver reload with VF assigned to guest (Stefan Assmann) [986817]
- [net] sunrpc: Cleanup xs_destroy() (Steve Dickson) [769365]
- [net] sunrpc: close a rare race in xs_tcp_setup_socket (Steve Dickson) [769365]
- [net] sunrpc: remove duplicated include from clnt.c (Steve Dickson) [769365]
- [fs] nfs: use IS_ROOT not DCACHE_DISCONNECTED (Steve Dickson) [769365]
- [net] sunrpc: Fix buffer overflow checking in gss_encode_v0_msg/gss_encode_v1_msg (Steve Dickson) [769365]
- [net] sunrpc: gss_alloc_msg - choose _either_ a v0 message or a v1 message (Steve Dickson) [769365]
- [net] sunrpc: remove an unnecessary if statement (Steve Dickson) [769365]
- [fs] nfs: Remove useless 'error' assignment (Steve Dickson) [769365]
- [net] sunrpc: comment typo fix (Steve Dickson) [769365]
- [net] sunrpc: Add correct rcu_dereference annotation in rpc_clnt_set_transport (Steve Dickson) [769365]
- [fs] nfs: add support for multiple sec= mount options (Steve Dickson) [769365]
- [fs] nfs: stop using NFS_MOUNT_SECFLAVOUR server flag (Steve Dickson) [769365]
- [fs] nfs: cache parsed auth_info in nfs_server (Steve Dickson) [769365]
- [fs] nfs: separate passed security flavs from selected (Steve Dickson) [769365]
- [fs] nfs: make nfs_find_best_sec static (Steve Dickson) [769365]
- [fs] nfs: Fix possible endless state recovery wait (Steve Dickson) [769365]
- [fs] nfs: Set EXCHGID4_FLAG_SUPP_MOVED_MIGR (Steve Dickson) [769365]
- [fs] nfs: Handle SEQ4_STATUS_LEASE_MOVED (Steve Dickson) [769365]
- [fs] nfs: Handle NFS4ERR_LEASE_MOVED during async RENEW (Steve Dickson) [769365]
- [fs] nfs: Migration support for RELEASE_LOCKOWNER (Steve Dickson) [769365]
- [fs] nfs: Implement support for NFS4ERR_LEASE_MOVED (Steve Dickson) [769365]
- [fs] nfs: Support NFS4ERR_LEASE_MOVED recovery in state manager (Steve Dickson) [769365]
- [fs] nfs: Add method to detect whether an FSID is still on the server (Steve Dickson) [769365]
- [fs] nfs: Handle NFS4ERR_MOVED during delegation recall (Steve Dickson) [769365]
- [fs] nfs: Add migration recovery callouts in nfs4proc.c (Steve Dickson) [769365]
- [fs] nfs: Rename "stateid_invalid" label (Steve Dickson) [769365]
- [fs] nfs: Re-use exit code in nfs4_async_handle_error() (Steve Dickson) [769365]
- [fs] nfs: Add basic migration support to state manager thread (Steve Dickson) [769365]
- [fs] nfs: Add a super_block backpointer to the nfs_server struct (Steve Dickson) [769365]
- [fs] nfs: Add method to retrieve fs_locations during migration recovery (Steve Dickson) [769365]
- [fs] nfs: Export _nfs_display_fhandle() (Steve Dickson) [769365]
- [fs] nfs: Introduce a vector of migration recovery ops (Steve Dickson) [769365]
- [fs] nfs: Add functions to swap transports during migration recovery (Steve Dickson) [769365]
- [fs] nfs: Add nfs4_update_server (Steve Dickson) [769365]
- [net] sunrpc: Add a helper to switch the transport of an rpc_clnt (Steve Dickson) [769365]
- [net] sunrpc: Modify synopsis of rpc_client_register() (Steve Dickson) [769365]
- [fs] nfs: don't reprocess cached open CLAIM_PREVIOUS (Steve Dickson) [769365]
- [fs] nfs: Fix state reference counting in _nfs4_opendata_reclaim_to_nfs4_state (Steve Dickson) [769365]
- [fs] nfs: don't fail on missing fattr in open recover (Steve Dickson) [769365]
- [fs] nfs: fix NULL dereference in open recover (Steve Dickson) [769365]
- [fs] nfs: Don't change the security label as part of open reclaim (Steve Dickson) [769365]
- [fs] nfs: Remove zeroing state kern warnings (Steve Dickson) [769365]
- [net] sunrpc: call_connect_status should recheck bind and connect status on error (Steve Dickson) [769365]
- [net] sunrpc: Remove redundant initialisations of request rq_bytes_sent (Steve Dickson) [769365]
- [net] sunrpc: Fix RPC call retransmission statistics (Steve Dickson) [769365]
- [fs] nfs: Ensure that we disable the resend timeout for NFSv4 (Steve Dickson) [769365]
- [net] sunrpc: Add RPC task and client level options to disable the resend timeout (Steve Dickson) [769365]
- [net] sunrpc: Clean up - convert xprt_prepare_transmit to return a bool (Steve Dickson) [769365]
- [net] sunrpc: Clear the request rq_bytes_sent field in xprt_release_write (Steve Dickson) [769365]
- [net] sunrpc: Don't set the request connect_cookie until a successful transmit (Steve Dickson) [769365]
- [net] sunrpc: Only update the TCP connect cookie on a successful connect (Steve Dickson) [769365]
- [net] sunrpc: Enable the keepalive option for TCP sockets (Steve Dickson) [769365]
- [fs] nfs: Fix a use-after-free situation in _nfs4_proc_getlk() (Steve Dickson) [769365]
- [wireless] iwlwifi: enable shadow registers for 7000 (Stanislaw Gruszka) [1016320]
- [wireless] iwlwifi: support BSS only (Stanislaw Gruszka) [1016320]
- [fs] gfs2: Increase i_writecount during gfs2_setattr_chown (Robert S Peterson) [1049045]
- [mm] thp: give transparent hugepage code a separate copy_page (Rik van Riel) [1044367]
- [kernel] time: menu governor broken when nohz=off (George Beshers) [1043652]
- [s390] perf: fix compile error (undefined reference sie_exit) (Hendrik Brueckner) [1035261]
- [s390] mm: page_table_realloc returns failure (Hendrik Brueckner) [1035261]
- [virt] virtio-net: Set RXCSUM feature if GUEST_CSUM is available (Hendrik Brueckner) [1035261]
- [s390] kvm: Add helper function for setting condition code (Hendrik Brueckner) [1035261]
- [s390] kvm: Make KVM_HVA_ERR_BAD usable on s390 (Hendrik Brueckner) [1035261]
- [s390] kvm: use cookies for ioeventfd (Hendrik Brueckner) [1035261]
- [s390] kvm/kvm-io: support cookies (Hendrik Brueckner) [1035261]
- [s390] kvm: fix pfmf non-quiescing control handling (Hendrik Brueckner) [1035261]
- [s390] kvm: Fix sparse warnings in priv.c (Hendrik Brueckner) [1035261]
- [s390] kvm: declare virtual HW facilities (Hendrik Brueckner) [1035261]
- [s390] kvm: fix task size check (Hendrik Brueckner) [1035261]
- [s390] kvm: allow sie enablement for multi-threaded programs (Hendrik Brueckner) [1035261]
- [s390] qeth: Increase default MTU for OSA devices (Hendrik Brueckner) [1035261]
- [s390] kvm: Fixed priority of execution in STSI (Hendrik Brueckner) [1035261]
- [s390] kvm: Reworked LCTL and LCTLG instructions (Hendrik Brueckner) [1035261]
- [s390] kvm: Check for access exceptions during TPI (Hendrik Brueckner) [1035261]
- [s390] kvm: Check for PSTATE when handling DIAGNOSE (Hendrik Brueckner) [1035261]
- [s390] kvm: Privileged operation checks moved to instruction handlers (Hendrik Brueckner) [1035261]
- [s390] kvm: Privileged operation check for TPROT (Hendrik Brueckner) [1035261]
- [s390] kvm: Renamed PGM_PRIVILEGED_OPERATION (Hendrik Brueckner) [1035261]
- [s390] kvm: Fix epsw instruction decoding (Hendrik Brueckner) [1035261]
- [s390] kvm: Use common waitqueue (Hendrik Brueckner) [1035261]
- [s390] kvm: code cleanup to use common vcpu slab cache (Hendrik Brueckner) [1035261]
- [s390] kvm: Detect if perf samples belong to KVM host or guest (Hendrik Brueckner) [1035261]
- [s390] kvm: guest large pages (Hendrik Brueckner) [1035261]
- [s390] kvm: avoid automatic sie reentry (Hendrik Brueckner) [1035261]
- [s390] kvm: Kick guests out of sie if prefix page host pte is touched (Hendrik Brueckner) [1035261]
- [s390] kvm: Provide a way to prevent reentering SIE (Hendrik Brueckner) [1035261]
- [s390] kvm: Mark if a cpu is in SIE (Hendrik Brueckner) [1035261]
- [s390] kvm: rename RCP_xxx defines to PGSTE_xxx (Hendrik Brueckner) [1035261]
- [s390] kvm: fix psw rewinding in handle_skey (Hendrik Brueckner) [1035261]
- [s390] kvm: Provide function for setting the guest storage key (Hendrik Brueckner) [1035261]
- [s390] facility: decompose test_facility() (Hendrik Brueckner) [1035261]

* Mon Jan 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-68.el7]
- [kernel] perf: Account freq events globally (Jeremy Eder) [1025775]
- [kernel] perf: Roll back callchain buffer refcount under the callchain mutex (Jeremy Eder) [1025775]
- [kernel] watchdog: Make it work under full dynticks (Jeremy Eder) [1025775]
- [kernel] watchdog: Boot-disable by default on full dynticks (Jeremy Eder) [1025775]
- [kernel] watchdog: Rename confusing state variable (Jeremy Eder) [1025775]
- [kernel] watchdog: Register / unregister watchdog kthreads on sysctl control (Jeremy Eder) [1025775]
- [kernel] perf: Implement finer grained full dynticks kick (Jeremy Eder) [1025775]
- [kernel] perf: Account freq events per cpu (Jeremy Eder) [1025775]
- [kernel] perf: Migrate per cpu event accounting (Jeremy Eder) [1025775]
- [kernel] perf: Split the per-cpu accounting part of the event accounting code (Jeremy Eder) [1025775]
- [kernel] perf: Factor out event accounting code to account_event()/__free_event() (Jeremy Eder) [1025775]
- [kernel] perf: Sanitize get_callchain_buffer() (Jeremy Eder) [1025775]
- [kernel] perf: Fix branch stack refcount leak on callchain init failure (Jeremy Eder) [1025775]
- [tools] perf/test: Update command line callchain attribute tests (Jiri Olsa) [1036665]
- [tools] perf: Fixup mmap event consumption (Jiri Olsa) [1036665]
- [tools] perf/top: Split -G and --call-graph (Jiri Olsa) [1036665]
- [tools] perf/record: Split -g and --call-graph (Jiri Olsa) [1036665]
- [tools] perf/hists: Add color overhead for stdio output buffer (Jiri Olsa) [1036665]
- [tools] perf: Fix up /proc/PID/maps parsing (Jiri Olsa) [1036665]
- [tools] perf/script: Fix mem leak due to missing Py_DECREFs on dict entries (Jiri Olsa) [1036665]
- [tools] perf: Disable PERF_RECORD_MMAP2 support (Jiri Olsa) [1036665]
- [tools] perf/scripting/perl: Fix build error on Fedora 12 (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix to initialize fname always before use it (Jiri Olsa) [1036665]
- [tools] perf/session: Fix infinite loop on invalid perf.data file (Jiri Olsa) [1036665]
- [tools] perf: Fix installation of libexec components (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix to find line information for probe list (Jiri Olsa) [1036665]
- [tools] perf: Fix libaudit test (Jiri Olsa) [1036665]
- [tools] perf/stat: Set child_pid after perf_evlist__prepare_workload() (Jiri Olsa) [1036665]
- [tools] perf: Add default handler for mmap2 events (Jiri Olsa) [1036665]
- [tools] perf/symbols: Demangle cloned functions (Jiri Olsa) [1036665]
- [tools] perf/machine: Fix path unpopulated in machine__create_modules() (Jiri Olsa) [1036665]
- [tools] perf: Explicitly add libdl dependency (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix probing symbols with optimization suffix (Jiri Olsa) [1036665]
- [tools] perf/trace: Add mmap2 handler (Jiri Olsa) [1036665]
- [tools] perf/kmem: Make it work again on non NUMA machines (Jiri Olsa) [1036665]
- [tools] perf: Fix capabilities bitfield compatibility in 'struct perf_event_mmap_page' (Jiri Olsa) [1036665]
- [tools] perf: Fix old GCC build error in trace-event-parse.c:parse_proc_kallsyms() (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix finder to find lines of given function (Jiri Olsa) [1036665]
- [tools] perf/session: Check for SIGINT in more loops (Jiri Olsa) [1036665]
- [tools] perf: Fix compile with libelf without get_phdrnum (Jiri Olsa) [1036665]
- [tools] perf: Fix buildid cache handling of kallsyms with kcore (Jiri Olsa) [1036665]
- [tools] perf/annotate: Fix objdump line parsing offset validation (Jiri Olsa) [1036665]
- [tools] perf: Fill in new definitions for madvise()/mmap() flags (Jiri Olsa) [1036665]
- [tools] perf: Sharpen the libaudit dependencies test (Jiri Olsa) [1036665]
- [tools] perf: Add attr->mmap2 support (Jiri Olsa) [1036665]
- [tools] perf/kvm: Fix sample_type manipulation (Jiri Olsa) [1036665]
- [tools] perf/evlist: Fix id pos in perf_evlist__open() (Jiri Olsa) [1036665]
- [tools] perf/trace: Handle perf.data files with no tracepoints (Jiri Olsa) [1036665]
- [tools] perf/session: Separate progress bar update when processing events (Jiri Olsa) [1036665]
- [tools] perf/trace: Check if MAP_32BIT is defined (Jiri Olsa) [1036665]
- [tools] perf/hists: Fix formatting of long symbol names (Jiri Olsa) [1036665]
- [tools] perf/evlist: Fix parsing with no sample_id_all bit set (Jiri Olsa) [1036665]
- [tools] perf: Add test for parsing with no sample_id_all bit (Jiri Olsa) [1036665]
- [tools] perf/trace: Check control+C more often (Jiri Olsa) [1036665]
- [tools] perf/trace: Tell arg formatters the arg index (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for open's flags arg (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for lseek's whence arg (Jiri Olsa) [1036665]
- [tools] perf: Fix symbol offset computation for some dsos (Jiri Olsa) [1036665]
- [tools] perf/list: Skip unsupported events (Jiri Olsa) [1036665]
- [tools] perf/tests: Add 'keep tracking' test (Jiri Olsa) [1036665]
- [tools] perf: Add support for PERF_COUNT_SW_DUMMY (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for futex 'operation' parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow syscall arg formatters to mask args (Jiri Olsa) [1036665]
- [tools] perf/trace: Handle missing HUGEPAGE defines (Jiri Olsa) [1036665]
- [tools] perf/trace: Honor target pid / tid options when analyzing a file (Jiri Olsa) [1036665]
- [tools] perf/trace: Add option to analyze events in a file versus live (Jiri Olsa) [1036665]
- [tools] perf/evlist: Add tracepoint lookup by name (Jiri Olsa) [1036665]
- [tools] perf/tests: Add a sample parsing test (Jiri Olsa) [1036665]
- [tools] perf: Add a function to calculate sample event size (Jiri Olsa) [1036665]
- [tools] perf: Expand perf_event__synthesize_sample() (Jiri Olsa) [1036665]
- [tools] perf: Add missing 'abi' member to 'struct regs_dump' (Jiri Olsa) [1036665]
- [tools] perf: Add support for PERF_SAMPLE_IDENTIFIER (Jiri Olsa) [1036665]
- [tools] perf/evlist: Move perf_evlist__config() to a new source file (Jiri Olsa) [1036665]
- [tools] perf: Remove references to struct ip_event (Jiri Olsa) [1036665]
- [tools] perf/callchain: Remove unnecessary validation (Jiri Olsa) [1036665]
- [tools] perf/evsel: Tidy up sample parsing overflow checking (Jiri Olsa) [1036665]
- [tools] perf: change machine__findnew_thread() to set thread pid (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Fixup jobserver setup (Jiri Olsa) [1036665]
- [tools] perf: Add pid to struct thread (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for madvise behaviour/advice parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for mmap flags parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for mmap prot parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow overiding the formatting of syscall fields (Jiri Olsa) [1036665]
- [tools] perf/trace: Add aliases to remaining syscalls of the sys_enter_newfoo (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow printing syscall return values in hex (Jiri Olsa) [1036665]
- [tools] perf/trace: Simplify sys_exit return printing (Jiri Olsa) [1036665]
- [tools] perf/trace: Introduce syscall arg formatters (Jiri Olsa) [1036665]
- [tools] perf/trace: Hide sys_exit messages about syscall id = -1 (Jiri Olsa) [1036665]
- [tools] perf/trace: Add --verbose option (Jiri Olsa) [1036665]
- [tools] perf/trace: Support ! in -e expressions (Jiri Olsa) [1036665]
- [tools] perf: Don't install scripting files files when disabled (Jiri Olsa) [1036665]
- [tools] perf: Sample after exit loses thread correlation (Jiri Olsa) [1036665]
- [tools] perf/trace: Make command line arguments consistent with perf-record (Jiri Olsa) [1036665]
- [tools] perf/trace: Implement -o/--output filename (Jiri Olsa) [1036665]
- [tools] perf: Add debug prints (Jiri Olsa) [1036665]
- [tools] perf: Re-implement debug print function for linking python/perf.so (Jiri Olsa) [1036665]
- [tools] perf: Try to increase the file descriptor limits on EMFILE (Jiri Olsa) [1036665]
- [tools] perf/kvm: Remove force option to cmd_record (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow specifying which syscalls to trace (Jiri Olsa) [1036665]
- [tools] perf: Improve robustness of topology parsing code (Jiri Olsa) [1036665]
- [tools] perf/tests: Fix compile failure on do_sort_something (Jiri Olsa) [1036665]
- [tools] perf: Remove filter parameter of thread__find_addr_map() (Jiri Olsa) [1036665]
- [tools] perf: Remove filter parameter of thread__find_addr_location() (Jiri Olsa) [1036665]
- [tools] perf: Remove filter parameter of perf_event__preprocess_sample() (Jiri Olsa) [1036665]
- [tools] perf/annotate: Set the machines symbol filter (Jiri Olsa) [1036665]
- [tools] perf/mem: Remove unused symbol filter member (Jiri Olsa) [1036665]
- [tools] perf/report: Set the machines symbol filter (Jiri Olsa) [1036665]
- [tools] perf/top: Set the machines symbol filter (Jiri Olsa) [1036665]
- [tools] perf/machine: Add symbol filter to struct machine (Jiri Olsa) [1036665]
- [tools] perf/session: Change perf_session__has_traces to actually check for tracepoints (Jiri Olsa) [1036665]
- [tools] perf/evsel: Add option to limit stack depth in callchain dumps (Jiri Olsa) [1036665]
- [tools] perf/evsel: Add option to print stack trace on single line (Jiri Olsa) [1036665]
- [tools] perf/tool: Simplify options to perf_evsel__print_ip (Jiri Olsa) [1036665]
- [tools] perf/sched: Remove sched_process_fork tracepoint (Jiri Olsa) [1036665]
- [tools] perf/sched: Remove sched_process_exit tracepoint (Jiri Olsa) [1036665]
- [tools] perf/sched: Remove thread lookup in sample handler (Jiri Olsa) [1036665]
- [tools] perf/sched: Simplify arguments to read_events (Jiri Olsa) [1036665]
- [tools] perf/kvm: Update documentation with live command (Jiri Olsa) [1036665]
- [tools] perf/kvm: Option to print events that exceed a duration (Jiri Olsa) [1036665]
- [tools] perf/machine: Do not require /lib/modules/* on a guest (Jiri Olsa) [1036665]
- [tools] perf/tests: Add tests of new pinned modifier (Jiri Olsa) [1036665]
- [tools] perf: Add support for pinned modifier (Jiri Olsa) [1036665]
- [tools] perf/ui/gtk: Fix segmentation fault on perf_hpp__for_each_format loop (Jiri Olsa) [1036665]
- [tools] perf/kvm: Add option to analyze specific VM (Jiri Olsa) [1036665]
- [tools] perf/kvm: Add min and max stats to display (Jiri Olsa) [1036665]
- [tools] perf/kvm: Add live mode (Jiri Olsa) [1036665]
- [tools] perf/session: Export queue_event function (Jiri Olsa) [1036665]
- [tools] perf/annotate: Fix typo (Jiri Olsa) [1036665]
- [tools] perf/annotate: Improve description of '?' hotkey (Jiri Olsa) [1036665]
- [tools] perf/annotate: Add call target name if it is missing (Jiri Olsa) [1036665]
- [tools] perf/annotate: Remove nop at end of annotation (Jiri Olsa) [1036665]
- [tools] perf/annotate: Put dso name in symbol annotation title (Jiri Olsa) [1036665]
- [tools] perf/annotate: Allow disassembly using /proc/kcore (Jiri Olsa) [1036665]
- [tools] perf/tests: Add kcore to the object code reading test (Jiri Olsa) [1036665]
- [tools] perf/tests: Adjust the vmlinux symtab matches kallsyms test again (Jiri Olsa) [1036665]
- [tools] perf/symbols: Add support for reading from /proc/kcore (Jiri Olsa) [1036665]
- [tools] perf: Make it possible to read object code from kernel modules (Jiri Olsa) [1036665]
- [tools] perf/tests: Adjust the vmlinux symtab matches kallsyms test (Jiri Olsa) [1036665]
- [tools] perf: Make it possible to read object code from vmlinux (Jiri Olsa) [1036665]
- [tools] perf/symbols: Load kernel maps before using (Jiri Olsa) [1036665]
- [tools] perf/tests: Add test for reading object code (Jiri Olsa) [1036665]
- [tools] perf/symbols: avoid SyS kernel syscall aliases (Jiri Olsa) [1036665]
- [tools] perf/stat: Flush output after each line in interval mode (Jiri Olsa) [1036665]
- [tools] perf/stat: Add support for --initial-delay option (Jiri Olsa) [1036665]
- [tools] perf/evsel: Add support for enabling counters (Jiri Olsa) [1036665]
- [tools] perf/evlist: Remove obsolete dummy execve (Jiri Olsa) [1036665]
- [tools] perf/kvm: Split out tracepoints from record args (Jiri Olsa) [1036665]
- [tools] perf/session: Export a few functions for event processing (Jiri Olsa) [1036665]
- [tools] perf/stats: Add max and min stats (Jiri Olsa) [1036665]
- [tools] perf/top: move CONSOLE_CLEAR to header file (Jiri Olsa) [1036665]
- [tools] perf/util: Add parse_nsec_time() function (Jiri Olsa) [1036665]
- [tools] perf/python: Remove duplicate TID bit from mask (Jiri Olsa) [1036665]
- [tools] perf/trace: Beautify 'connect' result (Jiri Olsa) [1036665]
- [tools] perf: Fix compile of util/tsc.c (Jiri Olsa) [1036665]
- [tools] perf/evsel: Actually show symbol offset in stack trace when requested (Jiri Olsa) [1036665]
- [tools] perf: Add test for converting perf time to/from TSC (Jiri Olsa) [1036665]
- [tools] perf: Move weight back to common sort keys (Jiri Olsa) [1036665]
- [tools] perf/tests: Add broken install-* tests into tests/make (Jiri Olsa) [1036665]
- [tools] perf/tests: Add 'make install/install-bin' tests into tests/make (Jiri Olsa) [1036665]
- [tools] perf/tests: Add DESTDIR=TMP_DEST tests/make variable (Jiri Olsa) [1036665]
- [tools] perf/tests: Rename TMP to TMP_O tests/make variable (Jiri Olsa) [1036665]
- [tools] perf/tests: Run ctags/cscope make tests only with needed binaries (Jiri Olsa) [1036665]
- [tools] perf: Fix build with perl 5.18 (Jiri Olsa) [1036665]
- [tools] perf: Support callchain sorting based on addresses (Jiri Olsa) [1036665]
- [tools] perf/bench: Fix memcpy benchmark for large sizes (Jiri Olsa) [1036665]
- [tools] perf/evsel: Handle ENODEV on default cycles event (Jiri Olsa) [1036665]
- [tools] perf/script: Fix named threads support (Jiri Olsa) [1036665]
- [tools] perf/header: Recognize version number for perf data file (Jiri Olsa) [1036665]
- [tools] perf/header: Introduce feat_offset into perf_header (Jiri Olsa) [1036665]
- [tools] perf/header: Remove attr_offset from perf_header (Jiri Olsa) [1036665]
- [tools] perf/header: Remove data_offset seek as it's not needed (Jiri Olsa) [1036665]
- [tools] perf/session: Use session->fd instead of passing fd as argument (Jiri Olsa) [1036665]
- [tools] perf/symbols: Do not apply symfs for an absolute vmlinux path (Jiri Olsa) [1036665]
- [tools] perf: Fix 'make tools/perf' (Jiri Olsa) [1036665]
- [tools] perf: Remove event types framework completely (Jiri Olsa) [1036665]
- [tools] perf/record: Remove event types pushing (Jiri Olsa) [1036665]
- [tools] perf: Remove event types from perf data file (Jiri Olsa) [1036665]
- [tools] perf/timechart: Remove event types framework only user (Jiri Olsa) [1036665]
- [tools] perf/timechart: Use traceevent lib event-parse.h include (Jiri Olsa) [1036665]
- [tools] perf: Move hist_entry__period_snprintf into stdio code (Jiri Olsa) [1036665]
- [tools] perf/report/top: Add option to collapse undesired parts of call graph (Jiri Olsa) [1036665]
- [tools] perf/list: List kernel supplied event aliases (Jiri Olsa) [1036665]
- [tools] perf: Default to cpu// for events v5 (Jiri Olsa) [1036665]
- [tools] perf: struct thread has a tid not a pid (Jiri Olsa) [1036665]
- [tools] perf: Validate perf event header size (Jiri Olsa) [1036665]
- [tools] perf/evlist: Tidy duplicated munmap code (Jiri Olsa) [1036665]
- [tools] perf: Add const specifier to perf_pmu__find name parameter (Jiri Olsa) [1036665]
- [tools] perf/inject: Add missing 'finished_round' (Jiri Olsa) [1036665]
- [tools] perf: Fix missing tool parameter (Jiri Olsa) [1036665]
- [tools] perf/inject: Remove unused parameter (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Set rules hint for the hist browser (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Add a double-click handler for callchains (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Make column headers resizable (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Display callchain overhead also (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Add support for callchains (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Use GtkTreeStore instead of GtkListStore (Jiri Olsa) [1036665]
- [tools] perf/sched: Move struct perf_sched definition out of cmd_sched() (Jiri Olsa) [1036665]
- [tools] perf/util: Remove unused enum and macro in trace-event.h (Jiri Olsa) [1036665]
- [tools] perf/util: No need to call read_trace_init() in tracing_data_header() (Jiri Olsa) [1036665]
- [tools] perf/util: Rename read_*() functions in trace-event-info.c (Jiri Olsa) [1036665]
- [tools] perf/script: Adopt latency_format variable (Jiri Olsa) [1036665]
- [tools] perf/util: Get rid of unused header_page_* variables (Jiri Olsa) [1036665]
- [tools] perf/util: Parse header_page to get proper long size (Jiri Olsa) [1036665]
- [tools] perf/util: Skip reading header_event file (Jiri Olsa) [1036665]
- [tools] perf/util: Make file/host_bigendian variable local (Jiri Olsa) [1036665]
- [tools] perf/util: Save long size of traced system (Jiri Olsa) [1036665]
- [tools] perf/util: Save page size in a trace file to pevent (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Port kbuffer parser routines (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Add page_size field to pevent (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Add trace_seq_reset() (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Add const qualifier to string arguments (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Get rid of unused gui target (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Remove unused install targets (Jiri Olsa) [1036665]
- [tools] perf/parse events: Demystify memory allocations (Jiri Olsa) [1036665]
- [tools] perf/tests: Make terms a stack variable in test_term (Jiri Olsa) [1036665]
- [tools] perf: Don't free list head in parse_events__free_terms (Jiri Olsa) [1036665]
- [tools] perf/evlist: Fix use of uninitialized variable (Jiri Olsa) [1036665]
- [tools] perf/report: Fix perf_session__delete removal (Jiri Olsa) [1036665]
- [tools] perf: Do not elide parent symbol column (Jiri Olsa) [1036665]
- [tools] perf/util: Use evsel->name to get tracepoint_paths (Jiri Olsa) [1036665]
- [tools] perf/util: Move debugfs/tracing helper functions to util.c (Jiri Olsa) [1036665]
- [tools] perf: Remove callchain_cursor_reset call (Jiri Olsa) [1036665]
- [tools] perf: Add methods for setting/retrieving priv element of thread struct (Jiri Olsa) [1036665]
- [tools] perf: Use default include path notation for libtraceevent headers (Jiri Olsa) [1036665]
- [tools] perf/tests: Make TEST_ASSERT_VAL global (Jiri Olsa) [1036665]
- [tools] perf: Remove cwd from perf_session struct (Jiri Olsa) [1036665]
- [tools] perf/top: Add --objdump option (Jiri Olsa) [1036665]
- [tools] perf: Rename cpu_map__all() to cpu_map__empty() (Jiri Olsa) [1036665]
- [tools] perf: Update ABI comment (Jiri Olsa) [1036665]
- [tools] perf: Fix UAPI export of PERF_EVENT_IOC_ID (Jiri Olsa) [1036665]
- [tools] perf: Add a dummy software event to keep tracking (Jiri Olsa) [1036665]
- [tools] perf: Fix up MMAP2 buffer space reservation (Jiri Olsa) [1036665]
- [tools] perf: Add attr->mmap2 attribute to an event (Jiri Olsa) [1036665]
- [tools] perf: make events stream always parsable (Jiri Olsa) [1036665]
- [tools] perf/x86: Add ability to calculate TSC from perf sample timestamps (Jiri Olsa) [1036665]
- [tools] perf: Fix broken union in 'struct perf_event_mmap_page' (Jiri Olsa) [1036665]
- [tools] perf: Update perf_event_type documentation (Jiri Olsa) [1036665]
- [tools] perf: Remove the 'match' callback for auxiliary events processing (Jiri Olsa) [1036665]
- [edac] amd64_edac: Correct erratum 505 range (Kim Naru) [1013820]
- [edac] mce_amd: Add an MCE signature for new Fam15h models (Kim Naru) [1013820]
- [edac] amd64_edac: Fix incorrect wraparounds (Kim Naru) [1013820]
- [edac] amd64_edac: Get rid of boot_cpu_data accesses (Kim Naru) [1013820]
- [edac] amd64_edac: Add ECC decoding support for newer F15h model (Kim Naru) [1013820]
- [block] blk-mq: Don't reserve a tag for flush request (Mike Snitzer) [1048301]
- [lib] percpu_ida: fix a live lock (Mike Snitzer) [1048301]
- [net] ipv4: loopback device: ignore value changes after device is upped (Jiri Pirko) [1040347]
- [net] netfilter: only warn once on wrong seqadj usage (Jesper Brouer) [1031968]
- [net] ipvs: correct usage/allocation of seqadj ext in ipvs (Jesper Brouer) [1031968]
- [net] netfilter: WARN about wrong usage of sequence number adjustments (Jesper Brouer) [1031968]
- [net] vxlan: use custom ndo_change_mtu handler (Daniel Borkmann) [1039848]
- [net] Loosen constraints for recalculating checksum in skb_segment() (Vlad Yasevich) [1042762]
- [net] core: convert class code to use dev_groups (Jiri Benc) [1037452]
- [net] ptp: convert class code to use dev_groups (Jiri Benc) [1037452]

* Tue Jan 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-67.el7]
- [s390] time, vdso: fix clock_gettime for CLOCK_MONOTONIC (Hendrik Brueckner) [1036677]
- [s390] vdso: ectg gettime support for CLOCK_THREAD_CPUTIME_ID (Hendrik Brueckner) [1036677]
- [s390] vdso: fix access-list entry initialization (Hendrik Brueckner) [1036677]
- [s390] time, vdso: convert to the new update_vsyscall interface (Hendrik Brueckner) [1036677]

* Mon Jan 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-66.el7]
- [net] netfilter: fix wrong byte order in nf_ct_seqadj_set internal information (Jesper Brouer) [1045360]
- [net] br: fix use of ->rx_handler_data in code executed on non-rx_handler path (Jiri Pirko) [1039118]
- [net] openvswitch: Use flow hash during flow lookup operation (Francesco Fusco) [1043536]
- [net] openvswitch: TCP flags matching support (Francesco Fusco) [1043536]
- [net] openvswitch: Widen TCP flags handling (Francesco Fusco) [1043536]
- [net] openvswitch: Enable all GSO features on internal port (Francesco Fusco) [1043536]
- [net] openvswitch: collect mega flow mask stats (Francesco Fusco) [1043536]
- [net] openvswitch: Simplify mega-flow APIs (Francesco Fusco) [1043536]
- [net] openvswitch: Move mega-flow list out of rehashing struct (Francesco Fusco) [1043536]
- [net] openvswitch: Restructure datapath.c and flow.c (Francesco Fusco) [1043536]
- [net] openvswitch: remove duplicated include from vport-gre.c (Francesco Fusco) [1043536]
- [net] openvswitch: remove duplicated include from vport-vxlan.c (Francesco Fusco) [1043536]
- [net] openvswitch: Move flow table rehashing to flow install (Francesco Fusco) [1043536]
- [net] openvswitch: flow: fix potential illegal memory access in __parse_flow_nlattrs (Francesco Fusco) [1043536]
- [net] openvswitch: Fix alignment of struct sw_flow_key (Francesco Fusco) [1043536]
- [net] add BUG_ON if kernel advertises msg_namelen > sizeof(struct sockaddr_storage) (Florian Westphal) [1039870] {CVE-2013-7266 CVE-2013-7267 CVE-2013-7268 CVE-2013-7269 CVE-2013-7270 CVE-2013-7271}
- [net] rework recvmsg handler msg_name and msg_namelen logic (Florian Westphal) [1039870] {CVE-2013-7266 CVE-2013-7267 CVE-2013-7268 CVE-2013-7269 CVE-2013-7270 CVE-2013-7271}
- [acpi] acpi_gpio: protect against future KABI breakage (Prarit Bhargava) [1037769]
- [acpi] processor: Introduce apic_id in struct processor to save parsed APIC id (Prarit Bhargava) [1037769]
- [edac] sb_edac: add support for Ivy Bridge (Aristeu Rozanski) [1029153]
- [edac] sb_edac: avoid decoding the same error multiple times (Aristeu Rozanski) [1029153]
- [edac] sb_edac: rename mci_bind_devs() (Aristeu Rozanski) [1029153]
- [edac] sb_edac: enable multiple PCI id tables to be used (Aristeu Rozanski) [1029153]
- [edac] sb_edac: rework sad_pkg (Aristeu Rozanski) [1029153]
- [edac] sb_edac: allow different interleave lists (Aristeu Rozanski) [1029153]
- [edac] sb_edac: allow different dram_rule arrays (Aristeu Rozanski) [1029153]
- [edac] sb_edac: isolate TOHM retrieval (Aristeu Rozanski) [1029153]
- [edac] sb_edac: rename pci_br (Aristeu Rozanski) [1029153]
- [edac] sb_edac: isolate TOLM retrieval (Aristeu Rozanski) [1029153]
- [edac] sb_edac: make RANK_CFG_A value part of sbridge_info (Aristeu Rozanski) [1029153]
- [s390] time: revert direct ktime path for s390 clockevent device (Hendrik Brueckner) [1036682]
- [security] keys: fix uninitialized persistent_keyring_register_sem (Steve Best) [1030472]
- [sched] idle: Fix the idle polling state logic (Jeremy Eder) [1038152]
- [misc] enclosure: fix WARN_ON in dual path device removing (Steve Best) [1030291]
- [security] keys: Pre-clear struct key on allocation (David Howells) [1032980]
- [powerpc] eeh: Use interruptible sleep in keehd (Steve Best) [1044378]

* Thu Jan 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-65.el7]
- [md] fix calculation of stacking limits on level change (Jes Sorensen) [1033479]
- [x86] better solution for x86 single cpu support check (Prarit Bhargava) [1032604]
- [kernel] sched: Fix asymmetric scheduling for POWER7 (Steve Best) [1032796]
- [fs] writeback: Fix data corruption on NFS (Jeff Layton) [1042112]
- [fs] writeback: do not sync data dirtied after sync start (Jeff Layton) [1042112]
- [fs] writeback: fix race that cause writeback hung (Jeff Layton) [1042112]
- [fs] writeback: make writeback_inodes_wb static (Jeff Layton) [1042112]
- [fs] writeback: fix occasional slow sync(1) (Jeff Layton) [1042112]
- [fs] writeback: don't check force_wait to handle bdi->work_list (Jeff Layton) [1042112]
- [fs] fs-writeback: make wb_do_writeback() as static (Jeff Layton) [1042112]
- [fs] writeback: Do not sort b_io list only because of block device inode (Jeff Layton) [1042112]
- [fs] sync: don't block the flusher thread waiting on IO (Jeff Layton) [1042112]
- [security] selinux: process labeled IPsec TCP SYN-ACK packets properly in selinux_ip_postroute() (Paul Moore) [1040183]
- [security] selinux: look for IPsec labels on both inbound and outbound packets (Paul Moore) [1040183]
- [security] selinux: handle TCP SYN-ACK packets correctly in selinux_ip_postroute() (Paul Moore) [1040183]
- [security] selinux: handle TCP SYN-ACK packets correctly in selinux_ip_output() (Paul Moore) [1040183]
- [s390] signal: always restore saved runtime instrumentation psw bit (Hendrik Brueckner) [1029884]
- [s390] fix handling of runtime instrumentation psw bit (Hendrik Brueckner) [1029884]
- [platform] asus-nb-wmi: set wapf=4 for ASUSTeK COMPUTER INC. 1015E/U (Prarit Bhargava) [1043248]
- [platform] asus-nb-wmi: ignore ALS notification key code (Prarit Bhargava) [1043248]
- [fs] gfs2: Fix slab memory leak in gfs2_bufdata (Robert S Peterson) [1038123]
- [fs] gfs2: Fix use-after-free race when calling gfs2_remove_from_ail (Robert S Peterson) [1038123]
- [virt] kvm: fix guest-initiated crash with x2apic (Andrew Jones) [1042101] {CVE-2013-6376}
- [drm] qxl: fix memory leak in release list handling (Dave Airlie) [1035564]
- [scsi] ipr: Increase msi-x interrupt vectors to 16 (Steve Best) [1038501]

* Tue Dec 17 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-64.el7]
- [powerpc] powernv: Don't crash if there are no OPAL consoles (Steve Best) [1033086]
- [powerpc] powernv: Reserve the correct PE number (Steve Best) [1033086]
- [powerpc] powernv: Add PE to its own PELTV (Steve Best) [1033086]
- [powerpc] eeh: Output PHB3 diag-data (Steve Best) [1033086]
- [powerpc] powernv: Double size of log blob (Steve Best) [1033086]
- [powerpc] eeh: Output error number (Steve Best) [1033086]
- [powerpc] powernv: Support inbound error injection (Steve Best) [1033086]
- [powerpc] powernv: Enable EEH for PHB3 (Steve Best) [1033086]
- [powerpc] eeh: Fix undefined variable (Steve Best) [1033086]
- [powerpc] pci: Remove duplicate check in pcibios_fixup_bus() (Steve Best) [1033086]
- [powerpc] powernv: Needn't IO segment map for PHB3 (Steve Best) [1033086]
- [powerpc] powernv: Check primary PHB through ID (Steve Best) [1033086]
- [powerpc] powernv: Fetch PHB bus range from dev-tree (Steve Best) [1033086]
- [powerpc] powernv: Free PHB instance upon error (Steve Best) [1033086]
- [powerpc] eeh: Introdce flag to protect sysfs (Steve Best) [1033086]
- [powerpc] eeh: Fix unbalanced enable for IRQ (Steve Best) [1033086]
- [powerpc] eeh: Don't use pci_dev during BAR restore (Steve Best) [1033086]
- [powerpc] eeh: Use partial hotplug for EEH unaware drivers (Steve Best) [1033086]
- [powerpc] pci: Partial tree hotplug support (Steve Best) [1033086]
- [powerpc] eeh: Use safe list traversal when walking EEH devices (Steve Best) [1033086]
- [powerpc] eeh: Keep PE during hotplug (Steve Best) [1033086]
- [pci] hotplug: Don't need to remove from EEH cache twice (Steve Best) [1033086]
- [powerpc] pci: Override pcibios_release_device() (Steve Best) [1033086]
- [powerpc] eeh: Export functions for hotplug (Steve Best) [1033086]
- [powerpc] eeh: Remove reference to PCI device (Steve Best) [1033086]
- [powerpc] powernv: Use dev-node in PCI config accessors (Steve Best) [1033086]
- [powerpc] eeh: Avoid build warnings (Steve Best) [1033086]
- [powerpc] eeh: Refactor the output message (Steve Best) [1033086]
- [powerpc] eeh: Fix address catch for PowerNV (Steve Best) [1033086]
- [powerpc] powernv: Replace variables with flags (Steve Best) [1033086]
- [powerpc] eeh: Check PCIe link after reset (Steve Best) [1033086]
- [powerpc] eeh: Don't collect PCI-CFG data on PHB (Steve Best) [1033086]
- [powerpc] eeh: Debugfs for error injection (Steve Best) [1033086]
- [powerpc] powernv: Debugfs directory for PHB (Steve Best) [1033086]
- [powerpc] eeh: Register OPAL notifier for PCI error (Steve Best) [1033086]
- [powerpc] powernv/opal: Disable OPAL notifier upon poweroff (Steve Best) [1033086]
- [powerpc] powernv/opal: Notifier for OPAL events (Steve Best) [1033086]
- [powerpc] eeh: Allow to check fenced PHB proactively (Steve Best) [1033086]
- [powerpc] eeh: Enable EEH check for config access (Steve Best) [1033086]
- [powerpc] eeh: Initialization for PowerNV (Steve Best) [1033086]
- [powerpc] eeh: PowerNV EEH backends (Steve Best) [1033086]
- [powerpc] eeh: I/O chip next error (Steve Best) [1033086]
- [powerpc] eeh: I/O chip PE log and bridge setup (Steve Best) [1033086]
- [powerpc] eeh: I/O chip PE reset (Steve Best) [1033086]
- [powerpc] eeh: I/O chip EEH state retrieval (Steve Best) [1033086]
- [powerpc] eeh: I/O chip EEH enable option (Steve Best) [1033086]
- [powerpc] eeh: I/O chip post initialization (Steve Best) [1033086]
- [powerpc] eeh: EEH backend for P7IOC (Steve Best) [1033086]
- [powerpc] eeh: Sync OPAL API with firmware (Steve Best) [1033086]
- [powerpc] eeh: EEH core to handle special event (Steve Best) [1033086]
- [powerpc] eeh: Export confirm_error_lock (Steve Best) [1033086]
- [powerpc] eeh: Allow to purge EEH events (Steve Best) [1033086]
- [powerpc] eeh: Trace time on first error for PE (Steve Best) [1033086]
- [powerpc] eeh: Single kthread to handle events (Steve Best) [1033086]
- [powerpc] eeh: Delay EEH probe during hotplug (Steve Best) [1033086]
- [powerpc] eeh: Refactor eeh_reset_pe_once() (Steve Best) [1033086]
- [powerpc] eeh: EEH post initialization operation (Steve Best) [1033086]
- [powerpc] eeh: Make eeh_init() public (Steve Best) [1033086]
- [powerpc] eeh: Trace PCI bus from PE (Steve Best) [1033086]
- [powerpc] eeh: Make eeh_pe_get() public (Steve Best) [1033086]
- [powerpc] eeh: Make eeh_phb_pe_get() public (Steve Best) [1033086]
- [powerpc] eeh: Move common part to kernel directory (Steve Best) [1033086]
- [powerpc] eeh: Cleanup for EEH core (Steve Best) [1033086]
- [powerpc] eeh: Enhance converting EEH dev (Steve Best) [1033086]
- [s390] crypto: Fix aes-xts parameter corruption (Hendrik Brueckner) [1039937]
- [fs] aio: restore locking of ioctx list on removal (Mateusz Guzik) [1013373]
- [virt] kvm: Convert vapic synchronization to _cached functions (Andrew Jones) [1042092] {CVE-2013-6368}
- [virt] kvm: Fix potential divide by 0 in lapic (Andrew Jones) [1042084] {CVE-2013-6367}
- [virt] kvm: Improve create VCPU parameter (Andrew Jones) [1042074] {CVE-2013-4587}
- [cpufreq] check cpufreq driver is valid and cpufreq isn't disabled in cpufreq_get() (Jan Stancek) [1040409]
- [block] blk-mq: fix memory leaks on unplugging block device (Mike Snitzer) [1040675]
- [block] blk-mq: fix use-after-free of request (Mike Snitzer) [1040675]
- [block] blk-mq: fix dereference of rq->mq_ctx if allocation fails (Mike Snitzer) [1040675]
- [block] blk-mq: add blktrace insert event trace (Mike Snitzer) [1040675]
- [block] blk-mq: ensure that we set REQ_IO_STAT so diskstats work (Mike Snitzer) [1040675]
- [mm] numa: write pte_numa pte back to the page tables (Rik van Riel) [1040200]
- [mm] migrate: fix set cpupid on page migration twice against thp (Rik van Riel) [1040200]
- [mm] numa: Guarantee that tlb_flush_pending updates are visible before page table updates (Rik van Riel) [1040200]
- [sched] fix the theoretical signal_wake_up() vs schedule() race (Rik van Riel) [1040200]
- [sched] Add tracepoints related to NUMA task migration (Rik van Riel) [1040200]
- [mm] numa: Do not automatically migrate KSM pages (Rik van Riel) [1040200]
- [mm] numa: Trace tasks that fail migration due to rate limiting (Rik van Riel) [1040200]
- [mm] numa: Limit scope of lock for NUMA migrate rate limiting (Rik van Riel) [1040200]
- [mm] numa: Make NUMA-migrate related functions static (Rik van Riel) [1040200]
- [mm] numa: Defer TLB flush for THP migration as long as possible (Rik van Riel) [1040200]
- [mm] fix TLB flush race between migration, and change_protection_range (Rik van Riel) [1040200]
- [mm] numa: Avoid unnecessary disruption of NUMA hinting during migration (Rik van Riel) [1040200]
- [mm] numa: Clear numa hinting information on mprotect (Rik van Riel) [1040200]
- [sched] numa: Skip inaccessible VMAs (Rik van Riel) [1040200]
- [mm] numa: Avoid unnecessary work on the failure path (Rik van Riel) [1040200]
- [mm] numa: Ensure anon_vma is locked to prevent parallel THP splits (Rik van Riel) [1040200]
- [mm] numa: Do not clear PTE for pte_numa update (Rik van Riel) [1040200]
- [mm] numa: Do not clear PMD during PTE update scan (Rik van Riel) [1040200]
- [mm] Clear pmd_numa before invalidating (Rik van Riel) [1040200]
- [mm] numa: Call MMU notifiers on THP migration (Rik van Riel) [1040200]
- [mm] numa: Serialise parallel get_user_page against THP migration (Rik van Riel) [1040200]
- [mm] numa: return the number of base pages altered by protection changes (Rik van Riel) [1040200]

* Mon Dec 16 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-63.el7]
- [net] ipv6: router reachability probing (Jiri Benc) [1032118]
- [net] ipv6: remove the unnecessary statement in find_match() (Jiri Benc) [1032118]
- [net] arp/neighbour.h: Remove extern from function prototypes (Jiri Benc) [1032118]
- [net] netfilter: tproxy: fix build with IP6_NF_IPTABLES=n (Jiri Benc) [1035295]
- [net] netfilter: tproxy: remove nf_tproxy_core.h (Jiri Benc) [1035295]
- [net] netfilter: tproxy: remove nf_tproxy_core, keep tw sk assigned to skb (Jiri Benc) [1035295]
- [net] neigh: ipv6: respect default values set before an address is assigned to device (Jiri Pirko) [1040347]
- [net] neigh: restore old behaviour of default parms values (Jiri Pirko) [1040347]
- [net] neigh: use tbl->family to distinguish ipv4 from ipv6 (Jiri Pirko) [1040347]
- [net] neigh: wrap proc dointvec functions (Jiri Pirko) [1040347]
- [net] neigh: convert parms to an array (Jiri Pirko) [1040347]
- [net] net: neighbour: Remove CONFIG_ARPD (Jiri Pirko) [1040347]
- [net] ndisc: bool initializations should use true and false (Jiri Pirko) [1040347]
- [net] ipv4: add support for IFA_FLAGS nl attribute (Jiri Pirko) [1021871]
- [net] ipv6: addrconf: revert /proc/net/if_inet6 ifa_flag format (Jiri Pirko) [1021871]
- [net] ipv6: addrconf: introduce IFA_F_MANAGETEMPADDR to tell kernel to manage temporary addresses (Jiri Pirko) [1021871]
- [net] ipv6: addrconf: extend ifa_flags to u32 (Jiri Pirko) [1021871]
- [net] ipv6: Remove privacy config option (Jiri Pirko) [1021871]
- [net] ipv6: fix leaking uninitialized port number of offender sockaddr (Florian Westphal) [1035884] {CVE-2013-6405}
- [net] inet: fix addr_len/msg->msg_namelen assignment in recv_error and rxpmtu functions (Florian Westphal) [1035884] {CVE-2013-6405}
- [net] inet: prevent leakage of uninitialized memory to user in recv syscalls (Florian Westphal) [1035884] {CVE-2013-6405}
- [net] rename busy poll MIB counter (Michal Schmidt) [1038631]
- [net] rename CONFIG_NET_LL_RX_POLL to CONFIG_NET_RX_BUSY_POLL (Michal Schmidt) [1038631]
- [net] fix a compile error when CONFIG_NET_LL_RX_POLL is not set (Michal Schmidt) [1038631]
- [net] af_packet: block BH in prb_shutdown_retire_blk_timer() (Veaceslav Falico) [1034605]

* Mon Dec 16 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-62.el7]
- [scsi] pm80xx: remove unneeded NULL check (Rich Bono) [1019457]
- [scsi] pm80xx: Fix for 32 bit compilation warning (Rich Bono) [1019457]
- [scsi] pm80xx: Firmware logging support (Rich Bono) [1019457]
- [scsi] pm80xx: Phy settings support for motherboard controller (Rich Bono) [1019457]
- [scsi] pm80xx: IButton security feature support for motherboard controllers (Rich Bono) [1019457]
- [scsi] pm80xx: Print SAS address of IO failed device (Rich Bono) [1019457]
- [scsi] pm80xx: 4G boundary fix (Rich Bono) [1019457]
- [scsi] pm80xx: Queue rotation logic for inbound and outbound queues (Rich Bono) [1019457]
- [scsi] pm80xx: Set device state response logic fix (Rich Bono) [1019457]
- [scsi] pm80xx: Display controller BIOS version (Rich Bono) [1019457]
- [scsi] pm80xx: Indirect SMP request fix (Rich Bono) [1019457]
- [scsi] pm80xx: Device id changes to support series 8 controllers (Rich Bono) [1019457]
- [scsi] bfa: firmware update to 3.2.1.1 (Vijay Guvva) [726968]
- [scsi] bfa: Update the driver version to 3.2.21.1 (Vijay Guvva) [726968]
- [scsi] bfa: Chinook quad port 16G FC HBA claim issue (Vijay Guvva) [726968]
- [scsi] bfa: switch to fixed_size_llseek() (Vijay Guvva) [726968]
- [scsi] bfa: Fix crash when symb name set for offline vport (Vijay Guvva) [726968]
- [scsi] bfa: dis-associate bfa path_tov with dev_loss_tmo (Vijay Guvva) [726968]
- [scsi] bfa: Support for chinook-quad port card (Vijay Guvva) [726968]
- [scsi] bfa: fix endianess issue for firmware stats (Vijay Guvva) [726968]
- [scsi] bfa: Fix bug_on condition in RPSC rsp handling (Vijay Guvva) [726968]
- [scsi] bfa: Allow rsp queue process during ioc disable (Vijay Guvva) [726968]
- [scsi] bfa: firmware statistics update (Vijay Guvva) [726968]
- [scsi] bfa: fru vpd date update changes (Vijay Guvva) [726968]
- [scsi] bfa: driver compatibility with 32bit libs (Vijay Guvva) [726968]
- [scsi] bfa: kdump fix on 815 and 825 adapters (Vijay Guvva) [726968]
- [scsi] bfa: Fix FDISC timeout handling (Vijay Guvva) [726968]
- [scsi] bfa: Fix 1860 port initialize when ATC is enabled (Vijay Guvva) [726968]
- [scsi] bfa: FDMI enhancements (Vijay Guvva) [726968]
- [scsi] bfa: Fix WARN_ON condition check (Vijay Guvva) [726968]
- [scsi] bfa: Add dynamic diagnostic port support (Vijay Guvva) [726968]
- [scsi] bfa: Forward Error Correction status query (Vijay Guvva) [726968]
- [scsi] bfa: Support for FC BB credit recovery (Vijay Guvva) [726968]
- [scsi] bfa: Fixes for 0-terminated strncpy and possible null pointer dereference (Vijay Guvva) [726968]
- [scsi] bfa: fix for FC Direct Attach LUN discovery failure (Vijay Guvva) [726968]
- [scsi] bfa: fix faulty handling of events in lps sm (Vijay Guvva) [726968]
- [maintainers] Add maintainer info for bnx2i (Maurizio Lombardi) [725065]
- [scsi] bnx2i: Update version and copyright year 2013 (Maurizio Lombardi) [725065]
- [s390] uaccess: add missing page table walk range check (Hendrik Brueckner) [1036690]
- [fs] nfsd: don't try to reuse an expired DRC entry off the list (Jeff Layton) [1036971]
- [fs] nfsd: when reusing an existing repcache entry, unhash it first (Jeff Layton) [1036971]
- [s390] pci: implement hotplug notifications (Hendrik Brueckner) [1030312]
- [s390] pci: implement pcibios_remove_bus (Hendrik Brueckner) [1030312]
- [s390] pci: improve handling of bus resources (Hendrik Brueckner) [1030312]
- [s390] pci: cleanup function information block (Hendrik Brueckner) [1030312]
- [s390] pci: remove CONFIG_PCI_DEBUG dependancy (Hendrik Brueckner) [1030312]
- [s390] pci: message cleanup (Hendrik Brueckner) [1030312]
- [s390] pci: implement hibernation hooks (Hendrik Brueckner) [1030312]

* Thu Dec 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-61.el7]
- [ethernet] cxgb3: Fix warning about using rcu_dereference when not in a rcu-locked section (Veaceslav Falico) [1038494]
- [fs] btrfs: relocate csums properly with prealloc extents (Eric Sandeen) [1030074]
- [fs] btrfs: release path before starting transaction in can_nocow_extent (Eric Sandeen) [1030074]
- [fs] btrfs: fix oops caused by the space balance and dead roots (Eric Sandeen) [1030074]
- [fs] btrfs: insert orphan roots into fs radix tree (Eric Sandeen) [1030074]
- [fs] btrfs: limit delalloc pages outside of find_delalloc_range (Eric Sandeen) [1030074]
- [fs] btrfs: Fix crash due to not allocating integrity data for a bioset (Eric Sandeen) [1030074]
- [fs] btrfs: fix a use-after-free bug in btrfs_dev_replace_finishing (Eric Sandeen) [1030074]
- [fs] btrfs: eliminate races in worker stopping code (Eric Sandeen) [1030074]
- [fs] btrfs: fix crash of compressed writes (Eric Sandeen) [1030074]
- [fs] btrfs: fix transid verify errors when recovering log tree (Eric Sandeen) [1030074]
- [fs] vfs: fix subtle use-after-free of pipe_inode_info (Steve Best) [1033905]
- [powerpc] signals: Mark VSX not saved with small contexts (Steve Best) [1019549]
- [security] selinux: correct locking in selinux_netlbl_socket_connect() (Paul Moore) [991605]
- [net] xfrm: Fix potential null pointer dereference in xdst_queue_output (Herbert Xu) [1034891]
- [net] ipv6: introduce function to find route for redirect (Jiri Pirko) [1035996]
- [net] ipv6: handle Redirect ICMP Message with no Redirected Header option (Jiri Pirko) [1035996]

* Fri Dec 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-60.el7]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.20 (Veaceslav Falico) [1034281]
- [s390] allow to set gcc -mtune flag (Hendrik Brueckner) [1032642]
- [net] team: fix master carrier set when user linkup is enabled (Jiri Pirko) [1035258]
- [net] openvswitch: fix vport-netdev unregister (Francesco Fusco) [1004267]

* Thu Dec 05 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-59.el7]
- [pci] Fix whitespace, capitalization, and spelling errors (Myron Stowe) [1033834]
- [pci] Remove duplicate pci_disable_device() from pcie_portdrv_remove() (Myron Stowe) [1033834]
- [pci] Enable upstream bridges even for VFs on virtual buses (Myron Stowe) [1033834]
- [pci] Add pci_upstream_bridge() (Myron Stowe) [1033834]
- [pci] Add x86_msi.msi_mask_irq() and msix_mask_irq() (Myron Stowe) [1033834]
- [pci] Warn on driver probe return value greater than zero (Myron Stowe) [1033834]
- [pci] Drop warning about drivers that don't use pci_set_master() (Myron Stowe) [1033834]
- [pci] Workaround missing pci_set_master in pci drivers (Myron Stowe) [1033834]
- [powerpc] pci: Use pci_is_pcie() to simplify code fix (Myron Stowe) [1033834]
- [pci] Update pcie_ports 'auto' behavior for non-ACPI platforms (Myron Stowe) [1033834]
- [pci] Report pci_pme_active() kmalloc failure (Myron Stowe) [1033834]
- [pci] Fail MSI/MSI-X initialization if device is not in PCI_D0 (Myron Stowe) [1033834]
- [x86] pci: Coalesce multiple overlapping host bridge windows (Myron Stowe) [1033834]
- [misc] MAINTAINERS: Add arch/x86/pci to PCI file patterns (Myron Stowe) [1033834]
- [pci] pm: Remove pci_pm_complete() (Myron Stowe) [1033834]
- [pci] Add pci_dev_show_local_cpu() to simplify code (Myron Stowe) [1033834]
- [pci] Make pci_dev_pm_ops static (Myron Stowe) [1033834]
- [pci] Make pci_bus_attrs, pci_dev_attrs, dev_rescan_attr, dev_remove_attr, vga_attr static (Myron Stowe) [1033834]
- [pci] convert bus code to use dev_groups (Myron Stowe) [1033834]
- [pci] convert bus code to use drv_groups (Myron Stowe) [1033834]
- [pci] convert bus code to use bus_groups (Myron Stowe) [1033834]
- [drm] radeon: use pcie_get_readrq() and pcie_set_readrq() to simplify code (Myron Stowe) [1033834]
- [infiniband] qib: Drop qib_tune_pcie_caps() and qib_tune_pcie_coalesce() return values (Myron Stowe) [1033834]
- [pci] Remove unused PCI_MSIX_FLAGS_BIRMASK definition (Myron Stowe) [1033834]
- [pci] acpiphp_ibm: Convert to dynamic debug (Myron Stowe) [1033834]
- [pci] acpiphp: Convert to dynamic debug (Myron Stowe) [1033834]
- [pci] Remove Intel Haswell D3 delays (Myron Stowe) [1033834]
- [pci] Pass type, width, and prefetchability for window alignment (Myron Stowe) [1033834]
- [pci] Document reason for using pci_is_root_bus() (Myron Stowe) [1033834]
- [pci] Use pci_is_root_bus() to check for root bus (Myron Stowe) [1033834]
- [pci] Remove unused "is_pcie" from pci_dev structure (Myron Stowe) [1033834]
- [pci] Update pci_find_slot() description in pci.txt (Myron Stowe) [1033834]
- [scsi] qla2xxx: Use standard PCIe Capability Link register field names (Myron Stowe) [1033834]
- [pci] Fix comment typo, remove unnecessary !! in pci_is_pcie() (Myron Stowe) [1033834]
- [pci] Drop "setting latency timer" messages (Myron Stowe) [1033834]
- [infiniband] qib: Use pcie_set_mps() and pcie_get_mps() to simplify code (Myron Stowe) [1033834]
- [infiniband] qib: Use pci_is_root_bus() to check whether it is a root bus (Myron Stowe) [1033834]
- [pci] Export pcie_set_mps() and pcie_get_mps() (Myron Stowe) [1033834]
- [acpi] Decode _OSC bitmasks symbolically (Myron Stowe) [1033834]
- [acpi] Separate out _OSC "we don't support enough services" path (Myron Stowe) [1033834]
- [acpi] Separate out _OSC "PCIe port services disabled" path (Myron Stowe) [1033834]
- [acpi] Skip _OSC control tests if _OSC support call failed (Myron Stowe) [1033834]
- [acpi] Run _OSC only once for OSPM feature support (Myron Stowe) [1033834]
- [acpi] Split _OSC "support" and "control" flags into separate variables (Myron Stowe) [1033834]
- [acpi] Move _OSC stuff from acpi_pci_root_add() to negotiate_os_control() (Myron Stowe) [1033834]
- [acpi] Drop unnecessary _OSC existence tests (Myron Stowe) [1033834]
- [pci] Name _OSC #defines more consistently (Myron Stowe) [1033834]
- [acpi] Write OSC_PCI_CONTROL_MASKS like OSC_PCI_SUPPORT_MASKS (Myron Stowe) [1033834]
- [acpi] Remove unused OSC_PCI_NATIVE_HOTPLUG (Myron Stowe) [1033834]
- [acpi] Tidy acpi_run_osc() declarations (Myron Stowe) [1033834]
- [acpi] Rename OSC_QUERY_TYPE to OSC_QUERY_DWORD (Myron Stowe) [1033834]
- [acpi] Write _OSC bit field definitions in hex (Myron Stowe) [1033834]
- [powerpc] pci: Use pci_is_pcie() to simplify code (Myron Stowe) [1033834]
- [scsi] qla2xxx: Use pcie_is_pcie() to simplify code (Myron Stowe) [1033834]
- [scsi] csiostor: Use pcie_capability_clear_and_set_word() to simplify (Myron Stowe) [1033834]
- [scsi] bfa: Use pcie_set()/get_readrq() to simplify code (Myron Stowe) [1033834]
- [x86] pci: Use cached pci_dev->pcie_cap to simplify code (Myron Stowe) [1033834]
- [pci] Use pci_is_pcie() to simplify code (Myron Stowe) [1033834]
- [ethernet] be2net: call napi_disable() for all event queues (Ivan Vecera) [1032872]
- [mm] get rid of unnecessary pageblock scanning in setup_zone_migrate_reserve (Motohiro Kosaki) [1023873]
- [s390] mm: handle asce-type exceptions as normal page fault (Hendrik Brueckner) [1033645]
- [s390] 3270: fix missing device_destroy() call (Hendrik Brueckner) [1032553]
- [s390] boot: Install bzImage as default kernel image (Hendrik Brueckner) [1032548]
- [x86] perf: Fix shared register mutual exclusion enforcement (Jiri Olsa) [1032093]
- [mm] readahead: fix sequential read cache miss detection (Rik van Riel) [1032279]
- [block] fix a race between request completion and timeout handling (Jeff Moyer) [1032138]
- [s390] mm: correct tlb flush on page table upgrade (Hendrik Brueckner) [1029601]

* Wed Dec 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-58.el7]
- [pci] msi: add default MSI operations for !HAVE_GENERIC_HARDIRQS platforms (Myron Stowe) [1034514]
- [of] of_pci: add registry of MSI chips (Myron Stowe) [1034514]
- [pci] Introduce new MSI chip infrastructure (Myron Stowe) [1034514]
- [pci] remove ARCH_SUPPORTS_MSI kconfig option (Myron Stowe) [1034514]
- [pci] use weak functions for MSI arch-specific functions (Myron Stowe) [1034514]
- [of] of_pci: Add of_pci_parse_bus_range() function (Myron Stowe) [1034514]
- [of] of_pci: Add of_pci_get_devfn() function (Myron Stowe) [1034514]
- [fs] sysfs: sysfs_create_groups returns a value (Myron Stowe) [1034491]
- [fs] sysfs: add sysfs_create/remove_groups for when SYSFS is not enabled (Myron Stowe) [1034491]
- [fs] sysfs/group: fix up kerneldoc (Myron Stowe) [1034491]
- [fs] sysfs/group: update copyright to add myself and the LF (Myron Stowe) [1034491]
- [fs] sysfs/group: add kerneldoc for sysfs_remove_group (Myron Stowe) [1034491]
- [fs] sysfs/group: fix up broken string coding style (Myron Stowe) [1034491]
- [fs] sysfs/group: fix up some * coding style issues (Myron Stowe) [1034491]
- [fs] sysfs/group: fix trailing whitespace (Myron Stowe) [1034491]
- [fs] sysfs/group: move EXPORT_SYMBOL_GPL() to the proper location (Myron Stowe) [1034491]
- [fs] sysfs: add sysfs_create/remove_groups() (Myron Stowe) [1034491]
- [base] bus_type: add bus_groups (Myron Stowe) [1034491]
- [base] bus_type: add drv_groups (Myron Stowe) [1034491]
- [base] bus_type: add dev_groups (Myron Stowe) [1034491]
- [ethernet] e1000e: fix overrun of PHY RAR array (John Green) [1031123]
- [kernel] perf/ftrace: Fix paranoid level for enabling function tracer (Jiri Olsa) [1027778] {CVE-2013-2930}
- [powerpc] kdump: Adding symbols in vmcoreinfo to facilitate dump filtering (Steve Best) [1025746]
- [s390] block/dasd: hold request queue sysfs lock when calling elevator_init() (Tomoki Sekiyama) [1030615]
- [block] elevator: acquire q->sysfs_lock in elevator_change() (Tomoki Sekiyama) [1030615]
- [block] elevator: Fix a race in elevator switching and dm device initialization (Tomoki Sekiyama) [1030615]
- [s390] vtime: correct idle time calculation (Hendrik Brueckner) [1029891]
- [s390] time: fix get_tod_clock_ext inline assembly (Hendrik Brueckner) [1029891]
- [s390] time: correct use of store clock fast (Hendrik Brueckner) [1029891]
- [s390] time: return with irqs disabled from psw_idle (Hendrik Brueckner) [1029891]
- [s390] fix save and restore of the floating-point-control register (Hendrik Brueckner) [1029602]
- [s390] compat, signal: change return values to -EFAULT (Hendrik Brueckner) [1029602]
- [net] flow_dissector: fail on evil iph->ihl (Jason Wang) [1007955] {CVE-2013-4348}

* Tue Nov 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-57.el7]
- [acpi] Correct faulty check of Secure Level in acpi_os_get_root_pointer() (Lenny Szubowicz) [1034598]

* Tue Nov 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-56.el7]
- [net] netfilter: push reasm skb through instead of original frag skbs (Jiri Pirko) [1032012]
- [net] ip6_output: fragment outgoing reassembled skb properly (Jiri Pirko) [1032012]
- [net] ipv6: fix headroom calculation in udp6_ufo_fragment (Jiri Pirko) [1030016] {CVE-2013-4563}
- [net] macvtap: limit head length of skb allocated (Jason Wang) [1029380]
- [net] tuntap: limit head length of skb allocated (Jason Wang) [1029380]
- [fs] nfs: check if gssd is running before attempting to use krb5i auth in SETCLIENTID call (Jeff Layton) [998616]
- [net] sunrpc: replace sunrpc_net->gssd_running flag with a more reliable check (Jeff Layton) [998616]
- [net] sunrpc: create a new dummy pipe for gssd to hold open (Jeff Layton) [998616]
- [s390] scm_block: do not hide eadm subchannel dependency (Hendrik Brueckner) [1032542]
- [s390] qeth: avoid buffer overflow in snmp ioctl (Hendrik Brueckner) [1029890]
- [s390] zfcpdump: Add support for XFS (Hendrik Brueckner) [1028103]
- [x86] setup: print out a message if !ACPI (Prarit Bhargava) [1033181]
- [cpufreq] intel_pstate: skip the driver if ACPI has power mgmt option (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Add static declarations to internal functions (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Add Baytrail support (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Refactor driver to support CPUs with different MSR layouts (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Correct calculation of min pstate value (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Improve accuracy by not truncating until final result (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Fix type mismatch warning (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Fix max_perf_pct on resume (Prarit Bhargava) [1031793]
- [cpufreq] add new routine cpufreq_verify_within_cpu_limits() (Prarit Bhargava) [1031793]
- [cpufreq] Optimize cpufreq_frequency_table_verify() (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: fix no_turbo (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Add Haswell CPU models (Prarit Bhargava) [1031793]
- [cpufreq] Drop the owner field from struct cpufreq_driver (Prarit Bhargava) [1031793]
- [cpufreq] Use rwsem for protecting critical sections (Prarit Bhargava) [1031793]
- [cpufreq] delete __cpuinit usage from all cpufreq files (Prarit Bhargava) [1031793]
- [powerpc] ppc64 address space capped at 32TB, mmap randomisation disabled (Steve Best) [1031762]

* Thu Nov 21 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-55.el7]
- [kernel] hung_task: add method to reset detector (Marcelo Tosatti) [987202]
- [virt] pvclock: detect watchdog reset at pvclock read (Marcelo Tosatti) [987202]
- [fs] cifs: stop trying to use virtual circuits (Sachin Prabhu) [1026387]
- [security] keys: Fix keyring content gc scanner (David Howells) [1030482]
- [fs] ext4: fix warning in ext4_da_update_reserve_space() (Lukas Czerner) [1022185]
- [fs] quota: provide interface for readding allocated space into reserved space (Lukas Czerner) [1022185]
- [fs] nfs: don't retry detect_trunking with RPC_AUTH_UNIX more than once (Jeff Layton) [1030404]
- [net] sunrpc: Avoid deep recursion in rpc_release_client (Jeff Layton) [1030404]
- [net] sunrpc: Fix a data corruption issue when retransmitting RPC calls (Jeff Layton) [1030062]
- [fs] nfs: Remove redundant checks in nfs_setsecurity+nfs4_label_init_security (Jeff Layton) [1030725]
- [fs] nfs: Sanity check the server reply in _nfs4_server_capabilities (Jeff Layton) [1030725]
- [fs] nfs: encode_readdir - only ask for labels when doing readdirplus (Jeff Layton) [1030725]
- [fs] nfs: set security label when revalidating inode (Jeff Layton) [1030725]
- [fs] nfs: Fix a mismatch between Linux labeled NFS and the NFSv4.2 spec (Jeff Layton) [1030725]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.18 (Veaceslav Falico) [1028210]

* Thu Nov 21 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-54.el7]
- [fs] gfs2: Fix ref count bug relating to atomic_open (Robert S Peterson) [1032800]

* Mon Nov 18 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-53.el7]
- [ethernet] mlx4: Fix pages never dma unmapped on rx (Steve Best) [1030192]
- [kernel] Add method for displaying affection for Red Hat (Prarit Bhargava) [1025450]
- [powerpc] Fix fatal SLB miss when restoring PPR (Steve Best) [1027633]
- [fs] gfs2: Implement a "rgrp has no extents longer than X" scheme (Robert S Peterson) [1019462]
- [fs] gfs2: Drop inadequate rgrps from the reservation tree (Robert S Peterson) [1019462]
- [fs] gfs2: If requested is too large, use the largest extent in the rgrp (Robert S Peterson) [1019462]
- [fs] gfs2: Add allocation parameters structure (Robert S Peterson) [1019462]
- [security] keys: Fix error handling in big_key instantiation (David Howells) [1029877]
- [kernel] move get_online_cpus/put_online_cpus locking out (Rik van Riel) [1027267]
- [kernel] sched/numa: Cure update_numa_stats() vs. hotplug (Rik van Riel) [1027267]
- [kernel] sched/numa: Fix NULL pointer dereference in task_numa_migrate() (Rik van Riel) [1028100]
- [scsi] hpsa: remove P822se PCI ID (Tomas Henzl) [1029009]
- [scsi] hpsa: correct gen9 PCI IDs (Tomas Henzl) [1029009]
- [scsi] scsi_dh_alua: ALUA handler attach should succeed while TPG is transitioning (Ewan Milne) [1020355]
- [scsi] scsi_dh_alua: ALUA check sense should retry device internal reset unit attention (Ewan Milne) [1020355]
- [scsi] scsi_debug: fix endianness bug in sdebug_build_parts() (Maurizio Lombardi) [1017128]
- [block] blk-mq: don't disallow request merges for req->special being set (Mike Snitzer) [1016109]
- [block] blk-mq: mq plug list breakage (Mike Snitzer) [1016109]
- [block] blk-mq: fix for flush deadlock (Mike Snitzer) [1016109]
- [block] blk-mq: add blk_mq_stop_hw_queues (Mike Snitzer) [1016109]
- [block] blk-mq: fix permissions for ipi_redirect sysfs attribute (Mike Snitzer) [1016109]
- [block] blk-mq: zero out ctx_map during initialization (Mike Snitzer) [1016109]
- [block] blk-mq: cache rq->q (Mike Snitzer) [1016109]
- [block] blk-mq: use a separate plug list for blk-mq requests (Mike Snitzer) [1016109]
- [block] blk-mq: switch to percpu-ida for tag management (Mike Snitzer) [1016109]
- [lib] percpu_ida: add an API to return free tags (Mike Snitzer) [1016109]
- [lib] percpu_ida: add percpu_ida_for_each_free (Mike Snitzer) [1016109]
- [lib] percpu_ida: make percpu_ida percpu size/batch configurable (Mike Snitzer) [1016109]
- [lib] idr: Percpu ida (Mike Snitzer) [1016109]
- [block] blk-mq: call exit_hctx on hw queue teardown (Mike Snitzer) [1016109]
- [lib] percpu_counter: __this_cpu_write() doesn't need to be protected by spinlock (Mike Snitzer) [1016109]
- [block] blk-mq: fix blk_mq_start_stopped_hw_queues from irq context (Mike Snitzer) [1016109]
- [block] blk-mq: cleanup blk_mq_bio_to_request (Mike Snitzer) [1016109]
- [block] blk-mq: kill blk_mq_finish_request (Mike Snitzer) [1016109]
- [block] blk-mq: always complete bios in blk_mq_complete_request (Mike Snitzer) [1016109]
- [block] blk-mq: dont call blk_mq_free_request from blk_mq_finish_request (Mike Snitzer) [1016109]
- [block] blk-mq: more careful bio completion (Mike Snitzer) [1016109]
- [block] use blk-exec.c infrastructure for blk-mq (Mike Snitzer) [1016109]
- [block] make blk_get_put_request work for blk-mq drivers (Mike Snitzer) [1016109]
- [block] remove request ref_count (Mike Snitzer) [1016109]
- [block] blk-mq: Lower minimum queue depth from 4 to 1 (Mike Snitzer) [1016109]
- [block] blk-mq: Do not fail blk_mq_reg::queue_depth value of zero (Mike Snitzer) [1016109]
- [block] blk-mq: Do not allocate more cache entries than used (Mike Snitzer) [1016109]
- [block] blk-mq: Check queue depth is valid (Mike Snitzer) [1016109]
- [block] blk-mq: Sanity check reserved tags (Mike Snitzer) [1016109]

* Fri Nov 15 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-52.el7]
- [x86] trace: Change user|kernel_page_fault to page_fault_user|kernel (Seiji Aguchi) [726853]
- [x86] trace: Add page fault tracepoints (Seiji Aguchi) [726853]
- [x86] trace: Delete __trace_alloc_intr_gate() (Seiji Aguchi) [726853]
- [x86] trace: Register exception handler to trace IDT (Seiji Aguchi) [726853]
- [x86] trace: Remove __alloc_intr_gate() (Seiji Aguchi) [726853]
- [kernel] audit: call audit_bprm() only once to add AUDIT_EXECVE information (Richard Guy Briggs) [1010367]
- [kernel] audit: move audit_aux_data_execve contents into audit_context union (Richard Guy Briggs) [1010367]
- [kernel] audit: remove unused envc member of audit_aux_data_execve (Richard Guy Briggs) [1010367]
- [kernel] audit: Kill the unused struct audit_aux_data_capset (Richard Guy Briggs) [1010367]
- [fs] gfs2: fix dentry leaks (Abhijith Das) [1010350]
- [fs] gfs2: d_splice_alias() can't return error (Abhijith Das) [1010350]
- [fs] atomic_open: take care of EEXIST in no-open case with O_CREAT|O_EXCL in fs/namei.c (Abhijith Das) [1010350]
- [fs] vfs: don't set FILE_CREATED before calling ->atomic_open() (Abhijith Das) [1010350]
- [fs] nfs: set FILE_CREATED (Abhijith Das) [1010350]
- [fs] gfs2: set FILE_CREATED (Abhijith Das) [1010350]
- [fs] vfs: improve i_op->atomic_open() documentation (Abhijith Das) [1010350]
- [net] svcrpc: set cr_gss_mech from gss-proxy as well as legacy upcall (J. Bruce Fields) [1026643]
- [mm] zbud: fix condition check on allocation size (Jerome Marchand) [1009496]
- [kernel] sched: Optimize task_sched_runtime() (Larry Woodman) [986058]
- [x86] setup: add a customer friendly message for single cpu systems (Prarit Bhargava) [1009066]
- [x86] efi: Disable secure boot if shim is in insecure mode (Lenny Szubowicz) [1004888]
- [kernel] modsign: Support not importing certs from db (Lenny Szubowicz) [1004888]
- [kernel] modsign: Import certificates from UEFI Secure Boot (Lenny Szubowicz) [1004888]
- [kernel] keys: Add a system blacklist keyring (Lenny Szubowicz) [1004888]
- [crypto] asymmetric_keys: Add an EFI signature blob parser and key loader (Lenny Szubowicz) [1004888]
- [kernel] efi: Add EFI signature data types (Lenny Szubowicz) [1004888]
- [kernel] hibernate: Disable if securelevel above zero (Lenny Szubowicz) [903815]
- [x86] efi: Add EFI_SECURE_BOOT bit (Lenny Szubowicz) [903815]
- [x86] Add option to automatically set securelevel when in Secure Boot mode (Lenny Szubowicz) [903815]
- [platform] asus-wmi: Restrict debugfs interface when securelevel is set (Lenny Szubowicz) [903815]
- [x86] Restrict MSR access when securelevel is set (Lenny Szubowicz) [903815]
- [kernel] uswsusp: Disable when securelevel is set (Lenny Szubowicz) [903815]
- [kernel] kexec: Disable at runtime if securelevel has been set (Lenny Szubowicz) [903815]
- [acpi] Ignore acpi_rsdp kernel parameter when securelevel is set (Lenny Szubowicz) [903815]
- [acpi] Limit access to custom_method if securelevel is set (Lenny Szubowicz) [903815]
- [char] mem: Restrict /dev/mem and /dev/kmem when securelevel is set (Lenny Szubowicz) [903815]
- [x86] Lock down IO port access when securelevel is enabled (Lenny Szubowicz) [903815]
- [pci] Lock down BAR access when securelevel is enabled (Lenny Szubowicz) [903815]
- [x86] Enforce module signatures when securelevel is greater than 0 (Lenny Szubowicz) [903815]
- [kernel] Add BSD-style securelevel support (Lenny Szubowicz) [903815]

* Thu Nov 14 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-51.el7]
- [net] nfnetlink: do not ack malformed messages (Jiri Benc) [1023123]
- [net] netfilter: nft_compat: use _safe version of list_for_each (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: remove duplicated include from nf_tables_ipv4.c (Jiri Benc) [1023123]
- [net] netfilter: bridge: nf_tables: add filter chain type (Jiri Benc) [1023123]
- [net] netfilter: nft_nat: Fix endianness issue reported by sparse (Jiri Benc) [1023123]
- [net] netfilter: bridge: fix nf_tables bridge dependencies with main core (Jiri Benc) [1023123]
- [net] nf_tables: mark as Tech Preview (Jiri Benc) [1023123]
- [net] nf_tables: stuff structures to preserve kABI in the future (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add ARP filtering support (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add trace support (Jiri Benc) [1023123]
- [net] netfilter: nfnetlink: add batch support and use it from nf_tables (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add insert operation (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: complete net namespace support (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: Add support for IPv6 NAT (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add support for dormant tables (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: nft_payload: fix transport header base (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add compatibility layer for x_tables (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: convert built-in tables/chains to chain types (Jiri Benc) [1023123]
- [net] netfilter: nft_payload: add optimized payload implementation for small loads (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add optimized data comparison for small values (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: expression ops overloading (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add netlink set API (Jiri Benc) [1023123]
- [net] netfilter: add nftables (Jiri Benc) [1023123]
- [net] netfilter: nf_nat: move alloc_null_binding to nf_nat_core.c (Jiri Benc) [1023123]
- [net] netfilter: pass hook ops to hookfn (Jiri Benc) [1023123]
- [net] netlink: fix splat in skb_clone with large messages (Jiri Benc) [1023123]
- [net] netlink: allow large data transfers from user-space (Jiri Benc) [1023123]

* Wed Nov 13 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-50.el7]
- [virt] hyperv/vmbus: Fix a bug in channel rescind code (Jason Wang) [1017564]
- [virt] hyperv: Fix wrong check for synic_event_page (Jason Wang) [1017564]
- [virt] hyperv/vmbus: fix vmbus_recvpacket_raw() return code (Jason Wang) [1017564]
- [virt] hyperv/input: add a driver to support Hyper-V synthetic keyboard (Jason Wang) [1017564]
- [virt] hyperv: Correctly guard the local APIC calibration code (Jason Wang) [1017564]
- [virt] hyperv: Get the local APIC timer frequency from the hypervisor (Jason Wang) [1017564]
- [kernel] stop_machine: fix race between stop_two_cpus and stop_cpus (Rik van Riel) [1023627]
- [video] fb: make fp_get_options name argument const (Rob Clark) [1018414]
- [drm] nouveau/device: recognise GK208 (Rob Clark) [1018414]
- [drm] nouveau/graph: fix a number of missing explicit array terminators (Rob Clark) [1018414]
- [drm] nouveau/disp: semi-complete link training sequence even if display disappears (Rob Clark) [1018414]
- [drm] nouveau/bios: some older boards have shorter displayport tables (Rob Clark) [1018414]
- [drm] nouveau/fbcon: bracket entrypoints with a per-device enabled check (Rob Clark) [1018414]
- [drm] nouveau/disp: reorder writes to lane current control regs (Rob Clark) [1018414]
- [drm] nouveau/disp: reorder writes to lane current control regs (Rob Clark) [1018414]
- [drm] nouveau/disp: log if DP link training fails (Rob Clark) [1018414]
- [drm] nouveau/disp: disable display underflow reporting at init (Rob Clark) [1018414]
- [drm] nouveau/clock: fix accidental limiting of pll coefficients (Rob Clark) [1018414]
- [drm] nouveau/device: use an additional bit from NV_PMC_BOOT_0 to identify chipset (Rob Clark) [1018414]
- [drm] nouveau/bios/init: return failure condition on invalid opcodes (Rob Clark) [1018414]
- [drm] nouveau/therm: ack any pending IRQ at init (Rob Clark) [1018414]
- [drm] nouveau/therm: kill some over-zealous debugging (Rob Clark) [1018414]
- [drm] radeon: don't use PACKET2 on CIK (Rob Clark) [1018414]
- [drm] nouveau: split lock into list+exec and enable refcount locks (Rob Clark) [1018414]
- [drm] nouveau: convert event handler apis to split create/enable semantics (Rob Clark) [1018414]
- [drm] nouveau: share engine/channel constructor between implementations (Rob Clark) [1018414]
- [drm] nouveau: prepare for the sharing of constructors between implementations (Rob Clark) [1018414]
- [drm] nouveau: make vblank tracking data private to the implementations (Rob Clark) [1018414]
- [drm] nouveau: share engine/channel struct definitions between implementations (Rob Clark) [1018414]
- [drm] nouveau: Allow asymmetric nouveau_event_get/_put (Rob Clark) [1018414]
- [drm] nouveau: Move event index check from critical section (Rob Clark) [1018414]
- [drm] nouveau: Add priv field for event handlers (Rob Clark) [1018414]
- [drm] nouveau: off by one in nouveau_drm_vblank_enable() (Rob Clark) [1018414]
- [drm] backport to Linux 3.12-rc7 (Rob Clark) [1018414]
- [firmware] dmi: add support for exact DMI matches in addition to substring matching (Rob Clark) [1025360]
- [vga] vga_switcheroo: add driver control power feature (Rob Clark) [1025360]
- [mm] vmscan: new shrinker API (Rob Clark) [1025360]
- [kernel] Add arch_phys_wc_{add, del} to manipulate WC MTRRs if needed (Rob Clark) [1025360]
- [kernel] mutex: Move ww_mutex definitions to ww_mutex.h (Rob Clark) [1025360]
- [kernel] reservation: cross-device reservation support (Rob Clark) [1025360]
- [kernel] locking-selftests: Handle unexpected failures more strictly (Rob Clark) [1025360]
- [kernel] mutex: Add more w/w tests to test EDEADLK path handling (Rob Clark) [1025360]
- [kernel] mutex: Add more tests to lib/locking-selftest.c (Rob Clark) [1025360]
- [kernel] mutex: Add w/w tests to lib/locking-selftest.c (Rob Clark) [1025360]
- [kernel] mutex: Add w/w mutex slowpath debugging (Rob Clark) [1025360]
- [kernel] mutex: Add support for wound/wait style locks (Rob Clark) [1025360]
- [kernel] mutex: Make __mutex_fastpath_lock_retval return whether fastpath succeeded or not (Rob Clark) [1025360]

* Tue Nov 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-49.el7]
- [usb] misc/usb3503: Fix compile error due to incorrect regmap depedency (Don Zickus) [895641]
- [usb] storage: add quirk for mandatory READ_CAPACITY_16 (Don Zickus) [895641]
- [usb] serial/option: blacklist Olivetti Olicard200 (Don Zickus) [895641]
- [usb] quirks: add touchscreen that is dazzeled by remote wakeup (Don Zickus) [895641]
- [usb] quirks: add one device that cannot deal with suspension (Don Zickus) [895641]
- [usb] serial/option: add support for Inovia SEW858 device (Don Zickus) [895641]
- [usb] serial/ti_usb_3410_5052: add Abbott strip port ID to combined table as well (Don Zickus) [895641]
- [usb] support new huawei devices in option.c (Don Zickus) [895641]
- [usb] xhci: Fix spurious wakeups after S5 on Haswell (Don Zickus) [895641]
- [usb] xhci: fix write to USB3_PSSEN and XUSB2PRM pci config registers (Don Zickus) [895641]
- [usb] xhci: quirk for extra long delay for S4 (Don Zickus) [895641]
- [usb] xhci: Don't enable/disable RWE on bus suspend/resume (Don Zickus) [895641]
- [net] usbnet: fix handling padding packet (Don Zickus) [895641]
- [usb] imx21: accept very late isochronous URBs (Don Zickus) [895641]
- [usb] core: check usb device's state before sending a Set SEL control transfer (Don Zickus) [895641]
- [usb] xhci: Fix xHCI host issues on remote wakeup (Don Zickus) [1016889]
- [usb] serial/pl2303: distinguish between original and cloned HX chips (Don Zickus) [895641]
- [usb] fix typo in usb serial simple driver Kconfig (Don Zickus) [895641]
- [usb] core: fix incorrect type in assignment in descriptors_changed() (Don Zickus) [895641]
- [usb] core: compare and release one bos descriptor in usb_reset_and_verify_device() (Don Zickus) [895641]
- [usb] ehci: remove debugging statement with ehci statistics in ehci_stop() (Don Zickus) [895641]
- [usb] ehci: remove duplicate debug_async_open() prototype in ehci-dbg.c (Don Zickus) [895641]
- [usb] ehci: enable debugging code when CONFIG_DYNAMIC_DEBUG is set (Don Zickus) [895641]
- [usb] ehci: remove ehci_vdbg() verbose debugging statements (Don Zickus) [895641]
- [usb] xhci: Fix warning introduced by disabling runtime PM (Don Zickus) [1016889]
- [usb] storage: audit sysfs attribute permissions (Don Zickus) [895641]
- [usb] xhci: prevent "callbacks suppressed" when debug is not enabled (Don Zickus) [1016889]
- [usb] xhci: fix port BESL LPM capability checking (Don Zickus) [1016889]
- [usb] ohci: fix build error related to ohci_suspend/resume (Don Zickus) [895641]
- [usb] serial: clean up attribute permissions (Don Zickus) [895641]
- [usb] usbtmc: fix up attribute permissions (Don Zickus) [895641]
- [usb] core: be specific about attribute permissions (Don Zickus) [895641]
- [usb] core: use DRIVER_ATTR_RW() (Don Zickus) [895641]
- [usb] don't use bNbrPorts after initialization (Don Zickus) [895641]
- [usb] fail on usb_hub_create_port_device() errors (Don Zickus) [895641]
- [usb] fix cleanup after failure in hub_configure() (Don Zickus) [895641]
- [usb] ohci: add missing PCI PM callbacks to ohci-pci.c (Don Zickus) [895641]
- [usb] serial: fix stringify operator in usb-serial-simple (Don Zickus) [895641]
- [usb] wusbcore: Use usb_init_urb instead of creating the URB manually (Don Zickus) [895641]
- [usb] wusbcore: fix leak of urb in wa_xfer_destroy (Don Zickus) [895641]
- [usb] wusbcore: fix resource cleanup in error path in __wa_xfer_setup_segs (Don Zickus) [895641]
- [usb] wusbcore: clear RPIPE stall for control endpoints (Don Zickus) [895641]
- [usb] uss720: fix DMA-buffer allocation (Don Zickus) [895641]
- [usb] quatech2: fix port DMA-buffer allocations (Don Zickus) [895641]
- [usb] quatech2: fix serial DMA-buffer allocations (Don Zickus) [895641]
- [usb] keyspan: fix port DMA-buffer allocations (Don Zickus) [895641]
- [usb] keyspan: fix serial DMA-buffer allocations (Don Zickus) [895641]
- [usb] rh_call_control tbuf overflow fix (Don Zickus) [895641]
- [usb] host: add Kconfig option for EHSET (Don Zickus) [895641]
- [usb] serial/pl2303: improve the chip type detection/distinction (Don Zickus) [895641]
- [usb] serial/pl2303: improve the chip type information output on startup (Don Zickus) [895641]
- [usb] serial/pl2303: simplify the else-if contruct for type_1 chips in pl2303_startup() (Don Zickus) [895641]
- [usb] xhci: fix dma mask setup in xhci.c (Don Zickus) [1016889]
- [usb] xhci: trace debug statements related to ring expansion (Don Zickus) [1016889]
- [usb] xhci: trace debug messages related to driver initialization and unload (Don Zickus) [1016889]
- [usb] xhci: trace debug statements for urb cancellation (Don Zickus) [1016889]
- [usb] xhci: add xhci_cmd_completion trace event (Don Zickus) [1016889]
- [usb] xhci: add xhci_address_ctx trace event (Don Zickus) [1016889]
- [usb] xhci: add trace for debug messages related to endpoint reset (Don Zickus) [1016889]
- [usb] xhci: add trace for debug messages related to quirks (Don Zickus) [1016889]
- [usb] xhci: add trace for debug messages related to changing contexts (Don Zickus) [1016889]
- [usb] xhci: add traces for debug messages in xhci_address_device() (Don Zickus) [1016889]
- [usb] xhci: remove CONFIG_USB_XHCI_HCD_DEBUGGING and unused code (Don Zickus) [1016889]
- [usb] xhci: replace printk(KERN_DEBUG ...) (Don Zickus) [1016889]
- [usb] xhci: replace xhci_info() with xhci_dbg() (Don Zickus) [1016889]
- [usb] xhci: Add Device Tree support to XHCI Platform driver (Don Zickus) [1016889]
- [usb] serial/pl2303: add two comments concerning the supported baud rates with HX chips (Don Zickus) [895641]
- [usb] serial/pl2303: also use the divisor based baud rate encoding method for baud rates < 115200 with HX chips (Don Zickus) [895641]
- [usb] serial/pl2303: increase the allowed baud rate range for the divisor based encoding method (Don Zickus) [895641]
- [usb] serial/pl2303: move the two baud rate encoding methods to separate functions (Don Zickus) [895641]
- [usb] serial/pl2303: remove 500000 baud from the list of standard baud rates (Don Zickus) [895641]
- [usb] serial/pl2303: do not round to the next nearest standard baud rate for the divisor based baud rate encoding method (Don Zickus) [895641]
- [usb] serial/pl2303: fix the upper baud rate limit check for type_0/1 chips (Don Zickus) [895641]
- [usb] serial/pl2303: fix+improve the divsor based baud rate encoding method (Don Zickus) [895641]
- [usb] hwa: avoid constant suspend and resume on the root hub (Don Zickus) [895641]
- [usb] adutux: fix big-endian device-type reporting (Don Zickus) [895641]
- [usb] usbtmc: fix big-endian probe of Rigol devices (Don Zickus) [895641]
- [usb] wusbcore: clean up list locking in urb enqueue (Don Zickus) [895641]
- [usb] wusbcore: fix root hub hub_status_data to only return > 0 if status has actually changed (Don Zickus) [895641]
- [usb] ehci: Add support for SINGLE_STEP_SET_FEATURE test of EHSET (Don Zickus) [895641]
- [usb] hcd: Log error code if reset() fails (Don Zickus) [895641]
- [usb] misc/usb3503: Support operation with no I2C control (Don Zickus) [895641]
- [usb] misc/usb3503: Add USB3503A to the compatible list (Don Zickus) [895641]
- [usb] misc/usb3503: Default to hub mode (Don Zickus) [895641]
- [usb] misc/usb3503: Fix typos in error messages (Don Zickus) [895641]
- [usb] misc/usb3503: Factor out I2C probe (Don Zickus) [895641]
- [usb] misc/usb3503: Convert to regmap (Don Zickus) [895641]
- [usb] misc/usb3503: Actively manage Hub Connect GPIO (Don Zickus) [895641]
- [usb] misc/usb3503: Use gpio_set_value_cansleep() (Don Zickus) [895641]
- [usb] Move definition of USB_EHCI_BIG_ENDIAN_MMIO et al. out side of the ifs (Don Zickus) [895641]
- [usb] misc/usb3503: Convert to devm_ APIs (Don Zickus) [895641]
- [usb] serial: move the "simple" drivers into usb-serial-simple.c (Don Zickus) [895641]
- [net] usbnet: support DMA SG (Don Zickus) [895641]
- [usb] xhci: mark no_sg_constraint (Don Zickus) [1016889]
- [usb] introduce usb_device_no_sg_constraint() helper (Don Zickus) [895641]
- [usb] ehci: support running URB giveback in tasklet context (Don Zickus) [895641]
- [usb] ehci: improve interrupt qh unlink (Don Zickus) [895641]
- [usb] ehci: improve ehci_endpoint_disable (Don Zickus) [895641]
- [usb] hcd: support giveback of URB in tasklet context (Don Zickus) [895641]
- [usb] fix some scripts/kernel-doc warnings (Don Zickus) [895641]
- [usb] ehci: don't depend on hardware for tracking port resets and resumes (Don Zickus) [895641]
- [usb] ehci: keep better track of resuming ports (Don Zickus) [895641]
- [usb] pl2303: restrict the divisor based baud rate encoding method to the "HX" chip type (Don Zickus) [895641]
- [usb] refactor code for enabling/disabling remote wakeup (Don Zickus) [895641]
- [usb] simplify the interface of usb_get_status() (Don Zickus) [895641]
- [usb] xhci: add missing dma-mapping.h includes (Don Zickus) [895641]
- [net] usbnet: centralize computing of max rx/tx qlen (Don Zickus) [895641]
- [usb] serial: add driver for Suunto ANT+ USB device (Don Zickus) [895641]
- [usb] ohci_usb warn "irq nobody cared" on shutdown (Don Zickus) [895641]
- [usb] ohci-ep93xx: tidy up driver (*probe) and (*remove) (Don Zickus) [895641]
- [usb] ohci-ep93xx: use devm_clk_get() (Don Zickus) [895641]
- [usb] ohci-ep93xx: use platform_get_irq() (Don Zickus) [895641]
- [usb] ohci-ep93xx: use devm_ioremap_resource() (Don Zickus) [895641]
- [usb] usb-skeleton: add retry for nonblocking read (Don Zickus) [895641]
- [usb] usbtmc: convert to devm_kzalloc (Don Zickus) [895641]
- [usb] usbtmc: remove redundant braces (Don Zickus) [895641]
- [usb] usbtmc: call pr_err instead of plain printk (Don Zickus) [895641]
- [usb] usbtmc: remove trailing spaces (Don Zickus) [895641]
- [usb] usbfs: Allow printer class 'get_device_id' without needing to claim the intf (Don Zickus) [895641]
- [usb] remove redundant "#if" (Don Zickus) [895641]
- [usb] misc: EHSET Test Fixture device driver for host compliance (Don Zickus) [895641]
- [usb] clamp bInterval to allowed range (Don Zickus) [895641]
- [usb] atm/speedtch: be careful with bInterval (Don Zickus) [895641]
- [usb] cdc-acm: be careful with bInterval (Don Zickus) [895641]
- [usb] fix build warning in pci-quirks.h when CONFIG_PCI is not enabled (Don Zickus) [895641]
- [usb] xhci: Mark two functions __maybe_unused (Don Zickus) [895641]
- [usb] check sg buffer size in usb_submit_urb (Don Zickus) [895641]
- [usb] isp1362: move debug files from proc to debugfs (Don Zickus) [895641]
- [usb] sl811: move debug files from proc to debugfs (Don Zickus) [895641]
- [usb] remove unneeded idr.h include (Don Zickus) [895641]
- [usb] sl811: remove CONFIG_USB_DEBUG dependency (Don Zickus) [895641]
- [usb] isp116x: remove dependency on CONFIG_USB_DEBUG (Don Zickus) [895641]
- [usb] isp1362: remove CONFIG_USB_DEBUG dependency (Don Zickus) [895641]
- [usb] isp1362: remove _DBG() usage (Don Zickus) [895641]
- [usb] isp1362: remove unused _WARN_ON() calls (Don Zickus) [895641]
- [usb] isp1362: remove unused _BUG_ON() calls (Don Zickus) [895641]
- [usb] usbatm: remove CONFIG_USB_DEBUG dependancy (Don Zickus) [895641]
- [usb] usbatm: move the atm_dbg() call to use dynamic debug (Don Zickus) [895641]
- [usb] usbatm: don't rely on CONFIG_USB_DEBUG (Don Zickus) [895641]
- [usb] usbatm: remove unneeded trace printk calls (Don Zickus) [895641]
- [usb] usbatm: remove unused UDSL_ASSERT macro (Don Zickus) [895641]
- [usb] ti_usb_3410_5052: remove vendor/product module parameters (Don Zickus) [895641]
- [usb] ti_usb_3410_5052: remove unused wait queue (Don Zickus) [895641]
- [usb] ti_usb_3410_5052: kill private fifo (Don Zickus) [895641]
- [usb] safe_serial: remove vendor/product module parameters (Don Zickus) [895641]
- [usb] mos7840: remove broken chase implementation (Don Zickus) [895641]
- [usb] io_ti: move port initialisation to probe (Don Zickus) [895641]
- [usb] io_ti: kill private fifo (Don Zickus) [895641]
- [usb] io_edgeport: remove unused defines (Don Zickus) [895641]
- [usb] ftdi_sio: remove unused defines (Don Zickus) [895641]
- [usb] ftdi_sio: remove vendor/product module parameters (Don Zickus) [895641]
- [usb] ftdi_sio: remove redundant raise of DTR/RTS at open (Don Zickus) [895641]
- [usb] ftdi_sio: clean up device initialisation (Don Zickus) [895641]
- [usb] oti6858: do not call set_termios with uninitialised data (Don Zickus) [895641]
- [usb] pl2303: remove debugging noise (Don Zickus) [895641]
- [usb] pl2303: clean up set_termios (Don Zickus) [895641]
- [usb] pl2303: clean up baud-rate handling (Don Zickus) [895641]
- [usb] pl2303: refactor baud-rate handling (Don Zickus) [895641]
- [usb] console: remove unnecessary operations test (Don Zickus) [895641]
- [usb] console: use dev_dbg (Don Zickus) [895641]
- [usb] serial: set drain delay at port probe (Don Zickus) [895641]
- [usb] serial: clean up dtr_rts (Don Zickus) [895641]
- [usb] serial: remove hupping check from tiocmiwait (Don Zickus) [895641]
- [usb] serial: remove defensive test from set_termios (Don Zickus) [895641]
- [usb] misc: remove CONFIG_USB_DEBUG from Makefile (Don Zickus) [895641]
- [usb] adutux: remove direct calls to printk() (Don Zickus) [895641]
- [usb] adutux: remove custom debug macro and module parameter (Don Zickus) [895641]
- [usb] adutux: remove custom debug macro (Don Zickus) [895641]
- [usb] adutux: remove unneeded tracing macros (Don Zickus) [895641]
- [usb] legotower: remove direct calls to printk() (Don Zickus) [895641]
- [usb] legotower: remove custom debug macro and module parameter (Don Zickus) [895641]
- [usb] legousbtower: remove custom debug macro (Don Zickus) [895641]
- [usb] legotower: remove unneeded tracing macros (Don Zickus) [895641]
- [usb] ldusb: remove custom dbg_info() macro (Don Zickus) [895641]
- [usb] xhci: Correct misplaced newlines (Don Zickus) [1016889]
- [usb] xhci: refactor EHCI/xHCI port switching (Don Zickus) [1016889 970717]
- [usb] xhci: Report USB 2.1 link status for L1 (Don Zickus) [1016889]
- [usb] xhci: Refactor port status into a new function (Don Zickus) [1016889]
- [usb] xhci: add the suspend/resume functionality (Don Zickus) [1016889]
- [usb] move the definition of USB_MAXCHILDREN (Don Zickus) [895641]
- [usb] atm: avoid parsing names as kthread_run() format strings (Don Zickus) [895641]
- [usb] xhci: Add missing unlocks on error paths (Don Zickus) [895641]
- [usb] ehci-atmel: prepare clk before calling enable (Don Zickus) [895641]
- [usb] hwa: fix device probe failure (Don Zickus) [895641]
- [usb] wusbcore: add sysfs attribute for retry count (Don Zickus) [895641]
- [usb] wusbcore: add sysfs attribute for DNTS count and interval (Don Zickus) [895641]
- [usb] check usb_hub_to_struct_hub() return value (Don Zickus) [895641]
- [usb] ehci: Remove double assignment of .start in ehci_msp_hc_driver (Don Zickus) [895641]
- [usb] ehci: export ehci_handshake for ehci-hcd sub-drivers (Don Zickus) [895641]
- [usb] wusbcore: add scatter gather support (Don Zickus) [895641]
- [usb] cdc-acm: remove unneeded spin_lock_irqsave/restore on write path (Don Zickus) [895641]
- [usb] serial: increase the number of devices we support (Don Zickus) [895641]
- [usb] serial: make minor allocation dynamic (Don Zickus) [895641]
- [usb] xhci: remove BUG() in xhci_get_endpoint_type() (Don Zickus) [895641]
- [usb] xhci: Remove BUG in xhci_setup_addressable_virt_dev (Don Zickus) [895641]
- [usb] xhci: Remove BUG_ON in xhci_get_input_control_ctx (Don Zickus) [895641]
- [usb] xhci: Remove BUG_ON() in xhci_alloc_container_ctx (Don Zickus) [895641]
- [usb] ehci-platform: add pre_setup() method to platform data (Don Zickus) [895641]
- [usb] serial: add minor and port number (Don Zickus) [895641]
- [usb] wusbcore: ignore HWA_NOTIF_BPST_ADJ notifications (Don Zickus) [895641]
- [usb] wusbcore: add HWA-specific fields to usb_rpipe_descriptor (Don Zickus) [895641]
- [usb] wusbhc: disable suspend and resume on the root hub (Don Zickus) [895641]
- [usb] fix PTR_ERR translation in init_usb_class() (Don Zickus) [895641]
- [usb] wusbcore: reduce keepalive threshold from timeout/2 to timeout/3 (Don Zickus) [895641]
- [usb] host: make USB_ARCH_HAS_?HCI obsolete (Don Zickus) [895641]
- [usb] ohci: remove bogus #error (Don Zickus) [895641]
- [usb] add usb2 Link PM variables to sysfs and usb_device (Don Zickus) [895641]
- [usb] xhci: add USB2 Link power management BESL support (Don Zickus) [895641]
- [usb] xhci: define port register names and use them instead of magic numbers (Don Zickus) [895641]
- [usb] xhci: check usb2 port capabilities before adding hw link PM support (Don Zickus) [895641]
- [usb] xhci: unify parameter of xhci_msi_irq (Don Zickus) [895641]
- [usb] xhci-dbg: Display endpoint number and direction in context dump (Don Zickus) [895641]
- [usb] serial: pl2303 works at 500kbps (Don Zickus) [895641]
- [usb] ohci: add a name for the platform-private field (Don Zickus) [895641]
- [usb] ohci: make ohci-platform a separate driver (Don Zickus) [895641]
- [usb] misc/usb3503: Remove 100ms sleep on reset, conform to data sheet (Don Zickus) [895641]
- [usb] misc/usb3503: Fix up whitespace (Don Zickus) [895641]
- [usb] Allow the USB HCD to create Wireless USB root hubs (Don Zickus) [895641]
- [usb] serial: add support Infineon modem USB flashloader driver (Don Zickus) [895641]
- [usb] ohci: make ohci-pci a separate driver (Don Zickus) [895641]
- [usb] ohci: Generic changes to make ohci-pci a separate driver (Don Zickus) [895641]
- [usb] ohci: prepare to make ohci-hcd a library module (Don Zickus) [895641]
- [usb] fhci: upgrade the isochronous API (Don Zickus) [895641]
- [usb] imx21: upgrade the isochronous API (Don Zickus) [895641]
- [usb] serial: dump small buffers with help of *ph (Don Zickus) [895641]
- [usb] host: remove leftover release_mem_region (Don Zickus) [895641]
- [usb] misc/usb3503: Adding device tree entry 'disabled-ports' (Don Zickus) [895641]
- [usb] misc/usb3503: Add to select the ports to disable (Don Zickus) [895641]
- [usb] ehci: Only sleep for post-resume handover if devices use persist (Don Zickus) [895641]
- [usb] message: Fixed parenthesis error in sizeof function (Don Zickus) [895641]
- [usb] message: fixed error 'no space before bracket' (Don Zickus) [895641]
- [usb] devio: fixed error 'do not use assignment in if condition' (Don Zickus) [895641]
- [usb] devio: Fixed macro parenthesis error (Don Zickus) [895641]
- [usb] devio: fixed warning 'use <linux/uacces.h> instead <asm/uacces.h>' (Don Zickus) [895641]
- [usb] usbtmc: Change magic number to constant (Don Zickus) [895641]
- [usb] usbtmc: usbtmc_read sends multiple TMC header based on rigol_quirk (Don Zickus) [895641]
- [usb] usbtmc: Set rigol_quirk if device is listed (Don Zickus) [895641]
- [usb] usbtmc: TMC request code segregated from usbtmc_read (Don Zickus) [895641]
- [usb] usbtmc: Add flag rigol_quirk to usbtmc_device_data (Don Zickus) [895641]
- [usb] storage/alauda: initialize variables directly (Don Zickus) [895641]
- [usb] storage/sddr09: initialize variables directly (Don Zickus) [895641]
- [usb] fsl: add missing platform_driver owner (Don Zickus) [895641]
- [usb] quatech2: Staticize local symbol (Don Zickus) [895641]
- [usb] misc: Fixed assignment error in if statement (Don Zickus) [895641]
- [usb] misc: Added space after closing brace in adutux.c (Don Zickus) [895641]
- [usb] misc: Added space after comma in adutux.c (Don Zickus) [895641]
- [usb] misc: Reformatted pointer variables in adutux.c (Don Zickus) [895641]
- [usb] misc: Removed space before tabs in adutux.c (Don Zickus) [895641]
- [usb] misc: Replaced deprecated preprocessor in adutux.c (Don Zickus) [895641]
- [fs] nfsd: fix discarded security labels on setattr (J. Bruce Fields) [1025832]
- [fs] nfs: fix inverted test for delegation in nfs4_reclaim_open_state (Jeff Layton) [1025457]
- [x86] kdump: crashkernel=X try to reserve below 896M first, then try below 4G, then MAXMEM (Chao WANG) [994685]
- [kernel] audit: format user messages to size of MAX_AUDIT_MESSAGE_LENGTH (Richard Guy Briggs) [1019913]
- [kernel] audit_alloc: clear TIF_SYSCALL_AUDIT if !audit_context (Richard Guy Briggs) [1026043]

* Fri Nov 08 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-48.el7]
- [ethernet] qlcnic: Update version to 5.3.48 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Implement ndo_get_phys_port_id for 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable diagnostic test for multiple Tx queues (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable Tx queue changes using ethtool for 82xx Series adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Multi Tx queue support for 82xx Series adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.3.47 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for 84xx adapters to load firmware from file (Chad Dupuis) [725018]
- [ethernet] qlcnic: Loopback Inter Driver Communication AEN handler (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add PVID support for 84xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable support for 844X adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.46 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Dump mailbox command data when a command times out (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix driver initialization for 83xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Flush mailbox command list when mailbox is not available (Chad Dupuis) [725018]
- [ethernet] qlcnic: Reinitialize mailbox data structures after firmware reset (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix diagnostic interrupt test for 83xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix beacon state return status handling (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix set driver version command (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix for flash update failure on 83xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix link speed and duplex display for 83xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix link speed display for 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix external loopback test (Chad Dupuis) [725018]
- [ethernet] qlcnic: Removed adapter series name from warning messages (Chad Dupuis) [725018]
- [ethernet] qlcnic: Free up memory in error path (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix ingress MAC learning (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix MAC address filter issue on 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.45 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable mailbox interface in poll mode when interrupts are not available (Chad Dupuis) [725018]
- [ethernet] qlcnic: Replace poll mode mailbox interface with interrupt based mailbox interface (Chad Dupuis) [725018]
- [ethernet] qlcnic: Interrupt based driver firmware mailbox mechanism (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enhance diagnostic loopback error codes (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix diagnostic interrupt test for 83xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix setting Guest VLAN (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix operation type and command type (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix initialization of work function (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix guest VLAN (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix releasing of Tx frag which was never mapped (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix dump template version mask (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix ethtool display for 83xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix panic while setting VF's MAC address (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix multicast packet handling for PF and VF (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix NULL pointer dereference in VF probe path (Chad Dupuis) [725018]
- [ethernet] qlcnic: Set __QLCNIC_DEV_UP in adapter state before enabling interrupts (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix invalid register offset calculation (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.44 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for 83xx suspend and resume (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for 'set driver version' in 83XX (Chad Dupuis) [725018]
- [ethernet] qlcnic: Cleanup of structure qlcnic_hardware_context (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for PEX DMA method to read memory section of adapter dump (Chad Dupuis) [725018]
- [ethernet] qlcnic: Minimize sleep duration within loopback diagnostic test (Chad Dupuis) [725018]
- [ethernet] qlcnic: Secondary unicast MAC address support (Chad Dupuis) [725018]
- [ethernet] qlcnic: Handle qlcnic_alloc_mbx_args() failure (Chad Dupuis) [725018]
- [ethernet] qlcnic: replace strict_strtoul() with kstrtoul() (Chad Dupuis) [725018]
- [ethernet] qlcnic: remove redundant D0 power state set (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix typo in printk (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.43 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enhance virtual NIC logging (Chad Dupuis) [725018]
- [ethernet] qlcnic: qlcnic_get_board_name() function cleanup (Chad Dupuis) [725018]
- [ethernet] qlcnic: Implement GET_LED_STATUS command for 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: modify reset recovery path in diag mode (Chad Dupuis) [725018]
- [ethernet] qlcnic: diagnostics routine changes (Chad Dupuis) [725018]
- [ethernet] qlcnic: Convert nested if-else to switch-case (Chad Dupuis) [725018]
- [ethernet] qlcnic: Initialize trans_work and idc_aen_work at VF probe (Chad Dupuis) [725018]
- [ethernet] qlcnic: Remove qlcnic_config_npars module parameter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update IRQ name for 8200 and 8300 Series adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Disable INT-x interrupt for 83xx on driver unload (Chad Dupuis) [725018]
- [ethernet] qlcnic: Support spoof check config (Chad Dupuis) [725018]
- [x86] Fix x86 invalid cpu boot failure message (Prarit Bhargava) [1024731]
- [virt] virtio-net: refill only when device is up during setting queues (Jason Wang) [1016469]
- [crypto] crc-t10dif: add MODULE_SOFTDEP (Kyle McMartin) [968869]
- [crypto] crct10dif: Add fallback for broken initrds (Kyle McMartin) [968869]
- [crypto] crct10dif: Use PTR_RET (Kyle McMartin) [968869]
- [crypto] crct10dif: Simple correctness and speed test for CRCT10DIF hash (Kyle McMartin) [968869]
- [crypto] crct10dif: Glue code to cast accelerated CRCT10DIF assembly as a crypto transform (Kyle McMartin) [968869]
- [crypto] crct10dif: Accelerated CRC T10 DIF computation with PCLMULQDQ instruction (Kyle McMartin) [968869]
- [crypto] crct10dif: Wrap crc_t10dif function all to use crypto transform framework (Kyle McMartin) [968869]
- [kernel] modules: add support for soft module dependencies (Kyle McMartin) [968869]
- [misc] mei: don't get stuck in select during reset (Prarit Bhargava) [1025420]
- [misc] mei/bus: do not overflow the device name buffer (Prarit Bhargava) [1025420]
- [misc] mei: wake also writers on reset (Prarit Bhargava) [1025420]
- [misc] mei/hbm: fix typo in error message (Prarit Bhargava) [1025420]
- [misc] mei: check whether hw start has succeeded (Prarit Bhargava) [1025420]
- [misc] mei: check if the hardware reset succeeded (Prarit Bhargava) [1025420]
- [misc] mei: mei_cl_connect, don't multiply the timeout twice (Prarit Bhargava) [1025420]
- [misc] mei: do not override a client writing state when buffering (Prarit Bhargava) [1025420]
- [misc] mei: move mei_cl_irq_write_complete to client.c (Prarit Bhargava) [1025420]
- [misc] mei: support HBM versioning (Prarit Bhargava) [1025420]
- [nfc] mei_phy: Clean up file (Prarit Bhargava) [1025420]
- [misc] mei: move mei_cl_complete to client.c (Prarit Bhargava) [1025420]
- [misc] mei: revamp interrupt thread handlers (Prarit Bhargava) [1025420]
- [virt] virtio-net: correctly handle cpu hotplug notifier during resuming (Jason Wang) [1016996]
- [virt] virtio-net: don't respond to cpu hotplug notifier if we're not ready (Jason Wang) [1016996]
- [fs] nfs: fix handling of invalid mount options in nfs_remount (Jeff Layton) [1021538]
- [fs] nfs: reject version and minorversion changes on remount attempts (Jeff Layton) [1021538]
- [drm] qxl: avoid an oops in the deferred io code (Dave Airlie) [1003728 1026182]
- [drm] qxl: fix disabling extra monitors from client (Dave Airlie) [1026182]
- [drm] qxl: remove unnecessary check (Dave Airlie) [1026182]
- [drm] qxl: prefer the monitor config resolution (Dave Airlie) [1026182]
- [drm] copy mode type in drm_mode_connector_list_update() (Dave Airlie) [1026182]
- [drm] qxl: notify that the monitor config changed (Dave Airlie) [1026182]
- [drm] return if changed in drm_helper_hpd_irq_event() (Dave Airlie) [1026182]
- [block] rsxx: Fix possible kernel panic with invalid config (Steve Best) [1024550]
- [block] rsxx: Disallow discards from being unmapped (Steve Best) [1024550]
- [virt] hid-hyperv: convert alloc+memcpy to memdup (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Increase the value of STORVSC_MAX_IO_REQUESTS (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Support FC devices (Jason Wang) [1026618]
- [virt] hyperv: Add the GUID fot synthetic fibre channel device (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Implement multi-channel support (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Update the storage protocol to win8 level (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Increase the value of scsi timeout for storvsc devices (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Terminate vmbus version negotiation on timeout (Jason Wang) [1026618]
- [virt] hv_util: Correctly support ws2008R2 and earlier (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Do not attempt to negoatiate a new version prematurely (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Fix a bug in the handling of channel offers (Jason Wang) [1026618]
- [virt] hyperv: remove HV_DRV_VERSION (Jason Wang) [1026618]
- [virt] hv_balloon: Initialize the transaction ID just before sending the packet (Jason Wang) [1026618]
- [virt] hv_util: Fix a bug in version negotiation code for util services (Jason Wang) [1026618]
- [virt] hyperv/vmbus: incorrect device name is printed when child device is unregistered (Jason Wang) [1026618]
- [virt] hyperv: allocate synic structures before hv_synic_init() (Jason Wang) [1026618]
- [virt] hyperv: check interrupt mask before read_index (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Implement multi-channel support (Jason Wang) [1026618]

* Thu Nov 07 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-47.el7]
- [net] bridge: pass correct vlan id to multicast code (Vlad Yasevich) [912737]
- [net] bridge: Fix updating FDB entries when the PVID is applied (Vlad Yasevich) [912737]
- [net] bridge: Fix the way the PVID is referenced (Vlad Yasevich) [912737]
- [net] bridge: Apply the PVID to priority-tagged frames (Vlad Yasevich) [912737]
- [net] bridge: Don't use VID 0 and 4095 in vlan filtering (Vlad Yasevich) [912737]
- [net] bridge: Correctly clamp MAX forward_delay when enabling STP (Vlad Yasevich) [997814]
- [net] bridge: Clamp forward_delay when enabling STP (Vlad Yasevich) [997814]
- [net] ipv6: mld: introduce mld_{gq, ifc, dad}_stop_timer functions (Daniel Borkmann) [1023947]
- [net] ipv6: mld: refactor query processing into v1/v2 functions (Daniel Borkmann) [1023947]
- [net] ipv6: mld: similarly to MLDv2 have min max_delay of 1 (Daniel Borkmann) [1023947]
- [net] ipv6: mld: implement RFC3810 MLDv2 mode only (Daniel Borkmann) [1023947]
- [net] ipv6: mld: get rid of MLDV2_MRC and simplify calculation (Daniel Borkmann) [1023947]
- [net] ipv6: mld: clean up MLD_V1_SEEN macro (Daniel Borkmann) [1023947]
- [net] ipv6: mld: fix v1/v2 switchback timeout to rfc3810, 9.12. (Daniel Borkmann) [1023947]
- [net] ipv6: mcast: use defines for rfc3810/8.1 lengths (Daniel Borkmann) [1023947]
- [net] ipv6: *_start_timer: rather use unsigned long (Daniel Borkmann) [1023947]
- [net] ipv6: igmp6_event_query: use msecs_to_jiffies (Daniel Borkmann) [1023947]
- [net] ipv6: make unsolicited report intervals configurable for mld (Daniel Borkmann) [1023947]
- [net] ipv4, ipv6: send igmpv3/mld packets with TC_PRIO_CONTROL (Daniel Borkmann) [1023947]
- [net] bridge: disable snooping if there is no querier (Vlad Yasevich) [1019950]
- [net] unix: inherit SOCK_PASS{CRED, SEC} flags from socket to fix race (Daniel Borkmann) [1023964]

* Thu Nov 07 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-46.el7]
- [scsi] aacraid: missing capable() check in compat ioctl (Rich Bono) [1025840]
- [scsi] scsi_dh_rdac: Add new IBM 1813 product id to rdac devlist (Rob Evers) [1020969]
- [scsi] aic94xx: remove driver (Rich Bono) [978980]
- [scsi] qla4xxx: Populate local CHAP credentials for flash target sessions (Chad Dupuis) [1006158]
- [scsi] qla4xxx: Support setting of local CHAP index for flash target entry (Chad Dupuis) [1006158]
- [scsi] qla4xxx: Correct the check for local CHAP entry type (Chad Dupuis) [1006158]
- [scsi] qla4xxx: correctly update session discovery_parent_idx (Chad Dupuis) [1020197]
- [scsi] aacraid: avoid parsing names as kthread_run() format strings (Rich Bono) [752081]
- [scsi] hpsa: return 0 from driver probe function on success, not 1 (Tomas Henzl) [862713]
- [scsi] hpsa: remove unused Smart Array ID (Tomas Henzl) [862713]
- [scsi] hpsa: bump driver version to reflect changes (Tomas Henzl) [862713]
- [scsi] hpsa: housekeeping patch for device_id and product arrays (Tomas Henzl) [862713]
- [scsi] hpsa: add HP Smart Array Gen8 names (Tomas Henzl) [862713]
- [scsi] hpsa: add HP Smart Array Gen9 PCI ID's (Tomas Henzl) [862713]
- [treewide] Convert retrun typos to return (Tomas Henzl) [862713]
- [scsi] hpsa: fix warning with smp_processor_id() in preemptible (Tomas Henzl) [862713]
- [scsi] hpsa: remove unneeded variable (Tomas Henzl) [862713]
- [scsi] hpsa: fix a race in cmd_free/scsi_done (Tomas Henzl) [862713]

* Thu Nov 07 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-45.el7]
- [ethernet] tg3: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1024060]
- [ethernet] tg3: Miscellaneous conversions to ETH_ALEN (Ivan Vecera) [1024060]
- [ethernet] tg3: use phylib when robo switch is in use (Ivan Vecera) [1024060]
- [netdrv] ssb: provide phy address for Gigabit Ethernet driver (Ivan Vecera) [1024060]
- [ethernet] tg3: add support a phy at an address different than 01 (Ivan Vecera) [1024060]
- [ethernet] tg3: Update version to 3.134 (Ivan Vecera) [1024060]
- [ethernet] tg3: Remove unnecessary spinlock (Ivan Vecera) [1024060]
- [ethernet] tg3: Appropriately classify interrupts during request_irq (Ivan Vecera) [1024060]
- [ethernet] tg3: Remove redundant if check (Ivan Vecera) [1024060]
- [ethernet] tg3: Remove if 0'd code (Ivan Vecera) [1024060]
- [ethernet] tg3: LED in shared mode does not blink during traffic (Ivan Vecera) [1024060]
- [ethernet] tg3: Add support for new 577xx device ids (Ivan Vecera) [1024060]
- [ethernet] tg3: Add function tg3_phy_shdw_write() (Ivan Vecera) [1024060]
- [ethernet] tg3: Use pci_dev pm_cap (Ivan Vecera) [1024060]
- [ethernet] tg3: Expand led off fix to include 5720 (Ivan Vecera) [1024060]
- [s390] cio: Introduce on-close CHSC IOCTLs (Hendrik Brueckner) [1022446]
- [s390] cio: Make /dev/chsc a single-open device (Hendrik Brueckner) [1022442]
- [s390] cio: Introduce generic synchronous CHSC IOCTL (Hendrik Brueckner) [1022441]
- [s390] sclp: Add SCLP character device driver (Hendrik Brueckner) [1022425]
- [virt] kvm: Create non-coherent DMA registeration (Alex Williamson) [1025470]
- [virt] kvm: Convert iommu_flags to iommu_noncoherent (Alex Williamson) [1025470]
- [virt] kvm: Add VFIO device (Alex Williamson) [1025470]
- [vfio] vfio_iommu_type1: fix bug caused by break in nested loop (Alex Williamson) [1025468]
- [vfio] fix documentation more (Alex Williamson) [1025468]
- [vfio] vfio-pci: PCI hot reset interface (Alex Williamson) [1025468]
- [vfio] vfio-pci: Test for extended config space (Alex Williamson) [1025468]
- [vfio] vfio-pci: Use fdget() rather than eventfd_fget() (Alex Williamson) [1025468]
- [vfio] Add O_CLOEXEC flag to vfio device fd (Alex Williamson) [1025468]
- [vfio] use get_unused_fd_flags(0) instead of get_unused_fd() (Alex Williamson) [1025468]
- [vfio] add external user support (Alex Williamson) [1025468]
- [vfio] fix documentation (Alex Williamson) [1025468]
- [block] blk-throttle: Enable hierarchy even when sane mount flag is not specified (Vivek Goyal) [1015648]
- [block] blk-throttle: implement proper hierarchy support (Vivek Goyal) [1015648]
- [block] blk-throttle: implement throtl_grp->has_rules[] (Vivek Goyal) [1015648]
- [block] blk-throttle: Account for child group's start time in parent while bio climbs up (Vivek Goyal) [1015648]
- [block] blk-throttle: add throtl_qnode for dispatch fairness (Vivek Goyal) [1015648]
- [block] blk-throttle: make throtl_pending_timer_fn() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: make tg_dispatch_one_bio() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: make blk_throtl_bio() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: make blk_throtl_drain() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: dispatch from throtl_pending_timer_fn() (Vivek Goyal) [1015648]
- [block] blk-throttle: implement dispatch looping (Vivek Goyal) [1015648]
- [block] blk-throttle: separate out throtl_service_queue->pending_timer from throtl_data->dispatch_work (Vivek Goyal) [1015648]
- [block] blk-throttle: set REQ_THROTTLED from throtl_charge_bio() and gate stats update with it (Vivek Goyal) [1015648]
- [block] blk-throttle: move bio_lists[], implement sq_to_tg(), sq_to_td() and throtl_log() (Vivek Goyal) [1015648]
- [block] blk-throttle: add throtl_service_queue->parent_sq (Vivek Goyal) [1015648]
- [block] blk-throttle: generalize update_disptime optimization in blk_throtl_bio() (Vivek Goyal) [1015648]
- [block] blk-throttle: move bio_lists[] blk-throttle: dispatch to throtl_data->service_queue.bio_lists[] (Vivek Goyal) [1015648]
- [block] blk-throttle: move bio_lists[] and friends to throtl_service_queue (Vivek Goyal) [1015648]
- [block] blk-throttle: add throtl_grp->service_queue (Vivek Goyal) [1015648]
- [block] blk-throttle: reorganize throtl_service_queue passed around as argument (Vivek Goyal) [1015648]
- [block] blk-throttle: pass around throtl_service_queue instead of throtl_data (Vivek Goyal) [1015648]
- [block] blk-throttle: add backlink pointer from throtl_grp to throtl_data (Vivek Goyal) [1015648]
- [block] blk-throttle: simplify throtl_grp flag handling (Vivek Goyal) [1015648]
- [block] blk-throttle: rename throtl_rb_root to throtl_service_queue (Vivek Goyal) [1015648]
- [block] blk-throttle: remove pointless throtl_nr_queued() optimizations (Vivek Goyal) [1015648]
- [block] blk-throttle: relocate throtl_schedule_delayed_work() (Vivek Goyal) [1015648]
- [block] blk-throttle: collapse throtl_dispatch() into the work function (Vivek Goyal) [1015648]
- [block] blk-throttle: remove deferred config application mechanism (Vivek Goyal) [1015648]
- [block] blk-throttle: remove spurious throtl_enqueue_tg() call from throtl_select_dispatch() (Vivek Goyal) [1015648]
- [block] blkcg: move bulk of blkcg_gq release operations to the RCU callback (Vivek Goyal) [1015648]
- [block] blkcg: invoke blkcg_policy->pd_init() after parent is linked (Vivek Goyal) [1015648]
- [block] blkcg: implement blkg_for_each_descendant_post() (Vivek Goyal) [1015648]
- [block] blkcg: move blkg_for_each_descendant_pre() to block/blk-cgroup.h (Vivek Goyal) [1015648]
- [block] blkcg: fix error return path in blkg_create() (Vivek Goyal) [1015648]
- [char] ipmi: Add MODULE_ALIAS for autoloading ipmi driver on ACPI systems (Shyam Iyer) [844867]

* Wed Nov 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-44.el7]
- [security] keys: Fix UID check in keyctl_get_persistent() (David Howells) [991110]
- [security] keys: fix error return code in big_key_instantiate() (David Howells) [991110]
- [powerpc] tm: Switch out userspace PPR and DSCR sooner (Steve Best) [1016823]
- [virt] kvm: fix KVM_SET_XCRS loop (Paolo Bonzini) [1007897]
- [virt] kvm: fix KVM_SET_XCRS for CPUs that do not support XSAVE (Paolo Bonzini) [1007897]
- [virt] kvm: only copy XSAVE state for the supported features (Paolo Bonzini) [1007897]
- [virt] kvm: prevent setting unsupported XSAVE states (Paolo Bonzini) [1007897]
- [virt] kvm: mask unsupported XSAVE entries from leaf 0Dh index 0 (Paolo Bonzini) [1007897]
- [ethernet] bnx2x: remove unnecessary pci_set_drvdata() (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Add ndo_get_phys_port_id support (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Change variable type to bool (Michal Schmidt) [1022068]
- [ethernet] bnx2x: skb_is_gso_v6() requires skb_is_gso() (Michal Schmidt) [1022068]
- [ethernet] bnx2x: use pcie_get_minimum_link() (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Add support for EXTPHY2 LED mode (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Change function prototype (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Don't disable/enable SR-IOV when loading (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Correct VF driver info (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Test nvram when interface is down (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Staticize local symbols (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Disable VF access on PF removal (Michal Schmidt) [1022068]
- [ethernet] bnx2x: prevent FW assert on low mem during unload (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Set NETIF_F_HIGHDMA unconditionally (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Don't pretend during register dump (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Lock DMAE when used by statistic flow (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Prevent null pointer dereference on error flow (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix config when SR-IOV and iSCSI are enabled (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix Coalescing configuration (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Unlock VF-PF channel on MAC/VLAN config error (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Prevent an illegal pointer dereference during panic (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix Maximum CoS estimation for VFs (Michal Schmidt) [1022068]
- [ethernet] bnx2x: record rx queue for LRO packets (Michal Schmidt) [1022068]
- [ethernet] bnx2x: handle known but unsupported VF messages (Michal Schmidt) [1022068]
- [ethernet] bnx2x: prevent masked MCP parities from appearing (Michal Schmidt) [1022068]
- [ethernet] bnx2x: prevent masking error from cnic (Michal Schmidt) [1022068]
- [ethernet] bnx2x: add missing VF resource allocation during init (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix support for VFs on some PFs (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Prevent mistaken hangup between driver & FW (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix 848xx duplex settings (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Specific Active-DAC is not detected on 57810 (Michal Schmidt) [1022068]
- [ethernet] bnx2x: 57840 non-external loopback test fail on 1G (Michal Schmidt) [1022068]
- [ethernet] bnx2x: KR2 disablement fix (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Generalize KR work-around (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix bnx2i and bnx2fc regressions (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Use pci_dev pm_cap (Michal Schmidt) [1022068]
- [ethernet] bnx2x: avoid atomic allocations during initialization (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix configuration of doorbell block (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Restore a call to config_init (Michal Schmidt) [1022068]
- [ethernet] bnx2x: fix broken compilation with CONFIG_BNX2X_SRIOV is not set (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Add missing braces in bnx2x:bnx2x_link_initialize (Michal Schmidt) [1022068]
- [ethernet] bnx2x: VF RSS support - VF side (Michal Schmidt) [1022068]
- [ethernet] bnx2x: VF RSS support - PF side (Michal Schmidt) [1022068]
- [virt] hyperv-fb: add pci stub (Gerd Hoffmann) [1019185]
- [ethernet] ixgbevf: move API neg to reset path (Andy Gospodarek) [1023107]
- [ethernet] bna: firmware update to 3.2.1.1 (Ivan Vecera) [1007080]
- [fs] nfs: Fix a missing initialisation when reading the SELinux label (Jeff Layton) [1019591]
- [fs] nfs: fix oops when trying to set SELinux label (Jeff Layton) [1019591]
- [ethernet] r8169: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1025463]
- [ethernet] r8169: fix invalid register dump (Ivan Vecera) [1025463]
- [ethernet] r8169: remember WOL preferences on driver load (Ivan Vecera) [1025463]
- [ethernet] r8169, sis190: remove unnecessary length check (Ivan Vecera) [1025463]
- [ethernet] r8169: remove "PHY reset until link up" log spam (Ivan Vecera) [1025463]
- [ethernet] r8169: fix lockdep warning when removing interface (Ivan Vecera) [1025463]
- [ethernet] r8169: add a new chip for RTL8411 (Ivan Vecera) [1025463]
- [ethernet] be2net: Make lancer_wait_ready() static (Ivan Vecera) [1025412]
- [ethernet] be2net: Remove interface type (Ivan Vecera) [1025412]
- [ethernet] be2net: add support for ndo_busy_poll (Ivan Vecera) [1025412]
- [ethernet] be2net: Warn users of possible broken functionality on BE2 cards with very old FW versions with latest driver (Ivan Vecera) [1025412]
- [ethernet] be2net: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1025412]
- [ethernet] be2net: Rework PCIe error report log messaging (Ivan Vecera) [1025412]
- [ethernet] be2net: change the driver version number to 4.9.224.0 (Ivan Vecera) [1025412]
- [ethernet] be2net: Display RoCE specific counters in ethtool -S (Ivan Vecera) [1025412]
- [ethernet] be2net: Call version 2 of GET_STATS ioctl for Skyhawk-R (Ivan Vecera) [1025412]
- [ethernet] be2net: add a counter for pkts dropped in xmit path (Ivan Vecera) [1025412]
- [ethernet] be2net: fix adaptive interrupt coalescing (Ivan Vecera) [1025412]
- [ethernet] be2net: call ENABLE_VF cmd for Skyhawk-R too (Ivan Vecera) [1025412]
- [ethernet] be2net: Create single TXQ on BE3-R 1G ports (Ivan Vecera) [1025412]
- [ethernet] be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd (Ivan Vecera) [1025412]
- [ethernet] be2net: Call be_vf_setup() even when VFs are enbaled from previous load (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to display the VLAN priority for a VF (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to configure VLAN priority for a VF interface (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to allow VLAN configuration on VF interfaces (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix number of VLANs supported in UMC mode for BE3-R (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix VLAN promiscuous mode programming (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix the size of be_nic_res_desc structure (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to prevent Tx stall on SH-R when packet size < 32 (Ivan Vecera) [1025412]
- [ethernet] be2net: Remove extern from function prototypes (Ivan Vecera) [1025412]
- [ethernet] be2net: missing variable initialization (Ivan Vecera) [1025412]
- [drm] cirrus: do not attempt to acquire a reservation while in an interrupt handler (Gerd Hoffmann) [1017433]
- [drm] cirrus: Invalidate page tables when pinning a BO (Gerd Hoffmann) [1017433]
- [virt] kvm: introduce guest count uevent (Paolo Bonzini) [1004799]
- [ata] libahci: fix turning on LEDs in ahci_start_port() (David Milburn) [1024388]
- [kernel] audit: do not reject all AUDIT_INODE filter types (Richard Guy Briggs) [985971]
- [fs] fuse: drop dentry on failed revalidate (Brian Foster) [1006514]
- [fs] fuse: clean up return in fuse_dentry_revalidate() (Brian Foster) [1006514]
- [fs] fuse: use d_materialise_unique() (Brian Foster) [1006514]
- [fs] sysfs: use check_submounts_and_drop() (Brian Foster) [1006514]
- [fs] nfs: use check_submounts_and_drop() (Brian Foster) [1006514]
- [fs] gfs2: use check_submounts_and_drop() (Brian Foster) [1006514]
- [fs] vfs: check unlinked ancestors before mount (Brian Foster) [1006514]
- [fs] vfs: check submounts and drop atomically (Brian Foster) [1006514]
- [fs] vfs: add d_walk() (Brian Foster) [1006514]
- [fs] vfs: restructure d_genocide() (Brian Foster) [1006514]
- [powerpc] Only save/restore SDR1 if in hypervisor mode (Steve Best) [1018639]
- [wireless] brcmsmac: Further reduce log spam from tx phy messages (John Green) [974223]
- [wireless] brcmsmac: Reduce log spam in heavy tx, make err print in debug (John Green) [974223]

* Wed Nov 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-43.el7]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.17 (Veaceslav Falico) [1006938]

* Tue Nov 05 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-42.el7]
- [kernel] keys: align system_certificate_list (Jan Stancek) [985961]
- [security] keys: Fix keyring quota misaccounting on key replacement and unlink (David Howells) [1017806 991110]
- [security] keys: Fix a race between negating a key and reading the error set (David Howells) [991110]
- [security] keys: Make BIG_KEYS boolean (David Howells) [991110]
- [crypto] x.509: remove possible code fragility, enumeration values not handled (David Howells) [985961]
- [crypto] x.509: add module description and license (David Howells) [985961]
- [lib] mpi: add module description and license (David Howells) [985961]
- [security] keys: initialize root uid and session keyrings early (David Howells) [985961]
- [crypto] keys: verify a certificate is signed by a 'trusted' key (David Howells) [985961]
- [kernel] keys: Make the system 'trusted' keyring viewable by userspace (David Howells) [985961]
- [crypto] keys: Set the asymmetric-key type default search method (David Howells) [985961]
- [security] keys: Add a 'trusted' flag and a 'trusted only' flag (David Howells) [985961]
- [kernel] keys: Separate the kernel signature checking keyring from module signing (David Howells) [985961]
- [kernel] keys: Have make canonicalise the paths of the X.509 certs better to deduplicate (David Howells) [985961]
- [kernel] modsign: Load *.x509 files into kernel keyring (David Howells) [985961]
- [crypto] x.509: Remove certificate date checks (David Howells) [985961]
- [crypto] x.509: Handle certificates that lack an authorityKeyIdentifier field (David Howells) [985961]
- [crypto] x.509: Check the algorithm IDs obtained from parsing an X.509 certificate (David Howells) [985961]
- [crypto] x.509: Embed public_key_signature struct and create filler function (David Howells) [985961]
- [crypto] x.509: struct x509_certificate needs struct tm declaring (David Howells) [985961]
- [crypto] keys: Store public key algo ID in public_key_signature struct (David Howells) [985961]
- [crypto] keys: Split public_key_verify_signature() and make available (David Howells) [985961]
- [crypto] keys: Store public key algo ID in public_key struct (David Howells) [985961]
- [crypto] keys: Move the algorithm pointer array from x509 to public_key.c (David Howells) [985961]
- [crypto] keys: Rename public key parameter name arrays (David Howells) [985961]
- [security] keys: Add per-user_namespace registers for persistent per-UID kerberos caches (David Howells) [991110]
- [security] keys: Implement a big key type that can save to tmpfs (David Howells) [991110]
- [security] keys: Expand the capacity of a keyring (David Howells) [1014573 985961]
- [lib] assoc_array: Add a generic associative array implementation (David Howells) [1014573 985961]
- [security] keys: Drop the permissions argument from __keyring_search_one() (David Howells) [1014573 985961]
- [security] keys: Define a __key_get() wrapper to use rather than atomic_inc() (David Howells) [1014573 985961]
- [security] keys: Search for auth-key by name rather than target key ID (David Howells) [1014573 985961]
- [security] keys: Introduce a search context structure (David Howells) [1014573 985961]
- [security] keys: Consolidate the concept of an 'index key' for key access (David Howells) [1014573 985961]
- [security] keys: key_is_dead() should take a const key pointer argument (David Howells) [1014573 985961]
- [security] keys: Use bool in make_key_ref() and is_key_possessed() (David Howells) [1014573 985961]
- [security] keys: Skip key state checks when checking for possession (David Howells) [1014573 985961 991110]

* Fri Nov 01 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-41.el7]
- [net] bonding: ensure that TLB mode's active slave has correct mac filter (Veaceslav Falico) [1017573]
- [net] netfilter: synproxy: fix BUG_ON triggered by corrupt TCP packets (Jesper Brouer) [1015035]
- [net] proc_fs: print UIDs as unsigned int (Francesco Fusco) [996122]
- [net] ipv6: Unify {raw,udp}6_sock_seq_show (Francesco Fusco) [996122]
- [scsi] qla4xxx: Fix memory leak in func qla4_84xx_config_acb() (Chad Dupuis) [998557]
- [scsi] qla4xxx: 5.04.00.00.07.00-k0 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update driver version to 5.04.00-k1 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Return error if minidump data collection fails (Chad Dupuis) [998557]
- [scsi] qla4xxx: Fix the minidump data collection check in for loop (Chad Dupuis) [998557]
- [scsi] qla4xxx: Add pex-dma support for capturing minidump (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update driver version to 5.04.00-k0 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update Copyright header (Chad Dupuis) [998557]
- [scsi] qla4xxx: Implementation of ACB configuration during Loopback for ISP8042 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Added support for ISP8042 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update driver version to 5.03.00-k11 (Chad Dupuis) [948123]
- [scsi] qla4xxx: Export more firmware info in sysfs (Chad Dupuis) [948123]
- [scsi] qla4xxx: Only BIOS boot target entries should be at index 0 and 1 (Chad Dupuis) [948123]
- [scsi] qla4xxx: discovery_parent_idx can be shown without any check (Chad Dupuis) [948123]
- [scsi] qla4xxx: Set IPv6 traffic class if device type is IPv6 (Chad Dupuis) [948123]
- [scsi] qla4xxx: Use discovery_parent_idx instead of discovery_parent_type (Chad Dupuis) [948123]
- [scsi] qla4xxx: Allow removal of failed session using logout (Chad Dupuis) [948123]
- [scsi] qla4xxx: Update driver version to 5.03.00-k10 (Chad Dupuis) [948118]
- [scsi] qla4xxx: Exporting new attrs for iscsi session and connection in sysfs (Chad Dupuis) [948118]
- [scsi] libiscsi: Add missing prints for session and connection sysfs attrs (Chad Dupuis) [948118]
- [scsi] libiscsi: Added new boot entries in the session sysfs (Chad Dupuis) [948118]
- [fs] nfs: inform the VM about pages being committed or unstable (Jerome Marchand) [1009508]
- [mm] vmscan: take page buffers dirty and locked state into account (Jerome Marchand) [1009508]
- [mm] vmscan: treat pages marked for immediate reclaim as zone congestion (Jerome Marchand) [1009508]
- [mm] vmscan: move direct reclaim wait_iff_congested into shrink_list (Jerome Marchand) [1009508]
- [mm] vmscan: set zone flags before blocking (Jerome Marchand) [1009508]
- [mm] vmscan: stall page reclaim after a list of pages have been processed (Jerome Marchand) [1009508]
- [mm] vmscan: stall page reclaim and writeback pages based on dirty/writepage pages encountered (Jerome Marchand) [1009508]
- [mm] vmscan: move logic from balance_pgdat() to kswapd_shrink_zone() (Jerome Marchand) [1009508]
- [mm] vmscan: check if kswapd should writepage once per pgdat scan (Jerome Marchand) [1009508]
- [mm] vmscan: block kswapd if it is encountering pages under writeback (Jerome Marchand) [1009508]
- [mm] vmscan: have kswapd writeback pages based on dirty pages encountered, not priority (Jerome Marchand) [1009508]
- [mm] vmscan: do not allow kswapd to scan at maximum priority (Jerome Marchand) [1009508]
- [mm] vmscan: decide whether to compact the pgdat based on reclaim progress (Jerome Marchand) [1009508]
- [mm] vmscan: flatten kswapd priority loop (Jerome Marchand) [1009508]
- [mm] vmscan: obey proportional scanning requirements for kswapd (Jerome Marchand) [1009508]
- [mm] vmscan: limit the number of pages kswapd reclaims at each priority (Jerome Marchand) [1009508]
- [iommu] Remove stack trace from broken irq remapping warning (Neil Horman) [1012860]
- [kernel] audit: remove newline accidentally added during session id helper refactor (Richard Guy Briggs) [1010438]
- [security] audit: suppress stock memalloc failure warnings since already managed (Richard Guy Briggs) [1016852]
- [kernel] ntp: Make periodic RTC update more reliable (Prarit Bhargava) [1010351]

* Wed Oct 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-40.el7]
- [virt] kvm/ppc/Book3S: Fix compile error in XICS emulation (Veaceslav Falico) [1006938]
- [block] rsxx: fix Kernel Panic caused by mapping Discards (Steve Best) [1013995]
- [block] rsxx: Moving pci_map_page to prevent overflow (Steve Best) [1011024]
- [block] rsxx: Handling failed pci_map_page on PowerPC and double free (Steve Best) [1011024]
- [block] rsxx: Adding in debugfs entries (Steve Best) [1002025]
- [block] rsxx: Fixes incorrect stats calculation (Steve Best) [1002025]
- [block] rsxx: Adding EEH check inside cregs timeout (Steve Best) [1002025]
- [block] rsxx: Adapter address space sanity check (Steve Best) [1002025]
- [block] rsxx: Fixes DLPAR add kernel panic if partition still mounted (Steve Best) [1002025]
- [block] rsxx: Changing the adapter name to the official name (Steve Best) [1002025]
- [block] rsxx: Adding in sync_start module paramenter (Steve Best) [1002025]
- [block] rsxx: Allow block size to be determined by configuration (Steve Best) [1002025]
- [block] rsxx: Fixes soft-lockup issues during DMAs (Steve Best) [1002025]
- [block] rsxx: Restructured DMA cancel scheme (Steve Best) [1002025]
- [block] rsxx: Individual workqueues for interruptible events (Steve Best) [1002025]
- [md] Fix skipping recovery for read-only arrays (Jes Sorensen) [1016694]
- [kernel] nohz: Include local CPU in full dynticks global kick (Jarod Wilson) [988015]
- [kernel] nohz: Optimize full dynticks's sched hooks with static keys (Jarod Wilson) [988015]
- [kernel] nohz: Optimize full dynticks state checks with static keys (Jarod Wilson) [988015]
- [kernel] nohz: Rename a few state variables (Jarod Wilson) [988015]
- [kernel] vtime: Always debug check snapshot source _before_ updating it (Jarod Wilson) [988015]
- [kernel] vtime: Always scale generic vtime accounting results (Jarod Wilson) [988015]
- [kernel] vtime: Optimize full dynticks accounting off case with static keys (Jarod Wilson) [988015]
- [kernel] vtime: Describe overriden functions in dedicated arch headers (Jarod Wilson) [988015]
- [kernel] hardirq: Split preempt count mask definitions (Jarod Wilson) [988015]
- [kernel] context_tracking: Split low level state headers (Jarod Wilson) [988015]
- [kernel] vtime: Fix racy cputime delta update (Jarod Wilson) [988015]
- [kernel] vtime: Remove a few unneeded generic vtime state checks (Jarod Wilson) [988015]
- [kernel] context_tracking: User/kernel broundary cross trace events (Jarod Wilson) [988015]
- [kernel] context_tracking: Optimize context switch off case with static keys (Jarod Wilson) [988015]
- [kernel] context_tracking: Optimize guest APIs off case with static key (Jarod Wilson) [988015]
- [kernel] context_tracking: Optimize main APIs off case with static key (Jarod Wilson) [988015]
- [kernel] context_tracking: Ground setup for static key use (Jarod Wilson) [988015]
- [kernel] context_tracking: Remove full dynticks' hacky dependency on wide context tracking (Jarod Wilson) [988015]
- [kernel] nohz: Only enable context tracking on full dynticks CPUs (Jarod Wilson) [988015]
- [kernel] context_tracking: Fix runtime CPU off-case (Jarod Wilson) [988015]
- [kernel] vtime: Update a few comments (Jarod Wilson) [988015]
- [kernel] context_tracking: Fix guest accounting with native vtime (Jarod Wilson) [988015]
- [kernel] sched: Consolidate open coded preemptible() checks (Jarod Wilson) [988015]
- [kernel] nohz: fix compile warning in tick_nohz_init() (Jarod Wilson) [988015]
- [kernel] nohz: Do not warn about unstable tsc unless user uses nohz_full (Jarod Wilson) [988015]
- [kernel] nohz: Remove obsolete check for full dynticks CPUs to be RCU nocbs (Jarod Wilson) [988015]
- [kernel] nohz: Warn if the machine can not perform nohz_full (Jarod Wilson) [988015]
- [md] raid5: avoid finding "discard" stripe (Jes Sorensen) [1023485]
- [md] raid5: set bio bi_vcnt 0 for discard request (Jes Sorensen) [1023485]
- [powerpc] make lorax work again (Steve Best) [1022797]

* Tue Oct 29 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-39.el7]
- [netdrv] cnic: Fix crash in cnic_bnx2x_service_kcq() (Maurizio Lombardi) [1011203]
- [scsi] bnx2fc: Bump version from 1.0.14 to 2.4.1 (Maurizio Lombardi) [1011211]
- [scsi] bnx2fc: hung task timeout warning observed when rmmod bnx2x with active FCoE targets (Maurizio Lombardi) [1011211]
- [scsi] bnx2fc: Fixed a SCSI CMD cmpl race condition between ABTS and CLEANUP (Maurizio Lombardi) [1011211]
- [scsi] Allow error handling timeout to be specified (Ewan Milne) [1020944]
- [scsi] be2iscsi: Bump driver version (Rob Evers) [726165]
- [scsi] be2iscsi: Fix SGL posting for unaligned ICD values (Rob Evers) [726165]
- [scsi] be2iscsi: Fix AER handling in driver (Rob Evers) [726165]
- [scsi] be2iscsi: Invalidate WRB in Abort/Reset Path (Rob Evers) [726165]
- [scsi] be2iscsi: Fix Insufficient Buffer Error returned in MBX Completion (Rob Evers) [726165]
- [scsi] be2iscsi: Fix log level for protocol specific logs (Rob Evers) [726165]
- [scsi] be2iscsi: Fix MSIx creation for SKH-R adapter (Rob Evers) [726165]
- [scsi] be2iscsi: Display Port Identifier for each iSCSI function (Rob Evers) [726165]
- [scsi] be2iscsi: Dispaly CID available for connection offload (Rob Evers) [726165]
- [scsi] be2iscsi: Fix chute cleanup during drivers unload (Rob Evers) [726165]
- [scsi] be2iscsi: Fix connection offload to support Dual Chute (Rob Evers) [726165]
- [scsi] be2iscsi: Fix CID allocation/freeing to support Dual chute mode (Rob Evers) [726165]
- [scsi] be2iscsi: Fix WRB_Q posting to support Dual Chute mode (Rob Evers) [726165]
- [scsi] be2iscsi: Fix SGL Initilization and posting Pages for Dual Chute (Rob Evers) [726165]
- [scsi] be2iscsi: Fix Template HDR support for Dual Chute mode (Rob Evers) [726165]
- [scsi] be2iscsi: Fix changes in ASYNC Path for SKH-R adapter (Rob Evers) [726165]
- [scsi] be2iscsi: Config parameters update for Dual Chute Support (Rob Evers) [726165]
- [scsi] be2iscsi: Fix soft lock up issue during UE or if FW taking time to respond (Rob Evers) [726165]
- [scsi] be2iscsi: Fix locking mechanism in Unsol Path (Rob Evers) [726165]
- [scsi] be2iscsi: Fix negotiated parameters upload to FW (Rob Evers) [726165]
- [scsi] be2iscsi: Fix repeated issue of MAC ADDR get IOCTL (Rob Evers) [726165]
- [scsi] be2iscsi: Fix the MCCQ count leakage (Rob Evers) [726165]
- [scsi] be2iscsi: Fix Template HDR IOCTL (Rob Evers) [726165]
- [scsi] lpfc: Update lpfc version for 8.3.7.31.1p driver release (Rob Evers) [726157]
- [scsi] lpfc: Fixed issue of task management commands having a fixed timeout (Rob Evers) [726157]
- [scsi] lpfc: Fixed inconsistent spin lock usage (Rob Evers) [726157]
- [scsi] lpfc: Fix driver's abort loop functionality to skip IOs already getting aborted (Rob Evers) [726157]
- [scsi] lpfc: Fixed failure to allocate SCSI buffer on PPC64 platform for SLI4 devices (Rob Evers) [726157]
- [scsi] lpfc: Fix WARN_ON when driver unloads (Rob Evers) [726157]
- [scsi] lpfc: Avoided making pci bar ioremap call during dual-chute WQ/RQ pci bar selection (Rob Evers) [726157]
- [scsi] lpfc: Fixed driver iocbq structure's iocb_flag field running out of space (Rob Evers) [726157]
- [scsi] lpfc: Fix crash on driver load due to cpu affinity logic (Rob Evers) [726157]
- [scsi] lpfc: Fixed logging format of setting driver sysfs attributes hard to interpret (Rob Evers) [726157]
- [scsi] lpfc: Fixed back to back RSCNs discovery failure (Rob Evers) [726157]
- [scsi] lpfc: Fixed race condition between BSG I/O dispatch and timeout handling (Rob Evers) [726157]
- [scsi] lpfc: Fixed function mode field defined too small for not recognizing dual-chute mode (Rob Evers) [726157]
- [scsi] lpfc: Back out data count, (residual fcfi_parm) fix for bad target (Rob Evers) [726157]
- [scsi] lpfc: Fixed mailbox memory leak (Rob Evers) [726157]
- [scsi] lpfc: Fix random errors using first burst (Rob Evers) [726157]
- [scsi] lpfc: Fixed not able to log informational messages at early stage of driver init time (Rob Evers) [726157]
- [scsi] lpfc: Fixed using unsafe linked list macro for walking and deleting linked list (Rob Evers) [726157]
- [scsi] lpfc: Removed obsolete fcp_eq_count and fcp_wq_count driver attributes (Rob Evers) [726157]
- [scsi] lpfc: Update copyrights for 8.3.41 modifications (Rob Evers) [726157]
- [scsi] lpfc: Fixed the format of some log message fields (Rob Evers) [726157]
- [scsi] lpfc: Add first burst support to driver (Rob Evers) [726157]
- [scsi] lpfc: Fixed not able to perform PCI function reset when board was not in online mode (Rob Evers) [726157]
- [scsi] lpfc: Fixed failure in setting SLI3 board mode (Rob Evers) [726157]
- [scsi] lpfc: Fixed SLI3 failing FCP write on check-condition no-sense with residual zero (Rob Evers) [726157]
- [scsi] lpfc: Fixed support for 128 byte WQEs (Rob Evers) [726157]
- [scsi] lpfc: Ensure driver properly zeros unused fields in SLI4 mailbox commands (Rob Evers) [726157]
- [scsi] lpfc: Fixed max value of lpfc_lun_queue_depth (Rob Evers) [726157]
- [scsi] lpfc: Fixed Receive Queue varied frame size handling (Rob Evers) [726157]
- [scsi] lpfc: Fix mailbox byteswap issue on PPC (Rob Evers) [726157]
- [scsi] lpfc: Fixed freeing of iocb when internal loopback times out (Rob Evers) [726157]
- [scsi] lpfc: Update Copyrights to 2013 for 8.3.38, 8.3.39, and 8.3.40 modifications (Rob Evers) [726157]
- [scsi] lpfc: Fixed a race condition between SLI host and port failed FCF rediscovery (Rob Evers) [726157]
- [scsi] lpfc: Fixed issue mailbox wait routine failed to issue dump memory mbox command (Rob Evers) [726157]
- [scsi] lpfc: Fixed system panic due to unsafe walking and deleting linked list (Rob Evers) [726157]
- [scsi] lpfc: Fixed FCoE connection list vlan identifier and add FCF list debug (Rob Evers) [726157]
- [scsi] lpfc: Clarified the behavior of the lpfc_max_luns module parameter (Rob Evers) [726157]
- [scsi] lpfc: Fix to allow OCM to report FEC status (Rob Evers) [726157]
- [scsi] lpfc: Fixed a missing return code in a logging message (Rob Evers) [726157]
- [scsi] lpfc: Fixed some logging message fields (Rob Evers) [726157]
- [scsi] lpfc: Fixed list corruption when lpfc_drain_tx runs (Rob Evers) [726157]
- [scsi] lpfc: Fix starting reference tag when calculating BG error (Rob Evers) [726157]
- [scsi] lpfc: Fix inconsistent list removal causes crash (Rob Evers) [726157]
- [scsi] lpfc: Fixed system panic during handling unsolicited receive buffer error condition (Rob Evers) [726157]
- [scsi] lpfc: Fix BlockGuard error checking (Rob Evers) [726157]
- [scsi] lpfc: Fixed crash during FCoE failover testing (Rob Evers) [726157]
- [scsi] lpfc: Fix lpfc_used_cpu to be more dynamic (Rob Evers) [726157]
- [scsi] megaraid_sas: Fix synchronization problem between sysPD IO path and AEN path (Tomas Henzl) [1019819]
- [scsi] megaraid_sas: fixes for few endianess issues (Tomas Henzl) [1019819]
- [scsi] megaraid_sas: addded support for big endian architecture (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: Add High Availability clustering support using shared Logical Disks (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: fix memory leak if SGL has zero length entries (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: Changelog and driver version update (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support to differentiate between iMR vs MR Firmware (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support for Uneven Span PRL11 (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support for Extended MSI-x vectors for 12Gb/s controller (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Set IoFlags to enable Fast Path for JBODs for 12 Gb/s controllers (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support to display Customer branding details in syslog (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support for MegaRAID Fury (device ID-0x005f) 12Gb/s controllers (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Set IO request timeout value provided by OS timeout for Tape devices (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Free event detail memory without device ID check (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Update balance count in driver to be in sync of firmware (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Fix the interrupt mask for Gen2 controller (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Return DID_ERROR for SCSI IO, when controller is in critical h/w error (Tomas Henzl) [726228]
- [scsi] Add 'eh_deadline' to limit SCSI EH runtime (Ewan Milne) [988042]
- [scsi] remove check for 'resetting' (Ewan Milne) [988042]
- [scsi] dc395: Move 'last_reset' into internal host structure (Ewan Milne) [988042]
- [scsi] tmscsim: Move 'last_reset' into host structure (Ewan Milne) [988042]
- [scsi] advansys: Remove 'last_reset' references (Ewan Milne) [988042]
- [scsi] dpt_i2o: return SCSI_MLQUEUE_HOST_BUSY when in reset (Ewan Milne) [988042]
- [scsi] dpt_i2o: Remove DPTI_STATE_IOCTL (Ewan Milne) [988042]

* Tue Oct 29 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-38.el7]
- [net] ip_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [1014599]
- [net] ip6_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [1014599]
- [net] udp6: respect IPV6_DONTFRAG sockopt in case there are pending frames (Jiri Pirko) [1014599]
- [net] ipv6: udp packets following an UFO enqueued packet need also be handled by UFO (Jiri Pirko) [1011931] {CVE-2013-4387}
- [net] bonding: combine pr_debugs in bond_set_dev_addr into one (Nikolay Aleksandrov) [1020621]
- [net] bonding: when cloning a MAC use NET_ADDR_STOLEN (Nikolay Aleksandrov) [1020621]
- [net] bonding: remove unnecessary dev_addr_from_first member (Nikolay Aleksandrov) [1020621]
- [net] netfilter: nf_conntrack: use RCU safe kfree for conntrack extensions (Jesper Brouer) [1010252]
- [net] tcp: TSQ can use a dynamic limit (Jiri Pirko) [998775]
- [net] tcp: TSO packets automatic sizing (Jiri Pirko) [998775]
- [security] selinux: fix selinuxfs policy file on big endian systems (Eric Paris) [839671]
- [powerpc] Fix memory hotplug with sparse vmemmap (Steve Best) [805181]
- [powerpc] mm: Mark Memory Resources as busy (Steve Best) [805181]
- [tools] perf/bench: Fix failing assertions in numa bench (Petr Holasek) [1011923]
- [hid] pantherlord: heap overflow flaw (Radomir Vrbovsky) [1000436] {CVE-2013-2892}
- [powerpc] tm: Turn interrupts hard off in tm_reclaim() (Steve Best) [1017135]
- [powerpc] tm: Clear MSR RI in non-recoverable TM code (Steve Best) [1017135]
- [powerpc] perf: Fix handling of FAB events (Steve Best) [1015439]

* Thu Oct 24 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-37.el7]
- [fs] xfs: remove dead code from xlog_recover_inode_pass2 (Dave Chinner) [1001861]
- [fs] xfs: = vs == typo in ASSERT() (Dave Chinner) [1001861]
- [fs] xfs: don't assert fail on bad inode numbers (Dave Chinner) [1001861]
- [fs] xfs: aborted buf items can be in the AIL (Dave Chinner) [1001861]
- [fs] xfs: factor all the kmalloc-or-vmalloc fallback allocations (Dave Chinner) [1001861]
- [fs] xfs: fix memory allocation failures with ACLs (Dave Chinner) [1001861]
- [fs] xfs: ensure we copy buffer type in da btree root splits (Dave Chinner) [1001861]
- [fs] xfs: set remote symlink buffer type for recovery (Dave Chinner) [1001861]
- [fs] xfs: recovery of swap extents operations for CRC filesystems (Dave Chinner) [1001861]
- [fs] xfs: swap extents operations for CRC filesystems (Dave Chinner) [1001861]
- [fs] xfs: check magic numbers in dir3 leaf verifier first (Dave Chinner) [1001861]
- [fs] xfs: fix some minor sparse warnings (Dave Chinner) [1001861]
- [fs] xfs: fix endian warning in xlog_recover_get_buf_lsn() (Dave Chinner) [1001861]
- [fs] xfs: XFS_MOUNT_QUOTA_ALL needed by userspace (Dave Chinner) [1001861]
- [fs] xfs: dtype changed xfs_dir2_sfe_put_ino to xfs_dir3_sfe_put_ino (Dave Chinner) [1001861]
- [fs] xfs: Fix wrong flag ASSERT in xfs_attr_shortform_getvalue (Dave Chinner) [1001861]
- [fs] xfs: finish removing IOP_* macros (Dave Chinner) [1001861]
- [fs] xfs: inode log reservations are too small (Dave Chinner) [1001861]
- [fs] xfs: check correct status variable for xfs_inobt_get_rec() call (Dave Chinner) [1001861]
- [fs] xfs: inode buffers may not be valid during recovery readahead (Dave Chinner) [1001861]
- [fs] xfs: check LSN ordering for v5 superblocks during recovery (Dave Chinner) [1001861]
- [fs] xfs: btree block LSN escaping to disk uninitialised (Dave Chinner) [1001861]
- [fs] xfs: Assertion failed: first <= last && last < BBTOB(bp->b_length), file: fs/xfs/xfs_trans_buf.c, line: 568 (Dave Chinner) [1001861]
- [fs] xfs: fix bad dquot buffer size in log recovery readahead (Dave Chinner) [1001861]
- [fs] xfs: don't account buffer cancellation during log recovery readahead (Dave Chinner) [1001861]
- [fs] xfs: check for underflow in xfs_iformat_fork() (Dave Chinner) [1001861]
- [fs] xfs: xfs_dir3_sfe_put_ino can be static (Dave Chinner) [1001861]
- [fs] xfs: introduce object readahead to log recovery (Dave Chinner) [1001861]
- [fs] xfs: Simplify xfs_ail_min() with list_first_entry_or_null() (Dave Chinner) [1001861]
- [fs] xfs: Register hotcpu notifier after initialization (Dave Chinner) [1001861]
- [fs] xfs: add xfs sb v4 support for dirent filetype field (Dave Chinner) [1001861]
- [fs] xfs: Add write support for dirent filetype field (Dave Chinner) [1001861]
- [fs] xfs: Add read-only support for dirent filetype field (Dave Chinner) [1001861]
- [fs] xfs: Add support for the Q_XGETQSTATV (Dave Chinner) [1001861]
- [fs] quota: Add a new quotactl command Q_XGETQSTATV (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_mountfs() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_sb_quiet_read_verify() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_recover_do_dquot_buffer() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_log_unmount_write() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_ifree_cluster() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_ialloc_ag_select() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_extent_busy_update_extent() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_setsize_buftarg_early() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_punch_delalloc_range() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_last_before() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_validate_ret() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_count_tree() (Dave Chinner) [1001861]
- [fs] xfs: rename bio_add_buffer() to xfs_bio_add_buffer() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_find_head() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_recover_buffer_pass2() (Dave Chinner) [1001861]
- [fs] xfs: remove two unused macro definitions in xfs_linux.h (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_btree_get_iroot() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_iroot_realloc() (Dave Chinner) [1001861]
- [fs] xfs: remove one blank line in xfs_btree_make_block_unfull() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_write_setup_copy() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_mod_incore_sb_unlocked() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_btree_lookup() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_buf_free() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_check_sizes() (Dave Chinner) [1001861]
- [fs] xfs: use reference counts to free clean buffer items (Dave Chinner) [1001861]
- [fs] xfs: split the CIL lock (Dave Chinner) [1001861]
- [fs] xfs: Combine CIL insert and prepare passes (Dave Chinner) [1001861]
- [fs] xfs: avoid CIL allocation during insert (Dave Chinner) [1001861]
- [fs] xfs: Reduce allocations during CIL insertion (Dave Chinner) [1001861]
- [fs] xfs: return log item size in IOP_SIZE (Dave Chinner) [1001861]
- [fs] xfs: free bp in xlog_find_tail() error path (Dave Chinner) [1001861]
- [fs] xfs: free bp in xlog_find_zeroed() error path (Dave Chinner) [1001861]
- [fs] xfs: avoid double-free in xfs_attr_node_addname (Dave Chinner) [1001861]
- [fs] xfs: call roundup_64() to calculate the min_logblks (Dave Chinner) [1001861]
- [fs] xfs: Validate log space at mount time (Dave Chinner) [1001861]
- [fs] xfs: Add xfs_log_rlimit.c (Dave Chinner) [1001861]
- [fs] xfs: Refactor xfs_ticket_alloc() to extract a new helper (Dave Chinner) [1001861]
- [fs] xfs: Get rid of all XFS_XXX_LOG_RES() macro (Dave Chinner) [1001861]
- [fs] xfs: refactor xfs_trans_reserve() interface (Dave Chinner) [1001861]
- [fs] xfs: Make writeid transaction use tr_writeid (Dave Chinner) [1001861]
- [fs] xfs: Introduce tr_fsyncts to m_reservation (Dave Chinner) [1001861]
- [fs] xfs: Introduce a new structure to hold transaction reservation items (Dave Chinner) [1001861]
- [fs] xfs: make struct xfs_perag kernel only (Dave Chinner) [1001861]
- [fs] xfs: move kernel specific type definitions to xfs.h (Dave Chinner) [1001861]
- [fs] xfs: xfs_filestreams.h doesn't need __KERNEL__ (Dave Chinner) [1001861]
- [fs] xfs: remove __KERNEL__ check from xfs_dir2_leaf.c (Dave Chinner) [1001861]
- [fs] xfs: remove __KERNEL__ from debug code (Dave Chinner) [1001861]
- [fs] xfs: kill __KERNEL__ check for debug code in allocation code (Dave Chinner) [1001861]
- [fs] xfs: don't special case shared superblock mounts (Dave Chinner) [1001861]
- [fs] xfs: consolidate extent swap code (Dave Chinner) [1001861]
- [fs] xfs: consolidate xfs_utils.c (Dave Chinner) [1001861]
- [fs] xfs: consolidate xfs_rename.c (Dave Chinner) [1001861]
- [fs] xfs: kill xfs_vnodeops.[ch] (Dave Chinner) [1001861]
- [fs] xfs: fix issues that cause userspace warnings (Dave Chinner) [1001861]
- [fs] xfs: minor cleanups (Dave Chinner) [1001861]
- [fs] xfs: create xfs_bmap_util.[ch] (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_sb.c for sharing with libxfs (Dave Chinner) [1001861]
- [fs] xfs: split out the remote symlink handling (Dave Chinner) [1001861]
- [fs] xfs: split out attribute fork truncation code into separate file (Dave Chinner) [1001861]
- [fs] xfs: split out attribute listing code into separate file (Dave Chinner) [1001861]
- [fs] xfs: reshuffle dir2 definitions around for userspace (Dave Chinner) [1001861]
- [fs] xfs: move getdents code into it's own file (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_inode_buf.c for inode buffer operations (Dave Chinner) [1001861]
- [fs] xfs: move unrelated definitions out of xfs_inode.h (Dave Chinner) [1001861]
- [fs] xfs: move inode fork definitions to a new header file (Dave Chinner) [1001861]
- [fs] xfs: split out transaction reservation code (Dave Chinner) [1001861]
- [fs] xfs: sync minor header differences needed by userspace (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_quota_defs.h (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_rtalloc_defs.h (Dave Chinner) [1001861]
- [fs] xfs: split out on-disk transaction definitions (Dave Chinner) [1001861]
- [fs] xfs: separate icreate log format definitions from xfs_icreate_item.h (Dave Chinner) [1001861]
- [fs] xfs: separate dquot on disk format definitions out of xfs_quota.h (Dave Chinner) [1001861]
- [fs] xfs: split out EFI/EFD log item format definition (Dave Chinner) [1001861]
- [fs] xfs: split out buf log item format definitions (Dave Chinner) [1001861]
- [fs] xfs: split out inode log item format definition (Dave Chinner) [1001861]
- [fs] xfs: separate out log format definitions (Dave Chinner) [1001861]
- [fs] xfs: di_flushiter considered harmful (Dave Chinner) [1001861]
- [fs] xfs: Start using pquotaino from the superblock (Dave Chinner) [1001861]
- [fs] xfs: Initialize all quota inodes to be NULLFSINO (Dave Chinner) [1001861]
- [fs] xfs: Fix a deadlock in xfs_log_commit_cil() code path (Dave Chinner) [1001861]
- [fs] xfs: fix assertion failure in xfs_vm_write_failed() (Dave Chinner) [1001861]
- [fs] xfs: Fix the logic check for all quotas being turned off (Dave Chinner) [1001861]
- [fs] xfs: Add pquota fields where gquota is used (Dave Chinner) [1001861]
- [fs] xfs: fix sgid inheritance for subdirectories inheriting default acls (Dave Chinner) [1001861]
- [fs] xfs: dquot log reservations are too small (Dave Chinner) [1001861]
- [fs] xfs: remove local fork format handling from xfs_bmapi_write() (Dave Chinner) [1001861]
- [fs] xfs: use get_unused_fd_flags(0) instead of get_unused_fd() (Dave Chinner) [1001861]
- [fs] xfs: clean up unused codes at xfs_bulkstat() (Dave Chinner) [1001861]
- [fs] xfs: use XFS_BMAP_BMDR_SPACE vs. XFS_BROOT_SIZE_ADJ (Dave Chinner) [1001861]
- [fs] xfs: Remove incore use of XFS_OQUOTA_ENFD and XFS_OQUOTA_CHKD (Dave Chinner) [1001861]
- [fs] xfs: Change xfs_dquot_acct to be a 2-dimensional array (Dave Chinner) [1001861]
- [fs] xfs: Code cleanup and removal of some typedef usage (Dave Chinner) [1001861]
- [fs] xfs: Replace macro XFS_DQ_TO_QIP with a function (Dave Chinner) [1001861]
- [fs] xfs: Replace macro XFS_DQUOT_TREE with a function (Dave Chinner) [1001861]
- [fs] xfs: Define a new function xfs_is_quota_inode() (Dave Chinner) [1001861]
- [fs] xfs: implement inode change count (Dave Chinner) [1001861]
- [fs] xfs: Use inode create transaction (Dave Chinner) [1001861]
- [fs] xfs: Inode create item recovery (Dave Chinner) [1001861]
- [fs] xfs: Inode create transaction reservations (Dave Chinner) [1001861]
- [fs] xfs: Inode create log items (Dave Chinner) [1001861]
- [fs] xfs: Introduce an ordered buffer item (Dave Chinner) [1001861]
- [fs] xfs: Introduce ordered log vector support (Dave Chinner) [1001861]
- [fs] xfs: xfs_ifree doesn't need to modify the inode buffer (Dave Chinner) [1001861]
- [fs] xfs: don't do IO when creating an new inode (Dave Chinner) [1001861]
- [fs] xfs: don't use speculative prealloc for small files (Dave Chinner) [1001861]
- [fs] xfs: plug directory buffer readahead (Dave Chinner) [1001861]
- [fs] xfs: add pluging for bulkstat readahead (Dave Chinner) [1001861]
- [fs] xfs: Remove dead function prototype xfs_sync_inode_grab() (Dave Chinner) [1001861]
- [fs] xfs: Remove the left function variable from xfs_ialloc_get_rec() (Dave Chinner) [1001861]
- [fs] xfs: check on-disk (not incore) btree root size in dfrag.c (Dave Chinner) [1001861]
- [fs] xfs: Remove XFS_MOUNT_RETERR (Dave Chinner) [1001861]
- [fs] xfs: Remove two dead transaction log reservaion macros (Dave Chinner) [1001861]
- [fs] xfs: return FIEMAP_EXTENT_UNKNOWN for delayed allocation extent (Dave Chinner) [1001861]
- [fs] xfs: fix the symbolic link assert in xfs_ifree (Dave Chinner) [1001861]
- [fs] xfs: Remove struct xfs_chash from xfs_mount (Dave Chinner) [1001861]
- [fs] xfs: Don't keep silent if sunit/swidth can not be changed via mount (Dave Chinner) [1001861]
- [fs] xfs: Remove redundant error variable from xfs_growfs_data_private() (Dave Chinner) [1001861]
- [fs] xfs: Convert use of typedef ctl_table to struct ctl_table (Dave Chinner) [1001861]
- [fs] xfs: Avoid pathological backwards allocation (Dave Chinner) [1001861]

* Wed Oct 23 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-36.el7]
- [fs] btrfs: create the uuid tree on remount rw (Eric Sandeen) [1010071]
- [fs] btrfs: change extent-same to copy entire argument struct (Eric Sandeen) [1010071]
- [fs] btrfs: dir_inode_operations should use btrfs_update_time also (Eric Sandeen) [1010071]
- [fs] btrfs: add btrfs prefix to kernel log output (Eric Sandeen) [1010071]
- [fs] btrfs: refuse to remount read-write after abort (Eric Sandeen) [1010071]
- [fs] btrfs: don't leak transaction in btrfs_sync_file() (Eric Sandeen) [1010071]
- [fs] btrfs: add the missing mutex unlock in write_all_supers() (Eric Sandeen) [1010071]
- [fs] btrfs: iput inode on allocation failure (Eric Sandeen) [1010071]
- [fs] btrfs: remove space_info->reservation_progress (Eric Sandeen) [1010071]
- [fs] btrfs: kill delay_iput arg to the wait_ordered functions (Eric Sandeen) [1010071]
- [fs] btrfs: fix worst case calculator for space usage (Eric Sandeen) [1010071]
- [fs] btrfs: improve replacing nocow extents (Eric Sandeen) [1010071]
- [fs] btrfs: drop dir i_size when adding new names on replay (Eric Sandeen) [1010071]
- [fs] btrfs: replay dir_index items before other items (Eric Sandeen) [1010071]
- [fs] btrfs: check roots last log commit when checking if an inode has been logged (Eric Sandeen) [1010071]
- [fs] btrfs: actually log directory we are fsync()'ing (Eric Sandeen) [1010071]
- [fs] btrfs: actually limit the size of delalloc range (Eric Sandeen) [1010071]
- [fs] btrfs: allocate the free space by the existed max extent size when ENOSPC (Eric Sandeen) [1010071]
- [fs] btrfs: add lockdep and tracing annotations for uuid tree (Eric Sandeen) [1010071]
- [fs] btrfs: show compiled-in config features at module load time (Eric Sandeen) [1010071]
- [fs] btrfs: more efficient inode tree replace operation (Eric Sandeen) [1010071]
- [fs] btrfs: do not add replace target to the alloc_list (Eric Sandeen) [1010071]
- [fs] btrfs: fixup error handling in btrfs_reloc_cow (Eric Sandeen) [1010071]
- [fs] btrfs: optimize key searches in btrfs_search_slot (Eric Sandeen) [1010071]
- [fs] btrfs: don't use an async starter for most of our workers (Eric Sandeen) [1010071]
- [fs] btrfs: only update disk_i_size as we remove extents (Eric Sandeen) [1010071]
- [fs] btrfs: fix deadlock in uuid scan kthread (Eric Sandeen) [1010071]
- [fs] btrfs: stop refusing the relocation of chunk 0 (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory leak of uuid_root in free_fs_info (Eric Sandeen) [1010071]
- [fs] btrfs: reuse kbasename helper (Eric Sandeen) [1010071]
- [fs] btrfs: return btrfs error code for dev excl ops err (Eric Sandeen) [1010071]
- [fs] btrfs: allow partial ordered extent completion (Eric Sandeen) [1010071]
- [fs] btrfs: convert all bug_ons in free-space-cache.c (Eric Sandeen) [1010071]
- [fs] btrfs: add support for asserts (Eric Sandeen) [1010071]
- [fs] btrfs: adjust the fs_devices->missing count on unmount (Eric Sandeen) [1010071]
- [fs] btrfs: don't check for root_refs == 0 twice (Eric Sandeen) [1010071]
- [fs] btrfs: fix for patch "cleanup: don't check the same thing twice" (Eric Sandeen) [1010071]
- [fs] btrfs: get rid of one BUG() in write_all_supers() (Eric Sandeen) [1010071]
- [fs] btrfs: allocate prelim_ref with a slab allocater (Eric Sandeen) [1010071]
- [fs] btrfs: pass gfp_t to __add_prelim_ref() to avoid always using GFP_ATOMIC (Eric Sandeen) [1010071]
- [fs] btrfs: fix race conditions in BTRFS_IOC_FS_INFO ioctl (Eric Sandeen) [1010071]
- [fs] btrfs: fix race between removing a dev and writing sbs (Eric Sandeen) [1010071]
- [fs] btrfs: remove ourselves from the cluster list under lock (Eric Sandeen) [1010071]
- [fs] btrfs: do not clear our orphan item runtime flag on eexist (Eric Sandeen) [1010071]
- [fs] btrfs: fix send to deal with sparse files properly (Eric Sandeen) [1010071]
- [fs] btrfs: fix printing of non NULL terminated string (Eric Sandeen) [1010071]
- [fs] btrfs: Use z to format size_t (Eric Sandeen) [1010071]
- [fs] btrfs: Do not truncate sector_t on 32-bit with CONFIG_LBDAF=y (Eric Sandeen) [1010071]
- [fs] btrfs: PAGE_CACHE_SIZE is already unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_header_chunk_tree_uuid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_header_fsid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_dev_extent_chunk_tree_uuid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_device_fsid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_device_uuid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Format mirror_num as int (Eric Sandeen) [1010071]
- [fs] btrfs: Format PAGE_SIZE as unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make BTRFS_DEV_REPLACE_DEVID an unsigned long long constant (Eric Sandeen) [1010071]
- [fs] btrfs: Remove superfluous casts from u64 to unsigned long long (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory leak of orphan block rsv (Eric Sandeen) [1010071]
- [fs] btrfs: rollback btrfs_device fields on umount (Eric Sandeen) [1010071]
- [fs] btrfs: add alloc_fs_devices and switch to it (Eric Sandeen) [1010071]
- [fs] btrfs: add btrfs_alloc_device and switch to it (Eric Sandeen) [1010071]
- [fs] btrfs: find_next_devid: root -> fs_info (Eric Sandeen) [1010071]
- [fs] btrfs: don't allow the replace procedure on read only filesystems (Eric Sandeen) [1010071]
- [fs] btrfs: reset force_compress on btrfs_file_defrag failure (Eric Sandeen) [1010071]
- [fs] btrfs: use __u64 in exported user headers (Eric Sandeen) [1010071]
- [fs] btrfs: add mount option to force UUID tree checking (Eric Sandeen) [1010071]
- [fs] btrfs: check UUID tree during mount if required (Eric Sandeen) [1010071]
- [fs] btrfs: introduce uuid-tree-gen field (Eric Sandeen) [1010071]
- [fs] btrfs: fill UUID tree initially (Eric Sandeen) [1010071]
- [fs] btrfs: maintain subvolume items in the UUID tree (Eric Sandeen) [1010071]
- [fs] btrfs: create UUID tree if required (Eric Sandeen) [1010071]
- [fs] btrfs: support printing UUID tree elements (Eric Sandeen) [1010071]
- [fs] btrfs: introduce a tree for items that map UUIDs to something (Eric Sandeen) [1010071]
- [fs] btrfs: mark some local function as 'static' (Eric Sandeen) [1010071]
- [fs] btrfs: get rid of sparse warnings (Eric Sandeen) [1010071]
- [fs] btrfs: don't miss inode ref items in BTRFS_IOC_INO_LOOKUP (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error code to BTRFS_IOC_INO_LOOKUP handler (Eric Sandeen) [1010071]
- [fs] btrfs: remove reduplicate check when disabling quota (Eric Sandeen) [1010071]
- [fs] btrfs: move btrfs_free_qgroup_config() out of spin_lock and fix comments (Eric Sandeen) [1010071]
- [fs] btrfs: fix oops when writing dirty qgroups to disk (Eric Sandeen) [1010071]
- [fs] btrfs: fix send issues related to inode number reuse (Eric Sandeen) [1010071]
- [fs] btrfs: separate out tests into their own directory (Eric Sandeen) [1010071]
- [fs] btrfs: avoid starting a transaction in the write path (Eric Sandeen) [1010071]
- [fs] btrfs: fix heavy delalloc related deadlock (Eric Sandeen) [1010071]
- [fs] btrfs: fix the error handling wrt orphan items (Eric Sandeen) [1010071]
- [fs] btrfs: don't allow a subvol to be deleted if it is the default subovl (Eric Sandeen) [1010071]
- [fs] btrfs: skip subvol entries when checking if we've created a dir already (Eric Sandeen) [1010071]
- [fs] btrfs: offline dedupe (Eric Sandeen) [1010071]
- [fs] btrfs: Introduce extent_read_full_page_nolock() (Eric Sandeen) [1010071]
- [fs] btrfs: btrfs_ioctl_clone, Move clone code into it's own function (Eric Sandeen) [1010071]
- [fs] btrfs: abtract out range locking in clone ioctl() (Eric Sandeen) [1010071]
- [fs] btrfs: fix possible memory leak in find_parent_nodes() (Eric Sandeen) [1010071]
- [fs] btrfs: return ENOSPC when target space is full (Eric Sandeen) [1010071]
- [fs] btrfs: don't ignore errors from btrfs_run_delayed_items (Eric Sandeen) [1010071]
- [fs] btrfs: fix inode leak on kmalloc failure in tree-log.c (Eric Sandeen) [1010071]
- [fs] btrfs: allow compressed extents to be merged during defragment (Eric Sandeen) [1010071]
- [fs] btrfs: add mount option to set commit interval (Eric Sandeen) [1010071]
- [fs] btrfs: stop using GFP_ATOMIC when allocating rewind ebs (Eric Sandeen) [1010071]
- [fs] btrfs: deal with enomem in the rewind path (Eric Sandeen) [1010071]
- [fs] btrfs: check our parent dir when doing a compare send (Eric Sandeen) [1010071]
- [fs] btrfs: handle errors when doing slow caching (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error handling to read_tree_block (Eric Sandeen) [1010071]
- [fs] btrfs: Fix leak in __btrfs_map_block error path (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error check to find_parent_nodes (Eric Sandeen) [1010071]
- [fs] btrfs: optimize function btrfs_read_chunk_tree (Eric Sandeen) [1010071]
- [fs] btrfs: don't bug_on when we fail when cleaning up transactions (Eric Sandeen) [1010071]
- [fs] btrfs: change how we queue blocks for backref checking (Eric Sandeen) [1010071]
- [fs] btrfs: check to see if we have an inline item properly (Eric Sandeen) [1010071]
- [fs] btrfs: fix what bits we clear when erroring out from delalloc (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup arguments to extent_clear_unlock_delalloc (Eric Sandeen) [1010071]
- [fs] btrfs: use BTRFS_SUPER_INFO_SIZE macro at btrfs_read_dev_super() (Eric Sandeen) [1010071]
- [fs] btrfs: cache the extent map struct when reading several pages (Eric Sandeen) [1010071]
- [fs] btrfs: batch the extent state operation when reading pages (Eric Sandeen) [1010071]
- [fs] btrfs: batch the extent state operation in the end io handle of the read page (Eric Sandeen) [1010071]
- [fs] btrfs: don't cache the csum value into the extent state tree (Eric Sandeen) [1010071]
- [fs] btrfs: add branch prediction hints in the read page end IO function (Eric Sandeen) [1010071]
- [fs] btrfs: remove unnecessary argument of bio_readpage_error() (Eric Sandeen) [1010071]
- [fs] btrfs: add missing mounting options in btrfs_show_options() (Eric Sandeen) [1010071]
- [fs] btrfs: use u64 for subvolid when parsing mount options (Eric Sandeen) [1010071]
- [fs] btrfs: add sanity checks regarding to parsing mount options (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory leak when allocating pages for p/q stripes failed in raid56 (Eric Sandeen) [1010071]
- [fs] btrfs: fix and cleanup some error paths in raid56 (Eric Sandeen) [1010071]
- [fs] btrfs: don't bother autodefragging if our root is going away (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup reloc roots properly on error (Eric Sandeen) [1010071]
- [fs] btrfs: reset ret in record_one_backref (Eric Sandeen) [1010071]
- [fs] btrfs: fix get set label blocking against balance (Eric Sandeen) [1010071]
- [fs] btrfs: Print key type in decimal everywhere (Eric Sandeen) [1010071]
- [fs] btrfs: update delayed ref tracepoints (Eric Sandeen) [1010071]
- [fs] btrfs: btrfs_read_block_groups, Use enums to index (Eric Sandeen) [1010071]
- [fs] btrfs: Cleanup for using BTRFS_SETGET_STACK instead of raw convert (Eric Sandeen) [1010071]
- [fs] btrfs: set qgroup_ulist to be null after calling ulist_free() (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error checks to add_data_references (Eric Sandeen) [1010071]
- [fs] btrfs: make errors in btrfs_num_copies less noisy (Eric Sandeen) [1010071]
- [fs] btrfs: make free space caching faster with many non-inline extent references (Eric Sandeen) [1010071]
- [fs] btrfs: fall back to global reservation when removing subvolumes (Eric Sandeen) [1010071]
- [fs] btrfs: optimize btrfs_lookup_extent_info() (Eric Sandeen) [1010071]
- [fs] btrfs: Release uuid_mutex for shrink during device delete (Eric Sandeen) [1010071]
- [fs] btrfs: set lockdep class before locking new extent buffer (Eric Sandeen) [1010071]
- [fs] btrfs: return -1 when lzo compression makes data bigger (Eric Sandeen) [1010071]
- [fs] btrfs: stop using GFP_ATOMIC for the tree mod log allocations (Eric Sandeen) [1010071]
- [fs] btrfs: treewide: Add __GFP_NOWARN to k.alloc calls with v.alloc fallbacks (Eric Sandeen) [1010071]
- [fs] btrfs: don't loop on large offsets in readdir (Eric Sandeen) [1010071]
- [fs] btrfs: check to see if root_list is empty before adding it to dead roots (Eric Sandeen) [1010071]
- [fs] btrfs: release both paths before logging dir/changed extents (Eric Sandeen) [1010071]
- [fs] btrfs: allow splitting of hole em's when dropping extent cache (Eric Sandeen) [1010071]
- [fs] btrfs: make sure the backref walker catches all refs to our extent (Eric Sandeen) [1010071]
- [fs] btrfs: fix backref walking when we hit a compressed extent (Eric Sandeen) [1010071]
- [fs] btrfs: do not offset physical if we're compressed (Eric Sandeen) [1010071]
- [fs] btrfs: fix extent buffer leak after backref walking (Eric Sandeen) [1010071]
- [fs] btrfs: fix a bug of snapshot-aware defrag to make it work on partial extents (Eric Sandeen) [1010071]
- [fs] btrfs: fix file truncation if FALLOC_FL_KEEP_SIZE is specified (Eric Sandeen) [1010071]
- [fs] btrfs: fix wrong write offset when replacing a device (Eric Sandeen) [1010071]
- [fs] btrfs: re-add root to dead root list if we stop dropping it (Eric Sandeen) [1010071]
- [fs] btrfs: fix lock leak when resuming snapshot deletion (Eric Sandeen) [1010071]
- [fs] btrfs: update drop progress before stopping snapshot dropping (Eric Sandeen) [1010071]
- [fs] btrfs: wait ordered range before doing direct io (Eric Sandeen) [1010071]
- [fs] btrfs: only do the tree_mod_log_free_eb if this is our last ref (Eric Sandeen) [1010071]
- [fs] btrfs: hold the tree mod lock in __tree_mod_log_rewind (Eric Sandeen) [1010071]
- [fs] btrfs: make backref walking code handle skinny metadata (Eric Sandeen) [1010071]
- [fs] btrfs: fix crash regarding to ulist_add_merge (Eric Sandeen) [1010071]
- [fs] btrfs: fix several potential problems in copy_nocow_pages_for_inode (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup the code of copy_nocow_pages_for_inode() (Eric Sandeen) [1010071]
- [fs] btrfs: fix oops when recovering the file data by scrub function (Eric Sandeen) [1010071]
- [fs] btrfs: make the chunk allocator completely tree lockless (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup orphaned root orphan item (Eric Sandeen) [1010071]
- [fs] btrfs: fix wrong mirror number tuning (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup redundant code in btrfs_submit_direct() (Eric Sandeen) [1010071]
- [fs] btrfs: remove btrfs_sector_sum structure (Eric Sandeen) [1010071]
- [fs] btrfs: check if we can nocow if we don't have data space (Eric Sandeen) [1010071]
- [fs] btrfs: stop using try_to_writeback_inodes_sb_nr to flush delalloc (Eric Sandeen) [1010071]
- [fs] btrfs: use a percpu to keep track of possibly pinned bytes (Eric Sandeen) [1010071]
- [fs] btrfs: check for actual acls rather than just xattrs when caching no acl (Eric Sandeen) [1010071]
- [fs] btrfs: move btrfs_truncate_page to btrfs_cont_expand instead of btrfs_truncate (Eric Sandeen) [1010071]
- [fs] btrfs: optimize reada_for_balance (Eric Sandeen) [1010071]
- [fs] btrfs: optimize read_block_for_search (Eric Sandeen) [1010071]
- [fs] btrfs: unlock extent range on enospc in compressed submit (Eric Sandeen) [1010071]
- [fs] btrfs: fix the comment typo for btrfs_attach_transaction_barrier (Eric Sandeen) [1010071]
- [fs] btrfs: fix not being able to find skinny extents during relocate (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup backref search commit root flag stuff (Eric Sandeen) [1010071]
- [fs] btrfs: free csums when we're done scrubbing an extent (Eric Sandeen) [1010071]
- [fs] btrfs: fix transaction throttling for delayed refs (Eric Sandeen) [1010071]
- [fs] btrfs: stop waiting on current trans if we aborted (Eric Sandeen) [1010071]
- [fs] btrfs: wake up delayed ref flushing waiters on abort (Eric Sandeen) [1010071]
- [fs] btrfs: fix the code comments for LZO compression workspace (Eric Sandeen) [1010071]
- [fs] btrfs: fix broken nocow after balance (Eric Sandeen) [1010071]
- [fs] btrfs: more open-coded file_inode() (Eric Sandeen) [1010071]
- [fs] btrfs: exclude logged extents before replying when we are mixed (Eric Sandeen) [1010071]
- [fs] btrfs: put our inode if orphan cleanup fails (Eric Sandeen) [1010071]
- [fs] btrfs: add some missing iput()'s in btrfs_orphan_cleanup (Eric Sandeen) [1010071]
- [fs] btrfs: do not pin while under spin lock (Eric Sandeen) [1010071]
- [fs] btrfs: Cocci spatch "memdup.spatch" (Eric Sandeen) [1010071]
- [fs] btrfs: Cocci spatch "ptr_ret.spatch" (Eric Sandeen) [1010071]
- [fs] btrfs: fix qgroup rescan resume on mount (Eric Sandeen) [1010071]
- [fs] btrfs: avoid double free of fs_info->qgroup_ulist (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory patcher through fs_info->qgroup_ulist (Eric Sandeen) [1010071]
- [fs] btrfs: simplify unlink reservations (Eric Sandeen) [1010071]
- [fs] btrfs: merge pending IO for tree log write back (Eric Sandeen) [1010071]
- [fs] btrfs: allow file data clone within a file (Eric Sandeen) [1010071]
- [fs] btrfs: remove unused code in btrfs_del_root (Eric Sandeen) [1010071]
- [fs] btrfs: kill replicate code in replay_one_buffer (Eric Sandeen) [1010071]
- [fs] btrfs: check if leaf's parent exists before pushing items around (Eric Sandeen) [1010071]
- [fs] btrfs: update new flags for tracepoint (Eric Sandeen) [1010071]
- [fs] btrfs: dont do log_removal in insert_new_root (Eric Sandeen) [1010071]
- [fs] btrfs: return error code in btrfs_check_trunc_cache_free_space() (Eric Sandeen) [1010071]
- [fs] btrfs: fix estale with btrfs send (Eric Sandeen) [1010071]
- [fs] btrfs: device delete to get errors from the kernel (Eric Sandeen) [1010071]
- [fs] btrfs: do delay iput in sync_fs (Eric Sandeen) [1010071]
- [fs] btrfs: make the state of the transaction more readable (Eric Sandeen) [1010071]
- [fs] btrfs: remove the time check in btrfs_commit_transaction() (Eric Sandeen) [1010071]
- [fs] btrfs: remove unnecessary varient ->num_joined in btrfs_transaction structure (Eric Sandeen) [1010071]
- [fs] btrfs: don't flush the delalloc inodes in the while loop if flushoncommit is set (Eric Sandeen) [1010071]
- [fs] btrfs: don't wait for all the writers circularly during the transaction commit (Eric Sandeen) [1010071]
- [fs] btrfs: remove the code for the impossible case in cleanup_transaction() (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup unnecessary assignment when cleaning up all the residual transaction (Eric Sandeen) [1010071]
- [fs] btrfs: just flush the delalloc inodes in the source tree before snapshot creation (Eric Sandeen) [1010071]
- [fs] btrfs: introduce per-subvolume ordered extent list (Eric Sandeen) [1010071]
- [fs] btrfs: introduce per-subvolume delalloc inode list (Eric Sandeen) [1010071]
- [fs] btrfs: introduce grab/put functions for the root of the fs/file tree (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup the similar code of the fs root read (Eric Sandeen) [1010071]
- [fs] btrfs: make the snap/subv deletion end more early when the fs is R/O (Eric Sandeen) [1010071]
- [fs] btrfs: move the R/O check out of btrfs_clean_one_deleted_snapshot() (Eric Sandeen) [1010071]
- [fs] btrfs: make the cleaner complete early when the fs is going to be umounted (Eric Sandeen) [1010071]
- [fs] btrfs: remove unnecessary ->s_umount in cleaner_kthread() (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup: don't check the same thing twice (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup, btrfs_read_fs_root_no_name() doesn't return NULL (Eric Sandeen) [1010071]
- [fs] btrfs: delete unused function (Eric Sandeen) [1010071]
- [fs] btrfs: remove useless copy in quota_ctl (Eric Sandeen) [1010071]
- [fs] btrfs: Minor format cleanup (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup unused arguments in send.c (Eric Sandeen) [1010071]
- [fs] btrfs: add ioctl to wait for qgroup rescan completion (Eric Sandeen) [1010071]
- [fs] btrfs: introduce qgroup_ulist to avoid frequently allocating/freeing ulist (Eric Sandeen) [1010071]
- [fs] btrfs: show compiled-in config features at module load time (Eric Sandeen) [1010071]
- [fs] btrfs: move ifdef around sanity checks out of init_btrfs_fs (Eric Sandeen) [1010071]
- [fs] btrfs: add prefix to sanity tests messages (Eric Sandeen) [1010071]
- [fs] btrfs: add debug check for extent_io range alignment (Eric Sandeen) [1010071]
- [fs] btrfs: fix check on same raid type flag twice (Eric Sandeen) [1010071]
- [fs] btrfs: Fix typo in printk (Eric Sandeen) [1010071]
- [fs] btrfs: fix btrfs_extend_item() comment (Eric Sandeen) [1010071]

* Wed Oct 16 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-35.el7]
- [netdrv] mlx4: Fix handling of dma_map failure (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Notify user when TX ring in error state (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Disable global flow control when PFC enabled (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Coding style cleanup in mlx4_en_dcbnl_ieee_setpfc() (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Staticize local functions (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: VFs must ignore the enable_64b_cqe_eqe module param (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Don't give VFs MAC addresses which are derived from the PF MAC (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Respond to operation request by firmware (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix BlueFlame race (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: fix small memory leak on error (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add HW enforcement to VF link state (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Dynamic VST to VST vlan/qos changes (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fail device init if num_vfs is negative (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add warning in case of command timeouts (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Replace sscanf() with kstrtoint() (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Remove an unnecessary test (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add prints when TX timeout occurs (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix a race between napi poll function and RX ring cleanup (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Change log level from error to debug for vlan related messages (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Move register_netdev() to the end of initialization function (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Do not query stats when device port is down (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix resource leak in error flow (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: allow order-0 memory allocations in RX path (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add support for busy poll (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add VF link state support (Amir Vadai) [862498 868244 920465 978058 998202]
- [net] core: Add VF link state control (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: use __netdev_pick_tx instead of __skb_tx_hash in mlx4_en_select_queue (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: use one page fragment per incoming frame (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] ipoib: Fix pkey change flow for virtualization environments (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] ipoib: Make sure child devices use valid/proper pkeys (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Create QP1 using the pkey index which contains the default pkey (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] mlx4: Use default pkey when creating tunnel QPs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Fix redundant pointer check in dealloc flow (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Fix possible memory leak in iser_create_frwr_pool() (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Introduce fast memory registration model (FRWR) (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Place the fmr pool into a union in iser's IB conn struct (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Handle unaligned SG in separate function (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Generalize rdma memory registration (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Accept session->cmds_max from user space (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Restructure allocation/deallocation of connection resources (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Use proper debug level value for info prints (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Add Discovery support (Amir Vadai) [862498 868244 920465 978058 998202]
- [scsi] libiscsi: Exporting new attrs for iscsi session and connection in sysfs (Amir Vadai) [862498 868244 920465 978058 998202]
- [scsi] scsi_transport_iscsi: Exporting new attrs for iscsi session and connection in sysfs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Better checking of userspace values for receive flow steering (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] mlx4: Add receive flow steering support (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Export ib_create/destroy_flow through uverbs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Infrastructure for extensible uverbs commands (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Add receive flow steering support (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Fixes to XRC reference counting in uverbs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Add locking around event dispatching on XRC target QPs (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix XRC QPs detection in the resource tracker (Amir Vadai) [862498 868244 920465 978058 998202]
- [powerpc] irq: Don't switch to irq stack from softirq stack (Steve Best) [1016454]
- [powerpc] hvsi: Increase handshake timeout from 200ms to 400ms (Steve Best) [1012654]
- [powerpc] zimage: make the "OF" wrapper support ePAPR boot (Steve Best) [1012654]
- [powerpc] pseries: Do not start secondaries in Open Firmware (Steve Best) [1012654]
- [powerpc] Make prom_init.c endian safe (Steve Best) [1012654]
- [powerpc] Remove ksp_limit on ppc64 (Steve Best) [1012654]
- [powerpc] irq: Run softirqs off the top of the irq stack (Steve Best) [1012654]
- [mm] avoid reinserting isolated balloon pages into LRU lists (Rafael Aquini) [1017445]
- [kernel] sched: fix race in migrate_swap_stop (Rik van Riel) [683513]
- [kernel] sched/numa: Retry task_numa_migrate() periodically (Rik van Riel) [683513]
- [kernel] sched/numa: Use unsigned longs for numa group fault stats (Rik van Riel) [683513]
- [kernel] sched/numa: Skip some page migrations after a shared fault (Rik van Riel) [683513]
- [kernel] sched/numa: Remove the numa_balancing_scan_period_reset sysctl (Rik van Riel) [683513]
- [kernel] sched/numa: Adjust scan rate in task_numa_placement (Rik van Riel) [683513]
- [kernel] sched/numa: Take false sharing into account when adapting scan rate (Rik van Riel) [683513]
- [kernel] sched/numa: Be more careful about joining numa groups (Rik van Riel) [683513]
- [kernel] sched/numa: Avoid migrating tasks that are placed on their preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Fix task or group comparison (Rik van Riel) [683513]
- [kernel] sched/numa: Decide whether to favour task or group weights based on swap candidate relationships (Rik van Riel) [683513]
- [kernel] sched/numa: Add debugging (Rik van Riel) [683513]
- [kernel] sched/numa: Prevent parallel updates to group stats during placement (Rik van Riel) [683513]
- [kernel] sched/numa: Call task_numa_free() from do_execve () (Rik van Riel) [683513]
- [kernel] sched/numa: Use group fault statistics in numa placement (Rik van Riel) [683513]
- [kernel] sched/numa: Stay on the same node if CLONE_VM (Rik van Riel) [683513]
- [mm] numa: Do not batch handle PMD pages (Rik van Riel) [683513]
- [mm] numa: Do not group on RO pages (Rik van Riel) [683513]
- [mm] numa: Copy cpupid on page migration (Rik van Riel) [683513]
- [kernel] sched/numa: Report a NUMA task group ID (Rik van Riel) [683513]
- [kernel] sched/numa: Use {cpu, pid} to create task groups for shared faults (Rik van Riel) [683513]
- [mm] numa: Change page last {nid, pid} into {cpu, pid} (Rik van Riel) [683513]
- [kernel] sched/numa: Fix placement of workloads spread across multiple nodes (Rik van Riel) [683513]
- [kernel] sched/numa: Favor placing a task on the preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Use a system-wide search to find swap/migration candidates (Rik van Riel) [683513]
- [kernel] sched/numa: Introduce migrate_swap() (Rik van Riel) [683513]
- [kernel] stop_machine: Introduce stop_two_cpus() (Rik van Riel) [683513]
- [mm] numa: Trap pmd hinting faults only if we would otherwise trap PTE faults (Rik van Riel) [683513]
- [kernel] sched/numa: Do not trap hinting faults for shared libraries (Rik van Riel) [683513]
- [kernel] sched/numa: Increment numa_migrate_seq when task runs in correct location (Rik van Riel) [683513]
- [kernel] sched/numa: Retry migration of tasks to CPU on a preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Avoid overloading CPUs on a preferred NUMA node (Rik van Riel) [683513]
- [kernel] numa: Limit NUMA scanning to migrate-on-fault VMAs (Rik van Riel) [683513]
- [kernel] sched/numa: Do not migrate memory immediately after switching node (Rik van Riel) [683513]
- [mm] sched/numa: Set preferred NUMA node based on number of private faults (Rik van Riel) [683513]
- [kernel] sched/numa: Remove check that skips small VMAs (Rik van Riel) [683513]
- [mm] numa: Scan pages with elevated page_mapcount (Rik van Riel) [683513]
- [kernel] sched/numa: Check current-> mm before allocating NUMA faults (Rik van Riel) [683513]
- [kernel] sched/numa: Add infrastructure for split shared/ private accounting of NUMA hinting faults (Rik van Riel) [683513]
- [kernel] sched/numa: Reschedule task on preferred NUMA node once selected (Rik van Riel) [683513]
- [kernel] sched/numa: Resist moving tasks towards nodes with fewer hinting faults (Rik van Riel) [683513]
- [kernel] sched/numa: Favour moving tasks towards the preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Update NUMA hinting faults once per scan (Rik van Riel) [683513]
- [kernel] sched/numa: Select a preferred node with the most numa hinting faults (Rik van Riel) [683513]
- [mm] sched/numa: Track NUMA hinting faults on per-node basis (Rik van Riel) [683513]
- [mm] sched/numa: Slow scan rate if no NUMA hinting faults are being recorded (Rik van Riel) [683513]
- [mm] sched/numa: Set the scan rate proportional to the memory usage of the task being scanned (Rik van Riel) [683513]
- [mm] sched/numa: Initialise numa_next_scan properly (Rik van Riel) [683513]
- [mm] sched/numa: Continue PTE scanning even if migrate rate limited (Rik van Riel) [683513]
- [mm] sched/numa: Mitigate chance that same task always updates PTEs (Rik van Riel) [683513]
- [mm] numa: Do not migrate or account for hinting faults on the zero page (Rik van Riel) [683513]
- [mm] Only flush TLBs if a transhuge PMD is modified for NUMA pte scanning (Rik van Riel) [683513]
- [mm] Do not flush TLB during protection change if !pte_present && !migration_entry (Rik van Riel) [683513]
- [mm] Account for a THP NUMA hinting update as one PTE update (Rik van Riel) [683513]
- [mm] Close races between THP migration and PMD numa clearing (Rik van Riel) [683513]
- [mm] numa: Sanitize task_numa_fault() callsites (Rik van Riel) [683513]
- [mm] Prevent parallel splits during THP migration (Rik van Riel) [683513]
- [mm] Wait for THP migrations to complete during NUMA hinting faults (Rik van Riel) [683513]
- [mm] numa: Do not account for a hinting fault if we raced (Rik van Riel) [683513]
- [mm] sched/numa: Fix comments (Rik van Riel) [683513]
- [mm] numa: Document automatic NUMA balancing sysctls (Rik van Riel) [683513]
- [kernel] sched: monolithic code dump of what is being pushed (Rik van Riel) [683513]
- [kernel] sched: Use an accessor to read the rq clock (Rik van Riel) [683513]
- [kernel] sched: fix NUMA balancing when !SCHED_DEBUG (Rik van Riel) [683513]
- [kernel] sched: Ensure update_cfs_shares() is called for parents of continuously-running tasks (Rik van Riel) [683513]
- [kernel] sched: Fix some kernel-doc warnings (Rik van Riel) [683513]
- [virt] kvm/vmx: do not check bit 12 of EPT violation exit qualification when undefined (Gleb Natapov) [1009441]
- [virt] kvm/vmx: set "blocked by NMI" flag if EPT violation happens during IRET from NMI (Gleb Natapov) [1009441]

* Fri Oct 11 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-34.el7]
- [netdrv] netxen_nic: Update version to 4.0.81 (Chad Dupuis) [725019]
- [netdrv] netxen_nic: clean up unnecessary MSI/MSI-X capability find (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Convert mac address uses of 6 to ETH_ALEN (Chad Dupuis) [725019]
- [netdrv] netxen_nic: replace strict_strtoul() with kstrtoul() (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Avoid mixed mode interrupts (Chad Dupuis) [725019]
- [netdrv] netxen_nic: netxen_setup_intr() function code cleanup (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Log proper error message in case of mismatched adapter type (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Log driver version with firmware version (Chad Dupuis) [725019]
- [tools] perf/diff: Add generic order option for compute sorting (Jiri Olsa) [1011529]
- [tools] perf/diff: Making compute functions static (Jiri Olsa) [1011529]
- [tools] perf/diff: Update perf diff documentation for multiple data comparison (Jiri Olsa) [1011529]
- [tools] perf/diff: Change diff command to work over multiple data files (Jiri Olsa) [1011529]
- [tools] perf/diff: Move columns into struct data__file (Jiri Olsa) [1011529]
- [tools] perf/diff: Move diff related columns into diff command (Jiri Olsa) [1011529]
- [tools] perf/diff: Display data file info ahead of the diff output (Jiri Olsa) [1011529]
- [tools] perf/hists: Marking dummy hists entries (Jiri Olsa) [1011529]
- [tools] perf/diff: Switching the base hists to be pairs head (Jiri Olsa) [1011529]
- [tools] perf/diff: Introducing diff_data object to hold files (Jiri Olsa) [1011529]
- [tools] perf: Centralize default columns init in perf_hpp__init (Jiri Olsa) [1011529]
- [tools] perf: Add struct perf_hpp_fmt into hpp callbacks (Jiri Olsa) [1011529]
- [s390] vmcore: use vmcore for zfcpdump (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: enable /proc/vmcore mmap for s390 (Hendrik Brueckner) [1012102]
- [s390] vmcore: implement remap_oldmem_pfn_range for s390 (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: introduce remap_oldmem_pfn_range() (Hendrik Brueckner) [1012102]
- [s390] vmcore: use ELF header in new memory feature (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: introduce ELF header in new memory feature (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: Disable mmap for s390 (Hendrik Brueckner) [1012102]
- [s390] kdump: Allow copy_oldmem_page() copy to virtual memory (Hendrik Brueckner) [1012102]
- [tracing] Add function probe to trigger a ftrace dump of current CPU trace (Jiri Olsa) [1011527]
- [tracing] Add function probe to trigger a ftrace dump to console (Jiri Olsa) [1011527]
- [virt] xen-gnt: prevent adding duplicate gnt callbacks (Radim Krcmar) [1013818]
- [x86] microcode_amd: Fix patch level reporting for family 15h (Prarit Bhargava) [1014400]
- [tty] Fix SIGTTOU not sent with tcflush() (Oleg Nesterov) [1012397]
- [powerpc] sysfs: Disable writing to PURR in guest mode (Steve Best) [1015450]
- [powerpc] vio: fix modalias_show return values (Prarit Bhargava) [1007924]
- [powerpc] Correct FSCR bit definitions (Steve Best) [1008893]
- [x86] microcode/amd: Fix early microcode loading (Jarod Wilson) [1016168]
- [x86] microcode/amd: Make cpu_has_amd_erratum() use the correct struct cpuinfo_x86 (Jarod Wilson) [1016168]
- [x86] microcode/amd: Fix error path in apply_microcode_amd() (Jarod Wilson) [1016168]
- [x86] microcode/amd: Another early loading fixup (Jarod Wilson) [1016168]
- [x86] microcode/amd: Allow multiple families' bin files appended together (Jarod Wilson) [1016168]
- [x86] microcode/amd: Make find_ucode_in_initrd() __init (Jarod Wilson) [1016168]
- [x86] microcode/amd: Fix warnings and errors on with CONFIG_MICROCODE=m (Jarod Wilson) [1016168]
- [x86] microcode/amd: Early microcode patch loading support for AMD (Jarod Wilson) [1016168]
- [x86] microcode/amd: Refactor functions to prepare for early loading (Jarod Wilson) [1016168]
- [x86] microcode: Vendor abstract out save_microcode_in_initrd() (Jarod Wilson) [1016168]
- [x86] microcode/intel: Correct typo in printk (Jarod Wilson) [1016168]
- [block] nvme: Update nvme_id_power_state with latest spec (David Milburn) [1005908]
- [block] nvme: Split header file into user-visible and kernel-visible pieces (David Milburn) [1005908]
- [block] nvme: Merge issue on character device bring-up (David Milburn) [1005908]
- [block] nvme: Handle ioremap failure (David Milburn) [1005908]
- [block] nvme: Add pci suspend/resume driver callbacks (David Milburn) [1005908]
- [block] nvme: Use normal shutdown (David Milburn) [1005908]
- [block] nvme: Separate controller init from disk discovery (David Milburn) [1005908]
- [block] nvme: Separate queue alloc/free from create/delete (David Milburn) [1005908]
- [block] nvme: Group pci related actions in functions (David Milburn) [1005908]
- [block] nvme: Disk stats for read/write commands only (David Milburn) [1005908]
- [block] nvme: Bring up cdev on set feature failure (David Milburn) [1005908]
- [block] nvme: Fix checkpatch issues (David Milburn) [1005908]
- [block] nvme: Namespace IDs are unsigned (David Milburn) [1005908]
- [block] nvme: Call nvme_process_cq from submission path (David Milburn) [1005908]
- [block] nvme: Remove "process_cq did something" message (David Milburn) [1005908]
- [block] nvme: Return correct value from interrupt handler (David Milburn) [1005908]
- [block] nvme: Disk IO statistics (David Milburn) [1005908]
- [block] nvme: Restructure MSI / MSI-X setup (David Milburn) [1005908]
- [block] nvme: Use kzalloc instead of kmalloc+memset (David Milburn) [1005908]

* Fri Oct 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-33.el7]
- [fs] nfs: Give "flavor" an initial value to fix a compile warning (Jeff Layton) [1009119]
- [fs] nfs: try SECINFO_NO_NAME flavs until one works (Jeff Layton) [1009119]
- [fs] nfs: Ensure memory ordering between nfs4_ds_connect and nfs4_fl_prepare_ds (Jeff Layton) [1009119]
- [fs] nfs: nfs4_fl_prepare_ds, fix bugs when the connect attempt fails (Jeff Layton) [1009119]
- [fs] nfs: Honour the 'opened' parameter in the atomic_open() filesystem method (Jeff Layton) [1009119]
- [net] sunrpc: rpcsec_gss, fix crash on destroying gss auth (Jeff Layton) [1009119]
- [net] sunrpc: No, I did not intend to create a 256KiB hashtable (Jeff Layton) [1009119]
- [net] sunrpc: Add missing kuids conversion for printing (Jeff Layton) [1009119]
- [fs] nfs: sp4_mach_cred, WARN_ON -> WARN_ON_ONCE (Jeff Layton) [1009119]
- [fs] nfs: sp4_mach_cred, no need to ref count creds (Jeff Layton) [1009119]
- [fs] nfs: fix SECINFO* use of put_rpccred (Jeff Layton) [1009119]
- [fs] nfs: sp4_mach_cred: ask for WRITE and COMMIT (Jeff Layton) [1009119]
- [fs] nfs: fix decode_free_stateid (Jeff Layton) [1009119]
- [fs] nfs: use mach cred for SECINFO_NO_NAME w/ integrity (Jeff Layton) [1009119]
- [fs] nfs: nfs_compare_super shouldn't check the auth flavour unless 'sec=' was set (Jeff Layton) [1009119]
- [fs] nfs: Allow security autonegotiation for submounts (Jeff Layton) [1009119]
- [fs] nfs: Disallow security negotiation for lookups when 'sec=' is specified (Jeff Layton) [1009119]
- [fs] nfs: Fix security auto-negotiation (Jeff Layton) [1009119]
- [fs] nfs: Clean up nfs_parse_security_flavors() (Jeff Layton) [1009119]
- [fs] nfs: Clean up the auth flavour array mess (Jeff Layton) [1009119]
- [fs] nfs: Use MDS auth flavor for data server connection (Jeff Layton) [1009119]
- [fs] nfs: Map NFS4ERR_WRONG_CRED to EPERM (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED write and commit support (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED stateid support (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED secinfo suppor (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED cleanup support (Jeff Layton) [1009119]
- [fs] nfs: Add state protection handler (Jeff Layton) [1009119]
- [fs] nfs: Minimal SP4_MACH_CRED implementation (Jeff Layton) [1009119]
- [net] sunrpc: Replace pointer values with task->tk_pid and rpc_clnt->cl_clid (Jeff Layton) [1009119]
- [net] sunrpc: Add an identifier for struct rpc_clnt (Jeff Layton) [1009119]
- [net] sunrpc: Ensure rpc_task->tk_pid is available for tracepoints (Jeff Layton) [1009119]
- [fs] nfs: Document the recover_lost_locks kernel parameter (Jeff Layton) [1009119]
- [fs] nfs: Don't try to recover NFSv4 locks when they are lost (Jeff Layton) [1009119]
- [net] sunrpc: Add tracepoints to help debug socket connection issues (Jeff Layton) [1009119]
- [fs] nfs: Fix warning introduced by NFSv4.0 transport blocking patches (Jeff Layton) [1009119]
- [fs] nfs: fix CONFIG_NFS_V4_1 not enabled "make C=2" warning (Jeff Layton) [1009119]
- [fs] nfs: Update session draining barriers for NFSv4.0 transport blocking (Jeff Layton) [1009119]
- [fs] nfs: Add nfs4_sequence calls for OPEN_CONFIRM (Jeff Layton) [1009119]
- [fs] nfs: Add nfs4_sequence calls for RELEASE_LOCKOWNER (Jeff Layton) [1009119]
- [fs] nfs: Enable nfs4_setup_sequence() for DELEGRETURN (Jeff Layton) [1009119]
- [fs] nfs: NFSv4.0 transport blocking (Jeff Layton) [1009119]
- [fs] nfs: Add a slot table to struct nfs_client for NFSv4.0 transport blocking (Jeff Layton) [1009119]
- [fs] nfs: Add global helper for releasing slot table resources (Jeff Layton) [1009119]
- [fs] nfs: Add global helper to set up a stand-along nfs4_slot_table (Jeff Layton) [1009119]
- [fs] nfs: Enable slot table helpers for NFSv4.0 (Jeff Layton) [1009119]
- [fs] nfs: Remove unused call_sync minor version op (Jeff Layton) [1009119]
- [fs] nfs: Add RPC callouts to start NFSv4.0 synchronous requests (Jeff Layton) [1009119]
- [fs] nfs: Common versions of sequence helper functions (Jeff Layton) [1009119]
- [fs] nfs: Clean up nfs4_setup_sequence() (Jeff Layton) [1009119]
- [fs] nfs: Rename nfs41_call_sync_data as a common data structure (Jeff Layton) [1009119]
- [fs] nfs: When displaying session slot numbers, use "u" consistently (Jeff Layton) [1009119]
- [fs] nfs: Ensure that rmdir() waits for sillyrenames to complete (Jeff Layton) [1009119]
- [fs] nfs: use the mach cred for SECINFO w/ integrity (Jeff Layton) [1009119]
- [net] sunrpc: refactor rpcauth_checkverf error returns (Jeff Layton) [1009119]
- [fs] nfs: avoid expired credential keys for buffered writes (Jeff Layton) [1009119]
- [net] sunrpc: new rpc_credops to test credential expiry (Jeff Layton) [1009119]
- [net] sunrpc: don't map EKEYEXPIRED to EACCES in call_refreshresult (Jeff Layton) [1009119]
- [fs] nfs: Fix up two use-after-free issues with the new tracing code (Jeff Layton) [1009119]
- [fs] nfs: remove incorrect "Lock reclaim failed!" warning (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging test_stateid events (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging slot table operations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging layoutget/return/commit (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging reads and writes (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging getattr (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging the idmapper (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging delegations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging rename (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging inode manipulations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging lookup/create operations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging file locking (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging file open (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging state management problems (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging NFS hard links (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging NFS rename and sillyrename issues (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging directory changes (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging generic file create events (Jeff Layton) [1009119]
- [fs] nfs: Add event tracing for generic NFS lookups (Jeff Layton) [1009119]
- [fs] nfs: Pass in lookup flags from nfs_atomic_open to nfs_lookup (Jeff Layton) [1009119]
- [fs] nfs: Add event tracing for generic NFS events (Jeff Layton) [1009119]
- [fs] nfs: refactor code for calculating the crc32 hash of a filehandle (Jeff Layton) [1009119]
- [fs] nfs: Clean up nfs_sillyrename() (Jeff Layton) [1009119]
- [fs] nfs: Fix an incorrect pointer declaration in decode_first_pnfs_layout_type (Jeff Layton) [1009119]
- [fs] nfs: Deal with a sparse warning in nfs_idmap_get_key() (Jeff Layton) [1009119]
- [fs] nfs: Deal with some more sparse warnings (Jeff Layton) [1009119]
- [fs] nfs: Deal with a sparse warning in nfs4_opendata_alloc (Jeff Layton) [1009119]
- [fs] nfs: Deal with a sparse warning in nfs3_proc_create (Jeff Layton) [1009119]
- [fs] nfs: Remove the NFSv4 "open optimisation" from nfs_permission (Jeff Layton) [1009119]
- [fs] nfs: Use clientid management rpc_clnt for secinfo_no_name (Jeff Layton) [1009119]
- [fs] nfs: Use clientid management rpc_clnt for secinfo (Jeff Layton) [1009119]
- [fs] nfs: Increase NFS4_DEF_SLOT_TABLE_SIZE (Jeff Layton) [1009119]
- [fs] nfs: Remove unused authflavour parameter from init_client (Jeff Layton) [1009119]
- [fs] nfs: Never use user credentials for lease renewal (Jeff Layton) [1009119]
- [fs] nfs: Use root's credential for lease management when keytab is missing (Jeff Layton) [1009119]
- [fs] nfs: Refuse mount attempts with proto=udp (Jeff Layton) [1009119]
- [fs] nfs: Fix nfs4_init_uniform_client_string for net namespaces (Jeff Layton) [1009119]
- [fs] nfs: Use the mount point rpc_clnt for layoutreturn (Jeff Layton) [1009119]
- [fs] nfs: Fix return type of nfs4_end_drain_session() stub (Jeff Layton) [1009119]
- [fs] nfs: encode_attrs should not backfill the bitmap and attribute length (Jeff Layton) [1009119]
- [net] sunrpc: Fix memory corruption issue on 32-bit highmem systems (Jeff Layton) [1009119]
- [fs] nfs: Remove unnecessary call to nfs_setsecurity in nfs_fhget() (Jeff Layton) [1009119]
- [fs] nfs: Fix the sync mount option for nfs4 mounts (Jeff Layton) [1009119]
- [fs] nfs: Fix writeback performance issue on cache invalidation (Jeff Layton) [1009119]
- [net] sunrpc: If the rpcbind channel is disconnected, fail the call to unregister (Jeff Layton) [1009119]
- [net] sunrpc: Don't auto-disconnect from the local rpcbind socket (Jeff Layton) [1009119]
- [hid] zeroplus: validate output report details (Frantisek Hrbata) [999907] {CVE-2013-2889}
- [hid] provide a helper for validating hid reports (Frantisek Hrbata) [999907] {CVE-2013-2889}
- [s390] zfcp: enable FCP hardware data router by default (Hendrik Brueckner) [980146]
- [scsi] csiostor: fix failure to communicate with firmware, error -110 (Jay Fenlason) [917907]
- [block] mtip32xx: add SRSI support (David Milburn) [842533]
- [misc] hpilo: Correct panic when an AUX iLO is detected (Nigel Croxon) [996603]
- [Documentation] add write up on module signing (Kyle McMartin) [905495]
- [net] netfilter: SYNPROXY: let unrelated packets continue (Jesper Brouer) [1007439]
- [net] netfilter: synproxy_core: fix warning in __nf_ct_ext_add_length() (Jesper Brouer) [1007439]
- [net] netfilter: more strict TCP flag matching in SYNPROXY (Jesper Brouer) [1007439]
- [net] netfilter: add IPv6 SYNPROXY target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v6_init_sequence/cookie_v6_check (Jesper Brouer) [1007439]
- [net] netfilter: add SYNPROXY core/target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v4_init_sequence/cookie_v4_check (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: make sequence number adjustments usuable without NAT (Jesper Brouer) [1007439]
- [net] netfilter: nf_defrag_ipv6.o included twice (Jesper Brouer) [1007439]
- [net] netfilter: ip[6]t_REJECT, tcp-reset using wrong MAC source if bridged (Jesper Brouer) [1007439]
- [net] netfilter: export xt_HMARK.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: export xt_rpfilter.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix uninitialized variable (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: allow to attach expectations to conntracks (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: refactor ctnetlink_create_expect (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: fix tcp_in_window for Fast Open (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: don't send destroy events from iterator (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_{log, queue}, fix information leaks in netlink message (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: correct return value in tcpmss_mangle_packet (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPOPTSTRIP: fix possible off by one access (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: fix handling of malformed TCP header and options (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: use per-conntrack locking for sequence number adjustments (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: change sequence number adjustments to 32 bits (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: fix locking in nf_nat_seq_adjust() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove duplicate code in ctnetlink (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: constify sk_buff argument to nf_ct_attach() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove net_ratelimit() for LOG_INVALID() (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix incorrect NAT expectation dumping (Jesper Brouer) [1007439]
- [net] netfilter: Fix build errors with xt_socket.c (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: fix broken v0 support (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: add XT_SOCKET_NOWILDCARD flag (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: avoid large timeout for mid-stream pickup (Jesper Brouer) [1007439]
- [net] netfilter: check return code from nla_parse_tested (Jesper Brouer) [1007439]
- [net] Convert uses of typedef ctl_table to struct ctl_table (Jesper Brouer) [1007439]
- [net] netfilter: Implement RFC 1123 for FTP conntrack (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: avoid peer_portid test (Jesper Brouer) [1007439]
- [net] netfilter: don't panic on error while walking through the init path (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: use IP early demux (Jesper Brouer) [1007439]
- [net] netfilter: xt_CT: optimize XT_CT_NOTRACK (Jesper Brouer) [1007439]
- [net] qdisc: fix build with !CONFIG_NET_SCHED (Jesper Brouer) [1000395]
- [net] qdisc: make args to qdisc_create_default const (Jesper Brouer) [1000395]
- [net] qdisc: allow setting default queuing discipline (Jesper Brouer) [1000395]
- [net] Remove extern from include/net/ scheduling prototypes (Jesper Brouer) [1000395]
- [net] htb: fix sign extension bug (Jesper Brouer) [1000395]
- [net] htb: refactor struct htb_sched fields for performance (Jesper Brouer) [1000395]
- [net] htb: reorder struct htb_class fields for performance (Jesper Brouer) [1000395]
- [net] htb: do not setup default rate estimators (Jesper Brouer) [1000395]
- [net] net_sched: add 64bit rate estimators (Jesper Brouer) [1000395]

* Fri Oct 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-32.el7]
- [net] netfilter: SYNPROXY: let unrelated packets continue (Jesper Brouer) [1007439]
- [net] netfilter: synproxy_core: fix warning in __nf_ct_ext_add_length() (Jesper Brouer) [1007439]
- [net] netfilter: more strict TCP flag matching in SYNPROXY (Jesper Brouer) [1007439]
- [net] netfilter: add IPv6 SYNPROXY target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v6_init_sequence/cookie_v6_check (Jesper Brouer) [1007439]
- [net] netfilter: add SYNPROXY core/target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v4_init_sequence/cookie_v4_check (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: make sequence number adjustments usuable without NAT (Jesper Brouer) [1007439]
- [net] netfilter: nf_defrag_ipv6.o included twice (Jesper Brouer) [1007439]
- [net] netfilter: ip[6]t_REJECT, tcp-reset using wrong MAC source if bridged (Jesper Brouer) [1007439]
- [net] netfilter: export xt_HMARK.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: export xt_rpfilter.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix uninitialized variable (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: allow to attach expectations to conntracks (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: refactor ctnetlink_create_expect (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: fix tcp_in_window for Fast Open (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: don't send destroy events from iterator (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_{log, queue}, fix information leaks in netlink message (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: correct return value in tcpmss_mangle_packet (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPOPTSTRIP: fix possible off by one access (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: fix handling of malformed TCP header and options (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: use per-conntrack locking for sequence number adjustments (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: change sequence number adjustments to 32 bits (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: fix locking in nf_nat_seq_adjust() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove duplicate code in ctnetlink (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: constify sk_buff argument to nf_ct_attach() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove net_ratelimit() for LOG_INVALID() (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix incorrect NAT expectation dumping (Jesper Brouer) [1007439]
- [net] netfilter: Fix build errors with xt_socket.c (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: fix broken v0 support (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: add XT_SOCKET_NOWILDCARD flag (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: avoid large timeout for mid-stream pickup (Jesper Brouer) [1007439]
- [net] netfilter: check return code from nla_parse_tested (Jesper Brouer) [1007439]
- [net] Convert uses of typedef ctl_table to struct ctl_table (Jesper Brouer) [1007439]
- [net] netfilter: Implement RFC 1123 for FTP conntrack (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: avoid peer_portid test (Jesper Brouer) [1007439]
- [net] netfilter: don't panic on error while walking through the init path (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: use IP early demux (Jesper Brouer) [1007439]
- [net] netfilter: xt_CT: optimize XT_CT_NOTRACK (Jesper Brouer) [1007439]
- [net] qdisc: fix build with !CONFIG_NET_SCHED (Jesper Brouer) [1000395]
- [net] qdisc: make args to qdisc_create_default const (Jesper Brouer) [1000395]
- [net] qdisc: allow setting default queuing discipline (Jesper Brouer) [1000395]
- [net] Remove extern from include/net/ scheduling prototypes (Jesper Brouer) [1000395]
- [net] htb: fix sign extension bug (Jesper Brouer) [1000395]
- [net] htb: refactor struct htb_sched fields for performance (Jesper Brouer) [1000395]
- [net] htb: reorder struct htb_class fields for performance (Jesper Brouer) [1000395]
- [net] htb: do not setup default rate estimators (Jesper Brouer) [1000395]
- [net] net_sched: add 64bit rate estimators (Jesper Brouer) [1000395]

* Mon Sep 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-31.el7]
- [watchdog] hpwdt: Patch to ignore auxilary iLO devices (Nigel Croxon) [996605]
- [s390] tx: allow program interruption filtering in user space (Hendrik Brueckner) [1006517]
- [block] add padding for kabi to block_device_operations (Don Zickus) [988500]
- [fs] gfs2: Don't flag consistency error if first mounter is a spectator (Robert S Peterson) [1004448]
- [tty] disassociate_ctty() sends the extra SIGCONT (Oleg Nesterov) [1011820]
- [x86] mm: Add memory tracking support for 1G hugepages (David Bulkow) [1000149]
- [tty] hvc_iucv: Disconnect IUCV connection when lowering DTR (Hendrik Brueckner) [1007571]
- [tty] hvc_console: Add DTR/RTS callback to handle HUPCL control (Hendrik Brueckner) [1007571]
- [netdrv] enic: update enic maintainers and driver (Stefan Assmann) [747385]
- [netdrv] enic: Exposing symbols for Cisco's low latency driver (Stefan Assmann) [747385]
- [netdrv] enic: Try DMA 64 first, then failover to DMA (Stefan Assmann) [747385]
- [netdrv] enic: record q_number and rss_hash for skb (Stefan Assmann) [747385]
- [netdrv] enic: Add multi tx support for enic (Stefan Assmann) [747385]
- [netdrv] enic: Generate notification of hardware crash (Stefan Assmann) [747385]
- [netdrv] enic: Add an interface for USNIC to interact with firmware (Stefan Assmann) [747385]
- [netdrv] enic: Adding support for Cisco Low Latency NIC (Stefan Assmann) [747385]
- [netdrv] enic: Move ethtool code to a separate file (Stefan Assmann) [747385]
- [netdrv] enic: release rtnl_lock on error-path (Stefan Assmann) [747385]
- [powerpc] perf: Power7 Update testing ABI to list CPI-stack events (Steve Best) [1009105]
- [powerpc] perf: Make Power7 events available for perf (Steve Best) [1009105]
- [powerpc] perf: fix a typo of a Power7 event name (Steve Best) [1009105]
- [tools] perf/tests: Add parse events tests for leader sampling (Jiri Olsa) [1011533]
- [tools] perf/tests: Add attr record group sampling test (Jiri Olsa) [1011533]
- [tools] perf: Add 'S' event/group modifier to read sample value (Jiri Olsa) [1011533]
- [tools] perf/evsel: Add PERF_SAMPLE_READ sample related processing (Jiri Olsa) [1011533]
- [tools] perf/evlist: Add perf_evlist__id2sid method to get event ID related data (Jiri Olsa) [1011533]
- [tools] perf/evlist: Fix event ID retrieval for group format read case (Jiri Olsa) [1011533]
- [tools] perf: Add support for parsing PERF_SAMPLE_READ sample type (Jiri Olsa) [1011533]
- [kernel] perf/evlist: Use PERF_EVENT_IOC_ID perf ioctl to read event id (Jiri Olsa) [1011533]
- [kernel] perf: Do not get values from disabled counters in group format read (Jiri Olsa) [1011533]
- [kernel] perf: Add PERF_EVENT_IOC_ID ioctl to return event ID (Jiri Olsa) [1011533]
- [kernel] add support for init_array constructors fix (Frantisek Hrbata) [824466]
- [kernel] add support for init_array constructors (Frantisek Hrbata) [824466]
- [kernel] gcov: compile specific gcov implementation based on gcc version (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format fix 3 (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format checkpatch fixes (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format fix fix (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format fix (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 4.7 gcov format (Frantisek Hrbata) [824466]
- [kernel] gcov: move gcov structs definitions to a gcc version specific file (Frantisek Hrbata) [824466]

* Mon Sep 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-30.el7]
- [drm] qxl: add delayed fb operations (Dave Airlie) [1002056]
- [edac] Fix lockdep splat (Aristeu Rozanski) [967459]
- [mm] vmalloc: fix memleak in __vunmap (Jan Stancek) [1012358]
- [x86] perf_event_amd: Rework AMD PMU init code (Prarit Bhargava) [1000672]
- [md] dm: add reserved_bio_based_ios module parameter (Mike Snitzer) [1010450]
- [md] dm: add reserved_rq_based_ios module parameter (Mike Snitzer) [1010450]
- [md] dm: lower bio-based mempool reservation (Mike Snitzer) [1010450]
- [block] Add nr_bios to block_rq_remap tracepoint (Mike Snitzer) [1010450]
- [md] dm-mpath: disable WRITE SAME if it fails (Mike Snitzer) [987454]
- [md] dm-mpath: do not fail path on -ENOSPC (Mike Snitzer) [1010437]
- [scsi] Return ENODATA on medium error (Mike Snitzer) [1010437]
- [scsi] return ENOSPC on thin provisioning failure (Mike Snitzer) [1010437]
- [scsi] Set hostbyte status in scsi_check_sense() (Mike Snitzer) [1010437]
- [scsi] Document enhanced error codes (Mike Snitzer) [1010437]
- [md] dm-thin: do not expose non-zero discard limits if discards disabled (Mike Snitzer) [998421]
- [md] dm-snapshot: fix performance degradation due to small hash size (Mike Snitzer) [1010437]
- [md] dm-snapshot: workaround for a false positive lockdep warning (Mike Snitzer) [1010437]
- [md] dm-stripe: silence a couple sparse warnings (Mike Snitzer) [1010437]
- [md] dm-stats: fix possible counter corruption on 32-bit systems (Mike Snitzer) [1010437]
- [md] dm: add statistics support (Mike Snitzer) [1010437]
- [lib] math64: New separate div64_u64_rem helper (Mike Snitzer) [1010437]
- [md] dm-thin: always return -ENOSPC if no_free_space is set (Mike Snitzer) [1010437]
- [md] dm-ioctl: cleanup error handling in table_load (Mike Snitzer) [1010437]
- [md] dm-ioctl: increase granularity of type_lock when loading table (Mike Snitzer) [1010437]
- [md] dm-ioctl: prevent rename to empty name or uuid (Mike Snitzer) [1010437]
- [md] dm-thin: set pool read-only if breaking_sharing fails block allocation (Mike Snitzer) [1010437]
- [md] dm-thin: prefix pool error messages with pool device name (Mike Snitzer) [1010437]
- [md] dm: allow error target to replace bio-based and request-based targets (Mike Snitzer) [1010437]
- [md] dm-space-map: optimise sm_ll_dec and sm_ll_inc (Mike Snitzer) [1010437]
- [md] dm-btree: prefetch child nodes when walking tree for a dm_btree_del (Mike Snitzer) [1010437]
- [md] dm-btree: use pop_frame in dm_btree_del to cleanup code (Mike Snitzer) [1010437]
- [md] dm-cache: eliminate holes in cache structure (Mike Snitzer) [1010437]
- [md] dm-cache: fix stacking of geometry limits (Mike Snitzer) [1010437]
- [md] dm-thin: fix stacking of geometry limits (Mike Snitzer) [1010437]
- [md] dm-cache: add data block size limits to code and Documentation (Mike Snitzer) [1010437]
- [md] dm: stop using WQ_NON_REENTRANT (Mike Snitzer) [1010437]
- [md] dm-cache: avoid conflicting remove_mapping() in mq policy (Mike Snitzer) [1010437]
- [md] dm: optimize reorder structure (Mike Snitzer) [1010437]
- [md] dm: optimize use SRCU and RCU (Mike Snitzer) [1010437]
- [md] dm-bufio: submit writes outside lock (Mike Snitzer) [1010437]
- [md] dm-cache: fix arm link errors with inline (Mike Snitzer) [1010437]
- [md] dm-verity: use __ffs and __fls (Mike Snitzer) [1010437]
- [md] dm-flakey: correct ctr alloc failure mesg (Mike Snitzer) [1010437]
- [md] dm-verity: remove pointless comparison (Mike Snitzer) [1010437]
- [md] dm: use __GFP_HIGHMEM in __vmalloc (Mike Snitzer) [1010437]
- [md] dm-verity: fix inability to use a few specific devices sizes (Mike Snitzer) [1010437]
- [md] dm-ioctl: set noio flag to avoid __vmalloc deadlock (Mike Snitzer) [1010437]
- [md] dm-mpath: fix ioctl deadlock when no paths (Mike Snitzer) [1010437]
- [powerpc] Default arch idle could cede processor on pseries (Steve Best) [1008895]

* Wed Sep 25 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-29.el7]
- [s390] zfcp: remove access control tables interface (keep sysfs files) (Hendrik Brueckner) [1006516]
- [s390] zfcp: fix lock imbalance by reworking request queue locking (Hendrik Brueckner) [1006525]
- [s390] zfcp: fix schedule-inside-lock in scsi_device list loops (Hendrik Brueckner) [1006524]
- [x86] setup: avoid remapping data in parse_setup_data() (Nigel Croxon) [1004428]
- [hid] validate HID report id size (Frantisek Hrbata) [1000454] {CVE-2013-2888}
- [kernel] userns: prevent the use of user namespaces (Aristeu Rozanski) [993320]
- [crypto] x509: don't reject not-yet-valid keys (kyle mcmartin) [905910]
- [kernel] perf: Prevent race in unthrottling code (Jiri Olsa) [992941]
- [s390] pci: use adapter interrupt vector helpers (Hendrik Brueckner) [1005896]
- [s390] pci: cleanup function names (Hendrik Brueckner) [1005896]
- [s390] airq: introduce adapter interrupt vector helper (Hendrik Brueckner) [1005896]
- [s390] pci: use virtual memory for iommu bitmap (Hendrik Brueckner) [1005896]
- [s390] cio: fix unlocked access of global bitmap (Hendrik Brueckner) [1005896]
- [s390] pci: update function handle after resume from hibernate (Hendrik Brueckner) [1005896]
- [s390] pci: try harder to modify a function (Hendrik Brueckner) [1005896]
- [s390] pci: split lpf (Hendrik Brueckner) [1005896]
- [s390] hibernate: add early resume function (Hendrik Brueckner) [1005896]
- [s390] pci: add recover sysfs knob (Hendrik Brueckner) [1005896]
- [s390] pci: use claim_resource (Hendrik Brueckner) [1005896]
- [s390] pci/hotplug: convert to be builtin only (Hendrik Brueckner) [1005896]
- [s390] airq: simplify adapter interrupt code (Hendrik Brueckner) [1005896]
- [s390] qdio: cleanup chsc SADC usage (Hendrik Brueckner) [1005896]
- [s390] qdio: cleanup chsc SSQD usage (Hendrik Brueckner) [1005896]
- [s390] pci: remove per device debug attribute (Hendrik Brueckner) [1005896]
- [s390] pci: sysfs remove strlen (Hendrik Brueckner) [1005896]
- [s390] pci: remove pdev during unplug (Hendrik Brueckner) [1005896]
- [s390] pci: cleanup hotplug code (Hendrik Brueckner) [1005896]
- [s390] pci: implement pcibios_release_device (Hendrik Brueckner) [1005896]
- [s390] pci: use to_pci_dev (Hendrik Brueckner) [1005896]
- [netdrv] sfc: check for allocation failure (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Update copyright banners (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for Solarflare SFC9100 family (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make efx_mcdi_{init, fini}() call efx_mcdi_drv_attach() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Allocate NVRAM partition ID range for PHY images (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add EF10 register and structure definitions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Extend struct efx_tx_buffer to allow pushing option descriptors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use a global count of active queues instead of pending drains (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Prepare for RX scatter on EF10 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Initialise IRQ moderation for all NIC types from efx_init_eventq() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Allow efx_nic_type::dimension_resources to fail (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Allow event queue initialisation to fail (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Document conditions for multicast replication vs filter replacement (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Implement asynchronous MCDI requests (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove unnecessary use of atomic_t (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor efx_mcdi_rpc_start() and efx_mcdi_copyin() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for new board sensors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use extended MC_CMD_SENSOR_INFO and MC_CMD_READ_SENSORS (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Return an error code when a sensor is busy (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for reading packet length from prefix (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add TX merged completion counter (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Generalise packet hash lookup to support EF10 RX prefix (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename EFX_PAGE_BLOCK_SIZE to EFX_VI_PAGE_SIZE and adjust comments (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove early call to efx_nic_type::reconfigure_mac in efx_reset_up() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: use MCDI epoch flag to improve MC reboot detection in the driver (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add EF10 support for TX/RX DMA error events handling (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add a function pointer to abstract write of host time into NIC shared memory (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: PTP MCDI requests need to initialise periph ID field (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Delegate MAC/NIC statistic description to efx_nic_type (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove driver-local struct ethtool_string (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove more left-overs from Falcon GMAC support (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move MTD operations into efx_nic_type (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move NIC-type-specific MTD partition date into separate structures (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Eliminate struct efx_mtd (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename SPI stuff to show that it is Falcon-specific (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Cleanup Falcon-arch simple MAC filter state (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Define and use MCDI_POPULATE_DWORD_{1, 2, 3, 4, 5, 6, 7} (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add flag for stack-owned RX MAC filters (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor Falcon-arch filter removal (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make most filter operations NIC-type-specific (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor Falcon-arch search limit reset (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Split Falcon-arch-specific and common filter state (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Extend and abstract efx_filter_spec to cover Huntington/EF10 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Name the RX drop queue ID (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename Falcon-arch filter implementation types and functions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove unused filter_flags variables and efx_farch_filter_id_flags() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Do not assume efx_nic_type::ev_fini is idempotent (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: EFX_WORKAROUND_ALWAYS is really specific to Falcon-architecture (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Get rid of per-NIC-type phys_addr_channels and mem_map_size (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Update and improve kernel-doc for efx_mcdi_state & efx_mcdi_iface (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix race in completion handling (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for MCDI v2 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Update MCDI protocol definitions for EF10 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Translate MCDI error numbers received in events (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move and rename Falcon/Siena common NIC operations (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor queue teardown sequence to allow for EF10 flush behaviour (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove bogus call to efx_release_tx_buffers() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Stop RX refill before flushing RX queues (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Limit scope of a Falcon A1 IRQ workaround (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rework IRQ enable/disable (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove efx_process_channel_now() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename Falcon-architecture register definitions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make struct efx_special_buffer less special (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add GFP flags to efx_nic_alloc_buffer() and make most callers allow blocking (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make MCDI independent of Siena (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make efx_mcdi_init() call efx_mcdi_handle_assertion() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Collect all MCDI port functions into mcdi_port.c (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move efx_mcdi_mac_reconfigure() to siena.c and rename (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move siena_reset_hw() and siena_map_reset_reason() into MCDI module (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add and use MCDI_SET_QWORD() and MCDI_SET_ARRAY_QWORD() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Ensure MCDI buffers, but not lengths, are dword aligned (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use proper macros to declare and access MCDI arrays (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Introduce and use MCDI_CTL_SDU_LEN_MAX_V1 macro for Siena-specific code (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fill out the set of MCDI accessors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rationalise MCDI buffer accessors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Introduce and use MCDI_DECLARE_BUF macro (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move more Falcon-specific code and definitions into falcon.c (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move details of a Falcon bug workaround out of ethtool.c (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use efx_mcdi_mon() to find efx_mcdi_mon structure from efx_nic (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: const-qualify source pointers for MMIO write functions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix lookup of default RX MAC filters when steered using ethtool (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Enable RX scatter for flows steered by RFS (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix memory leak when discarding scattered packets (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Improve test for IOMMU in use (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix IRQ cleanup in case of a probe failure (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Do not pass non-TCP packets into GRO code (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Define and set RX buffer flag for packets parsed as TCP (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Enable accelerated RFS on vlans (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Report software timestamping capabilities (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Increase size of RX SKB header area (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Enable RX checksum offload for packets not handled by GRO (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix EEH with legacy interrupts (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Store port number in private data, not net_device::dev_id (Nikolay Aleksandrov) [1005248]

* Mon Sep 23 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-28.el7]
- [fs] namei: Add missing unlocks to error paths of mountpoint_last (Jeff Layton) [980172]
- [fs] autofs4: fix device ioctl mount lookup (Jeff Layton) [980172]
- [fs] namei: introduce kern_path_mountpoint() (Jeff Layton) [980172]
- [fs] namei: rename user_path_umountat() to user_path_mountpoint_at() (Jeff Layton) [980172]
- [fs] namei: take unlazy_walk() into umount_lookup_last() (Jeff Layton) [980172]
- [fs] vfs: allow umount to handle mountpoints without revalidating them (Jeff Layton) [980172]
- [acpi] apei: Soft-offline a page on firmware GHES notification (Janet Morgan) [984133]
- [acpi] apei: Add a boot option to disable ff mode for corrected errors (Janet Morgan) [984133]
- [mcheck] mce: Honour Firmware First for MCA banks listed in APEI HEST CMC (Janet Morgan) [984133]
- [fs] cifs: Respect epoch value from create lease context v2 (Sachin Prabhu) [1007981]
- [fs] cifs: Add create lease v2 context for SMB3 (Sachin Prabhu) [1007981]
- [fs] cifs: Move parsing lease buffer to ops struct (Sachin Prabhu) [1007981]
- [fs] cifs: Move creating lease buffer to ops struct (Sachin Prabhu) [1007981]
- [fs] cifs: Store lease state itself rather than a mapped oplock value (Sachin Prabhu) [1007981]
- [fs] cifs: Replace clientCanCache* bools with an integer (Sachin Prabhu) [1007981]
- [fs] cifs: quiet sparse compile warning (Sachin Prabhu) [1007981]
- [fs] cifs: Start using per session key for smb2/3 for signature generation (Sachin Prabhu) [1007981]
- [fs] cifs: Add a variable specific to NTLMSSP for key exchange (Sachin Prabhu) [1007981]
- [fs] cifs: Process post session setup code in respective dialect functions (Sachin Prabhu) [1007981]
- [fs] cifs: convert to use le32_add_cpu() (Sachin Prabhu) [1007981]
- [fs] cifs: Fix missing lease break (Sachin Prabhu) [1007981]
- [fs] cifs: Fix a memory leak when a lease break comes (Sachin Prabhu) [1007981]
- [fs] cifs: convert case-insensitive dentry ops to use new case conversion routines (Sachin Prabhu) [1007981]
- [fs] cifs: add new case-insensitive conversion routines that are based on wchar_t's (Sachin Prabhu) [1007981]
- [fs] cifs: Move and expand MAX_SERVER_SIZE definition (Sachin Prabhu) [1007981]
- [fs] cifs: Expand max share name length to 256 (Sachin Prabhu) [1007981]
- [fs] cifs: Move string length definitions to uapi (Sachin Prabhu) [1007981]
- [fs] cifs: Implement follow_link for nounix CIFS mounts (Sachin Prabhu) [1007981]
- [fs] cifs: Implement follow_link for SMB2 (Sachin Prabhu) [1007981]
- [fs] cifs: display iocharset= option in /proc/mounts (Sachin Prabhu) [1007981]
- [fs] cifs: create a new Documentation/ directory and move docfiles into it (Sachin Prabhu) [1007981]
- [fs] cifs: ensure that srv_mutex is held when dealing with ssocket pointer (Sachin Prabhu) [1007981]
- [fs] cifs: don't instantiate new dentries in readdir for inodes that need to be revalidated immediately (Sachin Prabhu) [1007981]
- [fs] cifs: set sb->s_d_op before calling d_make_root() (Sachin Prabhu) [1007981]
- [fs] cifs: file, initialize oparms.reconnect before using it (Sachin Prabhu) [1007981]
- [fs] cifs: Do not attempt to do cifs operations reading symlinks with SMB2 (Sachin Prabhu) [1007981]
- [fs] cifs: extend the buffer length enought for sprintf() using (Sachin Prabhu) [1007981]
- [fs] dlm: log an error for unmanaged lockspaces (David Teigland) [1008005]
- [acpi] acpi_ipmi, replace mutex with spin_lock_irqsave (Tony Camuso) [1007574]
- [kernel] sched: Micro-optimize the smart wake-affine logic (Larry Woodman) [947186]
- [kernel] sched: Implement smarter wake-affine logic (Larry Woodman) [947186]
- [net] sunrpc: rpcauth_create needs to know about rpc_clnt clone status (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Share all credential caches on a per-transport basis (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Share rpc_pipes when an rpc_clnt owns multiple rpcsec auth caches (Jeff Layton) [1002576]
- [net] sunrpc: Add a helper to allow sharing of rpc_pipefs directory objects (Jeff Layton) [1002576]
- [net] sunrpc: Remove the rpc_client->cl_dentry (Jeff Layton) [1002576]
- [fs] nfs: Convert idmapper to use the new framework for pipefs dentries (Jeff Layton) [1002576]
- [net] sunrpc: Remove the obsolete auth-only interface for pipefs dentry management (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Switch auth_gss to use the new framework for pipefs dentries (Jeff Layton) [1002576]
- [net] sunrpc: Add a framework to clean up management of rpc_pipefs directories (Jeff Layton) [1002576]
- [fs] nfs: Fix a potentially Oopsable condition in __nfs_idmap_unregister (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Fix an Oopsable condition when creating/destroying pipefs objects (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Further cleanups (Jeff Layton) [1002576]
- [net] sunrpc: Replace clnt->cl_principal (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Clean up upcall message allocation (Jeff Layton) [1002576]
- [net] sunrpc: Cleanup rpc_setup_pipedir (Jeff Layton) [1002576]
- [net] sunrpc: Remove unused struct rpc_clnt field cl_protname (Jeff Layton) [1002576]
- [net] sunrpc: Deprecate rpc_client->cl_protname (Jeff Layton) [1002576]
- [net] sunrpc/rpc_pipe: convert back to simple_dir_inode_operations (Jeff Layton) [1002576]
- [fs] libfs: make simple_lookup() usable for filesystems that set ->s_d_op (Jeff Layton) [1002576]
- [net] sunrpc: __rpc_lookup_create_exclusive, pass string instead of qstr (Jeff Layton) [1002576]
- [net] sunrpc: rpc_create_*_dir, don't bother with qstr (Jeff Layton) [1002576]

* Mon Sep 23 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-27.el7]
- [netdrv] i40e: include i40e in kernel proper (Stefan Assmann) [726825]
- [netdrv] i40e: debugfs interface (Stefan Assmann) [726825]
- [netdrv] i40e: init code and hardware support (Stefan Assmann) [726825]
- [netdrv] i40e: implement virtual device interface (Stefan Assmann) [726825]
- [netdrv] i40e: driver core headers (Stefan Assmann) [726825]
- [netdrv] i40e: driver ethtool core (Stefan Assmann) [726825]
- [netdrv] i40e: transmit, receive, and NAPI (Stefan Assmann) [726825]
- [netdrv] i40e: main driver core (Stefan Assmann) [726825]
- [netdrv] e1000e: balance semaphore put/get for 82573 (Dean Nelson) [726816]
- [netdrv] e1000e: resolve checkpatch JIFFIES_COMPARISON warning (Dean Nelson) [726816]
- [netdrv] e1000e: Avoid kernel crash during shutdown (Dean Nelson) [726816]
- [netdrv] e1000e: Add code to check for failure of pci_disable_link_state call (Dean Nelson) [726816]
- [netdrv] e1000e: cleanup whitespace in recent commit (Dean Nelson) [726816]
- [netdrv] e1000e: fix I217/I218 PHY initialization flow (Dean Nelson) [726816]
- [netdrv] e1000e: do not resume device from RPM suspend to read PHY status registers (Dean Nelson) [726816]
- [netdrv] e1000e: enable support for new device IDs (Dean Nelson) [726816]
- [netdrv] e1000e: ethtool unnecessarily takes device out of RPM suspend (Dean Nelson) [726816]
- [netdrv] e1000e: Tx hang on I218 when linked at 100Half and slow response at 10Mbps (Dean Nelson) [726816]
- [netdrv] e1000e: low throughput using 4K jumbos on I218 (Dean Nelson) [726816]
- [netdrv] e1000e: iAMT connections drop on driver unload when jumbo frames enabled (Dean Nelson) [726816]
- [netdrv] e1000e: disable ASPM L1 on 82583 (Dean Nelson) [726816]
- [netdrv] e1000e: Use marco instead of digit for defining e1000_rx_desc_packet_split (Dean Nelson) [726816]
- [netdrv] e1000e: Remove duplicate assignment of default rx/tx ring size (Dean Nelson) [726816]
- [netdrv] e1000e: restore call to pci_clear_master() (Dean Nelson) [726816]
- [netdrv] e1000e: Release mutex lock only if it has been initially acquired (Dean Nelson) [726816]
- [netdrv] e1000e: prevent warning from -Wunused-parameter (Dean Nelson) [726816]
- [netdrv] e1000e: cleanup whitespace (Dean Nelson) [726816]
- [netdrv] bna: Staticize local functions (Ivan Vecera) [978045]
- [netdrv] bna: switch to fixed_size_llseek() (Ivan Vecera) [978045]
- [fs] read_write: new helper, fixed_size_llseek() (Ivan Vecera) [978045]
- [netdrv] bna: Driver and Firmware Updated (Ivan Vecera) [978045]
- [netdrv] bna: Enahncement to Identify Default IOC Function (Ivan Vecera) [978045]
- [netdrv] bna: Fix Ucast Failure Handling (Ivan Vecera) [978045]
- [netdrv] bna: Clear Driver Config Flags When HW Resets (Ivan Vecera) [978045]
- [netdrv] tg3: Don't turn off led on 5719 serdes port 0 (Ivan Vecera) [1006987]
- [netdrv] tg3: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Ivan Vecera) [1006987]
- [netdrv] tg3: fix NULL pointer dereference in tg3_io_error_detected and tg3_io_slot_reset (Ivan Vecera) [1006987]
- [netdrv] tg3: clean up unnecessary MSI/MSI-X capability find (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix warning from pci_disable_device() (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix kernel crash (Ivan Vecera) [1006987]
- [netdrv] tg3: Update version to 3.133 (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix UDP fragments treated as RMCP (Ivan Vecera) [1006987]
- [netdrv] tg3: Enable support for timesync gpio output (Ivan Vecera) [1006987]
- [netdrv] tg3: Implement the shutdown handler (Ivan Vecera) [1006987]
- [netdrv] tg3: Allow NVRAM programming when interface is down (Ivan Vecera) [1006987]
- [netdrv] tg3: Remove incorrect switch to aux power (Ivan Vecera) [1006987]
- [netdrv] tg3: Prevent system hang during repeated EEH errors (Ivan Vecera) [1006987]
- [netdrv] tg3: remove redundant pm init code (Ivan Vecera) [1006987]
- [netdrv] tg3: Remove unnecessary lock around tg3_flag_set (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix misplaced empty line (Ivan Vecera) [1006987]
- [netdrv] tg3: Use descriptive label names in tg3_start (Ivan Vecera) [1006987]
- [netdrv] tg3: Make tg3_rings_reset() more concise (Ivan Vecera) [1006987]
- [netdrv] tg3: Simplify ring control block setup (Ivan Vecera) [1006987]
- [netdrv] tg3: Split APE driver state change out of boot reset signature update (Ivan Vecera) [1006987]
- [netdrv] tg3: Use module_pci_driver to register driver (Ivan Vecera) [1006987]
- [netdrv] tg3: Implement set/get_eee handlers (Ivan Vecera) [1006987]
- [netdrv] tg3: Simplify tg3_phy_eee_config_ok() by reusing tg3_eee_pull_config() (Ivan Vecera) [1006987]
- [netdrv] tg3: Add tg3_eee_pull_config() function (Ivan Vecera) [1006987]
- [netdrv] tg3: Add ethtool_eee struct and tg3_setup_eee() (Ivan Vecera) [1006987]
- [netdrv] be2net: set and query VEB/VEPA mode of the PF interface (Ivan Vecera) [726160]
- [netdrv] be2net: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Ivan Vecera) [726160]
- [netdrv] be2net: implement ethtool set/get_channel hooks (Ivan Vecera) [726160]
- [netdrv] be2net: refactor be_setup() to consolidate queue creation routines (Ivan Vecera) [726160]
- [netdrv] be2net: Fix be_cmd_if_create() to use MBOX if MCCQ is not created (Ivan Vecera) [726160]
- [netdrv] be2net: refactor be_get_resources() code (Ivan Vecera) [726160]
- [netdrv] be2net: Fixup profile management routines (Ivan Vecera) [726160]
- [netdrv] be2net: use EQ_CREATEv2 for SH-R (Ivan Vecera) [726160]
- [netdrv] be2net: Check for POST state in suspend-resume sequence (Ivan Vecera) [726160]
- [netdrv] be2net: fix disabling TX in be_close() (Ivan Vecera) [726160]
- [netdrv] be2net: Clear any capability flags that driver is not interested in (Ivan Vecera) [726160]
- [netdrv] be2net: update driver version (Ivan Vecera) [726160]
- [netdrv] be2net: Initialize "status" in be_cmd_get_die_temperature() (Ivan Vecera) [726160]
- [netdrv] be2net: fixup log msgs for async events (Ivan Vecera) [726160]
- [netdrv] be2net: Fix displaying supported speeds for BE2 (Ivan Vecera) [726160]
- [netdrv] be2net: don't limit max MAC and VLAN counts (Ivan Vecera) [726160]
- [netdrv] be2net: Do not call get_die_temperature cmd for VF (Ivan Vecera) [726160]
- [netdrv] be2net: Adding more speeds reported by get_settings (Ivan Vecera) [726160]
- [netdrv] be2net: Staticize local functions (Ivan Vecera) [726160]
- [netdrv] be2net: don't use dev_err when AER enabling fails (Ivan Vecera) [726160]
- [netdrv] be2net: delete primary MAC address while unloading (Ivan Vecera) [726160]
- [netdrv] be2net: use SET/GET_MAC_LIST for SH-R (Ivan Vecera) [726160]
- [netdrv] be2net: refactor MAC-addr setup code (Ivan Vecera) [726160]
- [netdrv] be2net: fix pmac_id for BE3 VFs (Ivan Vecera) [726160]
- [netdrv] be2net: allow VFs to program MAC and VLAN filters (Ivan Vecera) [726160]
- [netdrv] be2net: fix MAC address modification for VF (Ivan Vecera) [726160]
- [netdrv] be2net: replace numeric with standard PM state macros (Ivan Vecera) [726160]
- [netdrv] be2net: use pci_vfs_assigned()/pci_num_vf() instead of be_find_vfs() (Ivan Vecera) [726160]
- [netdrv] be2net: Implement initiate FW dump feature for Lancer (Ivan Vecera) [726160]
- [netdrv] be2net: Trim padded packets for Lancer (Ivan Vecera) [726160]
- [netdrv] be2net: Pad skb to meet min Tx pkt size in lancer (Ivan Vecera) [726160]
- [netdrv] be2net: cleanup be_get_drvinfo() (Ivan Vecera) [726160]
- [netdrv] be2net: refactor HW workarounds in be_xmit() (Ivan Vecera) [726160]
- [netdrv] mlx5: remove unused MLX5_DEBUG param in Kconfig (Amir Vadai) [864578]
- [netdrv] mlx5: Support MANAGE_PAGES and QUERY_PAGES firmware command changes (Amir Vadai) [864578]
- [netdrv] mlx5: remove health handler plugin (Amir Vadai) [864578]
- [infiniband] mlx5: Variable may be used uninitialized (Amir Vadai) [864578]
- [netdrv] mlx5: Implement new initialization sequence (Amir Vadai) [864578]
- [infiniband] mlx5: Fix stack info leak in mlx5_ib_alloc_ucontext() (Amir Vadai) [864578]
- [infiniband] mlx5: Fix error return code in init_one() (Amir Vadai) [864578]
- [netdrv] mlx5: fix error return code in mlx5_alloc_uuars() (Amir Vadai) [864578]
- [netdrv] mlx5: use after free in mlx5_cmd_comp_handler() (Amir Vadai) [864578]
- [netdrv] mlx5: Fix __udivdi3 when compiling for 32 bit arches (Amir Vadai) [864578]
- [netdrv] mlx5: Return -EFAULT instead of -EPERM (Amir Vadai) [864578]
- [netdrv] mlx5: Adjust hca_cap.uar_page_sz to conform to Connect-IB spec (Amir Vadai) [864578]
- [netdrv] mlx5: Fixes for sparse warnings (Amir Vadai) [864578]
- [infiniband] mlx5: Make profile[] static in main.c (Amir Vadai) [864578]
- [infiniband] mlx5: Add driver for Mellanox Connect-IB adapters (Amir Vadai) [864578]
- [infiniband] core: Add reserved values to enums for low-level driver use (Amir Vadai) [864578]

* Thu Sep 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-26.el7]
- [net] tuntap: correctly handle error in tun_set_iff() (Jiri Benc) [1007739] {CVE-2013-4343}
- [net] sctp: fix ipv6 ipsec encryption bug in sctp_v6_xmit (Daniel Borkmann) [998398] {CVE-2013-4350}
- [net] netlink: filter particular protocols from analyzers (Daniel Borkmann) [957721]
- [net] ipv6: accept tlv which includes only padding (Jiri Pirko) [990968]

* Thu Sep 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-25.el7]
- [scsi] mpt2sas: Bump driver version to v16.100.00.00 (Tomas Henzl) [736230]
- [scsi] mpt2sas: Remove phys on topology change (Tomas Henzl) [736230]
- [scsi] mpt2sas: Fix for kernel panic when driver loads with HBA connected to non LUN 0 configured expander (Tomas Henzl) [736230]
- [scsi] mpt2sas: when Async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Tomas Henzl) [736230]
- [scsi] mpt2sas: Infinite loop can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Tomas Henzl) [736230]
- [scsi] mpt2sas: The copyright in driver sources is updated for the year 2013 (Tomas Henzl) [736230]
- [scsi] mpt2sas: MPI2 Rev X (2.00.16) specifications (Tomas Henzl) [736230]
- [scsi] mpt2sas: Change in MPI2_RAID_ACTION_SYSTEM_SHUTDOWN_INITIATED notification methodology (Tomas Henzl) [736230]
- [scsi] mpt2sas: Null pointer deference possibility in mpt2sas_ctl_event_callback function (Tomas Henzl) [736230]
- [scsi] mpt2sas: fix cleanup on controller resource mapping failure (Tomas Henzl) [736230]
- [scsi] mpt2sas: fix for unused variable 'event_data' warning (Tomas Henzl) [736230]
- [scsi] mpt2sas: Calulate the Reply post queue depth calculation as per the MPI spec (Tomas Henzl) [736230]
- [scsi] mpt2sas: fix firmware failure with wrong task attribute (Tomas Henzl) [736230]
- [scsi] mpt2sas: Fix for device scan following host reset could get stuck in a infinite loop (Tomas Henzl) [736230]
- [scsi] mpt2sas: Update the timing requirements for issuing a Hard Reset (Tomas Henzl) [736230]
- [scsi] mpt2sas: MPI2 Rev W (2.00.15) specification (Tomas Henzl) [736230]
- [powerpc] Fix possible deadlock on page fault (Steve Best) [999374]
- [scsi] qla2xxx: Update driver version to 8.06.00.08.07.0-k (Chad Dupuis) [725014]
- [scsi] qla2xxx: Select link initialization option bits from current operating mode (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add loopback IDC-TIME-EXTEND aen handling support (Chad Dupuis) [725014]
- [scsi] qla2xxx: Set default critical temperature value in cases when ISPFX00 firmware doesn't provide it (Chad Dupuis) [725014]
- [scsi] qla2xxx: QLAFX00 make over temperature AEN handling informational, add log for normal temperature AEN (Chad Dupuis) [725014]
- [scsi] qla2xxx: Correct Interrupt Register offset for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove handling of Shutdown Requested AEN from qlafx00_process_aen() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Send all AENs for ISPFx00 to above layers (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add changes in initialization for ISPFX00 cards with BIOS (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add changes to support extended IOs for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add missing FCP statistics to sysfs interface (Chad Dupuis) [725014]
- [scsi] qla2xxx: Make log message that prints when a completion status requires a port down more readable (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add critical temperature handling for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Notify ISPFX00 firmware when driver is unloaded or system is shut down (Chad Dupuis) [725014]
- [scsi] qla2xxx: Reconfigure thermal temperature (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add setting of driver version string for vendor application (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove QL_DEBUG_LEVEL_17 defines from qla_nx.c (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add ISPFX00 specific bus reset routine (Chad Dupuis) [725014]
- [scsi] qla2xxx: Perform warm reset every 2 minutes if firmware load fails for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Set factory reset recovery timeout to 10 min. for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Correct multiqueue offset calculations (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix incorrect test after list_for_each_entry() exits (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add support for ISP8044 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Print some variables to hexadecimal string via *phN format (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix sparse warnings in qlafx00_fxdisc_iocb function (Chad Dupuis) [725014]
- [scsi] qla2xxx: Properly set the tagging for commands (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix a memory leak in an error path of qla2x00_process_els() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove an unused variable from qla2x00_remove_one() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix qla2xxx_check_risc_status() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Help Coverity with analyzing ct_sns_pkt initialization (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove redundant assignments (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove a dead assignment in qla24xx_build_scsi_crc_2_iocbs() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove two superfluous tests (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove dead code in qla2x00_configure_hba() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Clean up qla84xx_mgmt_cmd() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Clean up qla24xx_iidma() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix sparse warning from qla_mr.c and qla_iocb.c (Chad Dupuis) [725014]
- [scsi] qla2xxx: Do not take a second firmware dump when intentionally generating one (Chad Dupuis) [725014]
- [scsi] qla2xxx: Do not query FC statistics during chip reset (Chad Dupuis) [725014]
- [scsi] qla2xxx: Move qla2x00_free_device to the correct location (Chad Dupuis) [725014]
- [scsi] qla2xxx: Set the index in outstanding command array to NULL when cmd is aborted when the request timeout (Chad Dupuis) [725014]
- [scsi] qla2xxx: Clear the MBX_INTR_WAIT flag when the mailbox time-out happens (Chad Dupuis) [725014]
- [scsi] mpt3sas: Bump driver version to v02.100.00.00 (Tomas Henzl) [889435]
- [scsi] mpt3sas: Added a driver module parameter max_msix_vectors (Tomas Henzl) [889435]
- [scsi] mpt3sas: fix cleanup on controller resource mapping failure (Tomas Henzl) [889435]
- [scsi] mpt3sas: when async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Tomas Henzl) [889435]
- [scsi] mpt3sas: MPI2.5 Rev F v2.5.1.1 specification (Tomas Henzl) [889435]
- [scsi] mpt3sas: Infinite loops can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Tomas Henzl) [889435]
- [scsi] mpt3sas: fix for kernel panic when driver loads with HBA conected to non LUN 0 configured expander (Tomas Henzl) [889435]
- [scsi] mpt3sas: Updated the Hardware timing requirements (Tomas Henzl) [889435]
- [scsi] mpt3sas: 2013 source code copyright (Tomas Henzl) [889435]
- [netdrv] ixgbe: add support for older QSFP active DA cables (Andy Gospodarek) [726818]
- [netdrv] ixgbe: include QSFP PHY types in ixgbe_is_sfp() (Andy Gospodarek) [726818]
- [netdrv] ixgbe: add 1Gbps support for QSFP+ (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix SFF data dumps of SFP+ modules from an offset (Andy Gospodarek) [726818]
- [netdrv] ixgbe: cleanup some log messages (Andy Gospodarek) [726818]
- [netdrv] ixgbe: zero out mailbox buffer on init (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix link test when connected to 1Gbps link partner (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix incorrect limit value in ring transverse (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Check return value on eeprom reads (Andy Gospodarek) [726818]
- [netdrv] ixgbe: disable link when adapter goes down (Andy Gospodarek) [726818]
- [netdrv] ixgbe: add support for quad-port x520 adapter (Andy Gospodarek) [726818]
- [netdrv] ixgbe: clear semaphore bits on timeouts (Andy Gospodarek) [726818]
- [netdrv] ixgbe: rename LL_EXTENDED_STATS to use queue instead of q (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix lockdep annotation issue for ptp's work item (Andy Gospodarek) [726818]
- [netdrv] ixgbe: call pcie_get_mimimum_link to check if device has enough bandwidth (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix SFF data dumps of SFP+ modules (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix semaphore lock for I2C read/writes on 82598 (Andy Gospodarek) [726818]
- [netdrv] ixgbe: bump version number (Andy Gospodarek) [726818]
- [netdrv] ixgbe: add new media type (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix fc autoneg ethtool reporting (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Use pci_vfs_assigned instead of ixgbe_vfs_are_assigned (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Retain VLAN filtering in promiscuous + VT mode (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Fix Tx Hang issue with lldpad on 82598EB (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Set the SW prio_tc values at initialization to the HW setting (Andy Gospodarek) [726818]
- [pci] expose pcie_link_speed and pcix_bus_speed arrays (Andy Gospodarek) [726818]
- [pci] move enum pcie_link_width into pci.h (Andy Gospodarek) [726818]
- [pci] Add function to obtain minimum link width and speed (Andy Gospodarek) [726818]
- [netdrv] cnic: Update version to 2.5.18 (Tomas Henzl) [725064]
- [netdrv] cnic: Eliminate local copy of pfid (Tomas Henzl) [725064]
- [netdrv] cnic: Eliminate CNIC_PORT macro and port_mode in local struct (Tomas Henzl) [725064]
- [netdrv] cnic: Redefine BNX2X_HW_CID using existing bnx2x macros (Tomas Henzl) [725064]
- [netdrv] cnic: Use CHIP_NUM macros from bnx2x.h (Tomas Henzl) [725064]
- [netdrv] cnic: Convert mac address uses of 6 to ETH_ALEN (Tomas Henzl) [725064]
- [netdrv] cnic: Update version to 2.5.17 and copyright year (Tomas Henzl) [725064]
- [netdrv] cnic: Add missing error checking for RAMROD_CMD_ID_CLOSE (Tomas Henzl) [725064]
- [netdrv] cnic: Update TCP options setup for iSCSI (Tomas Henzl) [725064]
- [netdrv] cnic: Reset tcp_flags during cnic_cm_create() (Tomas Henzl) [725064]
- [netdrv] cnic: Simplify cnic_release() (Tomas Henzl) [725064]
- [netdrv] cnic: Simplify netdev events handling (Tomas Henzl) [725064]

* Thu Sep 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-24.el7]
- [Documentation] kvm: Add documentation on Hypercalls and features used for PV spinlock (Andrew Jones) [981581]
- [virt] kvm: Simplify kvm_for_each_vcpu with kvm_irq_delivery_to_apic (Andrew Jones) [981581]
- [virt] kvm: Add a hypercall to KVM hypervisor to support pv-ticketlocks (Andrew Jones) [981581]
- [virt] kvm: Paravirtual ticketlocks support for linux guests running on KVM hypervisor (Andrew Jones) [981581]
- [virt] kvm: Add configuration support to enable debug information for KVM Guests (Andrew Jones) [981581]
- [virt] kvm: Add KICK_CPU and PV_UNHALT definition to uapi (Andrew Jones) [981581]
- [virt] pvticketlock: Allow interrupts to be enabled while blocking (Andrew Jones) [981581]
- [virt] ticketlock: Add slowpath logic (Andrew Jones) [981581]
- [kernel] jump_label: Split jumplabel ratelimit (Andrew Jones) [981581]
- [virt] pvticketlock: Use callee-save for lock_spinning (Andrew Jones) [981581]
- [virt] pvticketlocks: Add xen_nopvspin parameter to disable xen pv ticketlocks (Andrew Jones) [981581]
- [virt] pvticketlock: Xen implementation for PV ticket locks (Andrew Jones) [981581]
- [virt] xen: Defer spinlock setup until boot CPU setup (Andrew Jones) [981581]
- [virt] ticketlock: Collapse a layer of functions (Andrew Jones) [981581]
- [virt] ticketlock: Don't inline _spin_unlock when using paravirt spinlocks (Andrew Jones) [981581]
- [virt] spinlock: Replace pv spinlocks with pv ticketlocks (Andrew Jones) [981581]
- [fs] proc/vmcore: support mmap() on /proc/vmcore (Nigel Croxon) [990298]
- [fs] proc/vmcore: calculate vmcore file size from buffer size and total size of vmcore objects (Nigel Croxon) [990298]
- [fs] proc/vmcore: allow user process to remap ELF note segment buffer (Nigel Croxon) [990298]
- [fs] proc/vmcore: allocate ELF note segment in the 2nd kernel vmalloc memory (Nigel Croxon) [990298]
- [mm] vmalloc: introduce remap_vmalloc_range_partial (Nigel Croxon) [990298]
- [mm] vmalloc: make find_vm_area check in range (Nigel Croxon) [990298]
- [fs] proc/vmcore: treat memory chunks referenced by PT_LOAD program header entries in page-size boundary in vmcore_list (Nigel Croxon) [990298]
- [fs] proc/vmcore: allocate buffer for ELF headers on page-size alignment (Nigel Croxon) [990298]
- [fs] proc/vmcore: clean up read_vmcore() (Nigel Croxon) [990298]
- [mm] add PAGE_ALIGNED() helper (Nigel Croxon) [990298]
- [fs] nfs Fix up nfs4_proc_lookup_mountpoint (Jeff Layton) [1007357]
- [fs] nfs: Don't check lock owner compatability unless file is locked (part 2) (Jeff Layton) [1007035]
- [fs] nfs: Don't check lock owner compatibility in writes unless file is locked (Jeff Layton) [1007035]
- [pci] Remove pcie_cap_has_devctl() (Myron Stowe) [1005229]
- [pci] Support PCIe Capability Slot registers only for ports with slots (Myron Stowe) [1005229]
- [pci] Remove PCIe Capability version checks (Myron Stowe) [1005229]
- [pci] Allow PCIe Capability link-related register access for switches (Myron Stowe) [1005229]
- [pci] Add offsets of PCIe capability registers (Myron Stowe) [1005229]
- [pci] Tidy bitmasks and spacing of PCIe capability definitions (Myron Stowe) [1005229]
- [pci] Remove obsolete comment reference to pci_pcie_cap2() (Myron Stowe) [1005229]
- [pci] Clarify PCI_EXP_TYPE_PCI_BRIDGE comment (Myron Stowe) [1005229]
- [pci] Rename PCIe capability definitions to follow convention (Myron Stowe) [1005229]
- [pci] Warn if unsafe MPS settings detected (Myron Stowe) [1005229]
- [pci] Fix MPS peer-to-peer DMA comment syntax (Myron Stowe) [1005229]
- [pci] Disable decoding for BAR sizing only when it was actually enabled (Myron Stowe) [1005229]
- [pci] Add comment about needing pci_msi_off() even when CONFIG_PCI_MSI=n (Myron Stowe) [1005229]
- [pci] Add pcibios_pm_ops for optional arch-specific hibernate functionality (Myron Stowe) [1005229]
- [pci] Don't restrict MPS for slots below Root Ports (Myron Stowe) [1005229]
- [pci] Simplify MPS test for Downstream Port (Myron Stowe) [1005229]
- [pci] Remove unnecessary check for pcie_get_mps() failure (Myron Stowe) [1005229]
- [pci] Simplify pcie_bus_configure_settings() interface (Myron Stowe) [1005229]
- [pci] Drop "PCI-E" prefix from Max Payload Size message (Myron Stowe) [1005229]
- [pci] Add pci_probe_reset_slot() and pci_probe_reset_bus() (Myron Stowe) [1005229]
- [pci] Remove aer_do_secondary_bus_reset() (Myron Stowe) [1005229]
- [pci] Tune secondary bus reset timing (Myron Stowe) [1005229]
- [pci] Wake-up devices before saving config space for reset (Myron Stowe) [1005229]
- [pci] Add pci_reset_slot() and pci_reset_bus() (Myron Stowe) [1005229]
- [pci] Split out pci_dev lock/unlock and save/restore (Myron Stowe) [1005229]
- [pci] Add slot reset option to pci_dev_reset() (Myron Stowe) [1005229]
- [pci] pciehp: Add reset_slot() method (Myron Stowe) [1005229]
- [pci] Add hotplug_slot_ops.reset_slot() (Myron Stowe) [1005229]
- [pci] quirks: Use pci_wait_for_pending_transaction() instead of for loop (Myron Stowe) [1005229]
- [netdrv] bnx2x: Use pci_wait_for_pending_transaction() instead of for loop (Myron Stowe) [1005229]
- [pci] quirks: Enable Bus Master during Function-Level Reset on Chelsio (Myron Stowe) [1005229]
- [pci] Add pci_wait_for_pending_transaction() (Myron Stowe) [1005229]
- [pci] Add pci_reset_bridge_secondary_bus() (Myron Stowe) [1005229]
- [pci] Align bridge I/O windows as required by downstream devices & bridges (Myron Stowe) [1005229]
- [pci] Fix types in pbus_size_io() (Myron Stowe) [1005229]
- [pci] Add comments for pbus_size_mem() parameters (Myron Stowe) [1005229]
- [pci] Enumerate subordinate buses, not devices, in pci_bus_get_depth() (Myron Stowe) [1005229]
- [pci] Fix comment typo for pci_add_cap_save_buffer() (Myron Stowe) [1005229]
- [pci] Return -ENOSYS for SR-IOV operations on non-SR-IOV devices (Myron Stowe) [1005229]
- [pci] Update NumVFs register when disabling SR-IOV (Myron Stowe) [1005229]
- [pci] mmconfig: Check earlier for MMCONFIG region at address zero (Myron Stowe) [1005229]
- [pci] Assign resources for hot-added host bridge more aggressively (Myron Stowe) [1005229]
- [pci] Move resource reallocation code to non-__init (Myron Stowe) [1005229]
- [pci] Delay enabling bridges until they're needed (Myron Stowe) [1005229]
- [pci] Assign resources on a per-bus basis (Myron Stowe) [1005229]
- [pci] Enable unassigned resource reallocation on per-bus basis (Myron Stowe) [1005229]
- [pci] Turn on reallocation for unassigned resources with host bridge offset (Myron Stowe) [1005229]
- [pci] Look for unassigned resources on per-bus basis (Myron Stowe) [1005229]
- [pci] Drop temporary variable in pci_assign_unassigned_resources() (Myron Stowe) [1005229]
- [pci] Claim ACS support for AMD southbridge devices (Myron Stowe) [1005229]
- [pci] Differentiate ACS controllable from enabled (Myron Stowe) [1005229]
- [pci] Check all ACS features for multifunction downstream ports (Myron Stowe) [1005229]
- [pci] Convert class code to use dev_groups (Myron Stowe) [1005229]
- [pci] mrst: Cleanup checkpatch.pl warnings (Myron Stowe) [1005229]
- [pci] Rename "PCI Express support" kconfig title (Myron Stowe) [1005229]
- [pci] Fix comment typo in iov.c (Myron Stowe) [1005229]
- [fs] sysfs: use file mode defines from stat.h (Myron Stowe) [1005229]
- [fs] sysfs: add more helper macro's for (bin_)attribute(_groups) (Myron Stowe) [1005229]
- [misc] device: add default groups to struct class (Myron Stowe) [1005229]
- [misc] device: Introduce device_create_groups (Myron Stowe) [1005229]
- [fs] sysfs: prevent warning when only using binary attributes (Myron Stowe) [1005229]
- [fs] sysfs: add support for binary attributes in groups (Myron Stowe) [1005229]
- [misc] device: add RW and RO attribute macros (Myron Stowe) [1005229]
- [misc] sysfs: add BIN_ATTR macro (Myron Stowe) [1005229]
- [misc] sysfs: add ATTRIBUTE_GROUPS() macro (Myron Stowe) [1005229]
- [misc] sysfs: add __ATTR_RW() macro (Myron Stowe) [1005229]

* Tue Sep 17 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-23.el7]
- [kernel] kexec: improve logging when crashkernel=auto can't be satisfied (Steve Best) [989576]

* Fri Sep 13 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-22.el7]
- [netdrv] bnx2: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Neil Horman) [725061]
- [netdrv] bnx2: clean up unnecessary MSI/MSI-X capability find (Neil Horman) [725061]
- [netdrv] bnx2: Update version to 2.2.4 (Neil Horman) [725061]
- [netdrv] bnx2: Add pci shutdown handler (Neil Horman) [725061]
- [netdrv] bnx2: Use SIMPLE_DEV_PM_OPS (Neil Horman) [725061]
- [netdrv] bnx2: Refactor WoL setup into a separate function (Neil Horman) [725061]
- [netdrv] bnx2: Use kernel APIs for WoL and power state changes (Neil Horman) [725061]
- [netdrv] bnx2: Handle error condition in ->slot_reset() (Neil Horman) [725061]
- [netdrv] bnx2: use pdev->pm_cap instead of pci_find_capability(.., PCI_CAP_ID_PM) (Neil Horman) [725061]
- [netdrv] bnx2: Use module_pci_driver to register driver (Neil Horman) [725061]
- [netdrv] igb: Update version number (Stefan Assmann) [726817]
- [netdrv] igb: Implementation to report advertised/supported link on i354 devices (Stefan Assmann) [726817]
- [netdrv] igb: Get speed and duplex for 1G non_copper devices (Stefan Assmann) [726817]
- [netdrv] igb: Support to get 2_5G link status for appropriate media type (Stefan Assmann) [726817]
- [netdrv] igb: No PHPM support in i354 devices (Stefan Assmann) [726817]
- [netdrv] igb: M88E1543 PHY downshift implementation (Stefan Assmann) [726817]
- [netdrv] igb: New PHY_ID for i354 device (Stefan Assmann) [726817]
- [netdrv] igb: Implementation of 1-sec delay for i210 devices (Stefan Assmann) [726817]
- [netdrv] igb: Don't look for a PBA in the iNVM when flashless (Stefan Assmann) [726817]
- [netdrv] igb: Expose RSS indirection table for ethtool (Stefan Assmann) [726817]
- [netdrv] igb: Add macro for size of RETA indirection table (Stefan Assmann) [726817]
- [netdrv] igb: Fix get_fw_version function for all parts (Stefan Assmann) [726817]
- [netdrv] igb: Add device support for flashless SKU of i210 device (Stefan Assmann) [726817]
- [netdrv] igb: Refactor NVM read functions to accommodate devices with no flash (Stefan Assmann) [726817]
- [netdrv] igb: Refactor of init_nvm_params (Stefan Assmann) [726817]
- [netdrv] igb: Update MTU so that it is always at least a standard frame size (Stefan Assmann) [726817]
- [netdrv] igb: don't allow SR-IOV without MSI-X (Stefan Assmann) [726817]
- [netdrv] igb: Added rcu_lock to avoid race (Stefan Assmann) [726817]
- [netdrv] igb: Read register for latch_on without return value (Stefan Assmann) [726817]
- [netdrv] igb: Reset the link when EEE setting changed (Stefan Assmann) [726817]
- [netdrv] igb: fix vlan filtering in promisc mode when not in VT mode (Stefan Assmann) [726817]
- [netdrv] igb: relase -> release (Stefan Assmann) [726817]
- [netdrv] igb: Removed unused i2c function (Stefan Assmann) [726817]
- [netdrv] igb: Implementation of i210/i211 LED support (Stefan Assmann) [726817]
- [netdrv] igb: Fix possible panic caused by Rx traffic arrival while interface is down (Stefan Assmann) [726817]
- [netdrv] igb: Fix set_ethtool function to call update nvm for entire image (Stefan Assmann) [726817]
- [netdrv] igb: SerDes flow control setting (Stefan Assmann) [726817]
- [netdrv] igb: Support for SFP modules discovery (Stefan Assmann) [726817]
- [netdrv] igb: Add update to last_rx_timestamp in Rx rings (Stefan Assmann) [726817]
- [netdrv] igb: Changed LEDs blink mechanism to include designs using cathode (Stefan Assmann) [726817]
- [virt] kvm/mmu: avoid fast page fault fixing mmio page fault (Gleb Natapov) [981979]
- [virt] kvm/vmx: mark unusable segment as nonpresent (Gleb Natapov) [981979]
- [virt] kvm: get rid of $(addprefix ../../../virt/kvm/, ...) in Makefiles (Gleb Natapov) [981979]
- [virt] kvm: Fix RTC interrupt coalescing tracking (Gleb Natapov) [981979]
- [virt] kvm: Add a tracepoint write_tsc_offset (Gleb Natapov) [981979]
- [virt] kvm: Inform users of mmio generation wraparound (Gleb Natapov) [981979]
- [virt] kvm: document fast invalidate all mmio sptes (Gleb Natapov) [981979]
- [virt] kvm: document fast invalidate all pages (Gleb Natapov) [981979]
- [virt] kvm: document fast page fault (Gleb Natapov) [981979]
- [virt] kvm: document mmio page fault (Gleb Natapov) [981979]
- [virt] kvm: document write_flooding_count (Gleb Natapov) [981979]
- [virt] kvm: document clear_spte_count (Gleb Natapov) [981979]
- [virt] kvm: drop kvm_mmu_zap_mmio_sptes (Gleb Natapov) [981979]
- [virt] kvm: init kvm generation close to mmio wrap-around value (Gleb Natapov) [981979]
- [virt] kvm: add tracepoint for check_mmio_spte (Gleb Natapov) [981979]
- [virt] kvm: fast invalidate all mmio sptes (Gleb Natapov) [981979]
- [virt] kvm: make return value of mmio page fault handler more readable (Gleb Natapov) [981979]
- [virt] kvm: store generation-number into mmio spte (Gleb Natapov) [981979]
- [virt] kvm: retain more available bits on mmio spte (Gleb Natapov) [981979]
- [virt] kvm: update the documentation for reverse mapping of parent_pte (Gleb Natapov) [981979]
- [Documentation] kvm: fix section numbers (Gleb Natapov) [981979]
- [virt] kvm: handle idiv overflow at kvm_write_tsc (Gleb Natapov) [981979]
- [virt] kvm: reduce KVM_REQ_MMU_RELOAD when root page is zapped (Gleb Natapov) [981979]
- [virt] kvm: reclaim the zapped-obsolete page first (Gleb Natapov) [981979]
- [virt] kvm: collapse TLB flushes when zap all pages (Gleb Natapov) [981979]
- [virt] kvm: zap pages in batch (Gleb Natapov) [981979]
- [virt] kvm: do not reuse the obsolete page (Gleb Natapov) [981979]
- [virt] kvm: add tracepoint for kvm_mmu_invalidate_all_pages (Gleb Natapov) [981979]
- [virt] kvm: show mmu_valid_gen in shadow page related tracepoints (Gleb Natapov) [981979]
- [virt] kvm: use the fast way to invalidate all pages (Gleb Natapov) [981979]
- [virt] kvm: fast invalidate all pages (Gleb Natapov) [981979]
- [virt] kvm: drop unnecessary kvm_reload_remote_mmus (Gleb Natapov) [981979]
- [virt] kvm: drop calling kvm_mmu_zap_all in emulator_fix_hypercall (Gleb Natapov) [981979]
- [virt] kvm: exclude ioeventfd from counting kvm_io_range limit (Gleb Natapov) [981979]
- [virt] kvm: convert XADD to fastop (Gleb Natapov) [981979]
- [virt] kvm: drop unused old-style inline emulation (Gleb Natapov) [981979]
- [virt] kvm: convert DIV/IDIV to fastop (Gleb Natapov) [981979]
- [virt] kvm: convert single-operand MUL/IMUL to fastop (Gleb Natapov) [981979]
- [virt] kvm: Switch fastop src operand to RDX (Gleb Natapov) [981979]
- [virt] kvm: switch MUL/DIV to DstXacc (Gleb Natapov) [981979]
- [virt] kvm: decode extended accumulator explicity (Gleb Natapov) [981979]
- [virt] kvm: add support for writing back the source operand (Gleb Natapov) [981979]
- [virt] kvm: clenaup locking in mmu_free_roots() (Gleb Natapov) [981979]
- [virt] kvm: limit difference between kvmclock updates (Gleb Natapov) [981979]
- [virt] kvm: Remove support for reporting coalesced APIC IRQs (Gleb Natapov) [981979]
- [virt] kvm: Use kvm_mmu_sync_roots() in kvm_mmu_load() (Gleb Natapov) [981979]
- [virt] kvm: add missing misc_deregister() on error in kvm_init() (Gleb Natapov) [981979]

* Thu Sep 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-21.el7]
- [net] net_sched: fix a typo in htb_change_class() (Jesper Brouer) [998588]
- [net] tcp_probe: adapt tbuf size for recent changes (Daniel Borkmann) [1000470]
- [net] tcp_probe: allow more advanced ingress filtering by mark (Daniel Borkmann) [1000470]
- [net] tcp_probe: add IPv6 support (Daniel Borkmann) [1000470]
- [net] tcp_probe: kprobes: adapt jtcp_rcv_established signature (Daniel Borkmann) [1000470]
- [net] tcp_probe: also include rcv_wnd next to snd_wnd (Daniel Borkmann) [1000470]
- [lib] vsprintf: add IPv4/v6 generic p[Ii]S[pfs] format specifier (Daniel Borkmann) [1000470]
- [net] ipv6: fix potential use after free in tcp_v6_do_rcv (Jiri Benc) [1004165]
- [net] netlabel: use domain based selectors when address based selectors are not available (Paul Moore) [983949]

* Wed Sep 11 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-20.el7]
- [fs] gfs2: dirty inode correctly in gfs2_write_end (Benjamin Marzinski) [1004054]
- [netdrv] bnx2x: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Michal Schmidt) [819849]
- [netdrv] bnx2x: clean up unnecessary MSI/MSI-X capability find (Michal Schmidt) [819849]
- [netdrv] bnx2x: Revising locking scheme for MAC configuration (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix VF stats sync (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix VF memory leak unload (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix functionality of configuring vlan list (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix move FP memory deallocations (Michal Schmidt) [819849]
- [netdrv] bnx2x: vf mark stats started (Michal Schmidt) [819849]
- [netdrv] bnx2x: set VF DMAE when first function has 0 supported VFs (Michal Schmidt) [819849]
- [netdrv] bnx2x: Protect against VFs' ndos when SR-IOV is disabled (Michal Schmidt) [819849]
- [netdrv] bnx2x: prevent VF benign attentions (Michal Schmidt) [819849]
- [netdrv] bnx2x: Consider DCBX remote error (Michal Schmidt) [819849]
- [netdrv] bnx2x: Change DCB context handling (Michal Schmidt) [819849]
- [netdrv] bnx2x: dropless flow control not always functional (Michal Schmidt) [819849]
- [netdrv] bnx2x: prevent crash in shutdown flow with CNIC (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix PTE write access error (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix memory leak in VF (Michal Schmidt) [819849]
- [netdrv] bnx2x: update fairness parameters following DCB negotiation (Michal Schmidt) [819849]
- [netdrv] bnx2x: protect different statistics flows (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix tunneling CSUM calculation (Michal Schmidt) [819849]
- [netdrv] bnx2x: fill in sane dump flag information (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix dump flag handling (Michal Schmidt) [819849]
- [netdrv] bnx2x: remove zeroing of dump data buffer (Michal Schmidt) [819849]
- [netdrv] bnx2x: Remove sparse and coccinelle warnings (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix compilation with no IOV support (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix 20G KR2 support claims (Michal Schmidt) [819849]
- [netdrv] bnx2x: improve VF timings (Michal Schmidt) [819849]
- [netdrv] bnx2x: VF ndo sanity (Michal Schmidt) [819849]
- [netdrv] bnx2x: Improve PF behaviour toward VF (Michal Schmidt) [819849]
- [netdrv] bnx2x: remove redundant D0 power state set (Michal Schmidt) [819849]
- [netdrv] bnx2x: replace mechanism to check for next available packet (Michal Schmidt) [819849]
- [netdrv] bnx2x: add support for busy-poll (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix a power state test (Michal Schmidt) [819849]
- [netdrv] bnx2x: semi-Semantic changes (Michal Schmidt) [819849]
- [netdrv] bnx2x: Revise prints (Michal Schmidt) [819849]
- [netdrv] bnx2x: Semantic removal and beautification (Michal Schmidt) [819849]
- [netdrv] bnx2x: Revise comments and alignment (Michal Schmidt) [819849]
- [netdrv] bnx2x: Semantic change of empty lines (Michal Schmidt) [819849]
- [netdrv] bnx2x: use XPS if possible for bnx2x_select_queue instead of pure hash (Michal Schmidt) [819849]
- [netdrv] bnx2x: Change to D3hot only on removal (Michal Schmidt) [819849]
- [netdrv] bnx2x: Implement PCI shutdown (Michal Schmidt) [819849]
- [netdrv] bnx2x: Count number of possible FCoE interfaces (Michal Schmidt) [819849]
- [netdrv] bnx2x: Ack unknown VF messages (Michal Schmidt) [819849]
- [netdrv] bnx2x: Add and correct PCI link speed prints (Michal Schmidt) [819849]
- [netdrv] bnx2x: Zero VFs starting MACs (Michal Schmidt) [819849]
- [netdrv] bnx2x: Enable `set_phys_id' for all functions (Michal Schmidt) [819849]
- [netdrv] bnx2x: Link-flap avoidance in switch dependent mode (Michal Schmidt) [819849]
- [netdrv] bnx2x: Add Private Flags Support (Michal Schmidt) [819849]
- [netdrv] bnx2x: dont reload on GRO change (Michal Schmidt) [819849]

* Tue Sep 10 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-19.el7]
- [crypto] nx: fix SHA-2 for chunks bigger than block size (Steve Best) [999606]
- [crypto] nx: fix GCM for zero length messages (Steve Best) [999606]
- [crypto] nx: fix XCBC for zero length messages (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-CCM (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-XCBC (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-GCM (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-CTR (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-CBC (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-ECB (Steve Best) [999606]
- [crypto] nx: add offset to nx_build_sg_lists() (Steve Best) [999606]
- [virt] virtio_console: prevent use-after-free of port name in port unplug (Amit Shah) [990419]
- [virt] virtio_console: fix locking around send_sigio_to_port() (Amit Shah) [986968]
- [virt] virtio_console: add locking in port unplug path (Amit Shah) [990419]
- [virt] virtio_console: add locks around buffer removal in port unplug path (Amit Shah) [990419]
- [virt] virtio_console: return -ENODEV on all read operations after unplug (Amit Shah) [975716]
- [virt] virtio_console: fix raising SIGIO after port unplug (Amit Shah) [986968]
- [virt] virtio_console: clean up port data immediately at time of unplug (Amit Shah) [990419]
- [virt] virtio_console: fix race in port_fops_open() and port unplug (Amit Shah) [990419]
- [virt] virtio_console: fix race with port unplug and open/close (Amit Shah) [990419]
- [virt] virtio_console: Add pipe_lock/unlock for splice_write (Amit Shah) [987722]
- [virt] virtio_console: Quit from splice_write if pipe->nrbufs is 0 (Amit Shah) [987722]
- [scsi] Generate uevents on certain unit attention codes (Ewan Milne) [740795]
- [virt] kvm: update masterclock when kvmclock_offset is calculated (Marcelo Tosatti) [978425]
- [acpi] pci_root: Fix _OSC ordering to allow PCIe hotplug use when available (Neil Horman) [990078]

* Thu Sep 05 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-18.el7]
- [net] ipv4: make snmp_mib_free static inline (Amerigo Wang) [970585]
- [net] vxlan: include net/ip6_checksum.h for csum_ipv6_magic() (Amerigo Wang) [970585]
- [net] vxlan: fix flowi6_proto value (Amerigo Wang) [970585]
- [net] udp: unify skb_udp_tunnel_segment() and skb_udp6_tunnel_segment() (Amerigo Wang) [970585]
- [net] ipv6: Add generic UDP Tunnel segmentation (Amerigo Wang) [970585]
- [net] vxlan: add ipv6 proxy support (Amerigo Wang) [970585]
- [net] ipv6: move in6_dev_finish_destroy() into core kernel (Amerigo Wang) [970585]
- [net] ipv6: add include file to suppress sparse warnings (Amerigo Wang) [970585]
- [net] vxlan: add ipv6 route short circuit support (Amerigo Wang) [970585]
- [net] vxlan: add ipv6 support (Amerigo Wang) [970585]
- [net] ipv6: do not call ndisc_send_rs() with write lock (Amerigo Wang) [970585]
- [net] ipv6: export in6addr_loopback to modules (Amerigo Wang) [970585]
- [net] ipv6: export a stub for IPv6 symbols used by vxlan (Amerigo Wang) [970585]
- [net] ipv6: Remove extern function prototypes (Amerigo Wang) [970585]
- [net] ipv6: always hold idev->lock before mca_lock (Amerigo Wang) [970585]
- [net] ipv6: move ip6_local_out into core kernel (Amerigo Wang) [970585]
- [net] ipv6: move ip6_dst_hoplimit() into core kernel (Amerigo Wang) [970585]
- [net] udp: move GSO functions to udp_offload (Amerigo Wang) [970585]
- [net] tcp: move GRO/GSO functions to tcp_offload (Amerigo Wang) [970585]
- [net] tcp: use tcp_skb_mss helper in tcp_tso_segment (Amerigo Wang) [970585]
- [scsi] csgb4i: convert skb->transport_header into skb_transport_header(skb) (Amerigo Wang) [970585]
- [net] pass correct parameter to skb_headers_offset_update() (Amerigo Wang) [970585]
- [netdrv] cxgb3: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] clean up skb headers code (Amerigo Wang) [970585]
- [net] Fix build warnings after mac_header and transport_header became __u16 (Amerigo Wang) [970585]
- [net] netfilter: Correct calculation using skb->tail and skb-network_header (Amerigo Wang) [970585]
- [net] Correct assignment of skb->network_header to skb->tail (Amerigo Wang) [970585]
- [net] sctp: Correct access to skb->{network, transport}_header (Amerigo Wang) [970585]
- [net] ipv4: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] ipv6: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [netdrv] cxgb3: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [netdrv] isdn: Correct comparison of skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] Copy inner_protocol in copy_skb_header() (Amerigo Wang) [970585]
- [net] mpls: Add limited GSO support (Amerigo Wang) [970585]
- [net] Use 16bits for *_headers fields of struct skbuff (Amerigo Wang) [970585]

* Wed Sep 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-17.el7]
- [fs] lockd: Don't call utsname()->nodename from nlmclnt_setlockargs (Jan Stancek) [999289]
- [scsi] ipr: Add sereral new CCIN definitions for new adapters support (Steve Best) [1002200]
- [virt] x86/xen: Sync the CMOS RTC as well as the Xen wallclock (Radim Krcmar) [1003683]
- [virt] x86/xen: Sync the wallclock when the system time is set (Radim Krcmar) [1003683]
- [virt] x86: Increase precision of x86_platform.get/set_wallclock() (Radim Krcmar) [1003683]
- [powerpc] Don't Oops when accessing /proc/powerpc/lparcfg without hypervisor (Steve Best) [1002206]
- [virt] xen/smp: initialize IPI vectors before marking CPU online (Radim Krcmar) [1003683]
- [virt] xen/events: mask events when changing their VCPU binding (Radim Krcmar) [1003683]
- [virt] xen/events: initialize local per-cpu mask for all possible events (Radim Krcmar) [1003683]
- [virt] x86/xen: do not identity map UNUSABLE regions in the machine E820 (Radim Krcmar) [1003683]
- [virt] xen/evtchn: avoid a deadlock when unbinding an event channel (Radim Krcmar) [1003683]
- [virt] xenbus: frontend resume cleanup (Radim Krcmar) [1003683]
- [virt] xen-netfront: pull on receive skb may need to happen earlier (Radim Krcmar) [1003683]
- [virt] xen: Use more current logging styles (Radim Krcmar) [1003683]
- [virt] xen/time: remove blocked time accounting from xen "clockchip" (Radim Krcmar) [1003683]
- [virt] xen: Convert printks to pr_<level> (Radim Krcmar) [1003683]
- [virt] xen: ifdef CONFIG_HIBERNATE_CALLBACKS xen_*_suspend (Radim Krcmar) [1003683]
- [virt] xen-blkfront: set blk_queue_max_hw_sectors correctly (Radim Krcmar) [1003683]
- [virt] xen/io: new macro to detect whether there are too many requests on the ring (Radim Krcmar) [1003683]
- [virt] xen-netfront: use skb_partial_csum_set() to simplify the codes (Radim Krcmar) [1003683]
- [virt] xen/time: Free onlined per-cpu data structure if we want to online it again (Radim Krcmar) [1003683]
- [virt] xen/time: Check that the per_cpu data structure has data before freeing (Radim Krcmar) [1003683]
- [virt] xen/time: Don't leak interrupt name when offlining (Radim Krcmar) [1003683]
- [virt] xen/time: Encapsulate the struct clock_event_device in another structure (Radim Krcmar) [1003683]
- [virt] xen/spinlock: Don't leak interrupt name when offlining (Radim Krcmar) [1003683]
- [virt] xen/smp: Don't leak interrupt name when offlining (Radim Krcmar) [1003683]
- [virt] xen/smp: Set the per-cpu IRQ number to a valid default (Radim Krcmar) [1003683]
- [virt] xen/smp: Introduce a common structure to contain the IRQ name and interrupt line (Radim Krcmar) [1003683]
- [virt] xen/smp: Coalesce the free_irq calls in one function (Radim Krcmar) [1003683]
- [virt] xen-blkback: Use physical sector size for setup (Radim Krcmar) [1003683]
- [virt] xen-blkfront: Introduce a 'max' module parameter to alter the amount of indirect segments (Radim Krcmar) [1003683]
- [virt] xen/netif: document feature-split-event-channels (Radim Krcmar) [1003683]
- [virt] xen-netfront: split event channels support for Xen frontend driver (Radim Krcmar) [1003683]
- [virt] xen-netfront: avoid leaking resources when setup_netfront fails (Radim Krcmar) [1003683]
- [virt] xen-blkfront: use a different scatterlist for each request (Radim Krcmar) [1003683]
- [virt] xen-block: implement indirect descriptors (Radim Krcmar) [1003683]
- [acpi] Try harder to resolve _ADR collisions for bridges (Myron Stowe) [1003183]
- [cpufreq] rename ignore_nice as ignore_nice_load (Myron Stowe) [1003183]
- [acpi] processor: move try_offline_node() after acpi_unmap_lsapic() (Myron Stowe) [1003183]
- [acpi] Drop physical_node_id_bitmap from struct acpi_device (Myron Stowe) [1003183]
- [acpi] pm: Walk physical_node_list under physical_node_lock (Myron Stowe) [1003183]
- [acpi] video: improve quirk check in acpi_video_bqc_quirk() (Myron Stowe) [1003183]
- [kernel] freezer: set PF_SUSPEND_TASK flag on tasks that call freeze_processes (Myron Stowe) [1003183]
- [acpi] battery: Fix parsing _BIX return value (Myron Stowe) [1003183]
- [cpufreq] Fix cpufreq driver module refcount balance after suspend/resume (Myron Stowe) [1003183]
- [cpufreq] intel_pstate: Change to scale off of max P-state (Myron Stowe) [1003183]
- [acpi] video: ignore BIOS initial backlight value for Fujitsu E753 (Myron Stowe) [1003183]
- [pnp] acpi: avoid garbage in resource name (Myron Stowe) [1003183]
- [power] sleep: Fix comment typo in pm_wakeup.h (Myron Stowe) [1003183]
- [power] sleep: avoid 'autosleep' in shutdown progress (Myron Stowe) [1003183]
- [acpi] scan: Always call acpi_bus_scan() for bus check notifications (Myron Stowe) [1003183]
- [acpi] scan: Do not try to attach scan handlers to devices having them (Myron Stowe) [1003183]

* Tue Sep 03 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-16.el7]
- [powerpc] Avoid link stack corruption for MMU on exceptions (Steve Best) [999556]
- [virt] net/hyperv: Fix the NETIF_F_SG flag setting in netvsc (Jason Wang) [984810]
- [pci] Retry allocation of only the resource type that failed (Myron Stowe) [1001217]
- [pci] pciehp: Convert pciehp to be builtin only, not modular (Myron Stowe) [1001217]
- [pci] hotplug: Convert to be builtin only, not modular (Myron Stowe) [1001217]
- [pci] pciehp: Fix null pointer deref when hot-removing SR-IOV device (Myron Stowe) [1001217]

* Fri Aug 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-15.el7]
- [drm] qxl: backport updates from v3.11-rc1 (Dave Airlie) [979176]
- [drm] add hotspot support for cursors (Dave Airlie) [983312]
- [virt] x86: Correctly detect hypervisor (Jason Wang) [985743]
- [virt] kvm: Switch to use hypervisor_cpuid_base() (Jason Wang) [985743]
- [virt] xen: Switch to use hypervisor_cpuid_base() (Jason Wang) [985743]
- [virt] x86: Introduce hypervisor_cpuid_base() (Jason Wang) [985743]
- [net] sunrpc: prepare NFS for 2038 (Harshula Jayasuriya) [847926]
- [netdrv] macvtap: Ignore tap features when VNET_HDR is off (Vlad Yasevich) [1001053]
- [netdrv] macvtap: Correctly set tap features when IFF_VNET_HDR is disabled (Vlad Yasevich) [1001053]
- [netdrv] macvtap: simplify usage of tap_features (Vlad Yasevich) [1001053]

* Thu Aug 29 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-14.el7]
- [net] openvswitch: optimize flow compare and mask functions (Thomas Graf) [1002051]
- [net] openvswitch: Rename key_len to key_end (Thomas Graf) [1002051]
- [net] openvswitch: Add SCTP support (Thomas Graf) [1002051]
- [net] ipv6: Add NEXTHDR_SCTP to ipv6.h (Thomas Graf) [1002051]
- [net] sctp: Refactor SCTP skb checksum computation (Thomas Graf) [1002051]
- [net] sctp: prevent checksum.h from double inclusion (Thomas Graf) [1002051]
- [net] openvswitch: Mega flow implementation (Thomas Graf) [1002051]
- [net] openvswitch: Fix argument descriptions in vport.c (Thomas Graf) [1002051]
- [net] openvswitch: link upper device for port devices (Thomas Graf) [1002051]
- [net] openvswitch: Use non rcu hlist_del() flow table entry (Thomas Graf) [1002051]
- [net] openvswitch: Use RCU lock for dp dump operation (Thomas Graf) [1002051]
- [net] openvswitch: Use RCU lock for flow dump operation (Thomas Graf) [1002051]
- [net] ipv6: prevent race between address creation and removal (Jiri Benc) [991392]
- [net] ipv6: move peer_addr init into ipv6_add_addr() (Jiri Benc) [991392]
- [net] ipv6: use ipv6_addr_scope() helper (Jiri Benc) [991392]
- [net] ipv6: add support of peer address (Jiri Benc) [991392]
- [net] rtm_to_ifaddr: free ifa if ifa_cacheinfo processing fails (Daniel Borkmann) [992908]
- [net] net_sched: restore "linklayer atm" handling (Jesper Brouer) [998588]
- [net] net_sched: psched_ratecfg_precompute() improvements (Jesper Brouer) [998588]
- [net] ip_tunnel: Do not use inner ip-header-id for tunnel ip-header-id (Amerigo Wang) [989522]
- [net] openvswitch: Add vxlan tunneling support (Amerigo Wang) [989522]
- [net] vxlan: Add tx-vlan offload support (Amerigo Wang) [989522]
- [net] vxlan: Improve vxlan headroom calculation (Amerigo Wang) [989522]
- [net] vxlan: Factor out vxlan send api (Amerigo Wang) [989522]
- [net] vxlan: Extend vxlan handlers for openvswitch (Amerigo Wang) [989522]
- [net] vxlan: Add vxlan recv demux (Amerigo Wang) [989522]
- [net] vxlan: Restructure vxlan receive (Amerigo Wang) [989522]
- [net] vxlan: Restructure vxlan socket apis (Amerigo Wang) [989522]
- [net] openvswitch: Reset tunnel key between input and output (Amerigo Wang) [989522]
- [net] openvswitch: Use correct type while allocating flex array (Amerigo Wang) [989522]
- [net] openvswitch: Fix bad merge resolution (Amerigo Wang) [989522]
- [net] rtnetlink: Fix inverted check in ndo_dflt_fdb_del() (Amerigo Wang) [989522]
- [net] rtnetlink: allow using zero MAC address in rtnl_fdb_{add, del} (Amerigo Wang) [989522]
- [net] vxlan: fix a soft lockup in vxlan module removal (Amerigo Wang) [989522]
- [net] vxlan: fix a regression of igmp join (Amerigo Wang) [989522]
- [net] vxlan: fix rcu related warning (Amerigo Wang) [989522]
- [net] vxlan: fdb: replace an existing entry (Amerigo Wang) [989522]
- [net] vxlan: fix igmp races (Amerigo Wang) [989522]
- [net] vxlan: unregister on namespace exit (Amerigo Wang) [989522]
- [net] vxlan: add necessary locking on device removal (Amerigo Wang) [989522]
- [net] vxlan: Fix kernel crash on rmmod (Amerigo Wang) [989522]
- [net] vxlan: fix function name spelling (Amerigo Wang) [989522]
- [net] vxlan: fdb: allow specifying multiple destinations for zero MAC (Amerigo Wang) [989522]
- [net] vxlan: allow removal of single destination from fdb entry (Amerigo Wang) [989522]
- [net] vxlan: introduce vxlan_fdb_parse (Amerigo Wang) [989522]
- [net] vxlan: introduce vxlan_fdb_find_rdst (Amerigo Wang) [989522]
- [net] vxlan: add implicit fdb entry for default destination (Amerigo Wang) [989522]
- [net] vxlan: Fix sparse warnings (Amerigo Wang) [989522]
- [net] vxlan: cosmetic cleanup's (Amerigo Wang) [989522]
- [net] vxlan: Use initializer for dummy structures (Amerigo Wang) [989522]
- [net] vxlan: port module param should be ushort (Amerigo Wang) [989522]
- [net] vxlan: convert remotes list to list_rcu (Amerigo Wang) [989522]
- [net] vxlan: make vxlan_xmit_one void (Amerigo Wang) [989522]
- [net] vxlan: move cleanup to uninit (Amerigo Wang) [989522]
- [net] vxlan: fix race caused by dropping rtnl_unlock (Amerigo Wang) [989522]
- [net] vxlan: send notification when MAC migrates (Amerigo Wang) [989522]
- [net] vxlan: move IGMP join/leave to work queue (Amerigo Wang) [989522]
- [net] vxlan: fix crash from work pending on module removal (Amerigo Wang) [989522]
- [net] vxlan: fix out of order operation on module removal (Amerigo Wang) [989522]
- [net] vxlan: defer vxlan init as late as possible (Amerigo Wang) [989522]
- [net] vxlan: use unsigned int instead of unsigned (Amerigo Wang) [989522]
- [net] vxlan: remove the unused rcu head from struct vxlan_rdst (Amerigo Wang) [989522]
- [net] vxlan: listen on multiple ports (Amerigo Wang) [989522]
- [rhel] Kconfig: enable CONFIG_OPENVSWITCH_GRE (Amerigo Wang) [992917]
- [net] ip_tunnel: embed hash list head (Amerigo Wang) [992917]
- [net] sit: fix tunnel update via netlink (Amerigo Wang) [992917]
- [net] ipv6: only apply anti-spoofing checks to not-pointopoint tunnels (Amerigo Wang) [992917]
- [net] gre: Fix MTU sizing check for gretap tunnels (Amerigo Wang) [992917]
- [net] ip_tunnels: Use skb-len to PMTU check (Amerigo Wang) [992917]
- [net] gso: Update tunnel segmentation to support Tx checksum offload (Amerigo Wang) [992917]
- [net] gre: move GSO functions to gre_offload (Amerigo Wang) [992917]
- [net] gre: fix a regression in ioctl (Amerigo Wang) [992917]
- [net] sit: add support of x-netns (Amerigo Wang) [992917]
- [net] dev: introduce skb_scrub_packet() (Amerigo Wang) [992917]
- [net] dev: remove duplicate 'skb->dev = dev' in dev_forward_skb() (Amerigo Wang) [992917]
- [net] sit: fix an oops when IFLA_IPTUN_PROTO is not set (Amerigo Wang) [992917]
- [net] sit: fix 4in4 + IPsec scenario (Amerigo Wang) [992917]
- [net] openvswitch: Add Kconfig dependency on GRE-DEMUX (Amerigo Wang) [992917]
- [net] ip_tunnel: Protect tunnel functions with CONFIG_INET guard (Amerigo Wang) [992917]
- [net] openvswitch: Use correct config guard (Amerigo Wang) [992917]
- [net] openvswitch: Add gre tunnel support (Amerigo Wang) [992917]
- [net] openvswitch: Optimize flow key match for non tunnel flows (Amerigo Wang) [992917]
- [net] openvswitch: Expand action buffer size (Amerigo Wang) [992917]
- [net] openvswitch: Add tunneling interface (Amerigo Wang) [992917]
- [net] openvswitch: Copy individual actions (Amerigo Wang) [992917]
- [net] ip_tunnel: Add dont fragment flag (Amerigo Wang) [992917]
- [net] ip_tunnel: push generic protocol handling to ip_tunnel module (Amerigo Wang) [992917]
- [net] ip_tunnel: extend iptunnel_xmit() (Amerigo Wang) [992917]
- [net] gre: export gre_handle_offloads() function (Amerigo Wang) [992917]
- [net] gre: export gre_build_header() function (Amerigo Wang) [992917]
- [net] gre: Allow multiple protocol listener for gre protocol (Amerigo Wang) [992917]
- [net] gre: Simplify gre protocol registration locking (Amerigo Wang) [992917]
- [net] openvswitch: make skb->csum consistent with rest of networking stack (Amerigo Wang) [992917]
- [net] openvswitch: Simplify interface ovs_flow_metadata_from_nlattrs() (Amerigo Wang) [992917]
- [net] openvswitch: Fix misspellings in comments and docs (Amerigo Wang) [992917]
- [net] openvswitch: Unify vport error stats handling (Amerigo Wang) [992917]
- [net] openvswitch: fix variable names in comment (Amerigo Wang) [992917]
- [net] openvswitch: Immediately exit on error in ovs_vport_cmd_set() (Amerigo Wang) [992917]
- [net] openvswitch: Remove unused get_config vport op (Amerigo Wang) [992917]
- [net] iptunnel: specify protocol outside IP header (Amerigo Wang) [992917]
- [net] sit: add IPv4 over IPv4 support (Amerigo Wang) [992917]
- [net] export physical port id via sysfs (Jiri Pirko) [991026]
- [net] rtnl: export physical port id via RT netlink (Jiri Pirko) [991026]
- [net] add ndo to get id of physical port of the device (Jiri Pirko) [991026]
- [net] busy_poll: revert unsupported bits from creation of BUSY_POLL socket option (Neil Horman) [958330]
- [net] busy_poll: rename busy poll socket op and globals (Neil Horman) [958330]
- [net] busy_poll: rename ll methods to busy-poll (Neil Horman) [958330]
- [net] busy_poll: rename include/net/ll_poll.h to include/net/busy_poll.h (Neil Horman) [958330]
- [net] busy_poll: change busy poll time accounting (Neil Horman) [958330]
- [net] busy_poll: rename low latency sockets functions to busy poll (Neil Horman) [958330]
- [net] busy_poll: lls fix build with allnoconfig (Neil Horman) [958330]
- [net] busy_poll: convert lls to use time_in_range() (Neil Horman) [958330]
- [net] busy_poll: avoid calling sched_clock when LLS is off (Neil Horman) [958330]
- [net] busy_poll: fix LLS debug_smp_processor_id() warning (Neil Horman) [958330]
- [net] busy_poll: poll/select low latency socket support (Neil Horman) [958330]
- [net] busy_poll: add socket option for low latency polling (Neil Horman) [958330]
- [net] busy_poll: remove NET_LL_RX_POLL config menu (Neil Horman) [958330]
- [net] busy_poll: convert low latency sockets to sched_clock() (Neil Horman) [958330]
- [net] busy_poll: change sysctl_net_ll_poll into an unsigned int (Neil Horman) [958330]
- [netdrv] ixgbe: add extra stats for ndo_ll_poll (Neil Horman) [958330]
- [netdrv] ixgbe: add support for ndo_ll_poll (Neil Horman) [958330]
- [net] tcp: add low latency socket poll support (Neil Horman) [958330]
- [net] udp: add low latency socket poll support (Neil Horman) [958330]
- [net] busy_poll: add low latency socket poll (Neil Horman) [958330]
- [net] add napi_id and hash (Neil Horman) [958330]

* Wed Aug 28 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-13.el7]
- [powerpc] pseries: Drop "select HOTPLUG" (Myron Stowe) [999178]
- [misc] Finally eradicate CONFIG_HOTPLUG (Myron Stowe) [999178]
- [vfio] vfio-pci: Avoid deadlock on remove (Alex Williamson) [912293]
- [vfio] Ignore sprurious notifies (Alex Williamson) [912293]
- [vfio] Don't overreact to DEL_DEVICE (Alex Williamson) [912293]
- [s390] qeth: Fix crash on initial MTU size change (Hendrik Brueckner) [997607]
- [s390] qeth: change default standard blkt settings for OSA (Hendrik Brueckner) [997635]
- [s390] dasd: fix hanging devices after path events (Hendrik Brueckner) [996178]
- [s390] zcrypt: Alias for new zcrypt device driver base module (Hendrik Brueckner) [996731]
- [s390] zfcp: status read buffers on first adapter open with link down (Hendrik Brueckner) [976636]
- [s390] zfcp: fix adapter (re)open recovery while link to SAN is down (Hendrik Brueckner) [889079]
- [netdrv] be2net: Fix to avoid hardware workaround when not needed (Ivan Vecera) [982900]
- [fs] gfs2: Take glock reference in examine_bucket() (Steven Whitehouse) [999897]
- [fs] gfs2: Check for glock already held in gfs2_getxattr (Steven Whitehouse) [997604]
- [crypto] nx: fix nx-aes-gcm verification (Steve Best) [997057]
- [s390] zfcp: remove access control tables interface (Hendrik Brueckner) [994519]
- [s390] zfcp: cfdc fops add owner (Hendrik Brueckner) [994519]
- [scsi] fcoe: cleanup return codes from fcoe_rcv (Neil Horman) [984876]
- [scsi] fcoe: make sure fcoe frames are unshared prior to manipulating them (Neil Horman) [984876]
- [scsi] fcoe: ensure that skb placed on the fip_recv_list are unshared (Neil Horman) [984876]
- [mm] zswap: add documentation (Steve Best) [731499]
- [mm] zswap: add to mm (Steve Best) [731499]
- [mm] zbud: add to mm (Steve Best) [731499]
- [misc] MAINTAINERS: add zswap and zbud maintainer (Steve Best) [731499]
- [fs] debugfs: add get/set for atomic types (Steve Best) [731499]

* Mon Aug 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-12.el7]
- [acpi] memhotplug: Fix a stale pointer in error path (Lenny Szubowicz) [995322]
- [powerpc] Add second POWER8 PVR entry (Steve Best) [995355]
- [acpi] power: add missing newline to debug messages (Myron Stowe) [998633]
- [tools] cpupower: Add Haswell family 0x45 specific idle monitor to show PC8, 9, 10 states (Myron Stowe) [998633]
- [tools] cpupower: Haswell also supports the C-states introduced with SandyBridge (Myron Stowe) [998633]
- [tools] cpupower: Introduce idle-set subcommand and C-state enabling/disabling (Myron Stowe) [998633]
- [tools] cpupower: Implement disabling of cstate interface (Myron Stowe) [998633]
- [tools] cpupower: Make idlestate usage unsigned (Myron Stowe) [998633]
- [acpi] fan: Initialize acpi_state variable (Myron Stowe) [998633]
- [acpi] scan: remove unused LIST_HEAD(acpi_device_list) (Myron Stowe) [998633]
- [acpi] dock: Actually define acpi_dock_init() as void (Myron Stowe) [998633]
- [acpi] pm: Fix corner case in acpi_bus_update_power() (Myron Stowe) [998633]
- [cpufreq] Fix serialization of frequency transitions (Myron Stowe) [998633]
- [cpufreq] Fix cpufreq regression after suspend/resume (Myron Stowe) [991615]
- [acpi] pm: Fix possible NULL pointer deref in acpi_pm_device_sleep_state() (Myron Stowe) [991615]
- [kernel] power: Warn about system time after resume with pm_trace (Myron Stowe) [991615]
- [cpufreq] don't leave stale policy pointer in cdbs->cur_policy (Myron Stowe) [991615]
- [cpufreq] acpi-cpufreq: Add new sysfs attribute freqdomain_cpus (Myron Stowe) [991615]
- [cpufreq] make sure frequency transitions are serialized (Myron Stowe) [991615]
- [acpi] implement acpi_os_get_timer() according the spec (Myron Stowe) [991615]
- [acpi] ec: Add HP Folio 13 to ec_dmi_table in order to skip DSDT scan (Myron Stowe) [991615]
- [acpi] Add CMOS RTC Operation Region handler support (Myron Stowe) [991615]
- [acpi] processor: Drop unused variable from processor_perflib.c (Myron Stowe) [991615]
- [cpufreq] powernow-k8: call CPUFREQ_POSTCHANGE notfier in error cases (Myron Stowe) [991615]
- [cpufreq] pcc: call CPUFREQ_POSTCHANGE notfier in error cases (Myron Stowe) [991615]
- [cpufreq] acpi-cpufreq: call CPUFREQ_POSTCHANGE notfier in error cases (Myron Stowe) [991615]
- [Documentation] power: Add pm_qos and dev_pm_qos to events-power.txt (Myron Stowe) [991615]
- [base] power/qos: Add dev_pm_qos_request tracepoints (Myron Stowe) [991615]
- [kernel] power/qos: Add pm_qos_request tracepoints (Myron Stowe) [991615]
- [kernel] power/qos: Add pm_qos_update_target/flags tracepoints (Myron Stowe) [991615]
- [acpi] processor: Remove unused macros in processor_driver.c (Myron Stowe) [991615]
- [Documentation] power: Update Documentation/power/pm_qos_interface.txt (Myron Stowe) [991615]
- [Documentation] cpu-hotplug: Rephrase the outdated description for MADT entries (Myron Stowe) [991615]
- [cpufreq] make __cpufreq_notify_transition() static (Myron Stowe) [991615]
- [cpufreq] Fix minor formatting issues (Myron Stowe) [991615]
- [cpufreq] Fix governor start/stop race condition (Myron Stowe) [991615]
- [kernel] power: Print last wakeup source on failed wakeup_count write (Myron Stowe) [991615]
- [kernel] power/qos: correct the valid range of pm_qos_class (Myron Stowe) [991615]
- [Documentation] video: update video_extension.txt for backlight control (Myron Stowe) [991615]
- [Documentation] video: move video_extension.txt to Documentation/acpi (Myron Stowe) [991615]
- [Documentation] video: add description for brightness_switch_enabled (Myron Stowe) [991615]
- [Documentation] Add ACPI namespace documentation (Myron Stowe) [991615]
- [Documentation] Add sysfs ABI documentation (Myron Stowe) [991615]
- [Documentation] MAINTAINERS: include Documentation/acpi (Myron Stowe) [991615]
- [acpi] acpica: Update version to 20130517 (Myron Stowe) [991615]
- [acpi] acpica: _CST repair, handle null package entries (Myron Stowe) [991615]
- [acpi] acpica: Add several repairs for _CST predefined name (Myron Stowe) [991615]
- [acpi] acpica: Move _PRT repair into the standard complex repair module (Myron Stowe) [991615]
- [acpi] scan: Do not bind ACPI drivers to objects with scan handlers (Myron Stowe) [991615]
- [acpi] pm: Rework and clean up acpi_dev_pm_get_state() (Myron Stowe) [991615]
- [acpi] pm: Replace ACPI_STATE_D3 with ACPI_STATE_D3_COLD in device_pm.c (Myron Stowe) [991615]
- [acpi] pm: Rename function acpi_device_power_state() and make it static (Myron Stowe) [991615]
- [acpi] pm: acpi_processor_suspend() can be static (Myron Stowe) [991615]
- [virt] xen/acpi: Register an acpi_suspend_lowlevel callback (Myron Stowe) [991615]
- [x86] acpi/sleep: Provide registration for acpi_suspend_lowlevel (Myron Stowe) [991615]
- [acpi] Remove unused flags in acpi_device_flags (Myron Stowe) [991615]
- [acpi] Remove useless initializers (Myron Stowe) [991615]
- [acpi] battery: Make sure all spaces are in correct places (Myron Stowe) [991615]
- [acpi] add _STA evaluation at do_acpi_find_child() (Myron Stowe) [991615]
- [acpi] ec: access user space with get_user()/put_user() (Myron Stowe) [991615]
- [cpufreq] Simplify userspace governor (Myron Stowe) [991615]
- [acpi] lpss: override SDIO private register space size from ACPI tables (Myron Stowe) [991615]
- [acpi] lpss: mask the UART TX completion interrupt (Myron Stowe) [991615]
- [acpi] lpss: add support for Intel BayTrail (Myron Stowe) [991615]
- [acpi] Do not use CONFIG_ACPI_HOTPLUG_MEMORY_MODULE (Myron Stowe) [991615]
- [cpufreq] x86: make X86_AMD_FREQ_SENSITIVITY select CPU_FREQ_TABLE (Myron Stowe) [991615]
- [cpufreq] powerpc: make CBE_RAS select CPU_FREQ_TABLE (Myron Stowe) [991615]
- [cpufreq] blackfin: enable driver for CONFIG_BFIN_CPU_FREQ (Myron Stowe) [991615]
- [acpi] acpica: Clear events initialized flag upon event component termination (Myron Stowe) [991615]
- [acpi] acpica: Fix possible memory leak in GPE init error path (Myron Stowe) [991615]
- [acpi] acpica: on termination, delete global lock pending lock (Myron Stowe) [991615]
- [acpi] acpica: Update interface to acpi_ut_valid_acpi_name() (Myron Stowe) [991615]
- [acpi] acpica: Do not use extended sleep registers unless HW-reduced bit is set (Myron Stowe) [991615]
- [acpi] acpica: Split table print utilities to a new a separate file (Myron Stowe) [991615]
- [acpi] acpica: Add option to disable loading of SSDTs from the RSDT/XSDT (Myron Stowe) [991615]
- [acpi] acpica: Standardize all switch() blocks (Myron Stowe) [991615]
- [acpi] acpica: Split internal error msg routines to a separate file (Myron Stowe) [991615]
- [acpi] acpica: Split buffer dump routines into separate file (Myron Stowe) [991615]
- [acpi] scan: Simplify ACPI driver probing (Myron Stowe) [991615]
- [base] power/wakeup: Adjust messaging for wake events during suspend (Myron Stowe) [991615]
- [cpuidle] Fix ARCH_NEEDS_CPU_IDLE_COUPLED dependency warning (Myron Stowe) [991615]
- [cpuidle] Comment the driver's framework code (Myron Stowe) [991615]
- [cpuidle] simplify multiple driver support (Myron Stowe) [991615]
- [cpufreq] powerpc: move cpufreq driver to drivers/cpufreq (Myron Stowe) [991615]
- [cpufreq] acpi-cpufreq: Add ACPI processor device IDs to acpi-cpufreq (Myron Stowe) [991615]
- [cpufreq] remove unnecessary cpufreq_cpu_{get,put}() calls (Myron Stowe) [991615]
- [Documentation] MAINTAINERS: Add git tree path for ARM specific updates to cpufreq (Myron Stowe) [991615]
- [cpufreq] rename index as driver_data in cpufreq_frequency_table (Myron Stowe) [991615]
- [Documentation] power: Update .runtime_idle() callback documentation (Myron Stowe) [991615]
- [kernel] power: Rework the "runtime idle" helper routine (Myron Stowe) [991615]
- [kernel] power: print physical addresses consistently with other parts of kernel (Myron Stowe) [991615]
- [cpuidle] improve governor Kconfig options (Myron Stowe) [991615]
- [Documentation] MAINTAINERS: update mailing list for devfreq(DVFS) (Myron Stowe) [991615]
- [devfreq] fix typo "CPU_EXYNOS4.12" twice (Myron Stowe) [991615]
- [devfreq] add comments and Documentation (Myron Stowe) [991615]
- [devfreq] account suspend/resume for stats (Myron Stowe) [991615]
- [mm] memory_hotplug: Move alternative function definitions to header (Myron Stowe) [991615]
- [acpi] processor: Fix potential NULL pointer dereference in acpi_processor_add() (Myron Stowe) [991615]
- [acpi] acpica: Update version to 20130418 (Myron Stowe) [991615]
- [acpi] acpica: Update for "orphan" embedded controller _REG method support (Myron Stowe) [991615]
- [acpi] acpica: Remove unused macros, no functional change (Myron Stowe) [991615]
- [acpi] acpica: Predefined name support, remove unused local variable (Myron Stowe) [991615]
- [acpi] acpica: Add argument typechecking for all predefined ACPI names (Myron Stowe) [991615]
- [acpi] acpica: Add BIOS error interface for predefined name validation support (Myron Stowe) [991615]
- [acpi] acpica: Change an exception code for the ASL UnLoad() operator (Myron Stowe) [991615]
- [acpi] memhotplug: Simplify memory removal (Myron Stowe) [991615]
- [acpi] scan: Add second pass of companion offlining to hot-remove code (Myron Stowe) [991615]
- [base] memory: Drop offline_memory_block() (Myron Stowe) [991615]
- [acpi] processor: Pass processor object handle to acpi_bind_one() (Myron Stowe) [991615]
- [acpi] Drop removal_type field from struct acpi_device (Myron Stowe) [991615]
- [base] memory: Simplify __memory_block_change_state() (Myron Stowe) [991615]
- [acpi] processor: Initialize per_cpu(processors, pr->id) properly (Myron Stowe) [991615]
- [base] cpu: Fix sysfs cpu/online of offlined CPUs (Myron Stowe) [991615]
- [cpufreq] Don't create empty /sys/devices/system/cpu/cpufreq directory (Myron Stowe) [991615]
- [cpufreq] Move get_cpu_idle_time() to cpufreq.c (Myron Stowe) [991615]
- [cpufreq] governors: Move get_governor_parent_kobj() to cpufreq.c (Myron Stowe) [991615]
- [cpufreq] Add EXPORT_SYMBOL_GPL for have_governor_per_policy (Myron Stowe) [991615]
- [pnp] restore automatic resolution of DMA conflicts (Myron Stowe) [991615]
- [net] af_unix: use freezable blocking calls in read (Myron Stowe) [991615]
- [kernel] sigtimedwait: use freezable blocking call (Myron Stowe) [991615]
- [kernel] nanosleep: use freezable blocking call (Myron Stowe) [991615]
- [kernel] futex: use freezable blocking call (Myron Stowe) [991615]
- [fs] select: use freezable blocking call (Myron Stowe) [991615]
- [fs] epoll: use freezable blocking call (Myron Stowe) [991615]
- [kernel] freezer: add new freezable helpers using freezer_do_not_count() (Myron Stowe) [991615]
- [kernel] freezer: convert freezable helpers to static inline where possible (Myron Stowe) [991615]
- [kernel] freezer: convert freezable helpers to freezer_do_not_count() (Myron Stowe) [991615]
- [kernel] freezer: skip waking up tasks with PF_FREEZER_SKIP set (Myron Stowe) [991615]
- [kernel] power: shorten freezer sleep time using exponential backoff (Myron Stowe) [991615]
- [kernel] lockdep: check that no locks held at freeze time (Myron Stowe) [991615]
- [kernel] lockdep: remove task argument from debug_check_no_locks_held (Myron Stowe) [991615]
- [fs] cifs: add unsafe versions of freezable helpers for CIFS (Myron Stowe) [991615]
- [fs] nfs: add unsafe versions of freezable helpers for NFS (Myron Stowe) [991615]
- [base] memory: Introduce offline/online callbacks for memory blocks (Myron Stowe) [991615]
- [acpi] memhotplug: Bind removable memory blocks to ACPI device nodes (Myron Stowe) [991615]
- [acpi] processor: Use common hotplug infrastructure (Myron Stowe) [991615]
- [acpi] hotplug: Use device offline/online for graceful hot-removal (Myron Stowe) [991615]
- [base] cpu: Use generic offline/online for CPU offline/online (Myron Stowe) [991615]
- [base] core: Add offline/online device operations (Myron Stowe) [991615]
- [scsi] bnx2i: Fix bug on some bnx2x devices that don't support iSCSI (Tomas Henzl) [957024]
- [x86] tracing: Add irq_enter/exit() in smp_trace_reschedule_interrupt() (Seiji Aguchi) [741673]
- [x86] trace: Add config option checking to the definitions of mce handlers (Seiji Aguchi) [741673]
- [x86] trace: Do not call local_irq_save() in load_current_idt() (Seiji Aguchi) [741673]
- [x86] trace: Move creation of irq tracepoints from apic.c to irq.c (Seiji Aguchi) [741673]
- [x86] trace: Add irq vector tracepoints (Seiji Aguchi) [741673]
- [x86] trace: Rename variables for debugging (Seiji Aguchi) [741673]
- [x86] trace: Introduce entering/exiting_irq() (Seiji Aguchi) [741673]
- [tracing] Add DEFINE_EVENT_FN() macro (Seiji Aguchi) [741673]
- [fs] pstore: Fail to unlink if a driver has not defined pstore_erase (Steve Best) [996930]
- [powerpc] pseries: Inform the hypervisor we are using EBB regs (Steve Best) [997646]
- [powerpc] perf: Export PERF_EVENT_CONFIG_EBB_SHIFT to userspace (Steve Best) [997646]
- [powerpc] perf: Set PPC_FEATURE2_EBB when we register the power8 PMU (Steve Best) [997646]
- [powerpc] Fix hypervisor facility unavaliable vector number (Steve Best) [995354]
- [powerpc] Fix context switch DSCR on POWER8 (Steve Best) [995354]
- [powerpc] Rework setting up H/FSCR bit definitions (Steve Best) [995354]
- [powerpc] Wire up the HV facility unavailable exception (Steve Best) [995354]
- [powerpc] Rename and flesh out the facility unavailable exception handler (Steve Best) [995354]
- [powerpc] Remove KVMTEST from RELON exception handlers (Steve Best) [995354]
- [powerpc] tm: Fix context switching TAR, PPR and DSCR SPRs (Steve Best) [988340]
- [powerpc] Save the TAR register earlier (Steve Best) [988340]

* Wed Aug 21 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-11.el7]
- [security] Revert: Secure Boot related kernel enforcements (Jarod Wilson) [903815]

* Tue Aug 20 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-10.el7]
- [block] blk-mq: blk-mq should free bios in pass through case (Mike Snitzer) [960150]
- [block] blk-mq: add missing percpu_counter_destroy for mq_usage_counter (Mike Snitzer) [960150]
- [fs] direct-io: only inc_dec inode->i_dio_count for file systems (Mike Snitzer) [960150]
- [lib] percpu_counter: make APIs irq safe (Mike Snitzer) [960150]
- [block] null_blk: multi queue aware block test driver (Mike Snitzer) [960150]
- [kernel] smp: Export __smp_call_function_single() (Mike Snitzer) [960150]
- [block] blk-mq: change sw <-> hw queue mappings on hotplug events (Mike Snitzer) [960150]
- [block] blk-mq: re-initialize queue data structure after CPU hotplug (Mike Snitzer) [960150]
- [block] blk-mq: add queue freeze/unfreeze support (Mike Snitzer) [960150]
- [block] blk-mq: fix timer infinite loop after first timeout event (Mike Snitzer) [960150]
- [block] blk-mq: timeout fixes (Mike Snitzer) [960150]
- [block] blk-mq: cpu hot plug_unplug fixes (Mike Snitzer) [960150]
- [block] blk-mq: flush handling (Mike Snitzer) [960150]
- [block] blk-mq: new multi-queue block IO queueing mechanism (Mike Snitzer) [960150]
- [block] make rq->cmd_flags be 64-bit (Mike Snitzer) [960150]
- [kernel] smp: don't warn about csd->flags having CSD_FLAG_LOCK cleared for !wait (Mike Snitzer) [960150]
- [mm] sched: Allow uaccess in atomic with pagefault_disable() (Michael S. Tsirkin) [988029]
- [mm] sched: Drop voluntary schedule from might_fault() (Michael S. Tsirkin) [988029]
- [x86] uaccess s/might_sleep/might_fault/ (Michael S. Tsirkin) [988029]
- [powerpc] uaccess s/might_sleep/might_fault/ (Michael S. Tsirkin) [988029]
- [misc] asm-generic: uaccess s/might_sleep/might_fault/ (Michael S. Tsirkin) [988029]
- [x86] efi: Disable secure boot if shim is in insecure mode (Lenny Szubowicz) [903815]
- [kernel] modsign: Import certificates from UEFI Secure Boot (Lenny Szubowicz) [903815]
- [kernel] keys: Add a system blacklist keyring (Lenny Szubowicz) [903815]
- [crypto] asymmetric_keys: Add an EFI signature blob parser and key loader (Lenny Szubowicz) [903815]
- [kernel] modsign: Fix including certificate twice when the signing_key.x509 already exists (Lenny Szubowicz) [903815]
- [kernel] keys: Add a 'trusted' flag and a 'trusted only' flag (Lenny Szubowicz) [903815]
- [kernel] modsign: Separate the kernel signature checking keyring from module signing (Lenny Szubowicz) [903815]
- [kernel] modsign: Load *.x509 files into kernel keyring (Lenny Szubowicz) [903815]
- [efi] Add EFI signature data types (Lenny Szubowicz) [903815]
- [kernel] modsign: Always enforce module signing in a Secure Boot environment (Lenny Szubowicz) [903815]
- [kernel] hibernate: Disable in a Secure Boot environment (Lenny Szubowicz) [903815]
- [kernel] kexec: Disable in a secure boot environment (Lenny Szubowicz) [903815]
- [x86] Lock down MSR writing in secure boot (Lenny Szubowicz) [903815]
- [acpi] Ignore acpi_rsdp kernel parameter in a secure boot environment (Lenny Szubowicz) [903815]
- [char] mem: Restrict /dev/mem and /dev/kmem in secure boot setups (Lenny Szubowicz) [903815]
- [platform] asus-wmi: Restrict debugfs interface (Lenny Szubowicz) [903815]
- [acpi] Limit access to custom_method (Lenny Szubowicz) [903815]
- [x86] Lock down IO port access in secure boot environments (Lenny Szubowicz) [903815]
- [pci] Lock down BAR access in secure boot environments (Lenny Szubowicz) [903815]
- [x86] efi: Enable secure boot lockdown automatically when enabled in firmware (Lenny Szubowicz) [903815]
- [kernel] Add a kernel parameter that will force on Secure Boot mode (Lenny Szubowicz) [903815]
- [security] selinux: define mapping for new Secure Boot capability (Lenny Szubowicz) [903815]
- [uapi] Add new secure boot capability (Lenny Szubowicz) [903815]
- [kernel] audit: fix mq_open and mq_unlink to add the MQ root as a hidden parent audit_names record (Jeff Layton) [908885 953186]
- [kernel] audit: log the audit_names record type (Jeff Layton) [908885 953186]
- [kernel] audit: add child record before the create to handle case where create fails (Jeff Layton) [908885 953186]
- [md] dm-raid: silence compiler warning on rebuilds_per_group (Jonathan E Brassow) [970782]
- [md] dm-raid: Fix raid_resume not reviving failed devices in all cases (Jonathan E Brassow) [970782]
- [md] dm-raid: Break-up untidy function (Jonathan E Brassow) [970782]
- [s390] zfcp: block queue limits with data router (Hendrik Brueckner) [976657]
- [scsi] scsi_lib: Fix race between starved list and device removal (Ewan Milne) [986037]
- [md] dm-switch: add switch target (Mike Snitzer) [983188]
- [wireless] disable WiMAX support (John Linville) [915650]
- [fs] gfs2: don't overrun reserved revokes (Benjamin Marzinski) [950622]
- [fs] gfs2: Reserve journal space for quota change in do_grow (Robert S Peterson) [979131]
- [x86] setup: Add cpu_has_hypervisor check to rh_check_supported() (Prarit Bhargava) [986048]
- [x86] sched: Optimize switch_mm() for multi-threaded workloads (Rik van Riel) [990747]
- [crypto] nx: fix concurrency issue (Steve Best) [996565]
- [powerpc] mm: Fix fallthrough bug in hpte_decode (Steve Best) [993326]
- [misc] Kconfig: enable building user namespace with xfs (Dave Chinner) [987255]
- [fs] xfs: add capability check to free eofblocks ioctl (Dave Chinner) [987255]
- [fs] xfs: create internal eofblocks structure with kuid_t types (Dave Chinner) [987255]
- [fs] xfs: convert kuid_t to/from uid_t for internal structures (Dave Chinner) [987255]
- [fs] xfs: ioctl check for capabilities in the current user namespace (Dave Chinner) [987255]
- [fs] xfs: convert kuid_t to/from uid_t in ACLs (Dave Chinner) [987255]
- [fs] xfs: create wrappers for converting kuid_t to/from uid_t (Dave Chinner) [987255]
- [md] raid5: fix interaction of 'replace' and 'recovery' (Jes Sorensen) [978055]
- [md] raid10: remove use-after-free bug (Jes Sorensen) [978055]
- [md] raid1: fix bio handling problems in process_checks() (Jes Sorensen) [978055]
- [md] Remove recent change which allows devices to skip recovery (Jes Sorensen) [978055]
- [md] raid10: fix two problems with RAID10 resync (Jes Sorensen) [978055]
- [md] raid10: fix bug which causes all RAID10 reshapes to move no data (Jes Sorensen) [978055]
- [md] raid5: allow 5-device RAID6 to be reshaped to 4-device (Jes Sorensen) [978055]
- [md] raid10: fix two bugs affecting RAID10 reshape (Jes Sorensen) [978055]
- [md] Remember the last sync operation that was performed (Jes Sorensen) [978055]
- [md] raid0: fix buglet in RAID5 -> RAID0 conversion (Jes Sorensen) [978055]
- [md] raid10: check In_sync flag in 'enough()' (Jes Sorensen) [978055]
- [md] raid10: locking changes for 'enough()' (Jes Sorensen) [978055]
- [md] replace strict_strto*() with kstrto*() (Jes Sorensen) [978055]
- [md] Wait for md_check_recovery before attempting device removal (Jes Sorensen) [978055]
- [md] dm-raid: Add ability to restore transiently failed devices on resume (Jes Sorensen) [978055]
- [net] ipv6: resend MLD report if a link-local address completes DAD (Flavio Leitner) [889455]
- [net] ipv6: introduce per-interface counter for dad-completed ipv6 addresses (Flavio Leitner) [889455]
- [net] ipv6: split duplicate address detection and router solicitation timer (Flavio Leitner) [889455]
- [net] tcp: introduce a per-route knob for quick ack (Amerigo Wang) [984504]
- [net] nlmon: use standard rtnetlink link api for add/del devices (Daniel Borkmann) [957721]
- [net] nlmon: fix comparison in nlmon_is_valid_mtu (Daniel Borkmann) [957721]
- [net] packet: nlmon: virtual netlink monitoring device for packet sockets (Daniel Borkmann) [957721]
- [net] netlink: virtual tap device management (Daniel Borkmann) [957721]
- [net] if_arp: add ARPHRD_NETLINK type (Daniel Borkmann) [957721]

* Tue Aug 13 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-9.el7]
- [kernel] sched: disable autogroups by default (Josh Poimboeuf) [989741]
- [powerpc] pseries: Add backward compatibilty to read old kernel oops-log (Steve Best) [991831]
- [powerpc] pseries: Fix buffer overflow when reading from pstore (Steve Best) [991831]
- [crypto] nx: saves chaining value from co-processor (Steve Best) [972656]
- [crypto] nx: fix limits to sg lists for SHA-2 (Steve Best) [972656]
- [crypto] nx: fix physical addresses added to sg lists (Steve Best) [972656]

* Mon Aug 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-8.el7]
- [net] ipv6: ip6_append_data_mtu did not care about pmtudisc and frag_size (Francesco Fusco) [994346] {CVE-2013-4163}
- [net] ipv6: call udp_push_pending_frames when uncorking a socket with AF_INET pending data (Francesco Fusco) [988355] {CVE-2013-4162}
- [kernel] sysctl: range checking in do_proc_dointvec_ms_jiffies_conv (Francesco Fusco) [972393]
- [net] neigh: prevent overflowing params in /proc/sys/net/ipv4/neigh/ (Francesco Fusco) [972393]
- [net] vhost-net: fix use-after-free in vhost_net_flush (Thomas Graf) [984723] {CVE-2013-4127}
- [powerpc] tm: Fix return of active 64bit signals (Steve Best) [731886]
- [powerpc] tm: Fix return of 32bit rt signals to active transactions (Steve Best) [731886]
- [powerpc] tm: Fix restoration of MSR on 32bit signal return (Steve Best) [731886]
- [powerpc] tm: Fix 32 bit non-rt signals (Steve Best) [731886]
- [powerpc] tm: Fix writing top half of MSR on 32 bit signals (Steve Best) [731886]
- [fs] nfs: verify open flags before allowing an atomic open (Jeff Layton) [984823]
- [s390] zfcp: module parameter dbflevel for early debugging (Hendrik Brueckner) [994597]
- [virt] virtio_net: fix the race between channels setting and refill (Jason Wang) [978153]
- [kernel] audit: restore order of tty and ses fields in log output (Richard Guy Briggs) [983157]
- [kernel] time/tick: Make oneshot broadcast robust vs. CPU offlining (Prarit Bhargava) [967464]
- [virt] virtio_net: fix race in RX VQ processing (Jason Wang) [989409]
- [virt] virtio: support unlocked queue poll (Jason Wang) [989409]
- [powerpc] mm: Use the correct SLB(LLP) encoding in tlbie instruction (Steve Best) [993448]
- [net] tuntap: do not zerocopy if iov needs more pages than MAX_SKB_FRAGS (Jason Wang) [982513]
- [net] tuntap: correctly linearize skb when zerocopy is used (Jason Wang) [982513]
- [virt] macvtap: do not zerocopy if iov needs more pages than MAX_SKB_FRAGS (Jason Wang) [990786]
- [virt] macvtap: do not assume 802.1Q when send vlan packets (Jason Wang) [990786]
- [virt] macvtap: fix the missing ret value of TUNSETQUEUE (Jason Wang) [990786]
- [virt] macvtap: correctly linearize skb when zerocopy is used (Jason Wang) [982513]
- [virt] macvtap: Perform GSO on forwarding path (Jason Wang) [895484]
- [virt] macvtap: Let TUNSETOFFLOAD actually controll offload features (Jason Wang) [895484]
- [virt] macvtap: Consistently use rcu functions (Jason Wang) [895484]
- [virt] macvtap: Convert to using rtnl lock (Jason Wang) [895484]
- [virt] macvtap: fix uninitialized return value macvtap_ioctl_set_queue() (Jason Wang) [731550]
- [virt] macvtap: slient sparse warnings (Jason Wang) [731550]
- [virt] macvtap: enable multiqueue flag (Jason Wang) [731550]
- [virt] macvtap: add TUNSETQUEUE ioctl (Jason Wang) [731550]
- [virt] macvtap: eliminate linear search (Jason Wang) [731550]
- [virt] macvtap: introduce macvtap_get_vlan() (Jason Wang) [731550]
- [virt] macvtap: do not add self to waitqueue if doing a nonblock read (Jason Wang) [731550]
- [virt] macvtap: fix a possible race between queue selection and changing queues (Jason Wang) [731550]

* Thu Aug 08 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-7.el7]
- [vfio] type1: Fix leak on error path (Alex Williamson) [984081]
- [vfio] Limit group opens (Alex Williamson) [984081]
- [vfio] type1: Fix missed frees and zero sized removes (Alex Williamson) [984081]
- [vfio] Provide module option to disable vfio_iommu_type1 hugepage support (Alex Williamson) [984081]
- [vfio] hugepage support for vfio_iommu_type1 (Alex Williamson) [984081]
- [vfio] Convert type1 iommu to use rbtree (Alex Williamson) [984081]
- [iommu] Use pa and zx instead of casting (Alex Williamson) [984081]
- [iommu] amd: Only unmap large pages from the first pte (Alex Williamson) [984081]
- [iommu] Fix compiler warning on pr_debug (Alex Williamson) [984081]
- [iommu] amd: Fix memory leak in free_pagetable (Alex Williamson) [984081]
- [iommu] Split iommu_unmaps (Alex Williamson) [984081]
- [iommu] intel, amd: Remove multifunction assumption around grouping (Alex Williamson) [984081]
- [x86] spinlock: make ticket lock increment 2, unconditionally (Rik van Riel) [970737]
- [virt] pvticketlock: When paravirtualizing ticket locks, increment by 2 (Rik van Riel) [970737]
- [scsi] isci: Fix a race condition in the SSP task management path (David Milburn) [990201]
- [netdrv] bnx2x: Wait for MCP validity during AER (Michal Schmidt) [797460]
- [virt] virtio_scsi: Fix virtqueue affinity setup (Asias He) [971826]
- [fs] nfs: fix open(O_RDONLY|O_TRUNC) in NFS4.0 (Jeff Layton) [987615]
- [watchdog] hpwdt: Add check for UEFI bits (Linda Knippers) [985195]
- [powerpc] mm/numa: VPHN topology change updates all siblings (Steve Best) [973594]
- [powerpc] powernv: Fix iommu initialization again (Steve Best) [979523]
- [firmware] efivars: If pstore_register fails, free unneeded pstore buffer (Lenny Szubowicz) [983597]
- [acpi] Eliminate console msg if pstore.backend excludes ERST (Lenny Szubowicz) [983597]
- [fs] pstore: Return unique error if backend registration excluded by kernel param (Lenny Szubowicz) [983597]

* Tue Aug 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-6.el7]
- [fs] locks: move file_lock_list to a set of percpu hlist_heads and convert file_lock_lock to an lglock (Jeff Layton) [976876]
- [fs] seq_file: add seq_list_*_percpu helpers (Jeff Layton) [976876]
- [fs] locks: give the blocked_hash its own spinlock (Jeff Layton) [976876]
- [fs] locks: add a new "lm_owner_key" lock operation (Jeff Layton) [976876]
- [fs] locks: turn the blocked_list into a hashtable (Jeff Layton) [976876]
- [fs] locks: convert fl_link to a hlist_node (Jeff Layton) [976876]
- [fs] locks: avoid taking global lock if possible when waking up blocked waiters (Jeff Layton) [976876]
- [fs] locks: protect most of the file_lock handling with i_lock (Jeff Layton) [976876]
- [fs] locks: encapsulate the fl_link list handling (Jeff Layton) [976876]
- [fs] locks: make "added" in __posix_lock_file a bool (Jeff Layton) [976876]
- [fs] locks: comment cleanups and clarifications (Jeff Layton) [976876]
- [fs] locks: make generic_add_lease and generic_delete_lease static (Jeff Layton) [976876]
- [fs] cifs: use posix_unblock_lock instead of locks_delete_block (Jeff Layton) [976876]
- [fs] locks: drop the unused filp argument to posix_unblock_lock (Jeff Layton) [976876]
- [scsi] ipr: IOA Status Code(IOASC) update (Steve Best) [731129]
- [scsi] ipr: qc_fill_rtf() method should not store alternate status register (Steve Best) [731129]
- [scsi] ipr: possible irq lock inversion dependency detected (Steve Best) [731129]
- [fs] nfsd: when dentry_open returns an error do not propagate as struct file (Steve Dickson) [987090]
- [net] sunrpc: underflow issue in decode_write_list() (Steve Dickson) [987090]
- [fs] nfsd: fix minorversion support interface (Steve Dickson) [987090]
- [fs] lockd: protect nlm_blocked access in nlmsvc_retry_blocked (Steve Dickson) [987090]
- [fs] nfsd: support minorversion 1 by default (Steve Dickson) [987090]
- [fs] nfsd: allow destroy_session over destroyed session (Steve Dickson) [987090]
- [net] sunrpc: fix failures to handle -1 uid's (Steve Dickson) [987090]
- [net] sunrpc: Don't schedule an upcall on a replaced cache entry (Steve Dickson) [987090]
- [net] sunrpc: xpt_auth_cache should be ignored when expired (Steve Dickson) [987090]
- [net] sunrpc/cache: ensure items removed from cache do not have pending upcalls (Steve Dickson) [987090]
- [net] sunrpc/cache: use cache_fresh_unlocked consistently and correctly (Steve Dickson) [987090]
- [net] sunrpc/cache: remove races with queuing an upcall (Steve Dickson) [987090]
- [fs] nfsd: return delegation immediately if lease fails (Steve Dickson) [987090]
- [fs] nfsd: do not throw away 4.1 lock state on last unlock (Steve Dickson) [987090]
- [fs] nfsd: delegation-based open reclaims should bypass permissions (Steve Dickson) [987090]
- [net] sunrpc: don't error out on small tcp fragment (Steve Dickson) [987090]
- [net] sunrpc: fix handling of too-short rpc's (Steve Dickson) [987090]
- [fs] nfsd: minor read_buf cleanup (Steve Dickson) [987090]
- [fs] nfsd: fix decoding of compounds across page boundaries (Steve Dickson) [987090]
- [fs] nfsd: clean up nfs4_open_delegation (Steve Dickson) [987090]
- [fs] nfsd: Don't give out read delegations on creates (Steve Dickson) [987090]
- [fs] nfsd: allow client to send no cb_sec flavors (Steve Dickson) [987090]
- [fs] nfsd: fail attempts to request gss on the backchannel (Steve Dickson) [987090]
- [fs] nfsd: implement minimal SP4_MACH_CRED (Steve Dickson) [987090]
- [net] sunrpc: store gss mech in svc_cred (Steve Dickson) [987090]
- [net] sunrpc: introduce init_svc_cred (Steve Dickson) [987090]
- [fs] nfsd: avoid undefined signed overflow (Steve Dickson) [987090]
- [net] sunrpc: the cache_detail in cache_is_valid is unused any more (Steve Dickson) [987090]
- [net] sunrpc: server back channel needs no rpcbind method (Steve Dickson) [987090]
- [fs] nfsd: fix compile in !CONFIG_NFSD_V4_SECURITY_LABEL case (Steve Dickson) [987090]
- [fs] nfsd: Server implementation of MAC Labeling (Steve Dickson) [987090]
- [fs] nfsd: Add NFS v4.2 support to the NFS server (Steve Dickson) [987090]
- [security] fix cap_inode_getsecctx returning garbage (Steve Dickson) [987090]
- [fs] nfsd: store correct client minorversion for >=4.2 (Steve Dickson) [987090]
- [fs] nfsd: get rid of the unused functions in vfs (Steve Dickson) [987090]
- [fs] nfs: Fix brainfart in attribute length calculation (Steve Dickson) [987090]
- [fs] nfs: Fix a regression against the FreeBSD server (Steve Dickson) [987090]
- [net] sunrpc/rpc_pipe: rpc_dir_inode_operations can be static (Steve Dickson) [987090]
- [fs] nfs: Allow nfs_updatepage to extend a write under additional circumstances (Steve Dickson) [987090]
- [fs] nfs: Make nfs_readdir revalidate less often (Steve Dickson) [987090]
- [fs] nfs: Make nfs_attribute_cache_expired() non-static (Steve Dickson) [987090]
- [net] sunrpc/rpc_pipe: set dentry operations at d_alloc time (Steve Dickson) [987090]
- [fs] nfs: set verifier on existing dentries in nfs_prime_dcache (Steve Dickson) [987090]
- [fs] nfs: Set NFS_CS_MIGRATION for NFSv4 mounts (Steve Dickson) [987090]
- [fs] nfs: Refactor nfs4_init_session and nfs4_init_channel_attrs (Steve Dickson) [987090]
- [fs] nfs: use pnfs_device maxcount for the objectlayout gdia_maxcount (Steve Dickson) [987090]
- [fs] nfs: use pnfs_device maxcount for the blocklayout gdia_maxcount (Steve Dickson) [987090]
- [fs] nfs: Fix gdia_maxcount calculation to fit in ca_maxresponsesize (Steve Dickson) [987090]
- [fs] nfs: Improve legacy idmapping fallback (Steve Dickson) [987090]
- [fs] nfs: end back channel session draining (Steve Dickson) [987090]
- [fs] nfs: Apply v4.1 capabilities to v4.2 (Steve Dickson) [987090]
- [fs] nfs: Clean up layout segment comparison helper names (Steve Dickson) [987090]
- [fs] nfs: layout segment comparison helpers should take 'const' parameters (Steve Dickson) [987090]
- [fs] nfs: Move the DNS resolver into the NFSv4 module (Steve Dickson) [987090]
- [net] sunrpc/rpc_pipefs: only set rpc_dentry_ops if d_op isn't already set (Steve Dickson) [987090]
- [fs] nfs: SETCLIENTID add the format string for the NETID (Steve Dickson) [987090]
- [fs] nfs: Add in v4.2 callback operation (Steve Dickson) [987090]
- [fs] nfs: Make callbacks minor version generic (Steve Dickson) [987090]
- [fs] nfs: Add Kconfig entry for Labeled NFS V4 client (Steve Dickson) [987090]
- [fs] nfs: Extend NFS xattr handlers to accept the security namespace (Steve Dickson) [987090]
- [fs] nfs: Client implementation of Labeled-NFS (Steve Dickson) [987090]
- [fs] nfs: Add label lifecycle management (Steve Dickson) [987090]
- [fs] nfs: Add labels to client function prototypes (Steve Dickson) [987090]
- [fs] nfs: Extend fattr bitmaps to support all 3 words (Steve Dickson) [987090]
- [fs] nfs: Introduce new label structure (Steve Dickson) [987090]
- [fs] nfs: Add label recommended attribute and NFSv4 flags (Steve Dickson) [987090]
- [fs] nfs: Added NFS v4.2 support to the NFS client (Steve Dickson) [987090]
- [security] selinux: Add new labeling type native labels (Steve Dickson) [987090]
- [security] lsm: Add flags field to security_sb_set_mnt_opts for in kernel mount data (Steve Dickson) [987090]
- [security] Add Hook to test if the particular xattr is part of a MAC model (Steve Dickson) [987090]
- [security] Add hook to calculate context based on a negative dentry (Steve Dickson) [987090]
- [fs] nfs: Close another NFSv4 recovery race (Steve Dickson) [987090]
- [fs] nfs: Move dentry instantiation into the NFSv4-specific atomic open code (Steve Dickson) [987090]
- [fs] nfs: Refactor _nfs4_open_and_get_state to set ctx->state (Steve Dickson) [987090]
- [fs] nfs: pass the nfs_open_context to nfs4_do_open (Steve Dickson) [987090]
- [fs] nfs: Remove redundant check for FMODE_EXEC in nfs_finish_open (Steve Dickson) [987090]
- [net] sunrpc: Remove redundant call to rpc_set_running() in __rpc_execute() (Steve Dickson) [987090]
- [net] sunrpc: Remove unused functions rpc_task_set/has_priority (Steve Dickson) [987090]
- [net] sunrpc: Remove the unused helpers task_for_each() and task_for_first() (Steve Dickson) [987090]
- [net] sunrpc: Remove unused function rpc_queue_empty (Steve Dickson) [987090]
- [net] sunrpc: Fix a potential race in rpc_execute (Steve Dickson) [987090]
- [fs] nfs: Simplify setting the layout header credential (Steve Dickson) [987090]
- [fs] nfs: Enable state protection (Steve Dickson) [987090]
- [fs] nfs: Use layout credentials for get_deviceinfo calls (Steve Dickson) [987090]
- [fs] nfs: Ensure that test_stateid and free_stateid use correct credentials (Steve Dickson) [987090]
- [fs] nfs: Ensure that reclaim_complete uses the right credential (Steve Dickson) [987090]
- [fs] nfs: Ensure that layoutreturn uses the correct credential (Steve Dickson) [987090]
- [fs] nfs: Ensure that layoutget is called using the layout credential (Steve Dickson) [987090]
- [fs] nfs: Add NFSv4.2 protocol constants (Steve Dickson) [987090]

* Fri Aug 02 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-5.el7]
- [fs] cifs: fix bad error handling in crypto code (Jeff Layton) [988398]
- [fs] cifs: Fix a deadlock when a file is reopened (Sachin Prabhu) [988398]
- [fs] cifs: Reopen the file if reconnect durable handle failed (Sachin Prabhu) [988398]
- [fs] cifs: Fix minor endian error in durable handle patch series (Sachin Prabhu) [988398]
- [fs] cifs: Reconnect durable handles for SMB2 (Sachin Prabhu) [988398]
- [fs] cifs: Make SMB2_open use cifs_open_parms struct (Sachin Prabhu) [988398]
- [fs] cifs: Introduce cifs_open_parms struct (Sachin Prabhu) [988398]
- [fs] cifs: Request durable open for SMB2 opens (Sachin Prabhu) [988398]
- [fs] cifs: Simplify SMB2 create context handling (Sachin Prabhu) [988398]
- [fs] cifs: Simplify SMB2_open code path (Sachin Prabhu) [988398]
- [fs] cifs: Respect create_options in smb2_open_file (Sachin Prabhu) [988398]
- [fs] cifs: Fix lease context buffer parsing (Sachin Prabhu) [988398]
- [fs] cifs: use sensible file nlink values if unprovided (Sachin Prabhu) [988398]
- [fs] cifs: Limit allocation of crypto mechanisms to dialect which requires (Sachin Prabhu) [988398]
- [fs] cifs: Don't pass inode to ->d_hash() and ->d_compare() (Sachin Prabhu) [988398]
- [fs] cifs: fill TRANS2_QUERY_FILE_INFO ByteCount fields (Sachin Prabhu) [988398]
- [fs] cifs: fix SMB2 signing enablement in cifs_enable_signing (Sachin Prabhu) [988398]
- [fs] cifs: Fix build warning (Sachin Prabhu) [988398]
- [fs] cifs: SMB3 Signing enablement (Sachin Prabhu) [988398]
- [fs] cifs: Do not set DFS flag on SMB2 open (Sachin Prabhu) [988398]
- [fs] cifs: fix static checker warning (Sachin Prabhu) [988398]
- [fs] cifs: try to handle the MUST SecurityFlags sanely (Sachin Prabhu) [988398]
- [fs] cifs: When server doesn't provide SecurityBuffer on SMB2Negotiate pick default (Sachin Prabhu) [988398]
- [fs] cifs: Handle big endianness in NTLM (ntlmv2) authentication (Sachin Prabhu) [988398]
- [fs] cifs: revalidate directories instiantiated via FIND_* in order to handle DFS referrals (Sachin Prabhu) [988398]
- [fs] cifs: SMB2 FSCTL and IOCTL worker function (Sachin Prabhu) [988398]
- [fs] cifs: Charge at least one credit, if server says that it supports multicredit (Sachin Prabhu) [988398]
- [fs] cifs: Remove typo (Sachin Prabhu) [988398]
- [fs] cifs: Some missing share flags (Sachin Prabhu) [988398]
- [fs] cifs: using strlcpy instead of strncpy (Sachin Prabhu) [988398]
- [fs] cifs: Update headers to update various SMB3 ioctl definitions (Sachin Prabhu) [988398]
- [fs] cifs: Update cifs version number (Sachin Prabhu) [988398]
- [fs] cifs: Add ability to dipslay SMB3 share flags and capabilities for debugging (Sachin Prabhu) [988398]
- [fs] cifs: Add some missing SMB3 and SMB3.02 flags (Sachin Prabhu) [988398]
- [fs] cifs: Add SMB3.02 dialect support (Sachin Prabhu) [988398]
- [fs] cifs: Fix endian error in SMB2 protocol negotiation (Sachin Prabhu) [988398]
- [fs] cifs: clean up the SecurityFlags write handler (Sachin Prabhu) [988398]
- [fs] cifs: update the default global_secflags to include "raw" NTLMv2 (Sachin Prabhu) [988398]
- [fs] move sectype to the cifs_ses instead of TCP_Server_Info (Sachin Prabhu) [988398]
- [fs] cifs: track the enablement of signing in the TCP_Server_Info (Sachin Prabhu) [988398]
- [fs] add new fields to smb_vol to track the requested security flavor (Sachin Prabhu) [988398]
- [fs] cifs: add new fields to cifs_ses to track requested security flavor (Sachin Prabhu) [988398]
- [fs] cifs: track the flavor of the NEGOTIATE reponse (Sachin Prabhu) [988398]
- [fs] cifs: add new "Unspecified" securityEnum value (Sachin Prabhu) [988398]
- [fs] cifs: factor out check for extended security bit into separate function (Sachin Prabhu) [988398]
- [fs] cifs: move handling of signed connections into separate function (Sachin Prabhu) [988398]
- [fs] cifs: break out lanman NEGOTIATE handling into separate function (Sachin Prabhu) [988398]
- [fs] cifs: break out decoding of security blob into separate function (Sachin Prabhu) [988398]
- [fs] cifs: remove the cifs_ses->flags field (Sachin Prabhu) [988398]
- [fs] cifs: throw a warning if negotiate or sess_setup ops are passed NULL server or session pointers (Sachin Prabhu) [988398]
- [fs] cifs: make decode_ascii_ssetup void return (Sachin Prabhu) [988398]
- [fs] cifs: remove useless memset in LANMAN auth code (Sachin Prabhu) [988398]
- [fs] cifs: remove protocolEnum definition (Sachin Prabhu) [988398]
- [fs] cifs: add a "nosharesock" mount option to force new sockets to server to be created (Sachin Prabhu) [988398]
- [fs] fuse: readdirplus cleanup (Niels de Vos) [988312]
- [fs] fuse: readdirplus change attributes once (Niels de Vos) [988312]
- [fs] fuse: readdirplus fix instantiate (Niels de Vos) [988312]
- [fs] fuse: readdirplus sanity checks (Niels de Vos) [988312]
- [fs] fuse: fix readdirplus dentry leak (Niels de Vos) [988312]
- [powerpc] hw_brk: Fix off by one error when validating DAWR region end (Steve Best) [843485]
- [powerpc] hw_brk: Fix clearing of extraneous IRQ (Steve Best) [843485]
- [powerpc] hw_brk: Fix setting of length for exact mode breakpoints (Steve Best) [843485]
- [powerpc] perf: Add power8 EBB support (Steve Best) [969176]
- [powerpc] perf: Core EBB support for 64-bit book3s (Steve Best) [969176]
- [powerpc] perf: Don't enable if we have zero events (Steve Best) [969176]
- [powerpc] powerpc/perf: Use existing out label in power_pmu_enable() (Steve Best) [969176]
- [powerpc] perf: Freeze PMC5/6 if we're not using them (Steve Best) [969176]
- [powerpc] powerpc/perf: Rework disable logic in pmu_disable() (Steve Best) [969176]
- [powerpc] perf: Check that events only include valid bits on Power8 (Steve Best) [969176]
- [ipc] sem: rename try_atomic_semop() to perform_atomic_semop(), docu update (Rik van Riel) [881820]
- [ipc] sem: replace shared sem_otime with per-semaphore value (Rik van Riel) [881820]
- [ipc] sem: always use only one queue for alter operations (Rik van Riel) [881820]
- [ipc] sem: separate wait-for-zero and alter tasks into seperate queues (Rik van Riel) [881820]
- [ipc] sem: cacheline align the semaphore structures (Rik van Riel) [881820]
- [fs] gfs2: Add atomic_open support (Steven Whitehouse) [983098]
- [fs] gfs2: Only do one directory search on create (Steven Whitehouse) [983098]
- [fs] pstore: Add hsize argument in write_buf call of pstore_ftrace_call (Steve Best) [947161]
- [powerpc] pseries: Support compression of oops text via pstore (Steve Best) [947161]
- [powerpc] pseries: Re-organise the oops compression code (Steve Best) [947161]
- [powerpc] pstore: Pass header size in the pstore write callback (Steve Best) [947161]
- [powerpc] pseries: Read common partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Read of-config partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Distinguish between a os-partition and non-os partition (Steve Best) [947161]
- [powerpc] pseries: Read rtas partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Read/Write oops nvram partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Introduce generic read function to read nvram-partitions (Steve Best) [947161]
- [powerpc] pseries: Add version and timestamp to oops header (Steve Best) [947161]
- [powerpc] pseries: Remove syslog prefix in uncompressed oops text (Steve Best) [947161]

* Wed Jul 31 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-4.el7]
- [x86] signals: Merge EFLAGS bit clearing into a single statement (Jiri Olsa) [986216]
- [x86] signals: Clear RF EFLAGS bit for signal handler (Jiri Olsa) [986216]
- [x86] signals: Propagate RF EFLAGS bit through the signal restore call (Jiri Olsa) [986216]
- [kernel] perf: Fix perf_lock_task_context() vs RCU (Jiri Olsa) [986216]
- [kernel] perf: Remove WARN_ON_ONCE() check in __perf_event_enable() for valid scenario (Jiri Olsa) [986216]
- [kernel] perf: Clone child context from parent context pmu (Jiri Olsa) [986216]
- [kernel] perf: Fix interrupt handler timing harness (Jiri Olsa) [986216]
- [kernel] perf: Drop sample rate when sampling is too slow (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Introduce "struct bp_cpuinfo" (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Simplify *register_wide_hw_breakpoint() (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Introduce cpumask_of_bp() (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Simplify the "weight" usage in toggle_bp_slot() paths (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Simplify list/idx mess in toggle_bp_slot() paths (Jiri Olsa) [986216]
- [kernel] perf: Add simple Haswell PMU support (Jiri Olsa) [986216]
- [kernel] perf: Add const qualifier to perf_pmu_register's 'name' arg (Jiri Olsa) [986216]
- [kernel] perf: Fix hypervisor branch sampling permission check (Jiri Olsa) [986216]
- [kernel] perf: Check branch sampling priv level in generic code (Jiri Olsa) [986216]
- [kernel] perf: Add sysfs entry to adjust multiplexing interval per PMU (Jiri Olsa) [986216]
- [kernel] perf: Use hrtimers for event multiplexing (Jiri Olsa) [986216]
- [kernel] perf: Fix hw breakpoints overflow period sampling (Jiri Olsa) [986216]
- [tools] perf/tests: Check proper prev_state size for sched_switch tp (Jiri Olsa) [984998]
- [tools] perf/tests: Omit end of the symbol check failure for test 1 (Jiri Olsa) [984998]
- [tools] perf/script: Fix broken include in Context.xs (Jiri Olsa) [984998]
- [tools] perf: Fix -ldw/-lelf link test when static linking (Jiri Olsa) [984998]
- [tools] perf: Fix perf version generation (Jiri Olsa) [984998]
- [tools] perf/stat: Fix per-socket output bug for uncore events (Jiri Olsa) [984998]
- [tools] perf/symbols: Fix vdso list searching (Jiri Olsa) [984998]
- [tools] perf/evsel: Fix missing increment in sample parsing (Jiri Olsa) [984998]
- [tools] perf: Update symbol_conf.nr_events when processing attribute events (Jiri Olsa) [984998]
- [tools] perf: Fix new_term() missing free on error path (Jiri Olsa) [984998]
- [tools] perf: Fix parse_events_terms() segfault on error path (Jiri Olsa) [984998]
- [tools] perf/evsel: Fix count parameter to read call in event_format__new (Jiri Olsa) [984998]
- [tools] perf: Fix -x/--exclude-other option for report command (Jiri Olsa) [984998]
- [tools] perf/evlist: Enhance perf_evlist__start_workload() (Jiri Olsa) [984998]
- [tools] perf/record: Remove -f/--force option (Jiri Olsa) [984998]
- [tools] perf/record: Remove -A/--append option (Jiri Olsa) [984998]
- [tools] perf/stat: Avoid sending SIGTERM to random processes (Jiri Olsa) [984998]
- [tools] perf: Include termios.h explicitly (Jiri Olsa) [984998]
- [tools] perf/bench: Fix memory allocation fail check in mem{set, cpy} workloads (Jiri Olsa) [984998]
- [tools] perf: Fix build errors with O and DESTDIR make vars set (Jiri Olsa) [984998]
- [tools] perf: Fix output directory of Documentation/ (Jiri Olsa) [984998]
- [tools] perf: Get only verbose output with V=1 (Jiri Olsa) [984998]
- [tools] perf: Add missing liblk.a dependency for python/perf.so (Jiri Olsa) [984998]
- [tools] perf: Remove '?=' Makefile STRIP assignment (Jiri Olsa) [984998]
- [tools] perf: Replace multiple line assignment with multiple statements (Jiri Olsa) [984998]
- [tools] perf: Replace tabs with spaces for all non-commands statements (Jiri Olsa) [984998]
- [tools] perf: Add NO_BIONIC variable to confiure bionic setup (Jiri Olsa) [984998]
- [tools] perf: Switch to full path C include directories (Jiri Olsa) [984998]
- [tools] perf: Merge all *LDFLAGS* make variable into LDFLAGS (Jiri Olsa) [984998]
- [tools] perf: Merge all *CFLAGS* make variable into CFLAGS (Jiri Olsa) [984998]
- [tools] perf/evlist: Reset SIGTERM handler in workload child process (Jiri Olsa) [984998]
- [tools] perf: Remove cwdlen from struct perf_session (Jiri Olsa) [984998]
- [tools] perf: Remove frozen from perf_header struct (Jiri Olsa) [984998]
- [tools] perf/tests: Fix exclude_guest|exclude_host checking for attr tests (Jiri Olsa) [984998]
- [tools] perf/tests: Fix attr test for record -d option (Jiri Olsa) [984998]
- [tools] perf: Final touches for CHK config move (Jiri Olsa) [984998]
- [tools] perf: Move paths config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libnuma check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move stdlib check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libbfd check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libpython check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libperl check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move gtk2 check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move slang check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libaudit check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libunwind check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libdw check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libelf check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move compiler and linker flags check into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move programs check into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move arch check into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Add automated make test suite (Jiri Olsa) [984998]
- [tools] perf: Save parent pid in thread struct (Jiri Olsa) [984998]
- [tools] perf/stats: Fix divide by 0 in variance (Jiri Olsa) [984998]
- [tools] perf/kvm: Handle realloc failures (Jiri Olsa) [984998]
- [tools] perf/evsel: Fix printing of perf_event_paranoid message (Jiri Olsa) [984998]
- [tools] perf/test: Fix typo (Jiri Olsa) [984998]
- [tools] perf/hists: Rename hist_entry__add_pair arguments (Jiri Olsa) [984998]
- [tools] perf/diff: Use internal rb tree for hists__precompute (Jiri Olsa) [984998]
- [tools] perf/report: Add report.percent-limit config variable (Jiri Olsa) [984998]
- [tools] perf/top: Add --percent-limit option (Jiri Olsa) [984998]
- [tools] perf/report: Add --percent-limit option (Jiri Olsa) [984998]
- [tools] perf/report: Don't bother locking when adding hist entries (Jiri Olsa) [984998]
- [tools] perf/hists: Move locking to its call-sites (Jiri Olsa) [984998]
- [tools] perf/top: Get rid of *_threaded() functions (Jiri Olsa) [984998]
- [tools] perf/top: Fix percent output when no samples collected (Jiri Olsa) [984998]
- [tools] perf/top: Fix -E option behavior (Jiri Olsa) [984998]
- [tools] perf/record: handle death by SIGTERM (Jiri Olsa) [984998]
- [tools] perf: Handle JITed code in shared memory (Jiri Olsa) [984998]
- [tools] perf/tests: Fix compile errors in bp_signal files (Jiri Olsa) [984998]
- [tools] perf: Fix tab vs spaces issue in Makefile ifdef/endif (Jiri Olsa) [984998]
- [tools] perf/hists browser: Use sort__has_sym (Jiri Olsa) [984998]
- [tools] perf/top: Use sort__has_sym (Jiri Olsa) [984998]
- [tools] perf/sort: Cleanup sort__has_sym setting (Jiri Olsa) [984998]
- [tools] perf/sort: Reorder HISTC_SRCLINE index (Jiri Olsa) [984998]
- [tools] perf/archive: Fix typo on Documentation (Jiri Olsa) [984998]
- [tools] perf/sort: Consolidate sort_entry__setup_elide() (Jiri Olsa) [984998]
- [tools] perf/sort: Separate out memory-specific sort keys (Jiri Olsa) [984998]
- [tools] perf/sort: Factor out common code in sort_dimension__add() (Jiri Olsa) [984998]
- [tools] perf/sort: Introduce sort__mode variable (Jiri Olsa) [984998]
- [tools] perf/report: Fix alignment of symbol column when -v is given (Jiri Olsa) [984998]
- [tools] perf/hists: Free unused mem info of a matched hist entry (Jiri Olsa) [984998]
- [tools] perf/hists: Fix an invalid memory free on he->branch_info (Jiri Olsa) [984998]
- [tools] perf: Fix bug in isupper() and islower() (Jiri Olsa) [984998]
- [mm] thp: define HPAGE_PMD_* constants as BUILD_BUG() if !THP (Steve Best) [947166]
- [powerpc] mm: Fix build warnings with CONFIG_TRANSPARENT_HUGEPAGE disabled (Steve Best) [947166]
- [powerpc] mm: Optimize hugepage invalidate (Steve Best) [947166]
- [powerpc] thp: Enable THP on PPC64 (Steve Best) [947166]
- [powerpc] mm: split hugepage when using subpage protection (Steve Best) [947166]
- [powerpc] mm: disable assert_pte_locked for collapse_huge_page (Steve Best) [947166]
- [powerpc] mm: Prevent gcc to re-read the pagetables (Steve Best) [947166]
- [powerpc] mm: Make linux pagetable walk safe with THP enabled (Steve Best) [947166]
- [powerpc] thp: Add code to handle HPTE faults for hugepages (Steve Best) [947166]
- [powerpc] mm: Update gup_pmd_range to handle transparent hugepages (Steve Best) [947166]
- [powerpc] kvm: Handle transparent hugepage in KVM (Steve Best) [947166]
- [powerpc] mm: Replace find_linux_pte with find_linux_pte_or_hugepte (Steve Best) [947166]
- [powerpc] mm: Update find_linux_pte_or_hugepte to handle transparent hugepages (Steve Best) [947166]
- [powerpc] mm: move find_linux_pte_or_hugepte and gup_hugepte to common code (Steve Best) [947166]
- [powerpc] thp: Implement transparent hugepages for ppc64 (Steve Best) [947166]
- [powerpc] thp: Double the PMD table size for THP (Steve Best) [947166]
- [powerpc] mm: handle hugepage size correctly when invalidating hpte entries (Steve Best) [947166]
- [mm] thp: deposit the transpare huge pgtable before set_pmd (Steve Best) [947166]
- [mm] thp: don't use HPAGE_SHIFT in transparent hugepage code (Steve Best) [947166]
- [mm] thp: withdraw the pgtable after pmdp related operations (Steve Best) [947166]
- [mm] thp: add pmd args to pgtable deposit and withdraw APIs (Steve Best) [947166]
- [mm] thp: use the correct function when updating access flags (Steve Best) [947166]

* Fri Jul 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-3.el7]
- [powerpc] mm/numa: Do not update sysfs cpu registration from invalid context (Steve Best) [967447]
- [misc] MAINTAINERS: Add ACPI folks for ACPI-related things under drivers/pci (Myron Stowe) [984759]
- [pci] Add CircuitCo vendor ID and subsystem ID (Myron Stowe) [984759]
- [pci] Use pdev->pm_cap instead of pci_find_capability(.., PCI_CAP_ID_PM) (Myron Stowe) [984759]
- [pci] Return early on allocation failures to unindent mainline code (Myron Stowe) [984759]
- [pci] Simplify IOV implementation and fix reference count races (Myron Stowe) [984759]
- [pci] Drop redundant setting of bus->is_added in virtfn_add_bus() (Myron Stowe) [984759]
- [pci] pci-acpi: Use correct power state strings in messages (Myron Stowe) [984759]
- [pci] Fix comment typo for pcie_pme_remove() (Myron Stowe) [984759]
- [pci] Rename pci_release_bus_bridge_dev() to pci_release_host_bridge_dev() (Myron Stowe) [984759]
- [pci] Fix refcount issue in pci_create_root_bus() error recovery path (Myron Stowe) [984759]
- [pci] Convert alloc_pci_dev(void) to pci_alloc_dev(bus) (Myron Stowe) [984759]
- [pci] Hide remove and rescan sysfs interfaces for SR-IOV virtual functions (Myron Stowe) [984759]
- [pci] Add pcibios_release_device() (Myron Stowe) [984759]
- [iommu] irq_remapping: Conserve interrupt resources when using multiple-MSIs (Myron Stowe) [984759]
- [i2c] i2c-piix4: Add AMD CZ SMBus device ID (Myron Stowe) [984759]
- [ata] ahci: Add AMD CZ SATA device ID (Myron Stowe) [984759]
- [pci] Put Hudson-2 device IDs together (Myron Stowe) [984759]
- [pci] Replace strict_strtoul() with kstrtoul() (Myron Stowe) [984759]
- [pci] Finish SR-IOV VF setup before adding the device (Myron Stowe) [984759]
- [pci] Fix comment typo for PCI_EXP_LNKCAP_CLKPM (Myron Stowe) [984759]
- [acpi] pci_root: Use dev_printk(), acpi_handle_print(), pr_xxx() when possible (Myron Stowe) [984759]
- [acpi] pci_root: Remove unused global list acpi_pci_roots (Myron Stowe) [984759]
- [acpi] pci_root: Introduce "handle" local for economy of expression (Myron Stowe) [984759]
- [acpi] pci_root: Combine duplicate adjacent "if" tests (Myron Stowe) [984759]
- [pci] Allocate only as many MSI vectors as requested by driver (Myron Stowe) [984759]
- [pci] Replace printks with appropriate pr_*() (Myron Stowe) [984759]
- [pci] Fix kerneldoc for pci_disable_link_state() (Myron Stowe) [984759]
- [x86] pci: Increase info->res_num before checking pci_use_crs (Myron Stowe) [984759]
- [pci] Fix INTC comment typo for pci_swizzle_interrupt_pin() (Myron Stowe) [984759]
- [pci] Convert ioapic.c to module_pci_driver (Myron Stowe) [984759]
- [pci] Introduce pci_alloc_dev(struct pci_bus*) to replace alloc_pci_dev() (Myron Stowe) [984759]
- [pci] Introduce pci_bus_{get|put}() to manage PCI bus reference count (Myron Stowe) [984759]
- [pci] Unset resource if initial BAR value is invalid (Myron Stowe) [984759]
- [pci] Consolidate calls to pcibios_bus_to_resource() in __pci_read_base() (Myron Stowe) [984759]
- [pci] Add 0x prefix to BAR register position in __pci_read_base() (Myron Stowe) [984759]
- [pci] aspm: Warn when driver asks to disable ASPM, but we can't do it (Myron Stowe) [984759]
- [powerpc] pci: Use PCI_UNKNOWN for unknown power state (Myron Stowe) [984759]
- [acpi] pci_root: Check acpi_resource_to_address64() return value (Myron Stowe) [984759]
- [pci] Work around Ivytown NTB BAR size issue (Myron Stowe) [984759]
- [net] sunrpc: Fix another issue with rpc_client_register() (Jeff Layton) [924649]
- [net] sunrpc: Fix a deadlock in rpc_client_register() (Jeff Layton) [924649]
- [net] sunrpc: PipeFS MOUNT notification optimization for dying clients (Jeff Layton) [924649]
- [net] sunrpc: split client creation routine into setup and registration (Jeff Layton) [924649]
- [net] sunrpc: fix races on PipeFS UMOUNT notifications (Jeff Layton) [924649]
- [net] sunrpc: fix races on PipeFS MOUNT notifications (Jeff Layton) [924649]

* Fri Jul 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-2.el7]
- [scsi] sd: fix crash when UA received on DIF enabled device (Ewan Milne) [979440]
- [md] dm-cache: add call to mark_tech_preview (Mike Snitzer) [982752]
- [fs] nfs: have NFSv3 try server-specified auth flavors in turn (Jeff Layton) [977649]
- [fs] nfs: have nfs_mount fake up a auth_flavs list when the server didn't provide it (Jeff Layton) [977649]
- [fs] nfs: move server_authlist into nfs_try_mount_request (Jeff Layton) [977649]
- [fs] nfs: refactor "need_mount" code out of nfs_try_mount (Jeff Layton) [977649]
- [pci] ear: Reset link for devices below Root Port or Downstream Port (Myron Stowe) [797485]
- [acpi] apei: Force fatal AER severity when component has been reset (Myron Stowe) [797485]
- [pci] aer: Remove "extern" from function declarations (Myron Stowe) [797485]
- [pci] aer: Move AER severity defines to aer.h (Myron Stowe) [797485]
- [pci] aer: Set dev->__aer_firmware_first only for matching devices (Myron Stowe) [797485]
- [pci] aer: Factor out HEST device type matching (Myron Stowe) [797485]
- [pci] aer: Don't parse HEST table for non-PCIe devices (Myron Stowe) [797485]

* Tue Jul 09 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-1.el7]
- [x86] fix !CONFIG_HYPERVISOR_GUEST compile (Andrew Jones)
- [s390x] crash: Fuzzy live dump for Linux on System z (Hendrik Brueckner) [805120]
- [xen] xenfv: fix hangs when kdumping (Andrew Jones) [845471]
- [libata] export ata_port port_no attribute via /sys (David Milburn) [951181]
- [s390x] kdump: Use 4 GiB for KEXEC_AUTO_THRESHOLD (Hendrik Brueckner) [953044]
- [x86] hpet: allow user controlled mmap for user processes (Prarit Bhargava) [788727]
- [mm] add memory tracking hooks (James Paradis) [725860]
- [kernel] clocksource, fix !CONFIG_CLOCKSOURCE_WATCHDOG compile (Prarit Bhargava) [914709]
- [x86] disable clocksource watchdog (Prarit Bhargava) [914709]
- [kdump] x86, fix kdump and unsupported HW check (Prarit Bhargava) [923256]
- [x86] support single cpu on guests only (Prarit Bhargava) [873806]
- [kernel] Mark power5, power6, !Intel, and !AMD systems as unsupported (Prarit Bhargava) [870129]
- [kernel] Backport RH specific TAINT flags (Prarit Bhargava) [870129]
- [s390x] zfcpdump: Add user space tool (Hendrik Brueckner) [825189]
- [kdump] crashkernel=auto fixes and cleanup (Dave Young) [804077]
- [fedora] /dev/crash driver (Kyle McMartin) [808839]
- [kdump] forward port crashkernel auto reservation code (Dave Young) [804077]
- [block] Change scheduler to CFQ for ATA/SATA (Vivek Goyal) [811016]
- [kernel] kbuild: AFTER_LINK (Roland McGrath)
- [ppc64] disable INFINIBAND_EHCA temporarily, it ftbfs (Kyle McMartin)
- [kernel] Add RHEL_{MAJOR,MINOR,RELEASE} to top level Makefile (Kyle McMartin)

* Mon Jun 03 2013 Kyle McMartin <kyle@redhat.com>
- Trimmed changelog for rhel7.git, see rhpkg git for earlier history.

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
